-- #########################################################
-- #########################################################
-- ConfigEnv.sql
-- #########################################################
-- #########################################################

SPOOL spool.txt
WHENEVER SQLERROR EXIT FAILURE ROLLBACK
WHENEVER OSERROR EXIT FAILURE ROLLBACK

-- #########################################################
-- #########################################################
-- VersionCheck.sql
-- #########################################################
-- #########################################################

declare
  Major$ NUMBER(10);
  Minor$ NUMBER(10);
begin
  select max(Major) into Major$ from DatabaseVersion;
  select max(Minor) into Minor$ from DatabaseVersion where Major = Major$;
  if (Major$ <> 1020) or (Minor$ <> 00) then
    raise_application_error(-20000, '  [' || TO_CHAR(Major$) || '.' || TO_CHAR(Minor$, 'FM00') || ']    [1020.00]');
  end if;
end;
/

-- #########################################################
-- #########################################################
-- ADD_OBJKIND_RIGHTKIND.sql
-- #########################################################
-- #########################################################


create or replace procedure AddObjKind(New_ID$ NUMBER, New_Name$ VARCHAR2) as
  CNT$ NUMBER(10);
begin
  select count(ID) into CNT$ from objectkind where ID = New_ID$ and Name = New_Name$;
  if (CNT$=0) then
    insert into objectkind
       (ID,Name)
        values
       (New_ID$,New_Name$);
  end if;
end;
/

commit work
/

create or replace procedure AddRightKind(New_ID$ NUMBER, New_Name$ VARCHAR2) as
  CNT$ NUMBER(10);
begin
  select count(ID) into CNT$ from RightKind where ID = New_ID$ and Name = New_Name$;
  if (CNT$=0) then
    insert into RightKind
       (ID,Name)
        values
       (New_ID$,New_Name$);
  end if;
end;
/

commit work
/

create or replace procedure AddDBRight(New_RightKindRef$ NUMBER, New_ObjectKindRef$ NUMBER) as
  CNT$ NUMBER(10);
begin
  select count(ID) into CNT$ from DBRights where RightKindRef = New_RightKindRef$ and ObjectKindRef = New_ObjectKindRef$;
  if (CNT$=0) then
    insert into DBRights
       (RightKindRef,ObjectKindRef)
        values
       (New_RightKindRef$,New_ObjectKindRef$);
  end if;
end;
/

commit work
/

call AddObjKind(33000000, ' ');

call AddRightKind(15, '   ');

call AddDBRight(4, 33000000);

call AddDBRight(11, 1000000);

call AddDBRight(15, 1000000);

commit work 
/

drop procedure AddObjKind;

drop procedure AddRightKind;

drop procedure AddDBRight;

commit work
/


-- #########################################################
-- #########################################################
-- Add_RealID_Constraints_And_Triggers.sql
-- #########################################################
-- #########################################################

ALTER TRIGGER TR_AGREEMENTS_BU_500 DISABLE
/
update agreements
set RealID = ID
where RealID is null
/
ALTER TRIGGER TR_AGREEMENTS_BU_500 ENABLE
/
ALTER TRIGGER TR_TENDERCAPTION_BU_500 DISABLE
/
update tendercaption
set RealID = ID
where RealID is null
/
ALTER TRIGGER TR_TENDERCAPTION_BU_500 ENABLE
/
ALTER TRIGGER TR_TENDEROBJECTS_BU_500 DISABLE
/
update tenderobjects
set RealID = ID
where RealID is null
/
ALTER TRIGGER TR_TENDEROBJECTS_BU_500 DISABLE
/
commit work
/
-- CREATE TRIGGER tendercaption_realid_bu_600
CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
--
  CurVal$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$FacialAccCls is null) then 
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then 
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then 
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then 
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then 
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then 
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then 
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then 
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then 
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then 
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then 
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then 
    new$SupportUndertaker := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_TENDERCAPTION_BU_3)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*             */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_CHANGEINNERNUMS');
  END IF;
      
  /*   !!!*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    RaiseException('EX_RollbackCancel');
  END IF;
      
  /*  ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or 
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_Ten_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_Ten_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or 
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_Ten_ChangeStateAdjust');    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_TENDERCAPTION_BU_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then 
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.1*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
          
  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and 
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
ALTER TABLE TB_tendercaption ADD (
  CONSTRAINT tendercaption_realid_not_null CHECK (realid is not null)
)
/
-- CREATE TRIGGER agreements_realid_bu_600
CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
--
  MaxNumber$ NUMBER (10);
  CurVal$ NUMBER (10);
  CNT$1 NUMBER(10);
  DetCount$ NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1*/
  /*    -*/
  if (new$CardAdvancePercent is null) then 
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then 
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then 
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then 
    new$FinCardAdvance := 0;    
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then 
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then 
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then 
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then 
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  /*    .  */
    
  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_AGREEMENTS_BU_3)
-- Create 03.12.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*            */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /* ,      ,   */
    if ((new$InnerNumber <> :old.InnerNumber) or 
        (new$AdjustmentNumber <> :old.AdjustmentNumber) or
        (new$AgreementType <> :old.AgreementType)) then
        RaiseException('EX_AGR_ChangeInnerNums');
    end if;    
    
    /*    !!!*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
        ((new$Accepted = 1) or (new$AcceptDate is null))) then
        RaiseException('EX_RollbackCancel');
    end if;    
    
    /*   ,     LastAccepted*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or 
        ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 1;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;    
    end if;
    
    /*    ,     LastAccepted*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
        ((new$Accepted = 0) or (new$AcceptDate is null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;    
    end if;
    
    /*   ,     LastAdjustment*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or 
        ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
        
        if (new$LastAdjustment = 1) then
            new$LastAdjustment := 0;
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;    

        SELECT Max(AdjustmentNumber) INTO MaxNumber$ FROm AgreementS 
        WHERE (InnerNumber = new$InnerNumber);
        /*    ,     */
        if ((new$adjustmentNumber=0) and (MaxNumber$<>0)) then
          RaiseException('EX_Agr_PrimaryAgrHasNotify');
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN  
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;
      
  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN    
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END; 
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_AGREEMENTS_BU_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;  
    end if;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;
          
    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then 
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);

  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and 
  ((new$Accepted <> :old.Accepted) or 
  (new$AcceptDate is not null and :old.AcceptDate is null) or 
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
ALTER TABLE TB_agreements ADD (
  CONSTRAINT agreements_realid_not_null CHECK (realid is not null)
)
/
-- CREATE TRIGGER tenderobjects_realid_bu_600
CREATE OR REPLACE TRIGGER TR_TENDEROBJECTS_BU
  BEFORE UPDATE
  ON TENDEROBJECTS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDEROBJECTS_BU_0)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (:new.OKDP is null) then 
    :new.OKDP := 0;
  END IF;
  if (:new.OKPCLS is null) then 
    :new.OKPCLS := 0;
  END IF;
  if (:new.MEASUREMENTCLS is null) then 
    :new.MEASUREMENTCLS := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.FacialAccCls is null) then 
    :new.FacialAccCls := 0;
  END IF;
  if (:new.OKPD is null) then 
    :new.OKPD := 0;
  END IF;
  if (:new.OKVED is null) then 
    :new.OKVED := 0;
  END IF;
  if (:new.OKPD2 is null) then 
    :new.OKPD2 := 0;
  END IF;
  if (:new.OKVED2 is null) then 
    :new.OKVED2 := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDEROBJECTS_BU_200)
-- Create 01.11.2004
-- - - - - - - - - - - - -

  /*        */
  if (:new.DocStateRef <> :old.DocStateRef) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(:new.id, :old.DocStateRef, :new.DocStateRef);
  end if;  

-- - - - - - - - - - - - -
-- BU_600 (tenderobjects_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.realid is null) then 
    :new.realid := :new.id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDEROBJECTS_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

  if (:New.RVersion is null) then
    :New.RVersion := 1;
  elsif ((:New.RVersion = -1) and (:Old.RVersion <> -1)) then
    :New.RVersion := :Old.RVersion;
  else
    :New.RVersion := :Old.RVersion + 1;
  end if;  

END;
/
ALTER TABLE tenderobjects ADD (
  CONSTRAINT tenderobjects_realid_not_null CHECK (realid is not null)
)
/
commit work 
/


-- #########################################################
-- #########################################################
-- add_tr_execdocdetail_Cost.sql
-- #########################################################
-- #########################################################

INSERT INTO SqlExceptions(Name, Code, Text) VALUES ('EX_EXECDOCEST_NEGATIVECOST', -20356, '    .')
/
commit work
/
-- CREATE TRIGGER TR_EXECDOCDETAIL_BI_20
CREATE OR REPLACE TRIGGER TR_EXECDOCDETAIL_BI
  BEFORE INSERT
  ON EXECUTIONDOCUMENTSDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_EXECDOCDETAIL_BI)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO :NEW.ID FROM DUAL;
   END IF;
   IF (:NEW.Amount IS NULL) THEN :NEW.amount := 0; END IF;
   IF (:NEW.OBJECT IS NULL) THEN :NEW.OBJECT := 0; END IF;
   IF (:NEW.ProductCls IS NULL) THEN :NEW.ProductCls := 0; END IF;
   IF (:NEW.Price IS NULL) THEN :NEW.Price := 0; END IF;
   IF (:NEW.PriceVAT IS NULL) THEN :NEW.PriceVAT := 0; END IF;
   IF (:NEW.COST IS NULL) THEN :NEW.COST := 0; END IF;
   IF (:NEW.VATPercent IS NULL) THEN :NEW.VATPercent := 0; END IF;
   IF (:NEW.VATSumma IS NULL) THEN :NEW.VATSumma := 0; END IF;
   IF (:NEW.Summa IS NULL) THEN :NEW.Summa := 0; END IF;

   /*   .   */
   SELECT c.BudgetRef
     INTO :NEW.BudgetRef
     FROM ExecutionDocumentsCaption c
    WHERE c.ID = :NEW.RecordIndex;

-- - - - - - - - - - - - -
-- BI_10 (tr_execdocdetail_bi_10)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (:new.senderId is null) then 
    :new.senderIdKey := -1;
  else
    :new.senderIdKey := :new.senderId;
  end if;

  if (:new.SenderRecordID is null)then
    :new.SenderRecordIDKey := :new.ID;
  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  end if;	

-- - - - - - - - - - - - -
-- BI_20 (TR_EXECDOCDETAIL_BI_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if ((:new.COST < 0) or (:new.SUMMA < 0)) then
    RaiseException('EX_EXECDOCEST_NEGATIVECOST');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_EXECDOCDETAIL_BI_500)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
-- CREATE TRIGGER TR_EXECDOCDETAIL_BU_20
CREATE OR REPLACE TRIGGER TR_EXECDOCDETAIL_BU
  BEFORE UPDATE
  ON EXECUTIONDOCUMENTSDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCDETAIL_BU)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (:NEW.Amount IS NULL) THEN :NEW.amount := 0; END IF;
   IF (:NEW.OBJECT IS NULL) THEN :NEW.OBJECT := 0; END IF;
   IF (:NEW.ProductCls IS NULL) THEN :NEW.ProductCls := 0; END IF;
   IF (:NEW.Price IS NULL) THEN :NEW.Price := 0; END IF;
   IF (:NEW.PriceVAT IS NULL) THEN :NEW.PriceVAT := 0; END IF;
   IF (:NEW.COST IS NULL) THEN :NEW.COST := 0; END IF;
   IF (:NEW.VATPercent IS NULL) THEN :NEW.VATPercent := 0; END IF;
   IF (:NEW.VATSumma IS NULL) THEN :NEW.VATSumma := 0; END IF;
   IF (:NEW.Summa IS NULL) THEN :NEW.Summa := 0; END IF;

   /*     */
   IF     (:NEW.BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((:NEW.BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_EXECDOCDETAIL_BU_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if ((:new.COST < 0) or (:new.SUMMA < 0)) then
    RaiseException('EX_EXECDOCEST_NEGATIVECOST');
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_ExecDocDet_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.RecordIndex <> :old.RecordIndex) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDDETAIL_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (:NEW.RVersion IS NULL) THEN
      :NEW.RVersion := 1;
   ELSE
      IF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         :NEW.RVersion := :OLD.RVersion;
      ELSE
         :NEW.RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

END;
/
-- CREATE TRIGGER TR_ESTIMATE_BI_20
CREATE OR REPLACE TRIGGER TR_ESTIMATE_BI
  BEFORE INSERT
  ON ESTIMATE
  FOR EACH ROW
DECLARE
  TempFacialAcc_Cls NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ESTIMATE_BI)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL
        INTO :NEW.ID
        FROM DUAL;
   END IF;

   IF (:NEW.FacialAcc_Cls IS NULL) THEN
      BEGIN
         SELECT FacialAcc_Cls
           INTO TempFacialAcc_Cls
           FROM Agreements
          WHERE (ID = :NEW.RecordIndex);
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            TempFacialAcc_Cls := NULL;
      END;

      :NEW.FacialAcc_Cls := TempFacialAcc_Cls;
   END IF;

   IF (:NEW.ProductCls IS NULL) THEN
      :NEW.ProductCls := 0;
   END IF;

   IF (:NEW.Amount IS NULL) THEN
      :NEW.amount := 0;
   END IF;

   IF (:NEW.OBJECT IS NULL) THEN
      :NEW.OBJECT := 0;
   END IF;

   IF (:NEW.Price IS NULL) THEN
      :NEW.Price := 0;
   END IF;

   IF (:NEW.PriceVAT IS NULL) THEN
      :NEW.PriceVAT := 0;
   END IF;

   IF (:NEW.COST IS NULL) THEN
      :NEW.COST := 0;
   END IF;

   IF (:NEW.VATPercent IS NULL) THEN
      :NEW.VATPercent := 0;
   END IF;

   IF (:NEW.VATSumma IS NULL) THEN
      :NEW.VATSumma := 0;
   END IF;

   IF (:NEW.Summa IS NULL) THEN
      :NEW.Summa := 0;
   END IF;

   IF (:NEW.FinSumma IS NULL) THEN
      :NEW.FinSumma := 0;
   END IF;

   /*   .   */
   SELECT c.BudgetRef
     INTO :NEW.BudgetRef
     FROM Agreements c
    WHERE c.ID = :NEW.RecordIndex;

-- - - - - - - - - - - - -
-- BI_10 (TR_ESTIMATE_BI_10)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (:new.senderId is null) then 
    :new.senderIdKey := -1;
  else
    :new.senderIdKey := :new.senderId;
  end if;

  if (:new.SenderRecordID is null)then
    :new.SenderRecordIDKey := :new.ID;
  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  end if;	

-- - - - - - - - - - - - -
-- BI_20 (TR_ESTIMATE_BI_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if ((:new.COST < 0) or (:new.SUMMA < 0)) then
    RaiseException('EX_EXECDOCEST_NEGATIVECOST');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_ESTIMATE_BI_500)
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
-- CREATE TRIGGER TR_ESTIMATE_BU_20
CREATE OR REPLACE TRIGGER TR_ESTIMATE_BU
  BEFORE UPDATE
  ON ESTIMATE
  FOR EACH ROW
DECLARE
  TempFacialAcc_Cls NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ESTIMATE_BU)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (:NEW.FacialAcc_Cls IS NULL) THEN
      BEGIN
         SELECT FacialAcc_Cls
           INTO TempFacialAcc_Cls
           FROM Agreements
          WHERE (ID = :NEW.RecordIndex);
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            TempFacialAcc_Cls := NULL;
      END;

      :NEW.FacialAcc_Cls := TempFacialAcc_Cls;
   END IF;

   IF (:NEW.ProductCls IS NULL) THEN
      :NEW.ProductCls := 0;
   END IF;

   IF (:NEW.Amount IS NULL) THEN
      :NEW.amount := 0;
   END IF;

   IF (:NEW.OBJECT IS NULL) THEN
      :NEW.OBJECT := 0;
   END IF;

   IF (:NEW.Price IS NULL) THEN
      :NEW.Price := 0;
   END IF;

   IF (:NEW.PriceVAT IS NULL) THEN
      :NEW.PriceVAT := 0;
   END IF;

   IF (:NEW.VATPercent IS NULL) THEN
      :NEW.VATPercent := 0;
   END IF;

   IF (:NEW.COST IS NULL) THEN
      :NEW.COST := 0;
   END IF;

   IF (:NEW.VATSumma IS NULL) THEN
      :NEW.VATSumma := 0;
   END IF;

   IF (:NEW.Summa IS NULL) THEN
      :NEW.Summa := 0;
   END IF;

   IF (:NEW.FinSumma IS NULL) THEN
      :NEW.FinSumma := 0;
   END IF;

   /*     */
   IF     (:NEW.BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((:NEW.BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_ESTIMATE_BU_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if ((:new.COST < 0) or (:new.SUMMA < 0)) then
    RaiseException('EX_EXECDOCEST_NEGATIVECOST');
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_Estimate_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.RecordIndex <> :old.RecordIndex) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ESTIMATE_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (:NEW.RVersion IS NULL) THEN
      :NEW.RVersion := 1;
   ELSE
      IF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         :NEW.RVersion := :OLD.RVersion;
      ELSE
         :NEW.RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_BUDGETDATA.sql
-- #########################################################
-- #########################################################

--,    (SenderIDKey, SenderRecordIDKey)
--       BudgetData,
--     (SenderID, SenderRecordID).
-- (SenderID, SenderRecordID)      (null, null),
--    
ALTER TRIGGER TR_BUDGETDATA_BU_500 DISABLE
/
commit work
/
--   (SenderID, SenderRecordID)  (    (null, null))
CREATE TABLE bdataDuplicate(
  SenderID NUMBER(10),
    CHECK((SenderID<=2147483647)AND(SenderID>-2147483648)),
  SenderRecordID NUMBER(10),
    CHECK((SenderRecordID<=2147483647)AND(SenderRecordID>-2147483648))
)
/
CREATE INDEX ind_bdataDuplicate_sid ON bdataDuplicate(SenderID)
/
CREATE INDEX ind_bdataDuplicate_srid ON bdataDuplicate(SenderRecordID)
/
commit work
/
INSERT INTO bdataDuplicate
    SELECT SenderID, SenderRecordID FROM BUDGETDATA
        WHERE SenderID is not null and SenderRecordID is not null
        GROUP BY SenderID, SenderRecordID HAVING count(ID) > 1
/
commit work
/
UPDATE BUDGETDATA bdata SET
  SenderID = NULL,
  SenderRecordID = NULL
WHERE
  EXISTS (SELECT SenderID
          FROM bdataDuplicate duplicate
          WHERE
            bdata.SenderID = duplicate.SenderID AND
            bdata.SEnderREcordId = duplicate.SenderRecordID)
/
commit work
/
DROP INDEX ind_bdataDuplicate_srid
/
DROP INDEX ind_bdataDuplicate_sid
/
DROP TABLE bdataDuplicate
/
commit work
/
--  (SenderID, SenderRecordID)     
ALTER TABLE BUDGETDATA ADD (
  SenderIDKey NUMBER(10),
    CHECK((SenderIDKey<=2147483647)AND(SenderIDKey>-2147483648)),
  SenderRecordIDKey NUMBER(10),
    CHECK((SenderRecordIDKey<=2147483647)AND(SenderRecordIDKey>-2147483648)),
  CONSTRAINT U_BudgetData_Sender unique (SenderIDKey, SenderRecordIDKey)
)
/
commit work
/
-- CREATE TRIGGER tr_BudgetData_bi_10
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BI
  BEFORE INSERT
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  OrgRefByAcc$ NUMBER(10);
  CapClsType$ NUMBER(10);
  AutoKesrCorr$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDGETDATA_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  IF (:new.id IS NULL) THEN 
    select g_shared.nextval into :new.id from dual;
  END IF;
  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KESRCorr IS NULL) THEN 
    :new.KESRCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN 
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .      */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  BEGIN

    /*  .   */
    SELECT bn.BudgetRef      INTO :new.BudgetRef FROM BudNotify bn
    WHERE bn.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag1$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind1$);
    IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind1$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;/* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
      SELECT Organizations FROM REGIONCLS
        WHERE NEW.REGIONCLS = ID
      INTO NEW.TransfertOrg_Ref;
  */
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_BudgetData_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.SenderID is null) then
    :new.SenderIDKey := -1;
        
  else
    :new.SenderIDKey := :new.SenderID;
  END IF;
      
  if (:new.SenderRecordID is null) then
    :new.SenderRecordIDKey := :new.ID;
        
  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_BUDGETDATA_BI_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.KESR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_BUDGETDATA_BI_200)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-   */
  if (:new.ProgIndex in (32, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             ():
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0    .*/
    GetIntConst(32, 25,AutoKesrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKesrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKesrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKesrCorr$  = 2)) then  /* ()*/
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else 
        :new.KesrCorr := :new.Kesr; /*         */
      END IF;  
    END IF;
  else
    /*       215-, 264-, 265-, 267-, 271-   */
    if (:new.ProgIndex in (215, 264, 265, 267, 271)) then
      /*     (215   ())
             ():
           =0     ,
           =1  .  2   .
                 */
      GetIntConst(32, 26,AutoKesrCorr$);
      if (((AutoKesrCorr$  = 0)and(:new.ProgIndex=215))or(:new.ProgIndex<>215)) then
        BEGIN
          select
          ifs.KESR
          into
          :new.KesrCorr       from
          InnerFinSource ifs
          where
          ifs.id = :new.ifs
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;  
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDGETDATA_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

  Update BudNotify set
  DocChangeDate = :new.UpdateDate,
  RVersion = -1
  where id = :new.recordindex;

END;
/
commit work
/
UPDATE BUDGETDATA
    SET SenderIDKey = -1,
        SenderRecordIDKey = ID
    WHERE (senderID is null)
        OR (SenderRecordID is null)
/
commit work
/
UPDATE BUDGETDATA
    SET SenderIDKey = SenderID,
        SenderRecordIDKey = SenderRecordID
    WHERE (SenderID is not null)
        AND (SenderRecordID is not null)
/
commit work
/
ALTER TRIGGER TR_BUDGETDATA_BU_500 ENABLE
/
commit work
/
ALTER TABLE BUDGETDATA MODIFY(SenderIDKey NOT NULL)
/
ALTER TABLE BUDGETDATA MODIFY(SenderRecordIDKey NOT NULL)
/

-- #########################################################
-- #########################################################
-- Alter_BUDNOTIFY.sql
-- #########################################################
-- #########################################################

--,   (SenderIDKey, SenderRecordIDKey,ExtID,ExtRootID )    
--     (SenderID, SenderRecordID)
-- (SenderID, SenderRecordID)      (null, null)
--    
--ExtID,ExtRootID     WEB  
ALTER TRIGGER TR_BUDNOTIFY_BU_500 DISABLE
/
commit work
/
--   (SenderID, SenderRecordID)  (    (null, null))
CREATE TABLE budnDuplicate(
  SenderID NUMBER(10),
    CHECK((SenderID<=2147483647)AND(SenderID>-2147483648)),
  SenderRecordID NUMBER(10),
    CHECK((SenderRecordID<=2147483647)AND(SenderRecordID>-2147483648))
)
/
CREATE INDEX ind_budnDuplicate_sid ON budnDuplicate(SenderID)
/
CREATE INDEX ind_budnDuplicate_srid ON budnDuplicate(SenderRecordID)
/
commit work
/
INSERT INTO budnDuplicate
    SELECT SenderID, SenderRecordID FROM budnotify
        WHERE SenderID is not null and SenderRecordID is not null
        GROUP BY SenderID, SenderRecordID HAVING count(ID) > 1
/
commit work
/
UPDATE budnotify budn SET
  SenderID = NULL,
  SenderRecordID = NULL
WHERE
  EXISTS (SELECT SenderID
          FROM budnDuplicate duplicate
          WHERE
            budn.SenderID = duplicate.SenderID AND
            budn.SEnderREcordId = duplicate.SenderRecordID)
/
commit work
/
DROP INDEX ind_budnDuplicate_srid
/
DROP INDEX ind_budnDuplicate_sid
/
DROP TABLE budnDuplicate
/
commit work
/
--  (SenderIDKey, SenderRecordIDKey)     
--ExtID,ExtRootID     WEB  
ALTER TABLE TB_BUDNOTIFY ADD (
  SenderIDKey NUMBER(10),
    CHECK((SenderIDKey<=2147483647)AND(SenderIDKey>-2147483648)),
  SenderRecordIDKey NUMBER(10),
    CHECK((SenderRecordIDKey<=2147483647)AND(SenderRecordIDKey>-2147483648)),
  ExtID VARCHAR2(50),/* UID     ,  GUID */
  ExtRootID VARCHAR2(50),/*   */
  CONSTRAINT U_BUDNOTIFY_Sender unique (SenderIDKey, SenderRecordIDKey)
)
/

CREATE OR REPLACE VIEW BUDNOTIFY (
  ID,
  DAT,
  DOCDAT,
  NOTE1,
  NOTIFYTYPE,
  BUDGETREF,
  DOCBASE,
  VARIANT,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SENDERID,
  SENDERRECORDID,
  ANUMBER,
  ATYPE,
  DOCUMENTSTATE,
  USERSVISA,
  DATEINPUT,
  ORGREF,
  REJECTCLS,
  REJECTNOTE,
  PLANDOCTYPE,
  RECORDINDEX,
  STIMATEID,
  CRYPTOSTATUS,
  RVERSION,
  DOCSTATEREF,
  DOCNUMBER,
  FACIALACCCLS,
  LASTEXTRCHANGE,
  BIDNUMBER,
  FAXDOCCOUNT,
  PLANKIND,
  ASSIGNMENTSOURCE,
  BA_LBO_FLAG,
  KPPERIOD,
  CLSTYPE,
  DATE_UTV_PP,
  PROGINDEX,
  NOTE,
  NOTE2,
  DOCCHANGEDATE,
  SIGNERS,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  EXTID,
  EXTROOTID)
AS
  SELECT
    ID,
    DAT,
    DOCDAT,
    NOTE1,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    REJECTNOTE,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID
  FROM TB_BUDNOTIFY
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_ID
  INSTEAD OF DELETE
  ON BUDNOTIFY
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_BUDNOTIFY_BD)
-- - - - - - - - - - - - -

  delete from BudgetData where (RecordIndex = :old.id);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_BUDNOTIFY
  WHERE id=:old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_BUDNOTIFY_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(tableid, recordid, deletedate, createruser, progindex) values(28, :old.id, SYSDATE, user, :old.progindex);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_II
  INSTEAD OF INSERT
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDNOTIFY_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$NotifyType is null) then 
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then 
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then 
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType is null) or (new$PlanDocType < 100)) then
    new$PlanDocType := 200;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;
      
  else
    new$AType := 1;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$FacialAccCls is null) then 
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then 
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then 
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> 0)and(new$OrgRef is null)) then
    BEGIN
      /*         
             - \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*         */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_BUDNOTIFY_BI_430)
-- Create 18.09.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    /*        */
    GetIntConst(30, 19, UseFax$);
    IF ((NEW$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      NEW$BidNumber := NEW$ANumber;
    end if;
    NEW$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDNOTIFY_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_BUDNOTIFY (
    ID,
    DAT,
    DOCDAT,
    NOTE1,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    REJECTNOTE,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID
  ) VALUES (
    new$ID,
    new$DAT,
    new$DOCDAT,
    new$NOTE1,
    new$NOTIFYTYPE,
    new$BUDGETREF,
    new$DOCBASE,
    new$VARIANT,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SENDERID,
    new$SENDERRECORDID,
    new$ANUMBER,
    new$ATYPE,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$DATEINPUT,
    new$ORGREF,
    new$REJECTCLS,
    new$REJECTNOTE,
    new$PLANDOCTYPE,
    new$RECORDINDEX,
    new$STIMATEID,
    new$CRYPTOSTATUS,
    new$RVERSION,
    new$DOCSTATEREF,
    new$DOCNUMBER,
    new$FACIALACCCLS,
    new$LASTEXTRCHANGE,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$PLANKIND,
    new$ASSIGNMENTSOURCE,
    new$BA_LBO_FLAG,
    new$KPPERIOD,
    new$CLSTYPE,
    new$DATE_UTV_PP,
    new$PROGINDEX,
    new$NOTE,
    new$NOTE2,
    new$DOCCHANGEDATE,
    new$SIGNERS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXTID,
    new$EXTROOTID);

-- - - - - - - - - - - - -
-- AI_500 (TR_BUDNOTIFY_AI_500)
-- - - - - - - - - - - - -

        delete from DelRecIndexes where (TableID = 28) and (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_IU
  INSTEAD OF UPDATE
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
--
  IsReject$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDNOTIFY_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$NotifyType is null) then 
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then 
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then 
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then 
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;
      
  else
    if (new$PlanDocType > 199) then
      new$AType := 1;
    END IF;
  END IF;
  if (new$PlanDocType is null) then
    if (new$AType = 1) then
      new$PlanDocType := 200;
          
    else
      new$PlanDocType := 100;
      
    END IF;
  END IF;
  /*    */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)              into DetCount$ from BudgetData where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');        
      END IF;
    END IF;
  END IF;
  if (new$FacialAccCls is null) then 
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then 
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then 
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> :old.FacialAccCLS)
  and(new$FacialAccCLS <> 0)) then
    BEGIN
      /*     -    \   
             - \  ,
           ,   \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*        */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDNOTIFY_BU_200)
-- Create 08.02.2005
-- - - - - - - - - - - - -

   --     
  IF (:OLD.DOCSTATEREF <> NEW$DOCSTATEREF) THEN
    INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      VALUES (NEW$ID, :OLD.DOCSTATEREF, NEW$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_BUDNOTIFY_BU_300)
-- Create 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from BudgetData d where d.RecordIndex = :new.id));
  end if;    

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDNOTIFY_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (NEW$RVersion IS NULL) THEN
    NEW$RVersion := 1;
  ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
    NEW$RVersion := :OLD.RVersion;
  ELSE
    NEW$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BUDNOTIFY SET
    ID = new$ID,
    DAT = new$DAT,
    DOCDAT = new$DOCDAT,
    NOTE1 = new$NOTE1,
    NOTIFYTYPE = new$NOTIFYTYPE,
    BUDGETREF = new$BUDGETREF,
    DOCBASE = new$DOCBASE,
    VARIANT = new$VARIANT,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    ANUMBER = new$ANUMBER,
    ATYPE = new$ATYPE,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    DATEINPUT = new$DATEINPUT,
    ORGREF = new$ORGREF,
    REJECTCLS = new$REJECTCLS,
    REJECTNOTE = new$REJECTNOTE,
    PLANDOCTYPE = new$PLANDOCTYPE,
    RECORDINDEX = new$RECORDINDEX,
    STIMATEID = new$STIMATEID,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    RVERSION = new$RVERSION,
    DOCSTATEREF = new$DOCSTATEREF,
    DOCNUMBER = new$DOCNUMBER,
    FACIALACCCLS = new$FACIALACCCLS,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    PLANKIND = new$PLANKIND,
    ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE,
    BA_LBO_FLAG = new$BA_LBO_FLAG,
    KPPERIOD = new$KPPERIOD,
    CLSTYPE = new$CLSTYPE,
    DATE_UTV_PP = new$DATE_UTV_PP,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    NOTE2 = new$NOTE2,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    SIGNERS = new$SIGNERS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXTID = new$EXTID,
    EXTROOTID = new$EXTROOTID
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_300 (TR_BudNotify_AU_300)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType <> :old.ClsType)and(new$ClsType <> 3)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update BudgetData set
      KD = 0,
      IFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update BudgetData set
      KD = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      KESR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update BudgetData set
      IFS = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      KESR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
      
    END IF;
  END IF;
  if ((new$ProgIndex in (252, 253))and(new$FacialAccCLS <> :old.FacialAccCLS)) then
    update BudgetData set
    facialacc_cls = new$FacialAccCLS
    where
    RecordIndex = new$id;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUDNOTIFY_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (NEW$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (28, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=28) and (RecordId=NEW$ID);
  end if;

END;
/
create index idx_BUDN_ExtID on TB_BUDNOTIFY(ExtID)
/
create index idx_BUDN_ExtRootID on TB_BUDNOTIFY(ExtRootID)
/

commit work
/
-- CREATE TRIGGER tr_BUDNOTIFY_bi_10
CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_II
  INSTEAD OF INSERT
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDNOTIFY_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$NotifyType is null) then 
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then 
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then 
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType is null) or (new$PlanDocType < 100)) then
    new$PlanDocType := 200;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;
      
  else
    new$AType := 1;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$FacialAccCls is null) then 
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then 
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then 
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> 0)and(new$OrgRef is null)) then
    BEGIN
      /*         
             - \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*         */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_BUDNOTIFY_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_BUDNOTIFY_BI_430)
-- Create 18.09.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    /*        */
    GetIntConst(30, 19, UseFax$);
    IF ((NEW$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      NEW$BidNumber := NEW$ANumber;
    end if;
    NEW$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDNOTIFY_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_BUDNOTIFY (
    ID,
    DAT,
    DOCDAT,
    NOTE1,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    REJECTNOTE,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID
  ) VALUES (
    new$ID,
    new$DAT,
    new$DOCDAT,
    new$NOTE1,
    new$NOTIFYTYPE,
    new$BUDGETREF,
    new$DOCBASE,
    new$VARIANT,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SENDERID,
    new$SENDERRECORDID,
    new$ANUMBER,
    new$ATYPE,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$DATEINPUT,
    new$ORGREF,
    new$REJECTCLS,
    new$REJECTNOTE,
    new$PLANDOCTYPE,
    new$RECORDINDEX,
    new$STIMATEID,
    new$CRYPTOSTATUS,
    new$RVERSION,
    new$DOCSTATEREF,
    new$DOCNUMBER,
    new$FACIALACCCLS,
    new$LASTEXTRCHANGE,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$PLANKIND,
    new$ASSIGNMENTSOURCE,
    new$BA_LBO_FLAG,
    new$KPPERIOD,
    new$CLSTYPE,
    new$DATE_UTV_PP,
    new$PROGINDEX,
    new$NOTE,
    new$NOTE2,
    new$DOCCHANGEDATE,
    new$SIGNERS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXTID,
    new$EXTROOTID);

-- - - - - - - - - - - - -
-- AI_500 (TR_BUDNOTIFY_AI_500)
-- - - - - - - - - - - - -

        delete from DelRecIndexes where (TableID = 28) and (RecordID = NEW$ID);

END;
/
commit work
/
UPDATE BUDNOTIFY
    SET SenderIDKey = -1,
        SenderRecordIDKey = ID
    WHERE (senderID is null)
        OR (SenderRecordID is null)
/
commit work
/
UPDATE BUDNOTIFY
    SET SenderIDKey = SenderID,
        SenderRecordIDKey = SenderRecordID
    WHERE (SenderID is not null)
        AND (SenderRecordID is not null)
/
commit work
/
ALTER TRIGGER TR_BUDNOTIFY_BU_500 ENABLE
/
commit work
/
ALTER TABLE TB_BUDNOTIFY MODIFY(SenderIDKey NOT NULL)
/
ALTER TABLE TB_BUDNOTIFY MODIFY(SenderRecordIDKey NOT NULL)
/

-- #########################################################
-- #########################################################
-- Alter_EX_AGR_ACCORGCHECK.sql
-- #########################################################
-- #########################################################

UPDATE SqlExceptions SET Text = '    ' WHERE UPPER(Name) = UPPER('EX_AGR_ACCORGCHECK')
/
commit work
/


-- #########################################################
-- #########################################################
-- Alter_FACIALFIN_DETAIL_N_CAPTION.sql
-- #########################################################
-- #########################################################

--,   SenderIDKey  SenderRecordIDKey
--  FacialFinDetail  FacialFinCaption
--       
--SenderID  SenderRecordID (      ,       !)
ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 DISABLE
/
ALTER TRIGGER TR_FACIALFINCAPTION_BU_500 DISABLE
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_210
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Create 28.04.2005
-- Last update 12.01.2009
-- - - - - - - - - - - - -

    /*  60 :  '   .'; source
        61 :  '      '; dest
        62 :  '   ';dest
        63 :  '    '; source
        64 :  '   '; source
        65 :  ' , ';dest
        66 :  '  ,  - '; source dest
        67 :  '   ';source
        68 :  '  \ ';dest
        69 :  '   \ '; dest
        70 :  '  \ ';source
        71 :  '   \ '; dest */

  /*ClsType*/
  if ((new$ClsType is NULL) and 
        ( 
          ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
          (new$ProgIndex = 60)
        )) then
    new$ClsType := 1; /*       ClsType */
  elsif ((new$ClsType is NULL) and (new$SourceKD <> 0) and
        (new$ProgIndex in (63,64,66,67,68,70))) then
    new$ClsType := 2; /*        ClsType */
  elsif (new$ClsType is null) then
    new$ClsType := 0; /*  -  */
  end if;  

  IF ((new$ClsType = 0) AND 
      (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
      (new$ProgIndex in (63,64,66,67,68,70)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 1) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 2) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  /*DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  end if;  

  IF ((new$DestClsType = 0) AND
      (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
      (new$ProgIndex in (61,62,65,69,71)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 1) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 2) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_200
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Create 28.04.2005
-- Last update 12.01.2009
-- - - - - - - - - - - - -

    /*  60 :  '   .'; source
        61 :  '      '; dest
        62 :  '   ';dest
        63 :  '    '; source
        64 :  '   '; source
        65 :  ' , ';dest
        66 :  '  ,  - '; source dest
        67 :  '   ';source
        68 :  '  \ ';dest
        69 :  '   \ '; dest
        70 :  '  \ ';source
        71 :  '   \ '; dest */

  /*ClsType*/
  if ((new$ClsType is NULL) and 
        ( 
          ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
          (new$ProgIndex = 60)
        )) then
    new$ClsType := 1; /*       ClsType */
  elsif ((new$ClsType is NULL) and (new$SourceKD <> 0) and
        (new$ProgIndex in (63,64,66,67,68,70))) then
    new$ClsType := 2; /*        ClsType */
  elsif (new$ClsType is null) then
    new$ClsType := 0; /*  -  */
  end if;  

  IF ((new$ClsType = 0) AND 
      (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
      (new$ProgIndex in (63,64,66,67,68,70)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 1) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 2) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  /*DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  end if;  

  IF ((new$DestClsType = 0) AND
      (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
      (new$ProgIndex in (61,62,65,69,71)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 1) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 2) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work
/
--   (SenderID, SenderRecordID)  (    (null, null))
CREATE TABLE ffdDuplicate(
  SenderID NUMBER(10),
    CHECK((SenderID<=2147483647)AND(SenderID>-2147483648)),
  SenderRecordID NUMBER(10),
    CHECK((SenderRecordID<=2147483647)AND(SenderRecordID>-2147483648))
)
/
CREATE INDEX ind_ffdDuplicate_sid ON ffdDuplicate(SenderID)
/
CREATE INDEX ind_ffdDuplicate_srid ON ffdDuplicate(SenderRecordID)
/
commit work
/
INSERT INTO ffdDuplicate
    SELECT SenderID, SenderRecordID FROM facialfindetail
        WHERE SenderID is not null and SenderRecordID is not null
        GROUP BY SenderID, SenderRecordID HAVING count(ID) > 1
/
commit work
/
UPDATE facialfindetail detail SET
  SenderID = NULL,
  SenderRecordID = NULL
WHERE
  EXISTS (SELECT SenderID
          FROM ffdDuplicate duplicate
          WHERE
            detail.SenderID = duplicate.SenderID AND
            detail.SEnderREcordId = duplicate.SenderRecordID)
/
commit work
/
DROP INDEX ind_ffdDuplicate_srid
/
DROP INDEX ind_ffdDuplicate_sid
/
DROP TABLE ffdDuplicate
/
commit work
/
CREATE TABLE ffcDuplicate(
  SenderID NUMBER(10),
    CHECK((SenderID<=2147483647)AND(SenderID>-2147483648)),
  SenderRecordID NUMBER(10),
    CHECK((SenderRecordID<=2147483647)AND(SenderRecordID>-2147483648))
)
/
CREATE INDEX ind_ffcDuplicate_sid ON ffcDuplicate(SenderID)
/
CREATE INDEX ind_ffcDuplicate_srid ON ffcDuplicate(SenderRecordID)
/
commit work
/
INSERT INTO ffcDuplicate
    SELECT SenderID, SenderRecordID FROM FacialFinCaption
        WHERE SenderID is not null and SenderRecordID is not null
        GROUP BY SenderID, SenderRecordID HAVING count(ID) > 1
/
commit work
/
UPDATE FacialFinCaption caption SET
  SenderID = NULL,
  SenderRecordID = NULL
WHERE
  EXISTS (SELECT SenderID
          FROM ffcDuplicate duplicate
          WHERE
            caption.SenderID = duplicate.SenderID AND
            caption.SEnderREcordId = duplicate.SenderRecordID)
/
commit work
/
DROP INDEX ind_ffcDuplicate_srid
/
DROP INDEX ind_ffcDuplicate_sid
/
DROP TABLE ffcDuplicate
/
commit work
/
--  (SenderIDKey, SenderRecordIDKey)  
ALTER TABLE TB_FACIALFINDETAIL ADD (
  SenderIDKey NUMBER(10),
    CHECK((SenderIDKey<=2147483647)AND(SenderIDKey>-2147483648)),
  SenderRecordIDKey NUMBER(10),
    CHECK((SenderRecordIDKey<=2147483647)AND(SenderRecordIDKey>-2147483648)),
  CONSTRAINT U_FacialFinDetail_Sender unique (SenderIDKey, SenderRecordIDKey)
)
/

CREATE OR REPLACE VIEW FACIALFINDETAIL (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  NOTE,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY
  FROM TB_FACIALFINDETAIL
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CapBuhOperationCLS$ NUMBER(10);
  CapClsType$ NUMBER(10);
  CapAcceptDate$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  PromiseAcceptDate$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Last update 12.01.2009
-- - - - - - - - - - - - -

 /*  ,    */
   BEGIN

     select
       ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate,
       ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
     into new$BudgetRef, CapBuhOperationCls$, CapClsType$, CapAcceptDate$,
       new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause
     from
       FacialFinCaption ffc
     where
       ffc.id = new$RecordIndex;
     
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       new$BudgetRef := NULL;
       CapBuhOperationCls$ := NULL;
       CapClsType$ := NULL;
       CapAcceptDate$ := NULL;
   END;

   /*      */
   if (new$BuhOperationCls is null) then new$BuhOperationCls := CapBuhOperationCls$; end if;

   /*      */
   if (new$ClsType is null) then new$ClsType := CapClsType$; end if;

   if (new$DestClsType is null) then new$DestClsType := new$ClsType; end if;
   
   /*      */
   if (new$AcceptDate is null) then new$AcceptDate := CapAcceptDate$; end if;

   /*      */
   if ((new$SourceFacialAcc_CLS is null) or (new$DestFacialAcc_CLS is null)) then
     BEGIN
       select SourceFacialAcc_CLS, DestFacialAcc_CLS
         into SourceFacialAcc_CLS$, DestFacialAcc_CLS$
       from FacialFinCaption
       where new$RecordIndex = id;
     EXCEPTION
       WHEN NO_DATA_FOUND THEN
         SourceFacialAcc_CLS$ := NULL;
         DestFacialAcc_CLS$ := NULL;
     END;

     if (new$SourceFacialAcc_CLS is null) then new$SourceFacialAcc_CLS := SourceFacialAcc_CLS$; end if;
     if (new$DestFacialAcc_CLS is null) then new$DestFacialAcc_CLS := DestFacialAcc_CLS$; end if;
   end if;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND(new$DestPromise IS NOT NULL)AND
        (new$SourcePromise=new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Create 28.04.2005
-- Last update 15.12.2008
-- - - - - - - - - - - - -

    /*  60 :  '   .'; source
        61 :  '      '; dest
        62 :  '   ';dest
        63 :  '    '; source
        64 :  '   '; source
        65 :  ' , ';dest
        66 :  '  ,  - '; source dest
        67 :  '   ';source
        68 :  '  \ ';dest
        69 :  '   \ '; dest
        70 :  '  \ ';source
        71 :  '   \ '; dest */

  /*ClsType*/
  if ((New$ClsType is NULL) and 
        ( 
          ((New$SourceIFS <> 0) and (New$ProgIndex in (63,64,66,67,68,70))) or
          (New$ProgIndex = 60)
        )) then
    New$ClsType := 1; /*       ClsType */
  elsif ((New$ClsType is NULL) and (New$SourceKD <> 0) and
        (New$ProgIndex in (63,64,66,67,68,70))) then
    New$ClsType := 2; /*        ClsType */
  elsif (new$ClsType is null) then
    new$ClsType := 0; /*  -  */
  end if;  

  IF ((new$ClsType = 0) AND 
      (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
      (new$ProgIndex in (63,64,66,67,68,70)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;
  IF ((new$ClsType = 1) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;
  IF ((new$ClsType = 2) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  /*DestClsType*/
  if ((new$DestClsType is NULL) and
        ( 
          ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
        )) then
    new$DestClsType := 1; /*       ClsType */
  elsif ((new$DestClsType is NULL) and
          ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
        ) then
    new$DestClsType := 2; /*        ClsType */
  elsif (new$DestClsType is null) then
    new$DestClsType := 0; /*  -  */
  end if;      

  IF ((new$DestClsType = 0) AND
      (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
      (new$ProgIndex in (61,62,65,69,71)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;
  IF ((new$DestClsType = 1) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 2) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode1$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;    
    END IF;
  END IF;
  if (PromiseMode1$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .    */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* source    ,   ,   */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /* dest */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Create 28.04.2005
-- Last update 12.01.2009
-- - - - - - - - - - - - -

    /*  60 :  '   .'; source
        61 :  '      '; dest
        62 :  '   ';dest
        63 :  '    '; source
        64 :  '   '; source
        65 :  ' , ';dest
        66 :  '  ,  - '; source dest
        67 :  '   ';source
        68 :  '  \ ';dest
        69 :  '   \ '; dest
        70 :  '  \ ';source
        71 :  '   \ '; dest */

  /*ClsType*/
  if ((new$ClsType is NULL) and 
        ( 
          ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
          (new$ProgIndex = 60)
        )) then
    new$ClsType := 1; /*       ClsType */
  elsif ((new$ClsType is NULL) and (new$SourceKD <> 0) and
        (new$ProgIndex in (63,64,66,67,68,70))) then
    new$ClsType := 2; /*        ClsType */
  elsif (new$ClsType is null) then
    new$ClsType := 0; /*  -  */
  end if;  

  IF ((new$ClsType = 0) AND 
      (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
      (new$ProgIndex in (63,64,66,67,68,70)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 1) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 2) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  /*DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  end if;  

  IF ((new$DestClsType = 0) AND
      (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
      (new$ProgIndex in (61,62,65,69,71)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 1) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 2) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work
/
-- CREATE TRIGGER tr_FacialFinDetail_bi_10
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CapBuhOperationCLS$ NUMBER(10);
  CapClsType$ NUMBER(10);
  CapAcceptDate$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  PromiseAcceptDate$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Last update 12.01.2009
-- - - - - - - - - - - - -

 /*  ,    */
   BEGIN

     select
       ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate,
       ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
     into new$BudgetRef, CapBuhOperationCls$, CapClsType$, CapAcceptDate$,
       new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause
     from
       FacialFinCaption ffc
     where
       ffc.id = new$RecordIndex;
     
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       new$BudgetRef := NULL;
       CapBuhOperationCls$ := NULL;
       CapClsType$ := NULL;
       CapAcceptDate$ := NULL;
   END;

   /*      */
   if (new$BuhOperationCls is null) then new$BuhOperationCls := CapBuhOperationCls$; end if;

   /*      */
   if (new$ClsType is null) then new$ClsType := CapClsType$; end if;

   if (new$DestClsType is null) then new$DestClsType := new$ClsType; end if;
   
   /*      */
   if (new$AcceptDate is null) then new$AcceptDate := CapAcceptDate$; end if;

   /*      */
   if ((new$SourceFacialAcc_CLS is null) or (new$DestFacialAcc_CLS is null)) then
     BEGIN
       select SourceFacialAcc_CLS, DestFacialAcc_CLS
         into SourceFacialAcc_CLS$, DestFacialAcc_CLS$
       from FacialFinCaption
       where new$RecordIndex = id;
     EXCEPTION
       WHEN NO_DATA_FOUND THEN
         SourceFacialAcc_CLS$ := NULL;
         DestFacialAcc_CLS$ := NULL;
     END;

     if (new$SourceFacialAcc_CLS is null) then new$SourceFacialAcc_CLS := SourceFacialAcc_CLS$; end if;
     if (new$DestFacialAcc_CLS is null) then new$DestFacialAcc_CLS := DestFacialAcc_CLS$; end if;
   end if;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND(new$DestPromise IS NOT NULL)AND
        (new$SourcePromise=new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Create 28.04.2005
-- Last update 15.12.2008
-- - - - - - - - - - - - -

    /*  60 :  '   .'; source
        61 :  '      '; dest
        62 :  '   ';dest
        63 :  '    '; source
        64 :  '   '; source
        65 :  ' , ';dest
        66 :  '  ,  - '; source dest
        67 :  '   ';source
        68 :  '  \ ';dest
        69 :  '   \ '; dest
        70 :  '  \ ';source
        71 :  '   \ '; dest */

  /*ClsType*/
  if ((New$ClsType is NULL) and 
        ( 
          ((New$SourceIFS <> 0) and (New$ProgIndex in (63,64,66,67,68,70))) or
          (New$ProgIndex = 60)
        )) then
    New$ClsType := 1; /*       ClsType */
  elsif ((New$ClsType is NULL) and (New$SourceKD <> 0) and
        (New$ProgIndex in (63,64,66,67,68,70))) then
    New$ClsType := 2; /*        ClsType */
  elsif (new$ClsType is null) then
    new$ClsType := 0; /*  -  */
  end if;  

  IF ((new$ClsType = 0) AND 
      (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
      (new$ProgIndex in (63,64,66,67,68,70)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;
  IF ((new$ClsType = 1) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;
  IF ((new$ClsType = 2) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  /*DestClsType*/
  if ((new$DestClsType is NULL) and
        ( 
          ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
        )) then
    new$DestClsType := 1; /*       ClsType */
  elsif ((new$DestClsType is NULL) and
          ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
        ) then
    new$DestClsType := 2; /*        ClsType */
  elsif (new$DestClsType is null) then
    new$DestClsType := 0; /*  -  */
  end if;      

  IF ((new$DestClsType = 0) AND
      (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
      (new$ProgIndex in (61,62,65,69,71)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;
  IF ((new$DestClsType = 1) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 2) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode1$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;    
    END IF;
  END IF;
  if (PromiseMode1$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .    */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* source    ,   ,   */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /* dest */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/
commit work
/
UPDATE FACIALFINDETAIL
    SET SenderIDKey = -1,
        SenderRecordIDKey = ID
    WHERE (senderID is null)
        OR (SenderRecordID is null)
/
commit work
/
UPDATE FACIALFINDETAIL
    SET SenderIDKey = SenderID,
        SenderRecordIDKey = SenderRecordID
    WHERE (SenderID is not null)
        AND (SenderRecordID is not null)
/
commit work
/
--  (SenderIDKey, SenderRecordIDKey)   
ALTER TABLE TB_FACIALFINCAPTION ADD (
  SenderIDKey NUMBER(10),
    CHECK((SenderIDKey<=2147483647)AND(SenderIDKey>-2147483648)),
  SenderRecordIDKey NUMBER(10),
    CHECK((SenderRecordIDKey<=2147483647)AND(SenderRecordIDKey>-2147483648)),
  CONSTRAINT U_FacialFinCaption_Sender unique (SenderIDKey, SenderRecordIDKey)
)
/

CREATE OR REPLACE VIEW FACIALFINCAPTION (
  ID,
  DOCNUMBER,
  SOURCEDOCNUM,
  PAYDATE,
  ACCEPTDATE,
  DOCUMENTDATE,
  REESTRDATE,
  CREDIT,
  SOURCEACCOUNT,
  SOURCEFACIALACC_CLS,
  DESTACCOUNT,
  DESTFACIALACC_CLS,
  PROGINDEX,
  ARHIVEDOC,
  PAYSYMBOLCLS,
  PAYTYPECLS,
  NOTE,
  PERIOD,
  PAYPRIORITY,
  TYPEOPERATIONCLS,
  BUHPAYMENTCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  RECORDINDEX,
  SENDERID,
  SENDERRECORDID,
  REESTR_REF,
  REJECT_CLS,
  REJECTCAUSE,
  CLIENTBANKNUMBER,
  CRYPTOSTATUS,
  TRUSTNUMBER,
  LINKEDDOCUMENT,
  BNKRECORDID,
  SUBPROGINDEX,
  DOCUMENTSTATE,
  USERSVISA,
  TREASUARYDOCSTATECLS,
  DEPARTMENTCLS,
  NDS,
  TAXNOTE,
  MANAGERBID,
  BIDNUMBER,
  GROUPID,
  GROUPSUMMA,
  DOCSTATEREF,
  LASTEXTRCHANGE,
  FAXDOCCOUNT,
  STIMATEID,
  INTEGRATEDDOCREF,
  REQUESTNUMBER,
  REQUESTDATE,
  RVERSION,
  FEDERALFUNDSREF,
  ELDOCREF,
  BUHOPERATIONCLS,
  CLSTYPE,
  OPERATIONDIRECTION,
  SOURCETYPE,
  DESTTYPE,
  CARDNUMBER,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  CASHIERPERSONALINFO,
  BIDDATE,
  CARDREF,
  SOURCESTOREDPAYMENTPROPS,
  DESTSTOREDPAYMENTPROPS,
  STOREDPAYMENTNOTE,
  DOCCHANGEDATE,
  UINCODE,
  DOCOSN,
  SIGNERS,
  DESTCLSTYPE,
  SENDERIDKEY,
  SENDERRECORDIDKEY)
AS
  SELECT
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    REJECTCAUSE,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY
  FROM TB_FACIALFINCAPTION
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_ID
  INSTEAD OF DELETE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  reestrAccepted1$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_FACIALFINCAPTION_BD)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

 /*       */
  DELETE FROM FacialFinDetail
        WHERE (RecordIndex = :OLD.ID);

-- - - - - - - - - - - - -
-- BD_5 (TR_FACIALFINCAPTION_BD_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((:old.progIndex = 63) or (:old.progIndex = 64) or
  (:old.progIndex = 68) or (:old.progIndex = 70))
  and (:old.REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where 
      id = :old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
        
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrDelete');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BD_6 (TR_FACIALFINCAPTION_BD_6)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(id ) INTO CNT$1
  from paydocexchange where ((paydocref=:old.id)and(status<>0)and(CodeFormat<>50)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('ex_CannotChangeSended');
  else
    delete from PayDocExchange where paydocref = :old.id;  
  END IF;

-- - - - - - - - - - - - -
-- BD_430 (TR_FACIALFINCAPTION_BD_430)
-- Create 04.12.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*         */
  UPDATE FaxDocs
     SET OwnerID = NULL
  WHERE OwnerID = :OLD.ID;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINCAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_70 (TR_FACIALFINCAPTION_AD_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

--   /     
  IF (:OLD.SubProgIndex = 416) THEN
    UPDATE Guarantee
       SET SubRecordIndex = NULL,
           SubProgIndex = 0
     WHERE SubRecordIndex = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_FACIALFINCAPTION_AD_200)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*       */
  delete from StateJumpHistory
    where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_300 (TR_FACIALFINCAPTION_AD_300)
-- Create 24.02.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  IF (:OLD.FaxDocCount > 0) THEN
--    :old.FaxDocCount := :old.FaxDocCount;
    NULL;
  ELSE
    UPDATE FaxDocs
       SET OwnerID = NULL
     WHERE OwnerID = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINCAPTION_AD_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate, ProgIndex, Summa)
    VALUES (23, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_II
  INSTEAD OF INSERT
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  UseFax$ NUMBER(10);
  pdt$ NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  DocNumber$ NUMBER(10);
  CmpFacialAcc_Cls$ NUMBER(10);
  PIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINCAPTION_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$credit is null)then 
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then 
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then 
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then 
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then 
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then 
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then 
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then 
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection = 0) then
    new$SourceType := 1;
    new$DestType := 1;
     
  else
    if (new$OperationDirection = 1) then
      new$SourceType := 1;
      new$DestType := -1;
         
    else
      if (new$OperationDirection = 2) then
        new$SourceType := -1;
        new$DestType := 1;
             
      else
        new$SourceType := -1;
        new$DestType := -1;
             
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$); 
    if (DocNumber$ is null) then 
      new$DepartmentCls:= 0;
           
    else 
      new$DepartmentCls:= DocNumber$;
       
    END IF;
  END IF;
   
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    PIndex1$ := new$ProgIndex;
    if (PIndex1$=60) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    .*/
    END IF;
    if (PIndex1$=61) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*       */
    END IF;
    if (PIndex1$=62) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    */
    END IF;
    if (PIndex1$=63) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*     */
    END IF;
    if (PIndex1$=64) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=65) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  , */
    END IF;
    if (PIndex1$=66) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   ,  - */
    END IF;
    if (PIndex1$=67) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=68) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*   \ */
    END IF;
    if (PIndex1$=69) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=70) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   \ */
    END IF;
    if (PIndex1$=71) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=73) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   */
    END IF;
    if (PIndex1$=75) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  */
    END IF;
    if (PIndex1$=76) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*  */
    END IF;
    BEGIN

      select fa.BudgetRef      into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = CmpFacialAcc_Cls$

      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null )) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_FACIALFINCAPTION_BI_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_FACIALFINCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((new$progIndex = 63) or (new$progIndex = 64) or
  (new$progIndex = 68) or (new$progIndex = 70))
  and (new$REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where 
      id = new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
        
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrInsert');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_16 (TR_FACIALFINCAPTION_BI_16)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      .    FacialFinCaption
             */
   IF (new$Reestr_ref IS NULL) THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_FACIALFINCAPTION_BI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    pdt$ := NULL;
    IF (NEW$progindex = 63) THEN pdt$ := 302; END IF;
    IF (NEW$progindex = 66) THEN pdt$ := 301; END IF;
    IF (NEW$progindex = 64) THEN pdt$ := 304; END IF;

    /*       */
    GetIntConst(30, 19, UseFax$);
    IF ((new$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      new$BidNumber := new$DocNumber;
    END IF;
    SELECT COUNT(*) INTO new$FaxDocCount
    FROM FaxDocs
      WHERE (OwnerDocNumber=new$BidNumber)
        AND (ClientID=new$SenderID)
        AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
        AND (OwnerDate = new$DocumentDate)
        AND (PrimaryDocType = PDT$);
  ELSE
    new$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINCAPTION_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINCAPTION (
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    REJECTCAUSE,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$SOURCEDOCNUM,
    new$PAYDATE,
    new$ACCEPTDATE,
    new$DOCUMENTDATE,
    new$REESTRDATE,
    new$CREDIT,
    new$SOURCEACCOUNT,
    new$SOURCEFACIALACC_CLS,
    new$DESTACCOUNT,
    new$DESTFACIALACC_CLS,
    new$PROGINDEX,
    new$ARHIVEDOC,
    new$PAYSYMBOLCLS,
    new$PAYTYPECLS,
    new$NOTE,
    new$PERIOD,
    new$PAYPRIORITY,
    new$TYPEOPERATIONCLS,
    new$BUHPAYMENTCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$RECORDINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REESTR_REF,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CLIENTBANKNUMBER,
    new$CRYPTOSTATUS,
    new$TRUSTNUMBER,
    new$LINKEDDOCUMENT,
    new$BNKRECORDID,
    new$SUBPROGINDEX,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$TREASUARYDOCSTATECLS,
    new$DEPARTMENTCLS,
    new$NDS,
    new$TAXNOTE,
    new$MANAGERBID,
    new$BIDNUMBER,
    new$GROUPID,
    new$GROUPSUMMA,
    new$DOCSTATEREF,
    new$LASTEXTRCHANGE,
    new$FAXDOCCOUNT,
    new$STIMATEID,
    new$INTEGRATEDDOCREF,
    new$REQUESTNUMBER,
    new$REQUESTDATE,
    new$RVERSION,
    new$FEDERALFUNDSREF,
    new$ELDOCREF,
    new$BUHOPERATIONCLS,
    new$CLSTYPE,
    new$OPERATIONDIRECTION,
    new$SOURCETYPE,
    new$DESTTYPE,
    new$CARDNUMBER,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$CASHIERPERSONALINFO,
    new$BIDDATE,
    new$CARDREF,
    new$SOURCESTOREDPAYMENTPROPS,
    new$DESTSTOREDPAYMENTPROPS,
    new$STOREDPAYMENTNOTE,
    new$DOCCHANGEDATE,
    new$UINCODE,
    new$DOCOSN,
    new$SIGNERS,
    new$DESTCLSTYPE,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY);

-- - - - - - - - - - - - -
-- AI_430 (TR_FACIALFINCAPTION_AI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (new$SenderID IS NOT NULL) THEN
      /*       */
      pdt$ := NULL;
      IF (new$progindex = 63) THEN pdt$ := 302; END IF;
      IF (new$progindex = 66) THEN pdt$ := 301; END IF;
      IF (new$progindex = 64) THEN pdt$ := 304; END IF;

        UPDATE FaxDocs
            SET OwnerId=new$id
        WHERE
            (OwnerDocNumber=new$BidNumber)
            AND (ClientID=new$SenderID)
            AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
            AND (OwnerDate = new$DocumentDate)
            AND (primarydoctype = pdt$);
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINCAPTION_AI_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
     WHERE (TableID = 23) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  UseFax$ NUMBER(10);
  DocNumber$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is not null) then 
    /*      */
    GetIntConst(30, 19,UseFax$);
    if ((new$BidNumber is null) and (UseFax$ = 1)) then 
      new$BidNumber:= new$DocNumber;
      
    END IF;
  END IF;
  if (new$credit is null)then 
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then 
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then 
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then 
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then 
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then 
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then 
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then 
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;
          
    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;
              
      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;
                  
        else
          new$SourceType := -1;
          new$DestType := -1;
                  
        END IF;
      END IF;  
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$); 
    if (DocNumber$ is null) then 
      new$DepartmentCls:= 0;
          
    else 
      new$DepartmentCls:= DocNumber$;
      
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))                                             
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */
      
  else 
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where 
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
        
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(CodeFormat<>50)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_FACIALFINCAPTION_BU_10)
-- Create 16.03.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$IntegratedDocRef IS NOT NULL) THEN
        /*           ,       
      /*    */
      IF (    (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND (   (new$Reject_CLS = :OLD.Reject_CLS)
               OR ((new$Reject_CLS IS NULL) AND (:OLD.Reject_CLS IS NULL))
              )
          AND (   (new$RejectCause = :OLD.RejectCause)
               OR ((new$RejectCause IS NULL) AND (:OLD.RejectCause IS NULL))
              )
          AND (   (new$TREASUARYDOCSTATECLS = :OLD.TREASUARYDOCSTATECLS)
               OR (    (new$TREASUARYDOCSTATECLS IS NULL)
                   AND (:OLD.TREASUARYDOCSTATECLS IS NULL)
                  )
              )
          AND (   (new$DOCSTATEREF = :OLD.DOCSTATEREF)
               OR ((new$DOCSTATEREF IS NULL) AND (:OLD.DOCSTATEREF IS NULL))
              )
          AND (   (new$REESTR_REF = :OLD.REESTR_REF)
               OR ((new$REESTR_REF IS NULL) AND (:OLD.REESTR_REF IS NULL))
              )
          AND (new$SOURCEACCOUNT = :OLD.SOURCEACCOUNT)
          AND (new$DESTACCOUNT = :OLD.DESTACCOUNT)
         ) THEN
         new$AcceptDate := :OLD.AcceptDate;
      ELSE
         FOR R$ IN (SELECT fc.AcceptDate, fc.Reject_CLS, fc.RejectCause,
                           fc.TREASUARYDOCSTATECLS, fc.DOCSTATEREF,
                           fc.REESTR_REF, fc.SOURCEACCOUNT, fc.DESTACCOUNT
                      FROM FacialFinCaption fc
                     WHERE (fc.ID = :NEW.IntegratedDocRef)) LOOP
            IF (    (   (new$AcceptDate = R$.AcceptDate)
                     OR ((new$AcceptDate IS NULL) AND (R$.AcceptDate IS NULL)
                        )
                    )
                AND (   (new$Reject_CLS = R$.Reject_CLS)
                     OR ((new$Reject_CLS IS NULL) AND (R$.Reject_CLS IS NULL)
                        )
                    )
                AND (   (new$RejectCause = R$.RejectCause)
                     OR (    (new$RejectCause IS NULL)
                         AND (R$.RejectCause IS NULL)
                        )
                    )
                AND (   (new$TREASUARYDOCSTATECLS = R$.TREASUARYDOCSTATECLS)
                     OR (    (new$TREASUARYDOCSTATECLS IS NULL)
                         AND (R$.TREASUARYDOCSTATECLS IS NULL)
                        )
                    )
                AND (   (new$DOCSTATEREF = R$.DOCSTATEREF)
                     OR (    (new$DOCSTATEREF IS NULL)
                         AND (R$.DOCSTATEREF IS NULL)
                        )
                    )
                AND (   (new$REESTR_REF = R$.REESTR_REF)
                     OR ((new$REESTR_REF IS NULL) AND (R$.REESTR_REF IS NULL)
                        )
                    )
                AND (new$SOURCEACCOUNT = R$.SOURCEACCOUNT)
                AND (new$DESTACCOUNT = R$.DESTACCOUNT)
               ) THEN
               new$AcceptDate := R$.AcceptDate;
            ELSE
               RaiseException ('EX_CANNOTUPDATECHILDDOC');
            END IF;
         END LOOP;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;
      
  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);
      
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_FACIALFINCAPTION_AU_10)
-- Create 05.03.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 72) THEN                       /*   */
      IF (    (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND (   (new$Reject_CLS = :OLD.Reject_CLS)
               OR ((new$Reject_CLS IS NULL) AND (:OLD.Reject_CLS IS NULL))
              )
          AND (   (new$RejectCause = :OLD.RejectCause)
               OR ((new$RejectCause IS NULL) AND (:OLD.RejectCause IS NULL))
              )
          AND (   (new$TREASUARYDOCSTATECLS = :OLD.TREASUARYDOCSTATECLS)
               OR (    (new$TREASUARYDOCSTATECLS IS NULL)
                   AND (:OLD.TREASUARYDOCSTATECLS IS NULL)
                  )
              )
          AND (   (new$DOCSTATEREF = :OLD.DOCSTATEREF)
               OR ((new$DOCSTATEREF IS NULL) AND (:OLD.DOCSTATEREF IS NULL))
              )
          AND (   (new$REESTR_REF = :OLD.REESTR_REF)
               OR ((new$REESTR_REF IS NULL) AND (:OLD.REESTR_REF IS NULL))
              )
          AND (new$SOURCEACCOUNT = :OLD.SOURCEACCOUNT)
          AND (new$DESTACCOUNT = :OLD.DESTACCOUNT)
         ) THEN
         NULL;                /*      new$AcceptDate := :old.AcceptDate;   */
      ELSE
         /*    ,      */
         UPDATE TB_FacialFinCaption
            SET AcceptDate = new$AcceptDate,
                Reject_CLS = new$Reject_CLS,
                RejectCause = new$RejectCause,
                TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
                DOCSTATEREF = new$DOCSTATEREF,
                REESTR_REF = new$REESTR_REF,
                SOURCEACCOUNT = new$SOURCEACCOUNT,
                DESTACCOUNT = new$DESTACCOUNT
          WHERE IntegratedDocRef = new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*          ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      SourceKESR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestKESR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      SourceKESR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestKESR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
      
    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestKESR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestKESR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
commit work
/
-- CREATE TRIGGER tr_FacialFinCaption_bi_10
CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_II
  INSTEAD OF INSERT
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  UseFax$ NUMBER(10);
  pdt$ NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  DocNumber$ NUMBER(10);
  CmpFacialAcc_Cls$ NUMBER(10);
  PIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINCAPTION_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$credit is null)then 
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then 
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then 
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then 
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then 
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then 
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then 
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then 
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection = 0) then
    new$SourceType := 1;
    new$DestType := 1;
     
  else
    if (new$OperationDirection = 1) then
      new$SourceType := 1;
      new$DestType := -1;
         
    else
      if (new$OperationDirection = 2) then
        new$SourceType := -1;
        new$DestType := 1;
             
      else
        new$SourceType := -1;
        new$DestType := -1;
             
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$); 
    if (DocNumber$ is null) then 
      new$DepartmentCls:= 0;
           
    else 
      new$DepartmentCls:= DocNumber$;
       
    END IF;
  END IF;
   
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    PIndex1$ := new$ProgIndex;
    if (PIndex1$=60) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    .*/
    END IF;
    if (PIndex1$=61) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*       */
    END IF;
    if (PIndex1$=62) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    */
    END IF;
    if (PIndex1$=63) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*     */
    END IF;
    if (PIndex1$=64) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=65) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  , */
    END IF;
    if (PIndex1$=66) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   ,  - */
    END IF;
    if (PIndex1$=67) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=68) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*   \ */
    END IF;
    if (PIndex1$=69) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=70) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   \ */
    END IF;
    if (PIndex1$=71) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=73) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   */
    END IF;
    if (PIndex1$=75) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  */
    END IF;
    if (PIndex1$=76) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*  */
    END IF;
    BEGIN

      select fa.BudgetRef      into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = CmpFacialAcc_Cls$

      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null )) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_FACIALFINCAPTION_BI_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_FACIALFINCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((new$progIndex = 63) or (new$progIndex = 64) or
  (new$progIndex = 68) or (new$progIndex = 70))
  and (new$REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where 
      id = new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
        
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrInsert');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinCaption_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_16 (TR_FACIALFINCAPTION_BI_16)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      .    FacialFinCaption
             */
   IF (new$Reestr_ref IS NULL) THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_FACIALFINCAPTION_BI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    pdt$ := NULL;
    IF (NEW$progindex = 63) THEN pdt$ := 302; END IF;
    IF (NEW$progindex = 66) THEN pdt$ := 301; END IF;
    IF (NEW$progindex = 64) THEN pdt$ := 304; END IF;

    /*       */
    GetIntConst(30, 19, UseFax$);
    IF ((new$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      new$BidNumber := new$DocNumber;
    END IF;
    SELECT COUNT(*) INTO new$FaxDocCount
    FROM FaxDocs
      WHERE (OwnerDocNumber=new$BidNumber)
        AND (ClientID=new$SenderID)
        AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
        AND (OwnerDate = new$DocumentDate)
        AND (PrimaryDocType = PDT$);
  ELSE
    new$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINCAPTION_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINCAPTION (
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    REJECTCAUSE,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$SOURCEDOCNUM,
    new$PAYDATE,
    new$ACCEPTDATE,
    new$DOCUMENTDATE,
    new$REESTRDATE,
    new$CREDIT,
    new$SOURCEACCOUNT,
    new$SOURCEFACIALACC_CLS,
    new$DESTACCOUNT,
    new$DESTFACIALACC_CLS,
    new$PROGINDEX,
    new$ARHIVEDOC,
    new$PAYSYMBOLCLS,
    new$PAYTYPECLS,
    new$NOTE,
    new$PERIOD,
    new$PAYPRIORITY,
    new$TYPEOPERATIONCLS,
    new$BUHPAYMENTCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$RECORDINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REESTR_REF,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CLIENTBANKNUMBER,
    new$CRYPTOSTATUS,
    new$TRUSTNUMBER,
    new$LINKEDDOCUMENT,
    new$BNKRECORDID,
    new$SUBPROGINDEX,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$TREASUARYDOCSTATECLS,
    new$DEPARTMENTCLS,
    new$NDS,
    new$TAXNOTE,
    new$MANAGERBID,
    new$BIDNUMBER,
    new$GROUPID,
    new$GROUPSUMMA,
    new$DOCSTATEREF,
    new$LASTEXTRCHANGE,
    new$FAXDOCCOUNT,
    new$STIMATEID,
    new$INTEGRATEDDOCREF,
    new$REQUESTNUMBER,
    new$REQUESTDATE,
    new$RVERSION,
    new$FEDERALFUNDSREF,
    new$ELDOCREF,
    new$BUHOPERATIONCLS,
    new$CLSTYPE,
    new$OPERATIONDIRECTION,
    new$SOURCETYPE,
    new$DESTTYPE,
    new$CARDNUMBER,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$CASHIERPERSONALINFO,
    new$BIDDATE,
    new$CARDREF,
    new$SOURCESTOREDPAYMENTPROPS,
    new$DESTSTOREDPAYMENTPROPS,
    new$STOREDPAYMENTNOTE,
    new$DOCCHANGEDATE,
    new$UINCODE,
    new$DOCOSN,
    new$SIGNERS,
    new$DESTCLSTYPE,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY);

-- - - - - - - - - - - - -
-- AI_430 (TR_FACIALFINCAPTION_AI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (new$SenderID IS NOT NULL) THEN
      /*       */
      pdt$ := NULL;
      IF (new$progindex = 63) THEN pdt$ := 302; END IF;
      IF (new$progindex = 66) THEN pdt$ := 301; END IF;
      IF (new$progindex = 64) THEN pdt$ := 304; END IF;

        UPDATE FaxDocs
            SET OwnerId=new$id
        WHERE
            (OwnerDocNumber=new$BidNumber)
            AND (ClientID=new$SenderID)
            AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
            AND (OwnerDate = new$DocumentDate)
            AND (primarydoctype = pdt$);
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINCAPTION_AI_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
     WHERE (TableID = 23) AND (RecordID = new$ID);

END;
/
commit work
/
UPDATE FACIALFINCAPTION
    SET SenderIDKey = -1,
        SenderRecordIDKey = ID
    WHERE (senderID is null)
        OR (SenderRecordID is null)
/
commit work
/
UPDATE FACIALFINCAPTION
    SET SenderIDKey = SenderID,
        SenderRecordIDKey = SenderRecordID
    WHERE (SenderID is not null)
        AND (SenderRecordID is not null)
/
commit work
/
ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 ENABLE
/
ALTER TRIGGER TR_FACIALFINCAPTION_BU_500 ENABLE
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_210
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Create 28.04.2005
-- Last update 12.01.2009
-- - - - - - - - - - - - -

    /*  60 :  '   .'; source
        61 :  '      '; dest
        62 :  '   ';dest
        63 :  '    '; source
        64 :  '   '; source
        65 :  ' , ';dest
        66 :  '  ,  - '; source dest
        67 :  '   ';source
        68 :  '  \ ';dest
        69 :  '   \ '; dest
        70 :  '  \ ';source
        71 :  '   \ '; dest */

  /*ClsType*/
  if ((new$ClsType is NULL) and 
        ( 
          ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
          (new$ProgIndex = 60)
        )) then
    new$ClsType := 1; /*       ClsType */
  elsif ((new$ClsType is NULL) and (new$SourceKD <> 0) and
        (new$ProgIndex in (63,64,66,67,68,70))) then
    new$ClsType := 2; /*        ClsType */
  elsif (new$ClsType is null) then
    new$ClsType := 0; /*  -  */
  end if;  

  IF ((new$ClsType = 0) AND 
      (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
      (new$ProgIndex in (63,64,66,67,68,70)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 1) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 2) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  /*DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  end if;  

  IF ((new$DestClsType = 0) AND
      (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
      (new$ProgIndex in (61,62,65,69,71)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 1) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 2) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_200
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Create 28.04.2005
-- Last update 12.01.2009
-- - - - - - - - - - - - -

    /*  60 :  '   .'; source
        61 :  '      '; dest
        62 :  '   ';dest
        63 :  '    '; source
        64 :  '   '; source
        65 :  ' , ';dest
        66 :  '  ,  - '; source dest
        67 :  '   ';source
        68 :  '  \ ';dest
        69 :  '   \ '; dest
        70 :  '  \ ';source
        71 :  '   \ '; dest */

  /*ClsType*/
  if ((new$ClsType is NULL) and 
        ( 
          ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
          (new$ProgIndex = 60)
        )) then
    new$ClsType := 1; /*       ClsType */
  elsif ((new$ClsType is NULL) and (new$SourceKD <> 0) and
        (new$ProgIndex in (63,64,66,67,68,70))) then
    new$ClsType := 2; /*        ClsType */
  elsif (new$ClsType is null) then
    new$ClsType := 0; /*  -  */
  end if;  

  IF ((new$ClsType = 0) AND 
      (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
      (new$ProgIndex in (63,64,66,67,68,70)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 1) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 2) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  /*DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  end if;  

  IF ((new$DestClsType = 0) AND
      (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
      (new$ProgIndex in (61,62,65,69,71)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 1) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 2) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work
/
ALTER TABLE TB_FACIALFINDETAIL MODIFY(SenderIDKey NOT NULL)
/
ALTER TABLE TB_FACIALFINDETAIL MODIFY(SenderRecordIDKey NOT NULL)
/
ALTER TABLE TB_FACIALFINCAPTION MODIFY(SenderIDKey NOT NULL)
/
ALTER TABLE TB_FACIALFINCAPTION MODIFY(SenderRecordIDKey NOT NULL)
/

-- #########################################################
-- #########################################################
-- Alter_SignCertificate_Add_OwnerTitle.sql
-- #########################################################
-- #########################################################

ALTER TABLE SIGNCERTIFICATE ADD (
  OWNERTITLE VARCHAR2(255)
)
/
COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Alter_SignLog.sql
-- #########################################################
-- #########################################################

ALTER TRIGGER TR_SIGNLOG_BU_500 DISABLE
/
commit work
/
--   (SenderID, SenderRecordID)  (    (null, null))
CREATE TABLE signLogDuplicate(
  SenderID NUMBER(10),
    CHECK((SenderID<=2147483647)AND(SenderID>-2147483648)),
  SenderRecordID NUMBER(10),
    CHECK((SenderRecordID<=2147483647)AND(SenderRecordID>-2147483648))
)
/
CREATE INDEX ind_signLogDuplicate_sid ON signLogDuplicate(SenderID)
/
CREATE INDEX ind_signLogDuplicate_srid ON signLogDuplicate(SenderRecordID)
/
commit work
/
INSERT INTO signLogDuplicate
    SELECT SenderID, SenderRecordID FROM SignLog
        WHERE SenderID is not null and SenderRecordID is not null
        GROUP BY SenderID, SenderRecordID HAVING count(ID) > 1
/
commit work
/
UPDATE SignLog SET
  SenderID = NULL,
  SenderRecordID = NULL
WHERE
  EXISTS (SELECT SenderID
          FROM signLogDuplicate duplicate
          WHERE
            SignLog.SenderID = duplicate.SenderID AND
            SignLog.SEnderREcordId = duplicate.SenderRecordID)
/
commit work
/
DROP INDEX ind_signLogDuplicate_srid
/
DROP INDEX ind_signLogDuplicate_sid
/
DROP TABLE signLogDuplicate
/
commit work
/
--  (SenderID, SenderRecordID)     
ALTER TABLE SignLog ADD (
  SenderIDKey NUMBER(10),
    CHECK((SenderIDKey<=2147483647)AND(SenderIDKey>-2147483648)),
  SenderRecordIDKey NUMBER(10),
    CHECK((SenderRecordIDKey<=2147483647)AND(SenderRecordIDKey>-2147483648)),
  CONSTRAINT U_SignLog_Sender unique (SenderIDKey, SenderRecordIDKey)
)
/
commit work
/
-- CREATE TRIGGER tr_SignLog_bi_10
CREATE OR REPLACE TRIGGER TR_SIGNLOG_BI
  BEFORE INSERT
  ON SIGNLOG
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  ParamsID1$ NUMBER(10);
  CaptionID1$ NUMBER(10);
  CurSignOrder1$ NUMBER(10);
  CurrentMask1$ NUMBER(10);
  FullMask1$ NUMBER(10);
  IsStepEnd1$ NUMBER(10);
  IsSignEnd1$ NUMBER(10);
  SignMask1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_SIGNLOG_BI_0)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (:new.ID is null) then
    select g_shared.nextval into :new.ID from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_SignLog_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.SenderID is null) then
    :new.SenderIDKey := -1;
        
  else
    :new.SenderIDKey := :new.SenderID;
  END IF;
      
  if (:new.SenderRecordID is null) then
    :new.SenderRecordIDKey := :new.ID;
        
  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_SIGNLOG_BI_100)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(sp.id ) INTO CNT$1
  from SignParams sp where ((sp.DocID = :new.DocID)) AND (ROWNUM = 1);
  if (not(CNT$1<> 0)) then
    insert into SignParams(DocID, SignRef) values(:new.DocID, :new.SignRef);
  END IF;
  BEGIN

    select
    sp.id, ssd.SignOrder, ssd.RecordIndex, ssd.SignMask
    into
    ParamsID1$, CurSignOrder1$, CaptionID1$, SignMask1$   from
    SignParams sp
    left join SignSchemeDetail ssd on (ssd.id = :new.signref)
    where
    sp.DocID = :new.DocID
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

  select
  sum(ssd.SignMask)
  into
  CurrentMask1$   from
  SignLog sl
  left join SignSchemeDetail ssd on (ssd.id = sl.signref)
  where
  (sl.DocID = :new.DocID)and(ssd.SignOrder = CurSignOrder1$)
  ;
  if (CurrentMask1$  is null) then
    CurrentMask1$ := 0;
  END IF;

  select
  sum(ssd.SignMask)
  into
  FullMask1$   from
  SignSchemeDetail ssd
  where
  (ssd.SignOrder = CurSignOrder1$)and(ssd.RecordIndex = CaptionID1$)
  ;
  if (FullMask1$  = CurrentMask1$  + SignMask1$) then
    IsStepEnd1$ := 1;
      
  else
    IsStepEnd1$ := 0;
  END IF;

  IsSignEnd1$ := 0;
  if (IsStepEnd1$ = 1) then
    SELECT COUNT(ssd.id ) INTO CNT$2
    from SignSchemeDetail ssd where ((ssd.RecordIndex = CaptionID1$)and(ssd.SignOrder > CurSignOrder1$)) AND (ROWNUM = 1);
    if (not(CNT$2<> 0)) then
      IsSignEnd1$ := 1;
      
    END IF;
  END IF;
  update SignParams set
  SignRef = :new.SignRef,
  IsSignEnd = IsSignEnd1$,
  IsStepEnd = IsStepEnd1$,
  SignMask = CurrentMask1$  + SignMask1$

  where
  id = ParamsID1$;

-- - - - - - - - - - - - -
-- BI_500 (TR_SIGNLOG_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
commit work
/
UPDATE Signlog
    SET SenderIDKey = -1,
        SenderRecordIDKey = ID
    WHERE (senderID is null)
        OR (SenderRecordID is null)
/
commit work
/
UPDATE Signlog
    SET SenderIDKey = SenderID,
        SenderRecordIDKey = SenderRecordID
    WHERE (SenderIDKey is null)
        AND (SenderRecordIDKey is null)
/
commit work
/
ALTER TRIGGER TR_SIGNLOG_BU_500 ENABLE
/
commit work
/
ALTER TABLE SignLog MODIFY(SenderIDKey NOT NULL)
/
ALTER TABLE SignLog MODIFY(SenderRecordIDKey NOT NULL)
/

-- #########################################################
-- #########################################################
-- alter_tr_RemoteClient_bd.sql
-- #########################################################
-- #########################################################

/*      RemoteClient 
     ""  "  " */
-- ALTER TRIGGER tr_RemoteClient_bd
CREATE OR REPLACE TRIGGER TR_REMOTECLIENT_BD
  BEFORE DELETE
  ON REMOTECLIENT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (tr_remoteclient_bd)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  delete from RemoteReadRight
  where RemoteClient = :old.id;

  delete from RemoteInputRight
  where RemoteClient = :old.id;

  delete from RemoteClientAccount
  where RemoteClient = :old.id;

  delete from RemoteEDSRight
  where RemoteClient = :old.id;
      
  delete from SignCertificate
  where UserRef = :old.id;
      
  delete from SignDocumentsGroup
  where ClientRef = :old.id;    

  delete from RemoteMailClientMessages
  where RemoteClientRef = :old.id;    

END;
/
commit
/

-- #########################################################
-- #########################################################
-- Create_TR_TENDERPRODUCT_410.sql
-- #########################################################
-- #########################################################

INSERT INTO SqlExceptions(Name, Code, Text) VALUES ('EX_TEN_UNKNOWNLOT', -20357, '     :      .')
/
commit work
/
-- CREATE TRIGGER TR_TENDERPRODUCT_BI_410
CREATE OR REPLACE TRIGGER TR_TENDERPRODUCT_BI
  BEFORE INSERT
  ON TENDERPRODUCT
  FOR EACH ROW
DECLARE
  PosNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TENDERPRODUCT_BI)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.SubKESR is null) then 
    :new.SubKESR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.FinSourceCls is null) then 
    :new.FinSourceCls := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.TenderObjectCls is null) then 
    :new.TenderObjectCls := 0;
  END IF;
  if (:new.FactCls is null) then 
    :new.FactCls := 0;
  END IF;
  if (:new.OKATO is null) then 
    :new.OKATO := 0;
  END IF;
  if (:new.MeansTypeCls is null) then 
    :new.MeansTypeCls := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.AcceptPrice is null) then 
    :new.AcceptPrice := 0;
  END IF;
  if (:new.PriceVAT is null) then 
    :new.PriceVAT := 0;
  END IF;
  if (:new.AcceptAmount is null) then 
    :new.AcceptAmount := 0;
  END IF;
  if (:new.AcceptMonth01 is null) then 
    :new.AcceptMonth01 := 0;
  END IF;
  if (:new.AcceptMonth02 is null) then 
    :new.AcceptMonth02 := 0;
  END IF;
  if (:new.AcceptMonth03 is null) then 
    :new.AcceptMonth03 := 0;
  END IF;
  if (:new.AcceptMonth04 is null) then 
    :new.AcceptMonth04 := 0;
  END IF;
  if (:new.AcceptMonth05 is null) then 
    :new.AcceptMonth05 := 0;
  END IF;
  if (:new.AcceptMonth06 is null) then 
    :new.AcceptMonth06 := 0;
  END IF;
  if (:new.AcceptMonth07 is null) then 
    :new.AcceptMonth07 := 0;
  END IF;
  if (:new.AcceptMonth08 is null) then 
    :new.AcceptMonth08 := 0;
  END IF;
  if (:new.AcceptMonth09 is null) then 
    :new.AcceptMonth09 := 0;
  END IF;
  if (:new.AcceptMonth10 is null) then 
    :new.AcceptMonth10 := 0;
  END IF;
  if (:new.AcceptMonth11 is null) then 
    :new.AcceptMonth11 := 0;
  END IF;
  if (:new.AcceptMonth12 is null) then 
    :new.AcceptMonth12 := 0;
  END IF;
  if (:new.AcceptQuarter1 is null) then 
    :new.AcceptQuarter1 := 0;
  END IF;
  if (:new.AcceptQuarter2 is null) then 
    :new.AcceptQuarter2 := 0;
  END IF;
  if (:new.AcceptQuarter3 is null) then 
    :new.AcceptQuarter3 := 0;
  END IF;
  if (:new.AcceptQuarter4 is null) then 
    :new.AcceptQuarter4 := 0;
  END IF;
  if (:new.AcceptSumma is null) then 
    :new.AcceptSumma := 0;
  END IF;
  if (:new.DeliverySpec is null) then 
    :new.DeliverySpec := 0;
  END IF;
  if (:new.DeliveryPeriod is null) then 
    :new.DeliveryPeriod := 0;
  END IF;
  if (:new.DeliveryAmount is null) then 
    :new.DeliveryAmount := 0;
  END IF;
  if (:new.VatPercent is null) then 
    :new.VatPercent := 0;
  END IF;
  if (:new.AcceptVatSumma is null) then 
    :new.AcceptVatSumma := 0;
  END IF;
  if (:new.AcceptCost is null) then 
    :new.AcceptCost := 0;
  END IF;
  if (:new.AcceptTotalSumma is null) then 
    :new.AcceptTotalSumma := 0;
  END IF;
  if (:new.Equivalent is null) then 
    :new.Equivalent := 0;
  END IF;
  if (:new.SummaYear2 is null) then 
    :new.SummaYear2 := 0;
  END IF;
  if (:new.SummaYear3 is null) then 
    :new.SummaYear3 := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_TENDERPRODUCT_BI_10)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

    /*   1.2 */
   IF (:NEW.FacialAccCls IS NULL) THEN :NEW.FacialAccCls := 0; END IF;

   /*  .  ,     */
   IF ((:NEW.BudgetRef IS NULL) OR (:NEW.BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO :NEW.BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = :NEW.FacialAccCls;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            :NEW.BudgetRef := NULL;
      END;
   END IF;

   /*  ,    */
   IF ((:NEW.BudgetRef IS NULL) OR (:NEW.BudgetRef = 0)) THEN
      GetIntConst (-1, 3, :NEW.BudgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_TENDERPRODUCT_BI_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.PositionNumber is null) then
    select Max(PositionNumber)     INTO PosNumber$ from TenderProduct
    where (RecordIndex = :new.RecordIndex) and (ProgIndex = :new.ProgIndex) 
    ;
    if (PosNumber$ is null) then 
      PosNumber$ := 0;
    END IF;
    :new.PositionNumber := PosNumber$ + 1;
      
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_TENDERPRODUCT_BI_40)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (:new.senderId is null) then 
    :new.senderIdKey := -1;
      
  else 
    :new.senderIdKey := :new.senderId;
  END IF;
  if (:new.SenderRecordID is null) then
    :new.SenderRecordIDKey := :new.ID;
      
  else 
    :new.SenderRecordIDKey := :new.SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_410 (TR_TENDERPRODUCT_BI_410)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  FOR REC$1 IN (SELECT tl.ID  AS lotref FROM TenderLot tl WHERE (tl.ID = :new.LotRef) AND (tl.RecordIndex = :new.RecordIndex)   )
  LOOP
    if (not ((REC$1.lotref  = :new.LotRef) or (:new.lotref is null))) then
      RaiseException('EX_TEN_UNKNOWNLOT');  
    END IF;
  END LOOP;

-- - - - - - - - - - - - -
-- BI_500 (TR_TENDERPRODUCT_BI_500)
-- Last update 18.04.2006
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
commit work
/
-- CREATE TRIGGER TR_TENDERPRODUCT_BU_410
CREATE OR REPLACE TRIGGER TR_TENDERPRODUCT_BU
  BEFORE UPDATE
  ON TENDERPRODUCT
  FOR EACH ROW
DECLARE
  PosNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERPRODUCT_BU_0)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.FacialAccCls is null) then 
    :new.FacialAccCls := 0;
  END IF;
  if (:new.SubKESR is null) then 
    :new.SubKESR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.FinSourceCls is null) then 
    :new.FinSourceCls := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.TenderObjectCls is null) then 
    :new.TenderObjectCls := 0;
  END IF;
  if (:new.FactCls is null) then 
    :new.FactCls := 0;
  END IF;
  if (:new.OKATO is null) then 
    :new.OKATO := 0;
  END IF;
  if (:new.MeansTypeCls is null) then 
    :new.MeansTypeCls := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.AcceptPrice is null) then 
    :new.AcceptPrice := 0;
  END IF;
  if (:new.PriceVAT is null) then 
    :new.PriceVAT := 0;
  END IF;
  if (:new.AcceptAmount is null) then 
    :new.AcceptAmount := 0;
  END IF;
  if (:new.AcceptMonth01 is null) then 
    :new.AcceptMonth01 := 0;
  END IF;
  if (:new.AcceptMonth02 is null) then 
    :new.AcceptMonth02 := 0;
  END IF;
  if (:new.AcceptMonth03 is null) then 
    :new.AcceptMonth03 := 0;
  END IF;
  if (:new.AcceptMonth04 is null) then 
    :new.AcceptMonth04 := 0;
  END IF;
  if (:new.AcceptMonth05 is null) then 
    :new.AcceptMonth05 := 0;
  END IF;
  if (:new.AcceptMonth06 is null) then 
    :new.AcceptMonth06 := 0;
  END IF;
  if (:new.AcceptMonth07 is null) then 
    :new.AcceptMonth07 := 0;
  END IF;
  if (:new.AcceptMonth08 is null) then 
    :new.AcceptMonth08 := 0;
  END IF;
  if (:new.AcceptMonth09 is null) then 
    :new.AcceptMonth09 := 0;
  END IF;
  if (:new.AcceptMonth10 is null) then 
    :new.AcceptMonth10 := 0;
  END IF;
  if (:new.AcceptMonth11 is null) then 
    :new.AcceptMonth11 := 0;
  END IF;
  if (:new.AcceptMonth12 is null) then 
    :new.AcceptMonth12 := 0;
  END IF;
  if (:new.AcceptQuarter1 is null) then 
    :new.AcceptQuarter1 := 0;
  END IF;
  if (:new.AcceptQuarter2 is null) then 
    :new.AcceptQuarter2 := 0;
  END IF;
  if (:new.AcceptQuarter3 is null) then 
    :new.AcceptQuarter3 := 0;
  END IF;
  if (:new.AcceptQuarter4 is null) then 
    :new.AcceptQuarter4 := 0;
  END IF;
  if (:new.AcceptSumma is null) then 
    :new.AcceptSumma := 0;
  END IF;
  if (:new.DeliverySpec is null) then 
    :new.DeliverySpec := 0;
  END IF;
  if (:new.DeliveryPeriod is null) then 
    :new.DeliveryPeriod := 0;
  END IF;
  if (:new.DeliveryAmount is null) then 
    :new.DeliveryAmount := 0;
  END IF;
  if (:new.VatPercent is null) then 
    :new.VatPercent := 0;
  END IF;
  if (:new.AcceptVatSumma is null) then 
    :new.AcceptVatSumma := 0;
  END IF;
  if (:new.AcceptCost is null) then 
    :new.AcceptCost := 0;
  END IF;
  if (:new.AcceptTotalSumma is null) then 
    :new.AcceptTotalSumma := 0;
  END IF;
  if (:new.Equivalent is null) then 
    :new.Equivalent := 0;    
  END IF;
  if (:new.SummaYear2 is null) then 
    :new.SummaYear2 := 0;
  END IF;
  if (:new.SummaYear3 is null) then 
    :new.SummaYear3 := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_TENDERPRODUCT_BU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.PositionNumber is null) then
    select Max(PositionNumber)     INTO PosNumber$ from TenderProduct
    where (RecordIndex = :new.RecordIndex) and (ProgIndex = :new.ProgIndex) 
    ;
    if (PosNumber$ is null) then 
      PosNumber$ := 0;
    END IF;
    :new.PositionNumber := PosNumber$ + 1;
      
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_TenderProduct_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.RecordIndex <> :old.RecordIndex) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_410 (TR_TENDERPRODUCT_BU_410)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  FOR REC$1 IN (SELECT tl.ID  AS lotref FROM TenderLot tl WHERE (tl.ID = :new.LotRef) AND (tl.RecordIndex = :new.RecordIndex)   )
  LOOP
    if (not ((REC$1.lotref  = :new.LotRef) or (:new.lotref is null))) then
      RaiseException('EX_TEN_UNKNOWNLOT');  
    END IF;
  END LOOP;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERPRODUCT_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

  if (:New.RVersion is null) then
    :New.RVersion := 1;
  elsif ((:New.RVersion = -1) and (:Old.RVersion <> -1)) then
    :New.RVersion := :Old.RVersion;
  else
    :New.RVersion := :Old.RVersion + 1;
  end if;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Fix_trPromise_DetailAU30.sql
-- #########################################################
-- #########################################################

/* 
           .
          .
*/
-- CREATE TRIGGER TR_PROMISE_DETAIL_AU_30
CREATE OR REPLACE TRIGGER TR_PROMISE_DETAIL_IU
  INSTEAD OF UPDATE
  ON PROMISE_DETAIL
  FOR EACH ROW
DECLARE
  new$ID PROMISE_DETAIL.ID%TYPE := :NEW.ID;
  new$TITLE_REF PROMISE_DETAIL.TITLE_REF%TYPE := :NEW.TITLE_REF;
  new$PARENT_PROMISE PROMISE_DETAIL.PARENT_PROMISE%TYPE := :NEW.PARENT_PROMISE;
  new$KFSR PROMISE_DETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KVSR PROMISE_DETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PROMISE_DETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR PROMISE_DETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR PROMISE_DETAIL.KESR%TYPE := :NEW.KESR;
  new$FACT PROMISE_DETAIL.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PROMISE_DETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$DOCTYPE PROMISE_DETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$FINTYPE PROMISE_DETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FINSOURCE PROMISE_DETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$SUBKESR PROMISE_DETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$REGIONCLS PROMISE_DETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$SUMMA PROMISE_DETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$REGISTRNUMBER PROMISE_DETAIL.REGISTRNUMBER%TYPE := :NEW.REGISTRNUMBER;
  new$CLOSEDATE PROMISE_DETAIL.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHILD_PROMISE PROMISE_DETAIL.CHILD_PROMISE%TYPE := :NEW.CHILD_PROMISE;
  new$MONTH01 PROMISE_DETAIL.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PROMISE_DETAIL.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PROMISE_DETAIL.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PROMISE_DETAIL.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PROMISE_DETAIL.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PROMISE_DETAIL.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PROMISE_DETAIL.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PROMISE_DETAIL.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PROMISE_DETAIL.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PROMISE_DETAIL.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PROMISE_DETAIL.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PROMISE_DETAIL.MONTH12%TYPE := :NEW.MONTH12;
  new$BUDGETREF PROMISE_DETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER PROMISE_DETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PROMISE_DETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PROMISE_DETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PROMISE_DETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$MEANSTYPE PROMISE_DETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$SENDERID PROMISE_DETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PROMISE_DETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION PROMISE_DETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$DIRECTIONCLS PROMISE_DETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$BUHOPERATIONCLS PROMISE_DETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PROMISE_DETAIL.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PROMISE_DETAIL.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PROMISE_DETAIL.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PROMISE_DETAIL.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PROMISE_DETAIL.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PROMISE_DETAIL.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PROMISE_DETAIL.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PROMISE_DETAIL.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PROMISE_DETAIL.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PROMISE_DETAIL.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PROMISE_DETAIL.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PROMISE_DETAIL.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$STIMATEID PROMISE_DETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$SUMMAYEAR1 PROMISE_DETAIL.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PROMISE_DETAIL.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PROMISE_DETAIL.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PROMISE_DETAIL.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PROMISE_DETAIL.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PROMISE_DETAIL.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PROMISE_DETAIL.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PROMISE_DETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS PROMISE_DETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS PROMISE_DETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PROMISE_DETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
--
  CNT$ NUMBER(10);
  Parent_Promise$ tb_promise_detail.Parent_Promise%TYPE;
  Temp$ tb_promise_detail.Parent_Promise%TYPE;
  BudgetRef$ NUMBER(10);
  CNT$1 NUMBER(10);
  Promise_Count$ NUMBER(10);
  PayDoc_Count$ NUMBER(10);
  ParentDate1$ NUMBER(10);
  Accept_Revert1$ NUMBER(10);
  ChildNum$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PROMISE_DETAIL_BU)
-- Last update 07.12.2005
-- - - - - - - - - - - - -

   /*      */
   IF     (NEW$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((NEW$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

   IF (new$KFSR IS NULL) THEN new$KFSR := 0; END IF;
   IF (new$KVSR IS NULL) THEN new$KVSR := 0; END IF;
   IF (new$KCSR IS NULL) THEN new$KCSR := 0; END IF;
   IF (new$KVR IS NULL) THEN new$KVR := 0; END IF;
   IF (new$KESR IS NULL) THEN new$KESR := 0; END IF;
   IF (new$SubKESR IS NULL) THEN new$SubKESR := 0; END IF;
   IF (new$DirectionCls IS NULL) THEN new$DirectionCls := 0; END IF;
   IF (new$FacialAcc_Cls IS NULL) THEN new$FacialAcc_Cls := 0; END IF;
   IF (new$DocType IS NULL) THEN new$DocType := 0; END IF;
   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;
   IF (new$FinType IS NULL) THEN new$FinType := 0; END IF;
   IF (new$FinSource IS NULL) THEN new$FinSource := 0; END IF;
   IF (new$Fact IS NULL) THEN new$Fact := 0; END IF;
   IF (new$RegionCls IS NULL) THEN new$RegionCls := 0; END IF;
   IF (new$BuhOperationCLS IS NULL) THEN
     GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;
   IF (new$Month01Delta IS NULL) THEN new$Month01Delta := 0; END IF;
   IF (new$Month02Delta IS NULL) THEN new$Month02Delta := 0; END IF;
   IF (new$Month03Delta IS NULL) THEN new$Month03Delta := 0; END IF;
   IF (new$Month04Delta IS NULL) THEN new$Month04Delta := 0; END IF;
   IF (new$Month05Delta IS NULL) THEN new$Month05Delta := 0; END IF;
   IF (new$Month06Delta IS NULL) THEN new$Month06Delta := 0; END IF;
   IF (new$Month07Delta IS NULL) THEN new$Month07Delta := 0; END IF;
   IF (new$Month08Delta IS NULL) THEN new$Month08Delta := 0; END IF;
   IF (new$Month09Delta IS NULL) THEN new$Month09Delta := 0; END IF;
   IF (new$Month10Delta IS NULL) THEN new$Month10Delta := 0; END IF;
   IF (new$Month11Delta IS NULL) THEN new$Month11Delta := 0; END IF;
   IF (new$Month12Delta IS NULL) THEN new$Month12Delta := 0; END IF;
   IF (new$Month01 IS NULL) THEN new$Month01 := 0; END IF;
   IF (new$Month02 IS NULL) THEN new$Month02 := 0; END IF;
   IF (new$Month03 IS NULL) THEN new$Month03 := 0; END IF;
   IF (new$Month04 IS NULL) THEN new$Month04 := 0; END IF;
   IF (new$Month05 IS NULL) THEN new$Month05 := 0; END IF;
   IF (new$Month06 IS NULL) THEN new$Month06 := 0; END IF;
   IF (new$Month07 IS NULL) THEN new$Month07 := 0; END IF;
   IF (new$Month08 IS NULL) THEN new$Month08 := 0; END IF;
   IF (new$Month09 IS NULL) THEN new$Month09 := 0; END IF;
   IF (new$Month10 IS NULL) THEN new$Month10 := 0; END IF;
   IF (new$Month11 IS NULL) THEN new$Month11 := 0; END IF;
   IF (new$Month12 IS NULL) THEN new$Month12 := 0; END IF;
   IF (new$Summa IS NULL) THEN new$Summa := 0; END IF;

   new$SummaYear1 := new$Month01+new$Month02+new$Month03+new$Month04+new$Month05+new$Month06+
                  new$Month07+new$Month08+new$Month09+new$Month10+new$Month11+new$Month12; 
   IF (NEW$SummaYear2 IS NULL) THEN NEW$SummaYear2 := 0; END IF;
   IF (NEW$SummaYear3 IS NULL) THEN NEW$SummaYear3 := 0; END IF;

   /*       */
   IF new$RegistrNumber = :OLD.RegistrNumber THEN
      NULL;
   ELSE
      SELECT COUNT (ID)
        INTO CNT$
        FROM promise_detail
       WHERE (BudgetRef = new$BudgetRef)
         AND (RegistrNumber = new$RegistrNumber) AND (ROWNUM = 1);

      IF ((new$RegistrNumber IS NOT NULL) AND (CNT$ <> 0)) THEN
         RaiseException ('EX_PROMISE_NUMUQ');
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_PROMISE_DETAIL_BU_10)
-- Last update 03.07.2006
-- - - - - - - - - - - - -

  /*   ,         */
  if (((new$Parent_Promise is not null) and (:old.Parent_Promise is null)) or
      (new$Parent_Promise <> :old.Parent_Promise)) then

    select count(*) into CNT$ from  Promise_Detail pd  left join Promise_Caption pc
    on (pc.ID = pd.Title_Ref) where
     ((pd.Parent_Promise = new$Parent_Promise)
          and
     (pd.budgetref = new$budgetref)
          and
      /*   */
     (pc.ACCEPTED_REVERTED = 0)
          and
     /*   */
     (pd.ID <> :old.ID)) AND (ROWNUM = 1);

    if (CNT$ <> 0) then
      RaiseException('ex_promise_DeadLock');
    end if;

    Parent_Promise$ := new$Parent_Promise;
    budgetref$ := new$budgetref;
    /*            
              */
    while ((Parent_Promise$ is not null) and
           (new$RegistrNumber <> Parent_Promise$))
    LOOP
      Temp$ := Parent_Promise$;
      /*    ..   ,  into   
        :Parent_Promise*/
      Parent_Promise$ := null;
      BEGIN
        select Parent_Promise into Parent_Promise$
        from Promise_Detail
        where (RegistrNumber = Temp$) and (budgetref = budgetref$);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
           Parent_Promise$ := NULL;
      END;
    end LOOP;
    if (new$RegistrNumber = Parent_Promise$) then
      RaiseException('EX_Promise_Detail_CHECK_NUM');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_PROMISE_DETAIL_BU_20)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   -- :      
   IF (    (new$RegistrNumber IS NOT NULL)
       AND (new$RegistrNumber = new$Parent_Promise)
      ) THEN
      RaiseException ('EX_PROMISE_DETAIL_CHECK_NUM');
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_PROMISE_DETAIL_BU_100)
-- Create 29.04.2005
-- Last update 03.07.2006
-- - - - - - - - - - - - -

  select count(*)
  into cnt$
  from promise_detail prd where (prd.registrnumber=new$parent_promise) and (prd.budgetref = new$budgetref) AND (ROWNUM = 1);

  if (not (new$parent_promise is null) and (cnt$ > 0))
  then promise_delta(new$budgetref,new$parent_promise,new$month01,new$month02,
    new$month03,new$month04,new$month05,new$month06,new$month07,new$month08,new$month09,
    new$month10,new$month11,new$month12,
    new$summayear1,new$summayear2,new$summayear3,
    new$month01delta,new$month02delta,new$month03delta,new$month04delta,
    new$month05delta,new$month06delta,new$month07delta,new$month08delta,new$month09delta,
    new$month10delta,new$month11delta,new$month12delta,
    new$summayear1delta, new$summayear2delta, new$summayear3delta);
  end if;

  /*     */
  if (new$Parent_Promise is null) then
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
  end if;

-- - - - - - - - - - - - -
-- BU_510 (TR_PROMISE_DETAIL_BU_510)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(pd.REGISTRNUMBER
  ) INTO CNT$1
  from promise_detail pd
  where ((pd.REGISTRNUMBER = new$Parent_promise)
  and
  (pd.budgetref = new$budgetref)
  ) AND (ROWNUM = 1)     ;
  if (not(new$Parent_promise is null) and (not(CNT$1<> 0))) then
    RaiseException('EX_NOTFINDPARENTPROMISE');
  END IF;
  /*     , ,     */
  if (((new$RegistrNumber is null) and (:old.RegistrNumber is not null)) or
  (:old.RegistrNumber <> new$RegistrNumber)) then
    if (:old.registrnumber is not null) then
      select count(pd.Parent_Promise)
      into Promise_Count$         from Promise_Detail pd
      where (:old.RegistrNumber = pd.Parent_Promise) and (:old.budgetref = pd.budgetref)
      ;
      /*   ,  .*/
      if (Promise_Count$ > 0) then
        RaiseException('EX_CANTCHANGEBONUMBER');      
      END IF;
    END IF;
    /*    ,     */
    if (:old.registrnumber is not null) then
      select count(ffd.id)
      into PayDoc_Count$         from FacialFinDetail ffd
      where (((ffd.sourcepromise = :old.registrnumber) or (ffd.destpromise = :old.registrnumber)) and (ffd.budgetref = :old.budgetref))
      ;
      /*   ,  .*/
      if (PayDoc_Count$ > 0) then
        RaiseException('EX_Promise_ExPayDoc');      
      END IF;   
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PROMISE_DETAIL_BU_700)
-- Create 17.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PROMISE_DETAIL SET
    ID = new$ID,
    TITLE_REF = new$TITLE_REF,
    PARENT_PROMISE = new$PARENT_PROMISE,
    KFSR = new$KFSR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    FACT = new$FACT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    DOCTYPE = new$DOCTYPE,
    FINTYPE = new$FINTYPE,
    FINSOURCE = new$FINSOURCE,
    SUBKESR = new$SUBKESR,
    REGIONCLS = new$REGIONCLS,
    SUMMA = new$SUMMA,
    REGISTRNUMBER = new$REGISTRNUMBER,
    CLOSEDATE = new$CLOSEDATE,
    CHILD_PROMISE = new$CHILD_PROMISE,
    MONTH01 = new$MONTH01,
    MONTH02 = new$MONTH02,
    MONTH03 = new$MONTH03,
    MONTH04 = new$MONTH04,
    MONTH05 = new$MONTH05,
    MONTH06 = new$MONTH06,
    MONTH07 = new$MONTH07,
    MONTH08 = new$MONTH08,
    MONTH09 = new$MONTH09,
    MONTH10 = new$MONTH10,
    MONTH11 = new$MONTH11,
    MONTH12 = new$MONTH12,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    MEANSTYPE = new$MEANSTYPE,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    RVERSION = new$RVERSION,
    DIRECTIONCLS = new$DIRECTIONCLS,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MONTH01DELTA = new$MONTH01DELTA,
    MONTH02DELTA = new$MONTH02DELTA,
    MONTH03DELTA = new$MONTH03DELTA,
    MONTH04DELTA = new$MONTH04DELTA,
    MONTH05DELTA = new$MONTH05DELTA,
    MONTH06DELTA = new$MONTH06DELTA,
    MONTH07DELTA = new$MONTH07DELTA,
    MONTH08DELTA = new$MONTH08DELTA,
    MONTH09DELTA = new$MONTH09DELTA,
    MONTH10DELTA = new$MONTH10DELTA,
    MONTH11DELTA = new$MONTH11DELTA,
    MONTH12DELTA = new$MONTH12DELTA,
    STIMATEID = new$STIMATEID,
    SUMMAYEAR1 = new$SUMMAYEAR1,
    SUMMAYEAR2 = new$SUMMAYEAR2,
    SUMMAYEAR3 = new$SUMMAYEAR3,
    SUMMAYEAR1DELTA = new$SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA = new$SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA = new$SUMMAYEAR3DELTA,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_PROMISE_DETAIL_AU_30)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*        ,    */
  if (((new$Parent_Promise is null) and (:old.Parent_Promise is not null)) or
  (:old.Parent_Promise <> new$Parent_Promise)) then 
    update Promise_Detail set
    Child_Promise = null,
    CloseDate = null
    where
    (Child_Promise = :old.RegistrNumber) and
    (BudgetRef = :old.budgetref);
      
  END IF;
      
  /*    ,      ,        */
  if ((new$RegistrNumber is null) and (:old.RegistrNumber is not null)) then 
    update Promise_Detail set
    Child_Promise = null
    where
    (RegistrNumber = :old.Parent_Promise) and
    (budgetref = :old.budgetref);
      
  END IF;
      
  /*  ,       */
  if ((((new$Parent_Promise is not null) and  (:old.Parent_Promise is null)) or (:old.Parent_Promise <> new$Parent_Promise)) or
  (((new$RegistrNumber is not null) and  (:old.RegistrNumber is null)) or (:old.RegistrNumber <> new$RegistrNumber))) then
    BEGIN
      select AcceptDate, Accepted_Reverted
      into ParentDate1$, Accept_Revert1$     from Promise_Caption
      where (id = new$Title_Ref)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
        
    /*   ,      */
    if (Accept_Revert1$ = 1) then
      ParentDate1$ := null;
    END IF;
        
    ChildNum$ := new$RegistrNumber;
    if (ParentDate1$ is null) then
      ChildNum$ := null;
    END IF;

    /*           */
    update Promise_Detail set
    Child_Promise = ChildNum$,
    CloseDate = ParentDate1$

    where
    (RegistrNumber = new$Parent_Promise) and
    (BudgetRef = new$BudgetRef);
      
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PROMISE_DETAIL_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (76, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 76) AND (RecordId = new$ID);
   END IF;

END;
/

COMMIT WORK 
/

-- #########################################################
-- #########################################################
-- ProtocolReason8187.sql
-- #########################################################
-- #########################################################

/* ***************************************
  ''
****************************************/
CREATE OR REPLACE procedure AddProtocolReason(ID$ NUMBER,Name$ VARCHAR2)
AS
  CNT$1 NUMBER(10);
BEGIN
  SELECT COUNT(id ) INTO CNT$1
  from ProtocolReason where (id = ID$) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    update ProtocolReason set Name = Name$  where id = ID$;
      
  else
    insert into ProtocolReason(ID, Name) values (ID$, Name$);
  END IF;
END;
/
-- ALTER TRIGGER TR_ProtocolReason_BI
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BI
  BEFORE INSERT
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ProtocolReason_BI)
-- Create 27.10.2009
-- - - - - - - - - - - - -
  NULL;
--   RaiseException('EX_PR_BanInsert');

-- - - - - - - - - - - - -
-- BI_500 (TR_PROTOCOLREASON_BI_500)
-- Create 20.05.2009
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;    

END;
/
-- ALTER TRIGGER TR_ProtocolReason_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BU
  BEFORE UPDATE
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolReason_BU)
-- Create 27.10.2009
-- - - - - - - - - - - - -
  NULL;
--   RaiseException('EX_PR_BanUpdate');

END;
/
CALL AddProtocolReason(81, '. 83 . 2 . 2 44-  05.04.2013.')
/
CALL AddProtocolReason(82, '. 83 . 2 . 3 44-  05.04.2013.')
/
CALL AddProtocolReason(83, '. 83 . 2 . 6 44-  05.04.2013.')
/
CALL AddProtocolReason(84, '. 83 . 2 . 7 44-  05.04.2013.')
/
CALL AddProtocolReason(85, '. 83 . 2 . 8 44-  05.04.2013.')
/
CALL AddProtocolReason(86, '. 83 . 2 . 9 44-  05.04.2013.')
/
CALL AddProtocolReason(87, '. 83 . 2 . 10 44-  05.04.2013.')
/
-- ALTER TRIGGER TR_ProtocolReason_BI
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BI
  BEFORE INSERT
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ProtocolReason_BI)
-- Create 27.10.2009
-- - - - - - - - - - - - -

  RaiseException('EX_PR_BanInsert');

-- - - - - - - - - - - - -
-- BI_500 (TR_PROTOCOLREASON_BI_500)
-- Create 20.05.2009
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;    

END;
/
-- ALTER TRIGGER TR_ProtocolReason_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLREASON_BU
  BEFORE UPDATE
  ON PROTOCOLREASON
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolReason_BU)
-- Create 27.10.2009
-- - - - - - - - - - - - -

  RaiseException('EX_PR_BanUpdate');

END;
/
drop procedure AddProtocolReason
/
commit work
/

-- #########################################################
-- #########################################################
-- Add_Reg_Keys.sql
-- #########################################################
-- #########################################################

/*     RegUsers   ,   .  IP.
           .
*/
-- drop trigger TR_REGUSERS_BI_500
CREATE OR REPLACE TRIGGER TR_REGUSERS_BI
  BEFORE INSERT
  ON REGUSERS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_REGUSERS_BI)
-- - - - - - - - - - - - -

  if (:new.ID is null) then
    select g_Shared.NextVal into :new.ID from dual;
  end if;
  :new.DateBegin := SYSDATE;
  :new.DBUserName := USER;

END;
/
commit work 
/
/*        ,    */
ALTER TABLE RegUsers DROP (CreateDate)
/
ALTER TABLE RegUsers DROP (CreaterUser)
/
commit work 
/
-- drop trigger TR_REG_JOURNAL_BI_500
CREATE OR REPLACE TRIGGER TR_REG_JOURNAL_BI
  BEFORE INSERT
  ON REG_JOURNAL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_REG_JOURNAL_BI)
-- Create 06.10.2009
-- - - - - - - - - - - - -

  if (:new.id is null) then
    select g_shared.NextVal into :new.id from DUAL;
  end if;

  if (:new.DateBegin is null) then
    :new.DateBegin := SYSDATE;
  end if;  

END;
/
commit work 
/
/*   ,             (  ) */
ALTER TABLE REG_JOURNAL DROP (CreateDate)
/
ALTER TABLE REG_JOURNAL DROP (CreaterUser)
/
commit work 
/
ALTER TABLE RegUsers ADD (
  ProcPID NUMBER(10),/* PID  */
    CHECK((ProcPID<=2147483647)AND(ProcPID>-2147483648)),
  ProcName VARCHAR2(50),/*   ( )*/
  ProcVer VARCHAR2(20),/*  ( )*/
  NetIP VARCHAR2(20)/*    */
)
/
commit work 
/

-- #########################################################
-- #########################################################
-- alter_adm_add_autorization.sql
-- #########################################################
-- #########################################################

/*      "" */
ALTER TABLE DBGroups ADD (
  CreaterUser VARCHAR2(30),
  UpdaterUser VARCHAR2(30)
)
/
ALTER TABLE TB_DBUsers ADD (
  CreaterUser VARCHAR2(30),
  UpdaterUser VARCHAR2(30)
)
/

CREATE OR REPLACE VIEW DBUsers (
  ID,
  USERNAME,
  FIRSTNAME,
  MIDDLENAME,
  LASTNAME,
  NOTE,
  PHONE,
  DESCRIPTION,
  DEPARTMENTCLS,
  REMOTECLIENTREF,
  REMOTEID,
  CREATEDATE,
  UPDATEDATE,
  CRYPTOPARAMS,
  CRYPTOID,
  ORG_REF,
  NOTE2,
  EMAILADDRESS,
  PRINCIPALNAME,
  USERGUID,
  CREATERUSER,
  UPDATERUSER)
AS
  SELECT
    ID,
    USERNAME,
    FIRSTNAME,
    MIDDLENAME,
    LASTNAME,
    NOTE,
    PHONE,
    DESCRIPTION,
    DEPARTMENTCLS,
    REMOTECLIENTREF,
    REMOTEID,
    CREATEDATE,
    UPDATEDATE,
    CRYPTOPARAMS,
    CRYPTOID,
    ORG_REF,
    NOTE2,
    EMAILADDRESS,
    PRINCIPALNAME,
    USERGUID,
    CREATERUSER,
    UPDATERUSER
  FROM TB_DBUsers
/

CREATE OR REPLACE TRIGGER TR_DBUSERS_ID
  INSTEAD OF DELETE
  ON DBUSERS
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DBUSERS_BD)
-- - - - - - - - - - - - -

        --    SYSDBA
        if (:old.id = 0) then
                RaiseException('EX_CANTDELETETHIS');
        end if;

-- - - - - - - - - - - - -
-- BD_1 (TR_DBUSERS_BD_1)
-- - - - - - - - - - - - -

/*     */
        delete from User_Workplaces     where Users_ref = :old.id;
    delete from ReportsPermissions where Userid = :old.id;
    delete from UsersInGroups  where UserRef = :old.id;
    delete from UsersRights  where UserRef = :old.id;
    delete from DualRights  where (UserRef = :old.id) and (IsGroup = 0);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_DBUSERS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_DBUSERS_AD_10)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*    RemoteClients  DBUsers */  
  if (:old.RemoteClientRef is not null) then
    SELECT COUNT(dbu.ID ) INTO CNT$1
    from DBUsers dbu where (dbu.RemoteClientRef = :old.RemoteClientRef) AND (ROWNUM = 1);
    /*     DBUsers     RemoteClient,   ,     */
    if (not (CNT$1<> 0)) then
      delete from RemoteClient where ID = :old.RemoteClientRef;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_DBUSERS_AD_500)
-- - - - - - - - - - - - -

/*      */
  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
       values(100,:old.ID, sysdate);

END;
/

CREATE OR REPLACE TRIGGER TR_DBUSERS_II
  INSTEAD OF INSERT
  ON DBUSERS
  FOR EACH ROW
DECLARE
  new$ID DBUSERS.ID%TYPE := :NEW.ID;
  new$USERNAME DBUSERS.USERNAME%TYPE := :NEW.USERNAME;
  new$FIRSTNAME DBUSERS.FIRSTNAME%TYPE := :NEW.FIRSTNAME;
  new$MIDDLENAME DBUSERS.MIDDLENAME%TYPE := :NEW.MIDDLENAME;
  new$LASTNAME DBUSERS.LASTNAME%TYPE := :NEW.LASTNAME;
  new$NOTE DBUSERS.NOTE%TYPE := :NEW.NOTE;
  new$PHONE DBUSERS.PHONE%TYPE := :NEW.PHONE;
  new$DESCRIPTION DBUSERS.DESCRIPTION%TYPE := :NEW.DESCRIPTION;
  new$DEPARTMENTCLS DBUSERS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$REMOTECLIENTREF DBUSERS.REMOTECLIENTREF%TYPE := :NEW.REMOTECLIENTREF;
  new$REMOTEID DBUSERS.REMOTEID%TYPE := :NEW.REMOTEID;
  new$CREATEDATE DBUSERS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE DBUSERS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CRYPTOPARAMS DBUSERS.CRYPTOPARAMS%TYPE := :NEW.CRYPTOPARAMS;
  new$CRYPTOID DBUSERS.CRYPTOID%TYPE := :NEW.CRYPTOID;
  new$ORG_REF DBUSERS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$NOTE2 DBUSERS.NOTE2%TYPE := :NEW.NOTE2;
  new$EMAILADDRESS DBUSERS.EMAILADDRESS%TYPE := :NEW.EMAILADDRESS;
  new$PRINCIPALNAME DBUSERS.PRINCIPALNAME%TYPE := :NEW.PRINCIPALNAME;
  new$USERGUID DBUSERS.USERGUID%TYPE := :NEW.USERGUID;
  new$CREATERUSER DBUSERS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER DBUSERS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
--
  cGroupID$ NUMBER(10);
  acc1$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_DBUSERS_BI)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  new$UserName := Upper(new$UserName);
  if (new$RemoteClientRef is null) then 
    new$RemoteID := -1;
     
  else 
    new$RemoteID := new$RemoteClientRef;
  END IF;
  if (new$Org_Ref is null) then
    GetIntConst(-1, 2,acc1$);
    BEGIN
      select
      o.id
      into
      new$Org_Ref    from
      organizations o
      left join org_accounts oa on (oa.org_ref = o.id)
      where
      (oa.id = acc1$)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Org_Ref is null) then
      new$Org_Ref := 0;
     
    END IF;
  END IF;
  if (new$RemoteClientRef is not null) then
    new$PrincipalName := null;
  END IF;
  if (new$PrincipalName is not null) then
    SELECT COUNT(id ) INTO CNT$1
    from dbUsers where (PrincipalName = new$PrincipalName) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_DBUSERS_DUBLICATENAME');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_DBUSERS_BI_500)
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_DBUSERS (
    ID,
    USERNAME,
    FIRSTNAME,
    MIDDLENAME,
    LASTNAME,
    NOTE,
    PHONE,
    DESCRIPTION,
    DEPARTMENTCLS,
    REMOTECLIENTREF,
    REMOTEID,
    CREATEDATE,
    UPDATEDATE,
    CRYPTOPARAMS,
    CRYPTOID,
    ORG_REF,
    NOTE2,
    EMAILADDRESS,
    PRINCIPALNAME,
    USERGUID,
    CREATERUSER,
    UPDATERUSER
  ) VALUES (
    new$ID,
    new$USERNAME,
    new$FIRSTNAME,
    new$MIDDLENAME,
    new$LASTNAME,
    new$NOTE,
    new$PHONE,
    new$DESCRIPTION,
    new$DEPARTMENTCLS,
    new$REMOTECLIENTREF,
    new$REMOTEID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$CRYPTOPARAMS,
    new$CRYPTOID,
    new$ORG_REF,
    new$NOTE2,
    new$EMAILADDRESS,
    new$PRINCIPALNAME,
    new$USERGUID,
    new$CREATERUSER,
    new$UPDATERUSER);

-- - - - - - - - - - - - -
-- AI_0 (TR_DBUSERS_AI)
-- Last update 30.03.2006
-- - - - - - - - - - - - -

 insert into UsersInGroups (UserRef, GroupRef)
      values (new$id, 0);

 /*     */
 if (new$RemoteID = -1) then
     /*  ID  */
     select max(ID) into cGroupID$ from DBGroups where (Name = '');
     if (not (cGroupID$ is null)) then
        insert into UsersInGroups (UserRef, GroupRef)
        values (new$ID, cGroupID$);
     end if;
 /*     */
 else
     /*  ID   */
     select max(ID) into cGroupID$ from DBGroups where (Name = '');
     if (not (cGroupID$ is null)) then
        insert into UsersInGroups (UserRef, GroupRef)
        values (new$ID, cGroupID$);
     end if;
 end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_DBUSERS_AI_500)
-- Last update 18.02.2004
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 100) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_DBUSERS_IU
  INSTEAD OF UPDATE
  ON DBUSERS
  FOR EACH ROW
DECLARE
  new$ID DBUSERS.ID%TYPE := :NEW.ID;
  new$USERNAME DBUSERS.USERNAME%TYPE := :NEW.USERNAME;
  new$FIRSTNAME DBUSERS.FIRSTNAME%TYPE := :NEW.FIRSTNAME;
  new$MIDDLENAME DBUSERS.MIDDLENAME%TYPE := :NEW.MIDDLENAME;
  new$LASTNAME DBUSERS.LASTNAME%TYPE := :NEW.LASTNAME;
  new$NOTE DBUSERS.NOTE%TYPE := :NEW.NOTE;
  new$PHONE DBUSERS.PHONE%TYPE := :NEW.PHONE;
  new$DESCRIPTION DBUSERS.DESCRIPTION%TYPE := :NEW.DESCRIPTION;
  new$DEPARTMENTCLS DBUSERS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$REMOTECLIENTREF DBUSERS.REMOTECLIENTREF%TYPE := :NEW.REMOTECLIENTREF;
  new$REMOTEID DBUSERS.REMOTEID%TYPE := :NEW.REMOTEID;
  new$CREATEDATE DBUSERS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE DBUSERS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CRYPTOPARAMS DBUSERS.CRYPTOPARAMS%TYPE := :NEW.CRYPTOPARAMS;
  new$CRYPTOID DBUSERS.CRYPTOID%TYPE := :NEW.CRYPTOID;
  new$ORG_REF DBUSERS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$NOTE2 DBUSERS.NOTE2%TYPE := :NEW.NOTE2;
  new$EMAILADDRESS DBUSERS.EMAILADDRESS%TYPE := :NEW.EMAILADDRESS;
  new$PRINCIPALNAME DBUSERS.PRINCIPALNAME%TYPE := :NEW.PRINCIPALNAME;
  new$USERGUID DBUSERS.USERGUID%TYPE := :NEW.USERGUID;
  new$CREATERUSER DBUSERS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER DBUSERS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
--
  cGroupID1$ NUMBER(10);
  acc$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_DBUSERS_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  new$UserName := Upper(new$UserName);
  if (new$RemoteClientRef is null) then
    new$RemoteID := -1;
     
  else 
    new$RemoteID := new$RemoteClientRef;
  END IF;
  /*     ,       */
  if ((:old.RemoteID > 0) and (new$RemoteID = -1)) then
    select max(ID)       into cGroupID1$ from DBGroups where (Name = '')
    ;
    if (not (cGroupID1$ is null)) then
      update UsersInGroups uig set uig.GroupRef = cGroupID1$

      where (uig.UserRef = :old.ID) and
      ((select Name from DBGroups dbg where dbg.ID = uig.GroupRef) = '');
     
    END IF;
  END IF;
  /*     ,       */
  if ((:old.RemoteID = -1) and (new$RemoteID > 0)) then
    select max(ID)       into cGroupID1$ from DBGroups where (Name = '')
    ;
    if (not (cGroupID1$ is null)) then
      update UsersInGroups uig set uig.GroupRef = cGroupID1$

      where (uig.UserRef = :old.ID) and
      ((select Name from DBGroups dbg where dbg.ID = uig.GroupRef) = '');
     
    END IF;
  END IF;
  if (new$Org_Ref is null) then
    GetIntConst(-1, 2,acc$);
    BEGIN
      select
      o.id
      into
      new$Org_Ref    from
      organizations o
      left join org_accounts oa on (oa.org_ref = o.id)
      where
      (oa.id = acc$)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Org_Ref is null) then
      new$Org_Ref := 0;
     
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_DBUSERS_BU_1)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((:old.id = 0) and (new$UserName <> :old.UserName)) then 
    RaiseException('ex_CantUpdateThis');
  END IF;
  if (new$RemoteClientRef is not null) then
    new$PrincipalName := null;
  END IF;
  if (new$PrincipalName is not null) then
    SELECT COUNT(id ) INTO CNT$1
    from dbUsers where ((PrincipalName = new$PrincipalName) and id <> new$ID) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_DBUSERS_DUBLICATENAME');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_DBUSERS SET
    ID = new$ID,
    USERNAME = new$USERNAME,
    FIRSTNAME = new$FIRSTNAME,
    MIDDLENAME = new$MIDDLENAME,
    LASTNAME = new$LASTNAME,
    NOTE = new$NOTE,
    PHONE = new$PHONE,
    DESCRIPTION = new$DESCRIPTION,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    REMOTECLIENTREF = new$REMOTECLIENTREF,
    REMOTEID = new$REMOTEID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    CRYPTOPARAMS = new$CRYPTOPARAMS,
    CRYPTOID = new$CRYPTOID,
    ORG_REF = new$ORG_REF,
    NOTE2 = new$NOTE2,
    EMAILADDRESS = new$EMAILADDRESS,
    PRINCIPALNAME = new$PRINCIPALNAME,
    USERGUID = new$USERGUID,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_DBUSERS_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (100, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=100) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE ObjectKind ADD (
  CreaterUser VARCHAR2(30),
  UpdaterUser VARCHAR2(30)
)
/
ALTER TABLE RightKind ADD (
  CreaterUser VARCHAR2(30),
  UpdaterUser VARCHAR2(30)
)
/
ALTER TABLE GroupsRights ADD (
  CreaterUser VARCHAR2(30),
  UpdaterUser VARCHAR2(30)
)
/
ALTER TABLE UsersRights ADD (
  CreaterUser VARCHAR2(30),
  UpdaterUser VARCHAR2(30)
)
/
ALTER TABLE BudStructRights ADD (
  CreaterUser VARCHAR2(30),
  UpdaterUser VARCHAR2(30)
)
/
ALTER TABLE UsersInGroups ADD (
  CreaterUser VARCHAR2(30),
  UpdaterUser VARCHAR2(30)
)
/
ALTER TABLE DualRights ADD (
  CreaterUser VARCHAR2(30),
  UpdaterUser VARCHAR2(30)
)
/
commit work 
/
ALTER TRIGGER TR_DBGROUPS_BU_500 DISABLE
/
-- ALTER TRIGGER TR_DBGROUPS_BU_0
CREATE OR REPLACE TRIGGER TR_DBGROUPS_BU
  BEFORE UPDATE
  ON DBGROUPS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_DBGROUPS_BU_0)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    */
--   if (:old.ID < 10) then
--     RaiseException('ex_SystemGroup');
--   END IF;

END;
/
update DBGroups set
  CreaterUser = user,
  UpdaterUser = user
/
ALTER TRIGGER TR_DBGROUPS_BU_500 ENABLE
/
-- ALTER TRIGGER TR_DBGROUPS_BU_0
CREATE OR REPLACE TRIGGER TR_DBGROUPS_BU
  BEFORE UPDATE
  ON DBGROUPS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_DBGROUPS_BU_0)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    */
  if (:old.ID < 10) then
    RaiseException('ex_SystemGroup');
  END IF;

END;
/
ALTER TRIGGER TR_DBUSERS_BU_500 DISABLE
/
update DBUsers set
  CreaterUser = user,
  UpdaterUser = user
/
ALTER TRIGGER TR_DBUSERS_BU_500 ENABLE
/
ALTER TRIGGER TR_OBJECTKIND_BU_500 DISABLE
/
update ObjectKind set
  CreaterUser = user,
  UpdaterUser = user
/
ALTER TRIGGER TR_OBJECTKIND_BU_500 ENABLE
/
ALTER TRIGGER TR_RIGHTKIND_BU_500 DISABLE
/
update RightKind set
  CreaterUser = user,
  UpdaterUser = user
/
ALTER TRIGGER TR_RIGHTKIND_BU_500 ENABLE
/
ALTER TRIGGER TR_GROUPSRIGHTS_BU_500 DISABLE
/
update GroupsRights set
  CreaterUser = user,
  UpdaterUser = user
/
ALTER TRIGGER TR_GROUPSRIGHTS_BU_500 ENABLE
/
ALTER TRIGGER TR_USERSRIGHTS_BU_500 DISABLE
/
update UsersRights set
  CreaterUser = user,
  UpdaterUser = user
/
ALTER TRIGGER TR_USERSRIGHTS_BU_500 ENABLE
/
ALTER TRIGGER TR_BUDSTRUCTRIGHTS_BU_500 DISABLE
/
update BudStructRights set
  CreaterUser = user,
  UpdaterUser = user
/
ALTER TRIGGER TR_BUDSTRUCTRIGHTS_BU_500 ENABLE
/
ALTER TRIGGER TR_USERSINGROUPS_BU_500 DISABLE
/
update UsersInGroups set
  CreaterUser = user,
  UpdaterUser = user
/
ALTER TRIGGER TR_USERSINGROUPS_BU_500 ENABLE
/
ALTER TRIGGER TR_DUALRIGHTS_BU_500 DISABLE
/
update DualRights set
  CreaterUser = user,
  UpdaterUser = user
/
ALTER TRIGGER TR_DUALRIGHTS_BU_500 ENABLE
/
-- ALTER TRIGGER TR_DBGroups_BI_500
CREATE OR REPLACE TRIGGER TR_DBGROUPS_BI
  BEFORE INSERT
  ON DBGROUPS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_DBGROUPS_BI_0)
-- Last update 18.02.2004
-- - - - - - - - - - - - -

--    

  if (:new.ID is null) then select g_Shared.NextVal into :new.ID from dual; end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_DBGROUPS_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_DBGroups_BU_500
CREATE OR REPLACE TRIGGER TR_DBGROUPS_BU_500
  BEFORE UPDATE
  ON DBGROUPS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_DBGROUPS_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_DBUsers_BI_500
CREATE OR REPLACE TRIGGER TR_DBUSERS_II
  INSTEAD OF INSERT
  ON DBUSERS
  FOR EACH ROW
DECLARE
  new$ID DBUSERS.ID%TYPE := :NEW.ID;
  new$USERNAME DBUSERS.USERNAME%TYPE := :NEW.USERNAME;
  new$FIRSTNAME DBUSERS.FIRSTNAME%TYPE := :NEW.FIRSTNAME;
  new$MIDDLENAME DBUSERS.MIDDLENAME%TYPE := :NEW.MIDDLENAME;
  new$LASTNAME DBUSERS.LASTNAME%TYPE := :NEW.LASTNAME;
  new$NOTE DBUSERS.NOTE%TYPE := :NEW.NOTE;
  new$PHONE DBUSERS.PHONE%TYPE := :NEW.PHONE;
  new$DESCRIPTION DBUSERS.DESCRIPTION%TYPE := :NEW.DESCRIPTION;
  new$DEPARTMENTCLS DBUSERS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$REMOTECLIENTREF DBUSERS.REMOTECLIENTREF%TYPE := :NEW.REMOTECLIENTREF;
  new$REMOTEID DBUSERS.REMOTEID%TYPE := :NEW.REMOTEID;
  new$CREATEDATE DBUSERS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE DBUSERS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CRYPTOPARAMS DBUSERS.CRYPTOPARAMS%TYPE := :NEW.CRYPTOPARAMS;
  new$CRYPTOID DBUSERS.CRYPTOID%TYPE := :NEW.CRYPTOID;
  new$ORG_REF DBUSERS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$NOTE2 DBUSERS.NOTE2%TYPE := :NEW.NOTE2;
  new$EMAILADDRESS DBUSERS.EMAILADDRESS%TYPE := :NEW.EMAILADDRESS;
  new$PRINCIPALNAME DBUSERS.PRINCIPALNAME%TYPE := :NEW.PRINCIPALNAME;
  new$USERGUID DBUSERS.USERGUID%TYPE := :NEW.USERGUID;
  new$CREATERUSER DBUSERS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER DBUSERS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
--
  cGroupID$ NUMBER(10);
  acc1$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_DBUSERS_BI)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  new$UserName := Upper(new$UserName);
  if (new$RemoteClientRef is null) then 
    new$RemoteID := -1;
     
  else 
    new$RemoteID := new$RemoteClientRef;
  END IF;
  if (new$Org_Ref is null) then
    GetIntConst(-1, 2,acc1$);
    BEGIN
      select
      o.id
      into
      new$Org_Ref    from
      organizations o
      left join org_accounts oa on (oa.org_ref = o.id)
      where
      (oa.id = acc1$)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Org_Ref is null) then
      new$Org_Ref := 0;
     
    END IF;
  END IF;
  if (new$RemoteClientRef is not null) then
    new$PrincipalName := null;
  END IF;
  if (new$PrincipalName is not null) then
    SELECT COUNT(id ) INTO CNT$1
    from dbUsers where (PrincipalName = new$PrincipalName) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_DBUSERS_DUBLICATENAME');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_DBUSERS_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_DBUSERS (
    ID,
    USERNAME,
    FIRSTNAME,
    MIDDLENAME,
    LASTNAME,
    NOTE,
    PHONE,
    DESCRIPTION,
    DEPARTMENTCLS,
    REMOTECLIENTREF,
    REMOTEID,
    CREATEDATE,
    UPDATEDATE,
    CRYPTOPARAMS,
    CRYPTOID,
    ORG_REF,
    NOTE2,
    EMAILADDRESS,
    PRINCIPALNAME,
    USERGUID,
    CREATERUSER,
    UPDATERUSER
  ) VALUES (
    new$ID,
    new$USERNAME,
    new$FIRSTNAME,
    new$MIDDLENAME,
    new$LASTNAME,
    new$NOTE,
    new$PHONE,
    new$DESCRIPTION,
    new$DEPARTMENTCLS,
    new$REMOTECLIENTREF,
    new$REMOTEID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$CRYPTOPARAMS,
    new$CRYPTOID,
    new$ORG_REF,
    new$NOTE2,
    new$EMAILADDRESS,
    new$PRINCIPALNAME,
    new$USERGUID,
    new$CREATERUSER,
    new$UPDATERUSER);

-- - - - - - - - - - - - -
-- AI_0 (TR_DBUSERS_AI)
-- Last update 30.03.2006
-- - - - - - - - - - - - -

 insert into UsersInGroups (UserRef, GroupRef)
      values (new$id, 0);

 /*     */
 if (new$RemoteID = -1) then
     /*  ID  */
     select max(ID) into cGroupID$ from DBGroups where (Name = '');
     if (not (cGroupID$ is null)) then
        insert into UsersInGroups (UserRef, GroupRef)
        values (new$ID, cGroupID$);
     end if;
 /*     */
 else
     /*  ID   */
     select max(ID) into cGroupID$ from DBGroups where (Name = '');
     if (not (cGroupID$ is null)) then
        insert into UsersInGroups (UserRef, GroupRef)
        values (new$ID, cGroupID$);
     end if;
 end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_DBUSERS_AI_500)
-- Last update 18.02.2004
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 100) and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER TR_DBUsers_BU_500
CREATE OR REPLACE TRIGGER TR_DBUSERS_BU_500
  BEFORE UPDATE
  ON TB_DBUSERS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_DBUSERS_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_ObjectKind_BI_500
CREATE OR REPLACE TRIGGER TR_OBJECTKIND_BI
  BEFORE INSERT
  ON OBJECTKIND
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_500 (TR_OBJECTKIND_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_ObjectKind_BU_500
CREATE OR REPLACE TRIGGER TR_OBJECTKIND_BU_500
  BEFORE UPDATE
  ON OBJECTKIND
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_OBJECTKIND_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_RightKind_BI_500
CREATE OR REPLACE TRIGGER TR_RIGHTKIND_BI
  BEFORE INSERT
  ON RIGHTKIND
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_500 (TR_RIGHTKIND_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_RightKind_BU_500
CREATE OR REPLACE TRIGGER TR_RIGHTKIND_BU_500
  BEFORE UPDATE
  ON RIGHTKIND
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_RIGHTKIND_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_GroupsRights_BI_500
CREATE OR REPLACE TRIGGER TR_GROUPSRIGHTS_BI
  BEFORE INSERT
  ON GROUPSRIGHTS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_GROUPSRIGHTS_BI_0)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (:new.ID is null) then 
    select g_shared.nextval into :new.ID from dual;
  END IF;
  if (:new.IsReject is null) then 
    :new.IsReject := 0;
  END IF;
  /*     (  ) */
  if ((:new.RightKindRef is Null) and not (:new.RightRef is Null)) then
    BEGIN
      select RightKindRef   into :new.RightKindRef from DBRIGHTS dr where (dr.Id = :new.RightRef)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_GROUPSRIGHTS_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_GroupsRights_BU_500
CREATE OR REPLACE TRIGGER TR_GROUPSRIGHTS_BU_500
  BEFORE UPDATE
  ON GROUPSRIGHTS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_GROUPSRIGHTS_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_UsersRights_BI_500
CREATE OR REPLACE TRIGGER TR_USERSRIGHTS_BI
  BEFORE INSERT
  ON USERSRIGHTS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_USERSRIGHTS_BI_0)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (:new.ID is null) then 
    select g_shared.nextval into :new.ID from dual;
  END IF;
  if (:new.IsReject is null) then 
    :new.IsReject := 0;
  END IF;
  /*     (  ) */
  if ((:new.RightKindRef is Null) and not (:new.RightRef is Null)) then
    BEGIN
      select RightKindRef   into :new.RightKindRef from DBRIGHTS dr where (dr.Id = :new.RightRef)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_USERSRIGHTS_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_UsersRights_BU_500
CREATE OR REPLACE TRIGGER TR_USERSRIGHTS_BU_500
  BEFORE UPDATE
  ON USERSRIGHTS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_USERSRIGHTS_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_BudStructRights_BI_500
CREATE OR REPLACE TRIGGER TR_BUDSTRUCTRIGHTS_BI
  BEFORE INSERT
  ON BUDSTRUCTRIGHTS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_budstructrights_bi_0)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (:new.ID is null) then 
    select g_shared.nextval into :new.ID from dual;
  END IF;
  if (:new.RightRef is null) then 
    :new.RightRef := 4;
  END IF;
  if (:new.IsGroup is null) then 
    :new.IsGroup := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if ((:new.KCSR is null) or (:new.KCSR  is null)) then 
    :new.KCSR := '0';
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if ((:new.KVR is null) or (:new.KVR  is null)) then 
    :new.KVR := '0';
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.SubKESR is null) then 
    :new.SubKESR := 0;
  END IF;
  if (:new.RegionCls is null) then 
    :new.RegionCls := 0;
  END IF;
  if ((:new.DirectionCls is null) or (:new.DirectionCls  is null)) then 
    :new.DirectionCls := '0';
  END IF;
  if ((:new.Fact is null) or (:new.Fact  is null)) then 
    :new.Fact := '0';
  END IF;
  if ((:new.FinType is null) or (:new.FinType  is null)) then 
    :new.FinType := '0';
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.TransfertCls is null) then 
    :new.TransfertCls := 0;
  END IF;
  if ((:new.BudAllocationCls is null) or (:new.BudAllocationCls  is null)) then 
    :new.BudAllocationCls := '0';
  END IF;
  if ((:new.PayPromiseCls is null) or (:new.PayPromiseCls  is null)) then 
    :new.PayPromiseCls := '0';
  END IF;
  if ((:new.SubsidyCls is null) or (:new.SubsidyCls  is null)) then 
    :new.SubsidyCls := '0';
  END IF;
  if (:new.KfsrUP is null) then 
    :new.KFSRUp := :new.KFSR;
  END IF;
  if (:new.KVSRUP is null) then 
    :new.KVSRUP := :new.KVSR;
  END IF;
  if (:new.KCSRUP is null) then 
    :new.KCSRUP := :new.KCSR;
  END IF;
  if (:new.KVRUP is null) then 
    :new.KVRUP := :new.KVR;
  END IF;
  if (:new.KesrUP is null) then 
    :new.KesrUP := :new.Kesr;
  END IF;
  if (:new.SubKESRUP is null) then 
    :new.SubKESRUP := :new.SubKESR;
  END IF;
  if (:new.RegionClsUP is null) then 
    :new.RegionClsUP := :new.RegionCls;
  END IF;
  if ((:new.DirectionClsUp is null) or (:new.DirectionClsUp  is null)) then 
    :new.DirectionClsUp := :new.DirectionCls;
  END IF;
  if ((:new.FactUP is null) or (:new.FactUP is null)) then 
    :new.FactUP := :new.Fact;
  END IF;
  if ((:new.FinTypeUP is null) or (:new.FinTypeUP is null)) then 
    :new.FinTypeUP := :new.FinType;
  END IF;
  if (:new.MeansTypeUP is null) then 
    :new.MeansTypeUP := :new.MeansType;
  END IF;
  if (:new.TransfertClsUp is null) then 
    :new.TransfertClsUp := :new.TransfertCls;
  END IF;
  if ((:new.BudAllocationClsUp is null) or (:new.BudAllocationClsUp  is null)) then 
    :new.BudAllocationClsUp := :new.BudAllocationCls;
  END IF;
  if ((:new.PayPromiseClsUp is null) or (:new.PayPromiseClsUp  is null)) then 
    :new.PayPromiseClsUp := :new.PayPromiseCls;
  END IF;
  if ((:new.SubsidyClsUp is null) or (:new.SubsidyClsUp  is null)) then 
    :new.SubsidyClsUp := :new.SubsidyCls;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDSTRUCTRIGHTS_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_BudStructRights_BU_500
CREATE OR REPLACE TRIGGER TR_BUDSTRUCTRIGHTS_BU_500
  BEFORE UPDATE
  ON BUDSTRUCTRIGHTS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_BUDSTRUCTRIGHTS_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_UsersInGroups_BI_500
CREATE OR REPLACE TRIGGER TR_USERSINGROUPS_BI
  BEFORE INSERT
  ON USERSINGROUPS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_USERSINGROUPS_BI_0)
-- Last update 18.02.2004
-- - - - - - - - - - - - -

/*     */
  if (:new.ID is null) then select g_Shared.NextVal into :new.ID from dual; end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_USERSINGROUPS_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_UsersInGroups_BU_500
CREATE OR REPLACE TRIGGER TR_USERSINGROUPS_BU_500
  BEFORE UPDATE
  ON USERSINGROUPS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_USERSINGROUPS_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_DualRights_BI_500
CREATE OR REPLACE TRIGGER TR_DUALRIGHTS_BI
  BEFORE INSERT
  ON DUALRIGHTS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_DUALRIGHTS_BI_0)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (:new.ID is null) then 
    select g_shared.nextval into :new.ID from dual;
  END IF;
  if (:new.IsReject is null) then 
    :new.IsReject := 0;
  END IF;
  if (:new.IsGroup is null) then 
    :new.IsGroup := 0;
  END IF;
  /*       (    ) */
  if ((:new.RightKindRef is Null) and not (:new.RightRef is Null)) then
    BEGIN
      select RightKindRef, ObjectKindRef     into :new.RightKindRef, :new.ObjectKindRef from DBRIGHTS dr where (dr.Id = :new.RightRef)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_50 (tr_DualRights_bi_50)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((:new.ObjRef1 is not null) and (:new.ObjRef1Up is null)) then
    :new.ObjRef1Up := :new.ObjRef1;
  END IF;
  /* /    */
  if ((:new.ObjectKindRef in (8000000, 27000000)) and (:new.ObjRef2 is not null) and (:new.ObjRef2Up is null)) then
    FacialAcc_CLSUp(:new.ObjRef2,:new.ObjRef2Up);
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_DUALRIGHTS_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_DualRights_BU_500
CREATE OR REPLACE TRIGGER TR_DUALRIGHTS_BU_500
  BEFORE UPDATE
  ON DUALRIGHTS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_DUALRIGHTS_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
commit work 
/

ALTER TABLE DBGroups MODIFY(CreaterUser NOT NULL)
/
ALTER TABLE DBGroups MODIFY(UpdaterUser NOT NULL)
/
ALTER TABLE TB_DBUsers MODIFY(CreaterUser NOT NULL)
/
ALTER TABLE TB_DBUsers MODIFY(UpdaterUser NOT NULL)
/
ALTER TABLE ObjectKind MODIFY(CreaterUser NOT NULL)
/
ALTER TABLE ObjectKind MODIFY(UpdaterUser NOT NULL)
/
ALTER TABLE RightKind MODIFY(CreaterUser NOT NULL)
/
ALTER TABLE RightKind MODIFY(UpdaterUser NOT NULL)
/
ALTER TABLE GroupsRights MODIFY(CreaterUser NOT NULL)
/
ALTER TABLE GroupsRights MODIFY(UpdaterUser NOT NULL)
/
ALTER TABLE UsersRights MODIFY(CreaterUser NOT NULL)
/
ALTER TABLE UsersRights MODIFY(UpdaterUser NOT NULL)
/
ALTER TABLE BudStructRights MODIFY(CreaterUser NOT NULL)
/
ALTER TABLE BudStructRights MODIFY(UpdaterUser NOT NULL)
/
ALTER TABLE UsersInGroups MODIFY(CreaterUser NOT NULL)
/
ALTER TABLE UsersInGroups MODIFY(UpdaterUser NOT NULL)
/
ALTER TABLE DualRights MODIFY(CreaterUser NOT NULL)
/
ALTER TABLE DualRights MODIFY(UpdaterUser NOT NULL)
/

-- #########################################################
-- #########################################################
-- alter_ITF_CTRL_drop_FK_SCENARIO.sql
-- #########################################################
-- #########################################################

/*        ITF_CTRL, ..    -   */
ALTER TABLE ITF_CTRL DROP CONSTRAINT ITF_CTRL_FK_SCENARIO
/
DROP INDEX ITF_CTRL_FK_SCENARIO
/
commit work 
/

-- #########################################################
-- #########################################################
-- alter_TransfertCls_add_Fact.sql
-- #########################################################
-- #########################################################

/*  ""  "  " */
ALTER TABLE TB_TransfertCls ADD (
  Fact NUMBER(10)/*  */,
    CHECK((Fact<=2147483647)AND(Fact>-2147483648))
)
/

CREATE OR REPLACE VIEW TransfertCls (
  ID,
  REGIONCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  CODE,
  RECEIVEKVSR,
  RECEIVEKFSR,
  RECEIVEKVR,
  RECEIVEKESR,
  RECEIVEKD,
  TRANSFERKVSR,
  TRANSFERKFSR,
  TRANSFERKCSR,
  TRANSFERKVR,
  TRANSFERKESR,
  TRANSFERKDVALUE,
  TARGETMEANSSIGN,
  TARGETCLS,
  STARTDATE,
  DELETEDATE,
  NOTE,
  NAME,
  BUDGETREF,
  RECEIVEKCSR,
  SOURCELEVEL,
  DESTLEVEL,
  TRANSFERTKIND,
  GRANTKIND,
  TRANSFERTYEAR,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  FACT)
AS
  SELECT
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT
  FROM TB_TransfertCls
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_ID
  INSTEAD OF DELETE
  ON TRANSFERTCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_TRANSFERTCLS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_TRANSFERTCLS_AD_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
  values(203,:old.ID,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
--
  CurrentDate$ NUMBER;
  CNT$1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TRANSFERTCLS_BI)
-- Version 8.00.00.3
-- - - - - - - - - - - - -

  select g_shared.nextval into new$ID from dual;
   
  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then 
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0; 
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_TRANSFERTCLS_BI_200)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1$
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF)) AND (ROWNUM = 1);
  if ((CNT$1$<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKESR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
--
  CurrentDate$ NUMBER;
  CNT$1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TRANSFERTCLS_BU)
-- Version 8.00.00.3
-- - - - - - - - - - - - -

  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then 
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0;
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TRANSFERTCLS_BU_200)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1$
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF)) AND (ROWNUM = 1);
  if ((CNT$1$<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKESR = new$RECEIVEKESR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
commit work 
/
ALTER TRIGGER TR_TRANSFERTCLS_BU_500 DISABLE
/
update TransfertCls set
  Fact = 0
/
ALTER TRIGGER TR_TRANSFERTCLS_BU_500 ENABLE
/
commit work 
/
ALTER TABLE TB_TRANSFERTCLS ADD (
  CONSTRAINT FK_TRANSFERTCLS_FACT FOREIGN KEY (FACT) REFERENCES FACT(ID)
)
/
CREATE INDEX FK_TRANSFERTCLS_FACT ON TB_TRANSFERTCLS(FACT)
/
-- ALTER TRIGGER tr_transfertcls_bi
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
--
  CurrentDate$ NUMBER;
  CNT$1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TRANSFERTCLS_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  select g_shared.nextval into new$ID from dual;
   
  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then 
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0; 
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_TRANSFERTCLS_BI_200)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1$
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF)) AND (ROWNUM = 1);
  if ((CNT$1$<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKESR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/
-- ALTER TRIGGER tr_transfertcls_bu
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
--
  CurrentDate$ NUMBER;
  CNT$1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TRANSFERTCLS_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then 
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0;
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TRANSFERTCLS_BU_200)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1$
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF)) AND (ROWNUM = 1);
  if ((CNT$1$<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKESR = new$RECEIVEKESR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
-- ALTER TRIGGER tr_transfertcls_bi_200
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
--
  CurrentDate$ NUMBER;
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TRANSFERTCLS_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  select g_shared.nextval into new$ID from dual;
   
  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then 
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0; 
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_TRANSFERTCLS_BI_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKESR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/
-- ALTER TRIGGER tr_transfertcls_bu_200
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
--
  CurrentDate$ NUMBER;
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TRANSFERTCLS_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then 
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0;
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TRANSFERTCLS_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKESR = new$RECEIVEKESR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
commit work 
/
ALTER TABLE TB_TransfertCls MODIFY(Fact NOT NULL)
/

-- #########################################################
-- #########################################################
-- update_INTERFACES_set_CLS_909_910.sql
-- #########################################################
-- #########################################################

/*      09.09  09.10 */
update Interfaces set
  cls = 909
where
  (guid = '{D546596C-CBDC-4B6B-A2D4-FC836F1C980F}') and (Upper(Param) = '\(09.01.01)')
/
update Interfaces set
  cls = 910
where
  (guid = '{D546596C-CBDC-4B6B-A2D4-FC836F1C980F}') and (Upper(Param) = '\(09.01.02)')
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_All_Ext2.sql
-- #########################################################
-- #########################################################

/*             */
ALTER TABLE TB_Budgets_s ADD (
  StartDate DATE,
  DeleteDate DATE,
  ExtID VARCHAR2(50)/* UID     ,  GUID */
)
/

CREATE OR REPLACE VIEW Budgets_s (
  ID,
  NAME,
  LASTMODIFDATE_B,
  CURRENTBUDGET,
  NOTE,
  OKATO,
  ADDOKATO,
  CREATEDATE,
  UPDATEDATE,
  AYEAR,
  CREATERUSER,
  UPDATERUSER,
  BUDGETLEVEL,
  CHIEFNAME,
  CHIEFROLE,
  STARTDATE,
  DELETEDATE,
  EXTID)
AS
  SELECT
    ID,
    NAME,
    LASTMODIFDATE_B,
    CURRENTBUDGET,
    NOTE,
    OKATO,
    ADDOKATO,
    CREATEDATE,
    UPDATEDATE,
    AYEAR,
    CREATERUSER,
    UPDATERUSER,
    BUDGETLEVEL,
    CHIEFNAME,
    CHIEFROLE,
    STARTDATE,
    DELETEDATE,
    EXTID
  FROM TB_Budgets_s
/

CREATE OR REPLACE TRIGGER TR_BUDGETS_S_ID
  INSTEAD OF DELETE
  ON BUDGETS_S
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_BUDGETS_S
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_BUDGETS_S_AD_500)
-- Create 15.02.2006
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate) values (178, :old.ID, SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDGETS_S_II
  INSTEAD OF INSERT
  ON BUDGETS_S
  FOR EACH ROW
DECLARE
  new$ID BUDGETS_S.ID%TYPE := :NEW.ID;
  new$NAME BUDGETS_S.NAME%TYPE := :NEW.NAME;
  new$LASTMODIFDATE_B BUDGETS_S.LASTMODIFDATE_B%TYPE := :NEW.LASTMODIFDATE_B;
  new$CURRENTBUDGET BUDGETS_S.CURRENTBUDGET%TYPE := :NEW.CURRENTBUDGET;
  new$NOTE BUDGETS_S.NOTE%TYPE := :NEW.NOTE;
  new$OKATO BUDGETS_S.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO BUDGETS_S.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$CREATEDATE BUDGETS_S.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDGETS_S.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$AYEAR BUDGETS_S.AYEAR%TYPE := :NEW.AYEAR;
  new$CREATERUSER BUDGETS_S.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER BUDGETS_S.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETLEVEL BUDGETS_S.BUDGETLEVEL%TYPE := :NEW.BUDGETLEVEL;
  new$CHIEFNAME BUDGETS_S.CHIEFNAME%TYPE := :NEW.CHIEFNAME;
  new$CHIEFROLE BUDGETS_S.CHIEFROLE%TYPE := :NEW.CHIEFROLE;
  new$STARTDATE BUDGETS_S.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE BUDGETS_S.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$EXTID BUDGETS_S.EXTID%TYPE := :NEW.EXTID;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDGETS_S_BI)
-- Last update 01.12.2005
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL
        INTO new$ID
        FROM DUAL;
   END IF;

   IF (new$OKATO IS NULL) THEN
      new$OKATO := 0;
   END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_BUDGETS_S_BI_1)
-- Last update 06.12.2005
-- - - - - - - - - - - - -

   SELECT COUNT (*)
     INTO CNT$
     FROM Budgets_s
    WHERE (Note = new$note) AND (ROWNUM = 1);

   IF CNT$ > 0 THEN
      raiseException ('ex_Dublicate_FullName');
   END IF;

   SELECT COUNT (*)
     INTO CNT$
     FROM Budgets_s
    WHERE (NAME = new$Name) AND (ROWNUM = 1);

   IF CNT$ > 0 THEN
      raiseException ('ex_Dublicate_ShortName');
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_BUDGETS_S_BI_10)
-- Last update 12.04.2010
-- - - - - - - - - - - - -

  --      =1   
  --     =0     " "
  --  " "
  IF (new$currentbudget = 1) THEN
     UPDATE budgets_s
         SET currentbudget = 0
     WHERE ID <> new$ID;
     update intconst set
       constvalue = new$ID
     where (ProgIndex = -1) and (ConstIndex = 3);
     --     
     update intconst set
       constvalue = new$BudgetLevel
     where (ProgIndex = -1) and (ConstIndex = 5);
  ELSE
      new$currentbudget := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDGETS_S_BI_500)
-- Create 15.02.2006
-- Last update 02.10.2009
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_BUDGETS_S (
    ID,
    NAME,
    LASTMODIFDATE_B,
    CURRENTBUDGET,
    NOTE,
    OKATO,
    ADDOKATO,
    CREATEDATE,
    UPDATEDATE,
    AYEAR,
    CREATERUSER,
    UPDATERUSER,
    BUDGETLEVEL,
    CHIEFNAME,
    CHIEFROLE,
    STARTDATE,
    DELETEDATE,
    EXTID
  ) VALUES (
    new$ID,
    new$NAME,
    new$LASTMODIFDATE_B,
    new$CURRENTBUDGET,
    new$NOTE,
    new$OKATO,
    new$ADDOKATO,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$AYEAR,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$BUDGETLEVEL,
    new$CHIEFNAME,
    new$CHIEFROLE,
    new$STARTDATE,
    new$DELETEDATE,
    new$EXTID);

-- - - - - - - - - - - - -
-- AI_500 (TR_BUDGETS_S_AI_500)
-- Create 15.02.2006
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 178) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDGETS_S_IU
  INSTEAD OF UPDATE
  ON BUDGETS_S
  FOR EACH ROW
DECLARE
  new$ID BUDGETS_S.ID%TYPE := :NEW.ID;
  new$NAME BUDGETS_S.NAME%TYPE := :NEW.NAME;
  new$LASTMODIFDATE_B BUDGETS_S.LASTMODIFDATE_B%TYPE := :NEW.LASTMODIFDATE_B;
  new$CURRENTBUDGET BUDGETS_S.CURRENTBUDGET%TYPE := :NEW.CURRENTBUDGET;
  new$NOTE BUDGETS_S.NOTE%TYPE := :NEW.NOTE;
  new$OKATO BUDGETS_S.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO BUDGETS_S.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$CREATEDATE BUDGETS_S.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDGETS_S.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$AYEAR BUDGETS_S.AYEAR%TYPE := :NEW.AYEAR;
  new$CREATERUSER BUDGETS_S.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER BUDGETS_S.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETLEVEL BUDGETS_S.BUDGETLEVEL%TYPE := :NEW.BUDGETLEVEL;
  new$CHIEFNAME BUDGETS_S.CHIEFNAME%TYPE := :NEW.CHIEFNAME;
  new$CHIEFROLE BUDGETS_S.CHIEFROLE%TYPE := :NEW.CHIEFROLE;
  new$STARTDATE BUDGETS_S.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE BUDGETS_S.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$EXTID BUDGETS_S.EXTID%TYPE := :NEW.EXTID;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETS_S_BU)
-- Last update 01.12.2005
-- - - - - - - - - - - - -

   IF (new$OKATO IS NULL) THEN new$OKATO := 0; END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_BUDGETS_S_BU_1)
-- Last update 14.02.2006
-- - - - - - - - - - - - -

   SELECT COUNT (*) INTO CNT$ FROM Budgets_s
   WHERE (ID <> :old.ID) AND (Note = new$note) AND (ROWNUM = 1);

   IF CNT$ > 0 THEN
     raiseException ('ex_Dublicate_FullName');
   END IF;

   SELECT COUNT (*) INTO CNT$ FROM Budgets_s
   WHERE (ID <> :old.id) AND (NAME = new$Name) AND (ROWNUM = 1);

   IF CNT$ > 0 THEN
     raiseException ('ex_Dublicate_ShortName');
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_BUDGETS_S_BU_10)
-- Last update 12.04.2010
-- - - - - - - - - - - - -

  IF (new$CurrentBudget <> :OLD.CurrentBudget) THEN
      IF (new$currentbudget = 1) THEN
         UPDATE budgets_s
            SET currentbudget = 0
          WHERE ID <> new$ID;
         update intconst set
           constvalue = new$ID
         where (ProgIndex = -1) and (ConstIndex = 3);
         --         
         update intconst set
           constvalue = new$BudgetLevel
         where (Progindex = -1) and (ConstIndex = 5);
      ELSE
         new$currentbudget := 0;
      END IF;
  else
     --     ,    ,
     --      
     if (new$BudgetLevel <> :old.BudgetLevel) then
       update intconst set
         constvalue = new$BudgetLevel
       where (ProgIndex = -1) and (ConstIndex = 5);
     end if;  
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BUDGETS_S SET
    ID = new$ID,
    NAME = new$NAME,
    LASTMODIFDATE_B = new$LASTMODIFDATE_B,
    CURRENTBUDGET = new$CURRENTBUDGET,
    NOTE = new$NOTE,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    AYEAR = new$AYEAR,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETLEVEL = new$BUDGETLEVEL,
    CHIEFNAME = new$CHIEFNAME,
    CHIEFROLE = new$CHIEFROLE,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    EXTID = new$EXTID
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUDGETS_S_AU_500)
-- Create 15.02.2006
-- - - - - - - - - - - - -

  if (new$ID <> :old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (178, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID = 178) and (RecordId = new$ID);
  end if;

END;
/
ALTER TABLE KFSR ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE KESR ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE KVR ADD (
  ExtID VARCHAR2(50),/* UID     ,  GUID */
  ExtOwner VARCHAR2(50),/*    */
  ExtSyncDate DATE,/* ,  ,   */
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion NUMBER(10),/*     */
    CHECK((ExtVersion<=2147483647)AND(ExtVersion>-2147483648)),
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE KVR DROP CONSTRAINT uq_kvr_ver_key DROP INDEX
/
ALTER TABLE kvr ADD (
  CONSTRAINT uq_kvr_ver_key UNIQUE (code, budgetref, ExtID)
)
/
ALTER TABLE KCSR ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE KCSR DROP CONSTRAINT uq_kcsr_ver_key DROP INDEX
/
ALTER TABLE KCSR ADD (
  CONSTRAINT uq_kcsr_ver_key UNIQUE (code, budgetref, ExtID)
)
/
ALTER TABLE KVSR ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE KVSR DROP CONSTRAINT uq_kvsr_ver_key DROP INDEX
/
ALTER TABLE KVSR ADD (
  CONSTRAINT uq_kvsr_ver_key UNIQUE (code, budgetref, ExtID)
)
/
ALTER TABLE TB_Organizations ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE
)
/

CREATE OR REPLACE VIEW Organizations (
  ID,
  NAME,
  GOSNI,
  CITY,
  COUNTRY,
  PHONE,
  ADDRESS,
  ORG_CLS,
  INN20,
  SUBINN,
  FACIALACC,
  REGIONCLS,
  DIRNAME,
  BUGNAME,
  DIRPHONE,
  BUGPHONE,
  RCORG,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  INN,
  OKATO,
  EMAIL,
  WEBSITE,
  UFKCODE,
  ADDOKATO,
  SHORTNAME,
  RVERSION,
  SENDERID,
  KVSR,
  OKFS,
  OKOPF,
  OPENDATE,
  CLOSEDATE,
  CHANGEDATE,
  GENERALORG_REF,
  FEDERALREGIONCODE,
  ORG_TYPE,
  BUDGETREF,
  SUPPLIERSTATUS,
  COUNTRYCODE,
  DATECLOSE,
  ORGCODE,
  COSTAUTHORITY,
  INCOMEAUTHORITY,
  DEBTAUTHORITY,
  SVRAUTHORITY,
  CLIENTID,
  DATEOPEN,
  FUID,
  OKPO,
  OKTMO,
  DOCSTATEREF,
  CRYPTOSTATUS,
  OGRN,
  REJECT_CLS,
  REJECTCAUSE,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  REMOTEPBSCODE,
  REMOTENOTPBSCODE,
  USECHECK_CARD,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE)
AS
  SELECT
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    REJECTCAUSE,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  FROM TB_Organizations
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_ID
  INSTEAD OF DELETE
  ON ORGANIZATIONS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ORGANIZATIONS_BD)
-- Last update 09.06.2008
-- - - - - - - - - - - - -

  if (:old.ID = 0) then
    RaiseException('ex_CantDelUnknownOrg');
  end if;

  delete from Org_Accounts where org_ref = :old.id;
  delete from Banks where id = :old.id;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ORGANIZATIONS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_ORGANIZATIONS_AD_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

update Organizations set
    GeneralOrg_Ref = id
  where
    GeneralOrg_Ref = :old.id;

-- - - - - - - - - - - - -
-- AD_210 (TR_ORGANIZATIONS_AD_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*       */
  delete 
  from 
  StateJumpHistory
  where 
  DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ORGANIZATIONS_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(27, :old.ID ,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_II
  INSTEAD OF INSERT
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_Organizations_bi)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FUID is null) then 
    new$FUID := new$id;
  END IF;
  if (new$GOSNI is null) then 
    new$GOSNI := 0;
  END IF;
  if (new$Name is null) then 
    new$Name := '  ';
  END IF;
  if (new$City is null) then 
    GetVarcharConst(-1,7,new$City);
  END IF;
  if (new$COUNTRY is null) then 
    new$COUNTRY := '';
  END IF;
  if (new$CountryCode is null) then 
    new$CountryCode := 643;
  END IF;
  if (new$ORG_CLS is NULL) then 
    new$ORG_CLS:= 0;
  END IF;
  if (new$SubINN is null) then 
    new$SubINN:= 0;
  END IF;
  if (new$INN20 is null) then 
    new$INN20:= '';
  END IF;
  if (new$RCOrg is null) then 
    new$RCOrg := 0;
  END IF;
  if (new$RegionCls is null) then 
    new$RegionCls := 0;
  END IF;
  if (new$OKATO is null) then 
    new$OKATO := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$OKFS is null) then 
    new$OKFS := 0;
  END IF;
  if (new$OKOPF is null) then 
    new$OKOPF := 0;
  END IF;
  if (new$FederalRegionCode is null) then
    GetIntConst(-1, 27,new$FederalRegionCode);
  END IF;
  if (new$FederalRegionCode is null) then
    new$FederalRegionCode := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;
  /*    10 ,      */
  if ((new$INN > 9999999999.9) and (new$INN20 <> '') and (new$INN20 is not null)) then
    RaiseException('EX_WRONGKPP');
  END IF;
  check_unique_organization(new$inn,  new$inn20);
  if (new$CostAuthority is null) then 
    new$CostAuthority:= 0;
  END IF;
  if (new$IncomeAuthority is null) then 
    new$IncomeAuthority := 0;
  END IF;
  if (new$DebtAuthority is null) then 
    new$DebtAuthority := 0;
  END IF;
  if (new$SVRAuthority is null) then 
    new$SVRAuthority := 0;
  END IF;
  /*        */
  if (new$Org_Type is not null)
  then 
    if (new$Org_Type between 10100 and 10299) then
      new$CostAuthority:= 1;
    END IF;
    if (new$Org_Type between 10300 and 10399) then
      new$CostAuthority:= 2;
    END IF;
    if (new$Org_Type between 10400 and 10499) then
      new$CostAuthority:= 4;
    END IF;
    if (((new$Org_Type between 10500 and 10599) and (new$CostAuthority<>16)) or
    (((new$Org_Type between 10000 and 10099) or (new$Org_Type between 10600 and 10799))
    and (new$CostAuthority=0))) then
      new$CostAuthority:= 8;
        
    END IF;
  else 
    new$Org_Type := 0;
  END IF;
  if (new$UseCheck_Card is null) then 
    new$UseCheck_Card := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_ORGANIZATIONS_BI_10)
-- Last update 19.10.2006
-- - - - - - - - - - - - -

  if (new$FacialAcc is not null) then
    select count(id) into cnt$ from Organizations where (FacialAcc = new$FacialAcc) AND (ROWNUM = 1);
    if (cnt$ <> 0) then RaiseException('ex_DublicateFacialAcc'); end if;
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_ORGANIZATIONS_BI_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;

    /*       ,     */
    if (new$KVSR = 0) then
      select o.KVSR into new$KVSR
      from Organizations o
      where o.id = new$GeneralOrg_Ref;
    end if;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_ORGANIZATIONS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ORGANIZATIONS (
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    REJECTCAUSE,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  ) VALUES (
    new$ID,
    new$NAME,
    new$GOSNI,
    new$CITY,
    new$COUNTRY,
    new$PHONE,
    new$ADDRESS,
    new$ORG_CLS,
    new$INN20,
    new$SUBINN,
    new$FACIALACC,
    new$REGIONCLS,
    new$DIRNAME,
    new$BUGNAME,
    new$DIRPHONE,
    new$BUGPHONE,
    new$RCORG,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$INN,
    new$OKATO,
    new$EMAIL,
    new$WEBSITE,
    new$UFKCODE,
    new$ADDOKATO,
    new$SHORTNAME,
    new$RVERSION,
    new$SENDERID,
    new$KVSR,
    new$OKFS,
    new$OKOPF,
    new$OPENDATE,
    new$CLOSEDATE,
    new$CHANGEDATE,
    new$GENERALORG_REF,
    new$FEDERALREGIONCODE,
    new$ORG_TYPE,
    new$BUDGETREF,
    new$SUPPLIERSTATUS,
    new$COUNTRYCODE,
    new$DATECLOSE,
    new$ORGCODE,
    new$COSTAUTHORITY,
    new$INCOMEAUTHORITY,
    new$DEBTAUTHORITY,
    new$SVRAUTHORITY,
    new$CLIENTID,
    new$DATEOPEN,
    new$FUID,
    new$OKPO,
    new$OKTMO,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$OGRN,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$REMOTEPBSCODE,
    new$REMOTENOTPBSCODE,
    new$USECHECK_CARD,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ORGANIZATIONS_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 27) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CNT$ NUMBER(10);
  c1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$gosni is null) then 
    new$gosni := 0;
  END IF;
  if (new$city is null) then 
    getvarcharconst(-1,7,new$city);
  END IF;
  if (new$country is null) then 
    new$country := '';
  END IF;
  if (new$countrycode is null) then 
    new$countrycode := 643;
  END IF;
  if (new$org_cls is null) then 
    new$org_cls:= 0;
  END IF;
  if (new$inn20 is null) then 
    new$inn20:= '';
  END IF;
  if (new$rcorg is null) then 
    new$rcorg := 0;
  END IF;
  if (new$regioncls is null) then 
    new$regioncls := 0;
  END IF;
  if (new$okato is null) then 
    new$okato := 0;
  END IF;
  if (new$kvsr is null) then 
    new$kvsr := 0;
  END IF;
  if (new$okfs is null) then 
    new$okfs := 0;
  END IF;
  if (new$okopf is null) then 
    new$okopf := 0;
  END IF;
  if (new$federalregioncode is null) then
    getintconst(-1, 27,new$federalregioncode);
  END IF;
  if (new$federalregioncode is null) then
    new$federalregioncode := 0;
  END IF;
  if (new$budgetref is null) then 
    new$budgetref := 0;
  END IF;
  if (new$org_type is null) then 
    new$org_type := 0;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;

  /*    10 ,      */
  if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then 
    if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
      RaiseException('ex_wrongkpp');  
    END IF;
  END IF;
  if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
  or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
  then
    check_unique_organization(new$inn,  new$inn20);
  END IF;
   
  if (new$regioncls <> :old.regioncls) then
    update dfaccountsbuhtable set
    regioncls = new$regioncls
    where id = any (select id from org_accounts where org_ref = new$id);
  END IF;
  /*      */
  if (:old.id = 0) then
    RaiseException('ex_cantmodifyunknownorg');
  END IF;
  /*        */
  if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
  then 
    c1$ := new$costauthority;
    if (new$org_type between 10100 and 10299) then
      new$costauthority:= 1;
    END IF;
    if (new$org_type between 10300 and 10399) then
      new$costauthority:= 2;
    END IF;
    if (new$org_type between 10400 and 10499) then
      new$costauthority:= 4;
    END IF;
    if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
    (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
    and (new$costauthority=0))) then
      new$costauthority:= 8;
    END IF;
    if ((new$org_type=:old.org_type) and (c1$<>new$costauthority)) then
      RaiseException('ex_wrongcostauthority');  
    END IF;
  END IF;
  /*    RegionCls  ,  
         */
  if (new$regioncls <> :old.regioncls) then
    update facialacc_cls fac set
    fac.regioncls = new$regioncls
    where
    new$id = fac.org_ref;
      
  END IF;
  if (new$UseCheck_Card is null) then 
    new$UseCheck_Card := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- COMMENT     


    /*    */
    if ((new$DateClose is not null) and (:old.DateClose is null)) then
      /*         */
      update Org_Accounts set
        CloseCode = CloseCode + 10
      where Org_Ref = new$Id;
    end if;

    /*   /      */
    if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
      /*      / */
      update FacialAcc_Cls set
        DateClose = new$DateClose,
        CloseCode = CloseCode + 10
      where Org_ref = new$Id;
    end if;

    /*    */
    if ((new$DateClose is null) and (:old.DateClose is not null)) then
      update Org_Accounts set
        CloseCode = CloseCode - 10
      where Org_Ref = new$Id;

      /*      / */
      update FacialAcc_Cls set
        DateClose = new$DateClose,
        CloseCode = CloseCode - 10
      where Org_ref = new$Id;
    end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where                       
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where                       
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE KESRSubCode ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE Fact ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE Fact DROP CONSTRAINT uq_Fact_ver_key DROP INDEX
/
ALTER TABLE Fact ADD (
  CONSTRAINT uq_Fact_ver_key UNIQUE (code, budgetref, ExtID)
)
/
ALTER TABLE MeansType ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE DirectionCls ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE DirectionCls DROP CONSTRAINT uq_DirectionCls_ver_key DROP INDEX
/
ALTER TABLE DirectionCls ADD (
  CONSTRAINT uq_DirectionCls_ver_key UNIQUE (code, budgetref, ExtID)
)
/
ALTER TABLE SubsidyCls ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE SubsidyCls DROP CONSTRAINT uq_SubsidyCls_ver_key DROP INDEX
/
ALTER TABLE SubsidyCls ADD (
  CONSTRAINT uq_SubsidyCls_ver_key UNIQUE (code, budgetref, ExtID)
)
/
ALTER TABLE FinType ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE FinType DROP CONSTRAINT uq_FinType_ver_key DROP INDEX
/
ALTER TABLE FinType ADD (
  CONSTRAINT uq_FinType_ver_key UNIQUE (code, budgetref, ExtID)
)
/
ALTER TABLE NotifyTypes ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE TB_KD ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/

CREATE OR REPLACE VIEW KD (
  ID,
  REPCODE,
  CREATEDATE,
  UPDATEDATE,
  KVSR,
  DESCRIPTIONCODE,
  MAINDESCRIPTIONCODE,
  ITEMCODE,
  PROGRAMCODE,
  KESR,
  KDVALUE,
  REMOTEFLAG,
  UNIONFLAG,
  BUDGETREF,
  DELETEDATE,
  NAME,
  KD_LEVEL,
  STARTDATE,
  SHORTNAME,
  CREATERUSER,
  UPDATERUSER,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE)
AS
  SELECT
    ID,
    REPCODE,
    CREATEDATE,
    UPDATEDATE,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    KDVALUE,
    REMOTEFLAG,
    UNIONFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    KD_LEVEL,
    STARTDATE,
    SHORTNAME,
    CREATERUSER,
    UPDATERUSER,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  FROM TB_KD
/

CREATE OR REPLACE TRIGGER TR_KD_ID
  INSTEAD OF DELETE
  ON KD
  FOR EACH ROW
DECLARE
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_KD_BD_0)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  --    ,     
  if (:old.kvsr = 0) then
    select count(*) into CNT$
                 from kd kd1
                 where ((kd1.kvsr <> 0) and
                       ((kd1.descriptioncode-:old.descriptioncode>-1) and (kd1.descriptioncode-:old.descriptioncode<1)) and
                       (kd1.programcode = :old.programcode) and
                       (kd1.kesr = :old.kesr)) AND (ROWNUM = 1);
    if (CNT$ > 0) then
      RaiseException('EX_CANTDELBASECODE');
    end if;  
  end if;   

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_KD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_KD_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(80, :old.ID, sysdate);

END;
/

CREATE OR REPLACE TRIGGER TR_KD_II
  INSTEAD OF INSERT
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CNT$ NUMBER(10);
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sKESR$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KD_BI_0)
-- Version 7.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    BEGIN
      select kd_level into sKDLevel$ from KD where ((KESR = new$KESR) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$kesr = 0) then
    sKESR$ := '000';
        
  else
    if (new$kesr < 10) then
      sKESR$ := '00' || new$kesr;
          
    else
      if (new$kesr < 100) then
        sKESR$ := '0' || new$kesr;
            
      else
        sKESR$ := new$kesr;
      END IF;
    END IF;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sKESR$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KD_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_KD (
    ID,
    REPCODE,
    CREATEDATE,
    UPDATEDATE,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    KDVALUE,
    REMOTEFLAG,
    UNIONFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    KD_LEVEL,
    STARTDATE,
    SHORTNAME,
    CREATERUSER,
    UPDATERUSER,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  ) VALUES (
    new$ID,
    new$REPCODE,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$KDVALUE,
    new$REMOTEFLAG,
    new$UNIONFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$KD_LEVEL,
    new$STARTDATE,
    new$SHORTNAME,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE);

-- - - - - - - - - - - - -
-- AI_100 (TR_KD_AI_100)
-- Create 03.05.2005
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    select count(*) into CNT$
                     from kd kd1
                     where ((kd1.kvsr = 0) and
                           ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
                           (kd1.programcode = new$programcode) and
                           (kd1.kesr = new$kesr)) and (ROWNUM = 1);
    if (CNT$ = 0) then  
        insert into KD (KVSR, DescriptionCode, ProgramCode, KESR, Name, ShortName, RemoteFlag, kd_level)
        values (0, new$DescriptionCode, new$ProgramCode, new$KESR, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
    end if;  
  end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_KD_AI_500)
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 80)  and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sKESR$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 7.00.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  if (new$KVSR <> 0) then
    BEGIN
      select kd_level into sKDLevel$ from KD where ((KESR = new$KESR) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;

  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$kesr = 0) then
    sKESR$ := '000';
        
  else
    if (new$kesr < 10) then
      sKESR$ := '00' || new$kesr;
          
    else
      if (new$kesr < 100) then
        sKESR$ := '0' || new$kesr;
            
      else
        sKESR$ := new$kesr;
      END IF;
    END IF;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sKESR$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.kesr = new$kesr)
    ) AND (ROWNUM = 1)                     ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, KESR, Name, ShortName, RemoteFlag, kd_level)
      values (0, new$DescriptionCode, new$ProgramCode, new$KESR, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
        
    END IF;
  else
    /*   = 0,         ,     */
    update kd kd1 set
    name = new$name,
    ShortName = new$ShortName, 
    kd_level = new$kd_level
    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.kesr = new$kesr);
    /*        */
    if (new$deletedate is not null) then
      update kd kd1 set
      deletedate = new$deletedate
      where
      (kd1.kvsr <> 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.kesr = new$kesr) and
      (kd1.DeleteDate is null);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE TB_KD DROP CONSTRAINT UNQ_KD_KDVALUE_BUDGET DROP INDEX
/
ALTER TABLE TB_KD ADD (
  CONSTRAINT UNQ_KD_KDVALUE_BUDGET_ver_key UNIQUE (KDVALUE, BUDGETREF, ExtID)
)
/
ALTER TABLE TB_InnerFinSource ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/

CREATE OR REPLACE VIEW InnerFinSource (
  ID,
  CREATEDATE,
  UPDATEDATE,
  DIRECTION,
  KVSR,
  DESCRIPTIONCODE,
  MAINDESCRIPTIONCODE,
  ITEMCODE,
  PROGRAMCODE,
  KESR,
  FINSOURCEVALUE,
  UNIONFLAG,
  REMOTEFLAG,
  BUDGETREF,
  DELETEDATE,
  NAME,
  STARTDATE,
  SHORTNAME,
  CLSASPECT,
  CREATERUSER,
  UPDATERUSER,
  IFS_LEVEL,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE)
AS
  SELECT
    ID,
    CREATEDATE,
    UPDATEDATE,
    DIRECTION,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    FINSOURCEVALUE,
    UNIONFLAG,
    REMOTEFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    STARTDATE,
    SHORTNAME,
    CLSASPECT,
    CREATERUSER,
    UPDATERUSER,
    IFS_LEVEL,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  FROM TB_InnerFinSource
/

CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_ID
  INSTEAD OF DELETE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_INNERFINSOURCE_BD_0)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  --    ,     
  if (:old.kvsr = 0) then
    select count(*) into CNT$
                 from InnerFinSource ifs1
                 where ((ifs1.kvsr <> 0) and
                       ((ifs1.descriptioncode-:old.descriptioncode>-1) and (ifs1.descriptioncode-:old.descriptioncode<1)) and
                       (ifs1.kesr = :old.kesr)) AND (ROWNUM = 1);
    if (CNT$ > 0) then
      RaiseException('EX_CANTDELBASECODE');
    end if;
  end if;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INNERFINSOURCE
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_INNERFINSOURCE_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(145,:old.ID,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_II
  INSTEAD OF INSERT
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CNT$ NUMBER(10);
  tmp$ NUMBER(15,0);
  DescrCode1 NUMBER(10);
  DescrCode2 NUMBER(10);
  KVSRCode$ NUMBER(10);
  sKVSR VARCHAR2(3);
  sDescrCode1 VARCHAR2(7);
  sDescrCode2 VARCHAR2(7);
  sKESR VARCHAR2(3);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INNERFINSOURCE_BI_0)
-- Last update 27.10.2009
-- - - - - - - - - - - - -

  --  Id,    
  IF (new$ID IS NULL) THEN SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL; END IF;
  IF (new$KVSR IS NULL) THEN new$KVSR := 0; END IF;
  IF (new$KESR IS NULL) THEN new$KESR := 0; END IF;
  IF (new$ClsAspect IS NULL) THEN new$ClsAspect := 0; END IF;
  if (new$UnionFlag is null) then new$UnionFlag := 0; END IF;
  if (new$RemoteFlag is null) then new$RemoteFlag := 0; END IF;
  if (new$BudgetRef is null) then new$BudgetRef := 0; end if;

  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction into sIFSLevel$, sDirection$ from innerfinsource where ((KESR = new$KESR) and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;

  --         
  --   6xx, 8xx - 
  IF (new$Direction IS NULL) THEN
    if ((new$KESR between 300 and 399) or (new$KESR between 500 and 599)or (new$KESR between 800 and 899))
    THEN
      new$Direction := -1;
    ELSE
      new$Direction := 1;
    END IF;
  END IF;

  /*       */ 
  BEGIN
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      KVSRCode$ := NULL;
  END;    

  --  20-   
  --     
  if (KVSRCode$ = 0) then
      sKVSR := '000';
  elsif (KVSRCode$ < 10) then
      sKVSR := '00' || KVSRCode$;
  elsif (KVSRCode$ < 100) then
      sKVSR := '0' || KVSRCode$;
  else
      sKVSR := KVSRCode$;
  END IF;

  --    , , 
  tmp$ := new$DescriptionCode;
  DescrCode1 := TRUNC (tmp$ / 1000000);

  IF (DescrCode1 * 1000000 > tmp$) THEN
    DescrCode1 := DescrCode1 - 1;
  END IF;

  new$MainDescriptionCode := DescrCode1;          --   
  DescrCode2 := tmp$ - DescrCode1 * 1000000;
  DescrCode1 := TRUNC (DescrCode2 / 10000);

  IF (DescrCode1 * 10000 > DescrCode2) THEN
    DescrCode1 := DescrCode1 - 1;
  END IF;

  new$ItemCode := DescrCode1;                                     --
  new$ProgramCode := DescrCode2 - DescrCode1 * 10000;             --
  --      
  DescrCode1 := TRUNC (tmp$ / 10000000);

  IF (DescrCode1 * 10000000 > tmp$) THEN
    DescrCode1 := DescrCode1 - 1;
  END IF;

  DescrCode2 := tmp$ - DescrCode1 * 10000000;

  IF (DescrCode1 = 0) THEN
    sDescrCode1 := '0000000';
  ELSIF (DescrCode1 < 10) THEN
    sDescrCode1 := '000000' || DescrCode1;
  ELSIF (DescrCode1 < 100) THEN
    sDescrCode1 := '00000' || DescrCode1;
  ELSIF (DescrCode1 < 1000) THEN
    sDescrCode1 := '0000' || DescrCode1;
  ELSIF (DescrCode1 < 10000) THEN
    sDescrCode1 := '000' || DescrCode1;
  ELSIF (DescrCode1 < 100000) THEN
    sDescrCode1 := '00' || DescrCode1;
  ELSIF (DescrCode1 < 1000000) THEN
    sDescrCode1 := '0' || DescrCode1;
  ELSE
    sDescrCode1 := DescrCode1;
  END IF;

  IF (DescrCode2 = 0) THEN
    sDescrCode2 := '0000000';
  ELSIF (DescrCode2 < 10) THEN
    sDescrCode2 := '000000' || DescrCode2;
  ELSIF (DescrCode2 < 100) THEN
    sDescrCode2 := '00000' || DescrCode2;
  ELSIF (DescrCode2 < 1000) THEN
    sDescrCode2 := '0000' || DescrCode2;
  ELSIF (DescrCode2 < 10000) THEN
    sDescrCode2 := '000' || DescrCode2;
  ELSIF (DescrCode2 < 100000) THEN
    sDescrCode2 := '00' || DescrCode2;
  ELSIF (DescrCode2 < 1000000) THEN
    sDescrCode2 := '0' || DescrCode2;
  ELSE
    sDescrCode2 := DescrCode2;
  END IF;

  --     
  IF (new$kesr = 0) THEN
    sKESR := '000';
  ELSIF (new$kesr < 10) THEN
    sKESR := '00' || new$kesr;
  ELSIF (new$kesr < 100) THEN
    sKESR := '0' || new$kesr;
  ELSE
    sKESR := new$kesr;
  END IF;

  --     
  new$FinSourceValue := sKVSR || sDescrCode1 || sDescrCode2 || sKESR;

  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000')) then
    RaiseException('ex_CantModify_ZeroIFS');
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_INNERFINSOURCE_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INNERFINSOURCE (
    ID,
    CREATEDATE,
    UPDATEDATE,
    DIRECTION,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    FINSOURCEVALUE,
    UNIONFLAG,
    REMOTEFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    STARTDATE,
    SHORTNAME,
    CLSASPECT,
    CREATERUSER,
    UPDATERUSER,
    IFS_LEVEL,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  ) VALUES (
    new$ID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$DIRECTION,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$FINSOURCEVALUE,
    new$UNIONFLAG,
    new$REMOTEFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$STARTDATE,
    new$SHORTNAME,
    new$CLSASPECT,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$IFS_LEVEL,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE);

-- - - - - - - - - - - - -
-- AI_100 (TR_INNERFINSOURCE_AI_100)
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    select count(*) into CNT$
                     from InnerFinSource ifs1
                     where ((ifs1.kvsr = 0) and
                           ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
                           (ifs1.kesr = new$kesr)) AND (ROWNUM = 1);
    if (CNT$ = 0) then
        insert into InnerFinSource (KVSR, DescriptionCode, KESR, Name, ShortName, CLSAspect, RemoteFlag, Direction, IFS_Level)
        values (0, new$DescriptionCode, new$KESR, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$direction, new$IFS_Level);
    end if; 
  end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_INNERFINSOURCE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 145) and (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sKESR$ VARCHAR2(3);
  CNT$1 NUMBER(10);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  
  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction into sIFSLevel$, sDirection$ from innerfinsource where ((KESR = new$KESR) and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;  
  
  /*         
            =3,5,8 */
  if ((new$Direction is null)or(new$kesr <> :old.kesr)) then
    if ((new$KESR between 300 and 399) or (new$KESR between 500 and 599)or (new$KESR between 800 and 899))
    then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
    
  /*  20-    */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$kesr = 0) then
    sKESR$ := '000';
        
  else
    if (new$kesr < 10) then
      sKESR$ := '00' || new$kesr;
          
    else
      if (new$kesr < 100) then
        sKESR$ := '0' || new$kesr;
            
      else
        sKESR$ := new$kesr;
      END IF;
    END IF;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sKESR$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.kesr = new$kesr)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, KESR, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level)
      values (0, new$DescriptionCode, new$KESR, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level);
      
    END IF;
  else
    /*   = 0,         ,     */
    update InnerFinSource ifs1 set
    name = new$name,
    ShortName = new$ShortName,
    ifs_level = new$ifs_level,
    Direction = new$Direction
    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.kesr = new$kesr);
    /*        */
    if (new$deletedate is not null) then
      update InnerFinSource ifs1 set
      deletedate = new$deletedate
      where
      (ifs1.kvsr <> 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.kesr = new$kesr) and
      (ifs1.DeleteDate is null);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE TB_INNERFINSOURCE DROP CONSTRAINT UNQ_IFS_FSVALUE_BUDGET DROP INDEX
/
ALTER TABLE TB_INNERFINSOURCE ADD (
  CONSTRAINT UNQ_IFS_FSVALUE_BUDGET_ver_key UNIQUE (FINSOURCEVALUE, BUDGETREF, ExtID)
)
/
ALTER TABLE BudAllocationCls ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE BudAllocationCls DROP CONSTRAINT uk_BudAllocationCls_ver_key DROP INDEX
/
ALTER TABLE BudAllocationCls ADD (
  CONSTRAINT uq_BudAllocationCls_ver_key UNIQUE (code, budgetref, ExtID)
)
/
ALTER TABLE AssignmentKind ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE InvestObject ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion VARCHAR2(50),/*     */
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE InvestObject DROP CONSTRAINT unq_IO_ObjectCode_Budget DROP INDEX
/
ALTER TABLE InvestObject ADD (
  CONSTRAINT uq_InvestObject_ver_key UNIQUE (code, budgetref, ExtID)
)
/
ALTER TABLE TargetCls ADD (
  ExtID VARCHAR2(50),/* UID     ,  GUID */
  ExtOwner VARCHAR2(50),/*    */
  ExtSyncDate DATE,/* ,  ,   */
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion NUMBER(10),/*     */
    CHECK((ExtVersion<=2147483647)AND(ExtVersion>-2147483648)),
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE TB_TransfertCls ADD (
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion NUMBER(10),/*     */
    CHECK((ExtVersion<=2147483647)AND(ExtVersion>-2147483648)),
  ExtVersionDate DATE/*     */
)
/

CREATE OR REPLACE VIEW TransfertCls (
  ID,
  REGIONCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  CODE,
  RECEIVEKVSR,
  RECEIVEKFSR,
  RECEIVEKVR,
  RECEIVEKESR,
  RECEIVEKD,
  TRANSFERKVSR,
  TRANSFERKFSR,
  TRANSFERKCSR,
  TRANSFERKVR,
  TRANSFERKESR,
  TRANSFERKDVALUE,
  TARGETMEANSSIGN,
  TARGETCLS,
  STARTDATE,
  DELETEDATE,
  NOTE,
  NAME,
  BUDGETREF,
  RECEIVEKCSR,
  SOURCELEVEL,
  DESTLEVEL,
  TRANSFERTKIND,
  GRANTKIND,
  TRANSFERTYEAR,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  FACT,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE)
AS
  SELECT
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  FROM TB_TransfertCls
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_ID
  INSTEAD OF DELETE
  ON TRANSFERTCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_TRANSFERTCLS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_TRANSFERTCLS_AD_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
  values(203,:old.ID,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CurrentDate$ NUMBER;
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TRANSFERTCLS_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  select g_shared.nextval into new$ID from dual;
   
  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then 
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0; 
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_TRANSFERTCLS_BI_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKESR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CurrentDate$ NUMBER;
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TRANSFERTCLS_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then 
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0;
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TRANSFERTCLS_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKESR = new$RECEIVEKESR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
ALTER TABLE DocBase ADD (
  ExtID VARCHAR2(50),
  ExtOwner VARCHAR2(50),/*    */
  ExtSyncDate DATE,/* ,  ,   */
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion NUMBER(10),/*     */
    CHECK((ExtVersion<=2147483647)AND(ExtVersion>-2147483648)),
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE CommDirectionExpenceCls ADD (
  ExtID VARCHAR2(50),
  ExtOwner VARCHAR2(50),/*    */
  ExtSyncDate DATE,/* ,  ,   */
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion NUMBER(10),/*     */
    CHECK((ExtVersion<=2147483647)AND(ExtVersion>-2147483648)),
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE BuhAccPlan ADD (
  ExtID VARCHAR2(50),
  ExtOwner VARCHAR2(50),/*    */
  ExtSyncDate DATE,/* ,  ,   */
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion NUMBER(10),/*     */
    CHECK((ExtVersion<=2147483647)AND(ExtVersion>-2147483648)),
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE OKTMO ADD (
  ExtID VARCHAR2(50),
  ExtOwner VARCHAR2(50),/*    */
  ExtSyncDate DATE,/* ,  ,   */
  ExtRootID VARCHAR2(50),/*   */
  ExtVersion NUMBER(10),/*     */
    CHECK((ExtVersion<=2147483647)AND(ExtVersion>-2147483648)),
  ExtVersionDate DATE/*     */
)
/
ALTER TABLE OKTMO DROP CONSTRAINT UQ_OKTMO_CODE DROP INDEX
/
ALTER TABLE OKTMO ADD (
  CONSTRAINT UQ_OKTMO_CODE_ver_key UNIQUE (code, ExtID)
)
/

create index idx_Budget_ExtID on TB_Budgets_s(ExtID)
/
create index idx_KFSR_ExtID on KFSR(ExtID)
/
create index idx_KFSR_ExtRootID on KFSR(ExtRootID)
/
create index idx_KESR_ExtID on KESR(ExtID)
/
create index idx_KESR_ExtRootID on KESR(ExtRootID)
/
create index idx_KVR_ExtID on KVR(ExtID)
/
create index idx_KVR_ExtRootID on KVR(ExtRootID)
/
create index idx_KCSR_ExtID on KCSR(ExtID)
/
create index idx_KCSR_ExtRootID on KCSR(ExtRootID)
/
create index idx_KVSR_ExtID on KVSR(ExtID)
/
create index idx_KVSR_ExtRootID on KVSR(ExtRootID)
/
create index idx_Org_ExtID on TB_Organizations(ExtID)
/
create index idx_Org_ExtRootID on TB_Organizations(ExtRootID)
/
create index idx_KESRSub_ExtID on KESRSubCode(ExtID)
/
create index idx_KESRSub_ExtRootID on KESRSubCode(ExtRootID)
/
create index idx_Fact_ExtID on Fact(ExtID)
/
create index idx_Fact_ExtRootID on Fact(ExtRootID)
/
create index idx_MT_ExtID on MeansType(ExtID)
/
create index idx_MT_ExtRootID on MeansType(ExtRootID)
/
create index idx_DirCls_ExtID on DirectionCls(ExtID)
/
create index idx_DirCls_ExtRootID on DirectionCls(ExtRootID)
/
create index idx_SubsCls_ExtID on SubsidyCls(ExtID)
/
create index idx_SubsCls_ExtRootID on SubsidyCls(ExtRootID)
/
create index idx_FinType_ExtID on FinType(ExtID)
/
create index idx_FinType_ExtRootID on FinType(ExtRootID)
/

create index idx_NT_ExtID on NotifyTypes(ExtID)
/
create index idx_NT_ExtRootID on NotifyTypes(ExtRootID)
/
create index idx_KD_ExtID on TB_KD(ExtID)
/
create index idx_KD_ExtRootID on TB_KD(ExtRootID)
/
create index idx_IFS_ExtID on TB_INNERFINSOURCE(ExtID)
/
create index idx_IFS_ExtRootID on TB_INNERFINSOURCE(ExtRootID)
/
create index idx_BudAllocCls_ExtID on BudAllocationCls(ExtID)
/
create index idx_BudAllocCls_ExtRootID on BudAllocationCls(ExtRootID)
/
create index idx_AKind_ExtID on AssignmentKind(ExtID)
/
create index idx_AKind_ExtRootID on AssignmentKind(ExtRootID)
/
create index idx_IO_ExtID on InvestObject(ExtID)
/
create index idx_IO_ExtRootID on InvestObject(ExtRootID)
/
create index idx_Target_ExtID on TargetCls(ExtID)
/
create index idx_Target_ExtRootID on TargetCls(ExtRootID)
/
create index idx_Trans_ExtID on TB_TransfertCls(ExtID)
/
create index idx_Trans_ExtRootID on TB_TransfertCls(ExtRootID)
/
create index idx_DocBase_ExtID on DocBase(ExtID)
/
create index idx_DocBase_ExtRootID on DocBase(ExtRootID)
/
create index idx_ComDir_ExtID on CommDirectionExpenceCls(ExtID)
/
create index idx_ComDir_ExtRootID on CommDirectionExpenceCls(ExtRootID)
/
create index idx_BuhAcc_ExtID on BuhAccPlan(ExtID)
/
create index idx_BuhAcc_ExtRootID on BuhAccPlan(ExtRootID)
/
create index idx_OKTMO_ExtID on OKTMO(ExtID)
/
create index idx_OKTMO_ExtRootID on OKTMO(ExtRootID)
/


commit work
/

-- #########################################################
-- #########################################################
-- Alter_WEC_Note_from_255_to_1024.sql
-- #########################################################
-- #########################################################

/*     Note  255  1024   WritExecutionCaption. */
ALTER TABLE WritExecutionCaption ADD (
  Note_Buf VARCHAR2(255)
)
/
update WritExecutionCaption
  set Note_Buf = Note
/
ALTER TABLE WritExecutionCaption DROP (Note)
/
ALTER TABLE WritExecutionCaption ADD (
  Note VARCHAR2(1024)
)
/
update WritExecutionCaption
  set Note = Note_Buf
/
ALTER TABLE WritExecutionCaption DROP (Note_Buf)
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_WritExCpt_Add_Jud_Fields.sql
-- #########################################################
-- #########################################################

/*    NameJudicialAgencyRef, JudicialDecisionDate, 
   NumberPostNotice, DatePostNotice  CompletionDate   WritExecutionCaption. 
    ,    NumberDepartmentCB  Integer  Note50. */
ALTER TABLE WritExecutionCaption DROP (NumberDepartmentCB)
/
ALTER TABLE WritExecutionCaption ADD (
  NumberDepartmentCB VARCHAR2(50),/*   */
  NameJudicialAgencyRef NUMBER(10),/*   - */
    CHECK((NameJudicialAgencyRef<=2147483647)AND(NameJudicialAgencyRef>-2147483648)),
  JudicialDecisionDate NUMBER,/*     */
  NumberPostNotice VARCHAR2(50),/*    */
  CompletionDate NUMBER,/*    */
  DatePostNotice NUMBER,/*    */
  constraint FK_WEC_NameJudAgency_ref foreign key (NameJudicialAgencyRef) references TB_Organizations(ID)
)
/
CREATE INDEX FK_WEC_NameJudAgency_ref ON WritExecutionCaption(NameJudicialAgencyRef)
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_DocFields_Add_IsContainer_AttrFildKind_.sql
-- #########################################################
-- #########################################################

ALTER TABLE TB_DocumentFields ADD (
  ContainerRef NUMBER(10),/*   -,     FieldKind = 2 */
    CHECK((ContainerRef<=2147483647)AND(ContainerRef>-2147483648)),
  AttrFieldKind NUMBER(10)/*   - (null) /  (1)/ (2) */,
    CHECK((AttrFieldKind<=2147483647)AND(AttrFieldKind>-2147483648))
)
/

CREATE OR REPLACE VIEW DocumentFields (
  ID,
  NAME,
  ITFFIELDNAME,
  NOTE,
  ISBUDGET,
  DOCTYPEREF,
  DETAILNUMBER,
  CREATERUSER,
  UPDATEDATE,
  UPDATERUSER,
  CREATEDATE,
  TEMPLATEFIELD,
  ONLYREAD,
  REPORTFIELDNAME,
  DOCUMENTCLS,
  FIELDINFOREF,
  CONTAINERREF,
  ATTRFIELDKIND)
AS
  SELECT
    ID,
    NAME,
    ITFFIELDNAME,
    NOTE,
    ISBUDGET,
    DOCTYPEREF,
    DETAILNUMBER,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER,
    CREATEDATE,
    TEMPLATEFIELD,
    ONLYREAD,
    REPORTFIELDNAME,
    DOCUMENTCLS,
    FIELDINFOREF,
    CONTAINERREF,
    ATTRFIELDKIND
  FROM TB_DocumentFields
/

CREATE OR REPLACE TRIGGER TR_DOCUMENTFIELDS_ID
  INSTEAD OF DELETE
  ON DOCUMENTFIELDS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DOCUMENTFIELDS_BD)
-- Last update 29.06.2005
-- - - - - - - - - - - - -

--      
    delete from State_OpenFields
      where State_OpenFields.DocFieldRef = :old.ID;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_DOCUMENTFIELDS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_100 (TR_DOCUMENTFIELDS_AD_100)
-- Create 07.08.2007
-- - - - - - - - - - - - -

  /*       */
  update State_Filter set
    FilterActive = 0
  where
    FILTERVALUE like '%[' || :old.ID || ']%';

-- - - - - - - - - - - - -
-- AD_500 (TR_DOCUMENTFIELDS_AD_500)
-- Last update 29.06.2005
-- - - - - - - - - - - - -

/*   DelRecIndexes   */
  insert into DelRecIndexes(TableID, RecordId, DeleteDate)
       values (92, :old.ID, sysdate);

END;
/

CREATE OR REPLACE TRIGGER TR_DOCUMENTFIELDS_II
  INSTEAD OF INSERT
  ON DOCUMENTFIELDS
  FOR EACH ROW
DECLARE
  new$ID DOCUMENTFIELDS.ID%TYPE := :NEW.ID;
  new$NAME DOCUMENTFIELDS.NAME%TYPE := :NEW.NAME;
  new$ITFFIELDNAME DOCUMENTFIELDS.ITFFIELDNAME%TYPE := :NEW.ITFFIELDNAME;
  new$NOTE DOCUMENTFIELDS.NOTE%TYPE := :NEW.NOTE;
  new$ISBUDGET DOCUMENTFIELDS.ISBUDGET%TYPE := :NEW.ISBUDGET;
  new$DOCTYPEREF DOCUMENTFIELDS.DOCTYPEREF%TYPE := :NEW.DOCTYPEREF;
  new$DETAILNUMBER DOCUMENTFIELDS.DETAILNUMBER%TYPE := :NEW.DETAILNUMBER;
  new$CREATERUSER DOCUMENTFIELDS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE DOCUMENTFIELDS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER DOCUMENTFIELDS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CREATEDATE DOCUMENTFIELDS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$TEMPLATEFIELD DOCUMENTFIELDS.TEMPLATEFIELD%TYPE := :NEW.TEMPLATEFIELD;
  new$ONLYREAD DOCUMENTFIELDS.ONLYREAD%TYPE := :NEW.ONLYREAD;
  new$REPORTFIELDNAME DOCUMENTFIELDS.REPORTFIELDNAME%TYPE := :NEW.REPORTFIELDNAME;
  new$DOCUMENTCLS DOCUMENTFIELDS.DOCUMENTCLS%TYPE := :NEW.DOCUMENTCLS;
  new$FIELDINFOREF DOCUMENTFIELDS.FIELDINFOREF%TYPE := :NEW.FIELDINFOREF;
  new$CONTAINERREF DOCUMENTFIELDS.CONTAINERREF%TYPE := :NEW.CONTAINERREF;
  new$ATTRFIELDKIND DOCUMENTFIELDS.ATTRFIELDKIND%TYPE := :NEW.ATTRFIELDKIND;
--
  CNT$1 NUMBER(10);
  FieldID$ NUMBER(10);
  IDExists$ NUMBER(10);
  MinID$ NUMBER(10);
  MaxID$ NUMBER(10);
  Div_R$ NUMBER(10);
  Mod_R$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_DOCUMENTFIELDS_BI_0)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  IF (new$OnlyRead IS NULL ) THEN 
    new$OnlyRead := 0;
  END IF;
  IF (new$ID IS NULL) THEN 
    DivModFunc(new$DETAILNUMBER, 10,Div_R$, Mod_R$);
    MinID$ := (new$DOCTYPEREF*100+Mod_R$)*1000;
    IF (new$ISBUDGET IS NOT NULL) THEN
      MinID$ := MinID$+(new$ISBUDGET*10000);
    END IF;
    MaxID$ := MinID$+999;
    SELECT COUNT (ID)
    INTO FieldID$       FROM DocumentFields
    WHERE (DOCTYPEREF = new$DOCTYPEREF)
    AND (
    (
    (ISBUDGET IS NOT NULL AND new$ISBUDGET IS NOT NULL) AND
    (ISBUDGET = new$ISBUDGET)
    )
    OR (ISBUDGET IS NULL AND new$ISBUDGET IS NULL)
    )
    AND (DETAILNUMBER = new$DETAILNUMBER)
    ;
    FieldID$ := MinID$+FieldID$;
    IDExists$ := 1;
    WHILE (IDExists$  <> 0) LOOP
      FieldID$ := FieldID$+1;
      IF ((MaxID$  IS NOT NULL) AND (FieldID$  > MaxID$)) THEN 
        FieldID$ := MinID$;
        MaxID$ := NULL;
              
      END IF;
      SELECT COUNT (ID)
      INTO IDExists$         FROM DocumentFields
      WHERE (ID = FieldID$)
      ;
    END LOOP;
    new$ID := FieldID$;
      
  END IF;
  if ((new$documentcls is null)and(new$DETAILNUMBER<100)) then
    SELECT COUNT(dc.id ) INTO CNT$1
    from documentCls dc where (dc.id=new$doctyperef*100+new$DETAILNUMBER) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      new$documentcls := new$doctyperef*100+new$DETAILNUMBER;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_DOCUMENTFIELDS_BI_500)
-- Last update 29.06.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_DOCUMENTFIELDS (
    ID,
    NAME,
    ITFFIELDNAME,
    NOTE,
    ISBUDGET,
    DOCTYPEREF,
    DETAILNUMBER,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER,
    CREATEDATE,
    TEMPLATEFIELD,
    ONLYREAD,
    REPORTFIELDNAME,
    DOCUMENTCLS,
    FIELDINFOREF,
    CONTAINERREF,
    ATTRFIELDKIND
  ) VALUES (
    new$ID,
    new$NAME,
    new$ITFFIELDNAME,
    new$NOTE,
    new$ISBUDGET,
    new$DOCTYPEREF,
    new$DETAILNUMBER,
    new$CREATERUSER,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$CREATEDATE,
    new$TEMPLATEFIELD,
    new$ONLYREAD,
    new$REPORTFIELDNAME,
    new$DOCUMENTCLS,
    new$FIELDINFOREF,
    new$CONTAINERREF,
    new$ATTRFIELDKIND);

-- - - - - - - - - - - - -
-- AI_500 (TR_DOCUMENTFIELDS_AI_500)
-- Last update 29.06.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 92) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_DOCUMENTFIELDS_IU
  INSTEAD OF UPDATE
  ON DOCUMENTFIELDS
  FOR EACH ROW
DECLARE
  new$ID DOCUMENTFIELDS.ID%TYPE := :NEW.ID;
  new$NAME DOCUMENTFIELDS.NAME%TYPE := :NEW.NAME;
  new$ITFFIELDNAME DOCUMENTFIELDS.ITFFIELDNAME%TYPE := :NEW.ITFFIELDNAME;
  new$NOTE DOCUMENTFIELDS.NOTE%TYPE := :NEW.NOTE;
  new$ISBUDGET DOCUMENTFIELDS.ISBUDGET%TYPE := :NEW.ISBUDGET;
  new$DOCTYPEREF DOCUMENTFIELDS.DOCTYPEREF%TYPE := :NEW.DOCTYPEREF;
  new$DETAILNUMBER DOCUMENTFIELDS.DETAILNUMBER%TYPE := :NEW.DETAILNUMBER;
  new$CREATERUSER DOCUMENTFIELDS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE DOCUMENTFIELDS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER DOCUMENTFIELDS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CREATEDATE DOCUMENTFIELDS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$TEMPLATEFIELD DOCUMENTFIELDS.TEMPLATEFIELD%TYPE := :NEW.TEMPLATEFIELD;
  new$ONLYREAD DOCUMENTFIELDS.ONLYREAD%TYPE := :NEW.ONLYREAD;
  new$REPORTFIELDNAME DOCUMENTFIELDS.REPORTFIELDNAME%TYPE := :NEW.REPORTFIELDNAME;
  new$DOCUMENTCLS DOCUMENTFIELDS.DOCUMENTCLS%TYPE := :NEW.DOCUMENTCLS;
  new$FIELDINFOREF DOCUMENTFIELDS.FIELDINFOREF%TYPE := :NEW.FIELDINFOREF;
  new$CONTAINERREF DOCUMENTFIELDS.CONTAINERREF%TYPE := :NEW.CONTAINERREF;
  new$ATTRFIELDKIND DOCUMENTFIELDS.ATTRFIELDKIND%TYPE := :NEW.ATTRFIELDKIND;
--
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_DOCUMENTFIELDS_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$OnlyRead is null ) then 
    new$OnlyRead := 0;
  END IF;
  if (((new$doctyperef<>:old.doctyperef)or(new$DETAILNUMBER<>:old.DETAILNUMBER)or(new$documentcls is null))
  and(new$DETAILNUMBER<100)) then
    SELECT COUNT(dc.id ) INTO CNT$1
    from documentCls dc where (dc.id=new$doctyperef*100+new$DETAILNUMBER) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      new$documentcls := new$doctyperef*100+new$DETAILNUMBER;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_DOCUMENTFIELDS SET
    ID = new$ID,
    NAME = new$NAME,
    ITFFIELDNAME = new$ITFFIELDNAME,
    NOTE = new$NOTE,
    ISBUDGET = new$ISBUDGET,
    DOCTYPEREF = new$DOCTYPEREF,
    DETAILNUMBER = new$DETAILNUMBER,
    CREATERUSER = new$CREATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    CREATEDATE = new$CREATEDATE,
    TEMPLATEFIELD = new$TEMPLATEFIELD,
    ONLYREAD = new$ONLYREAD,
    REPORTFIELDNAME = new$REPORTFIELDNAME,
    DOCUMENTCLS = new$DOCUMENTCLS,
    FIELDINFOREF = new$FIELDINFOREF,
    CONTAINERREF = new$CONTAINERREF,
    ATTRFIELDKIND = new$ATTRFIELDKIND
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_500 (TR_DOCUMENTFIELDS_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (92, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=92) and (RecordId=new$ID);
  end if;

END;
/
COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Alter_WED_Add_IncomeCls.sql
-- #########################################################
-- #########################################################

/*    "ClsType"  "KD"   "WritExecutionDetail". */
ALTER TABLE WritExecutionDetail ADD (
  ClsType NUMBER(10) default 0,
    CHECK((ClsType<=2147483647)AND(ClsType>-2147483648)),
  KD NUMBER(10) default 0,
    CHECK((KD<=2147483647)AND(KD>-2147483648)),
  constraint FK_WED_KD foreign key (KD) references TB_KD(ID)    
)
/
CREATE INDEX FK_WED_KD ON WritExecutionDetail(KD)
/
-- CREATE TRIGGER TR_WritExecutionDetail_BI_110
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONDETAIL_BI
  BEFORE INSERT
  ON WRITEXECUTIONDETAIL
  FOR EACH ROW
DECLARE
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  ScheduleRef1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_WRITEXECUTIONDETAIL_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.BudgetRef is null) then
    BEGIN
      select 
      writ_c.BudgetRef 
      into :new.BudgetRef     from 
      WritExecutionCaption writ_c
      where 
      writ_c.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
    
  if (:new.Progindex is null) then 
    :new.Progindex := 556;  
  END IF;
  if (:new.FacialAcc_Cls is null) then 
    :new.FacialAcc_Cls := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.RegionCLS is null) then 
    :new.RegionCLS := 0;
  END IF;
  if (:new.Finsource is null) then 
    :new.Finsource := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.DocType is null) then 
    :new.DocType := 0;
  END IF;
  if (:new.SubKesr is null) then 
    :new.SubKesr := 0;
  END IF;
    
  if (:new.Month01 IS NULL) then  
    :new.Month01 := 0;
  END IF;
  if (:new.Month02 IS NULL) then  
    :new.Month02 := 0;
  END IF;
  if (:new.Month03 IS NULL) then  
    :new.Month03 := 0;
  END IF;
  if (:new.Month04 IS NULL) then  
    :new.Month04 := 0;
  END IF;
  if (:new.Month05 IS NULL) then  
    :new.Month05 := 0;
  END IF;
  if (:new.Month06 IS NULL) then  
    :new.Month06 := 0;
  END IF;
  if (:new.Month07 IS NULL) then  
    :new.Month07 := 0;
  END IF;
  if (:new.Month08 IS NULL) then  
    :new.Month08 := 0;
  END IF;
  if (:new.Month09 IS NULL) then  
    :new.Month09 := 0;
  END IF;
  if (:new.Month10 IS NULL) then  
    :new.Month10 := 0;
  END IF;
  if (:new.Month11 IS NULL) then  
    :new.Month11 := 0;
  END IF;
  if (:new.Month12 IS NULL) then  
    :new.Month12 := 0;
  END IF;
    
  if (:new.Quarter1 IS NULL) then  
    :new.Quarter1 := 0;
  END IF;
  if (:new.Quarter2 IS NULL) then  
    :new.Quarter2 := 0;
  END IF;
  if (:new.Quarter3 IS NULL) then  
    :new.Quarter3 := 0;
  END IF;
  if (:new.Quarter4 IS NULL) then  
    :new.Quarter4 := 0;
  END IF;
    
  if (:new.WritExecutionSumma is Null) then 
    :new.WritExecutionSumma := 0; 
  END IF;
  if ((not :new.PROMISE is null) and (not :new.BUDGETPROMISE is null)) then
    BEGIN
      select ps.id     into ScheduleRef1$ from PaymentSchedule ps
      where (ps.InnerPromiseNum = :new.BUDGETPROMISE) and
      (ps.ANumber = :new.PROMISE)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (ScheduleRef1$ <> 0) then
    :new.PScheduleRef := ScheduleRef1$;
      
  else
    :new.PScheduleRef := null;
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_WritExecutionDetail_BI_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.KD is NULL) then 
    :new.KD := 0;
  END IF;
    
  if (:new.ClsType is NULL) then
    if (:new.KD <> 0) then
      :new.ClsType := 2; /*       ClsType */
          
    else
      :new.ClsType := 0;	
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND (:new.KD <> 0)) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.KESR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_WRITEXECUTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (:new.Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = :new.PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((:new.Promise is not null) and (:new.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = :new.Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        :new.BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
    /*    ,   ,   */
    if ((:new.BudgetPromise is not null) and (:new.Promise is null)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = :new.BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      :new.Promise := BPInnerNum$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_WRITEXECUTIONDETAIL_BI_210)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (:new.Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = :new.Promise and ps.InnerPromiseNum = :new.BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_WRITEXECUTIONDETAIL_BI_500)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER TR_WritExecutionDetail_BU_110
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONDETAIL_BU
  BEFORE UPDATE
  ON WRITEXECUTIONDETAIL
  FOR EACH ROW
DECLARE
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  ConstCheck1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  ScheduleRef1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_WRITEXECUTIONDETAIL_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (:new.BudgetRef is null) then
    BEGIN
      select 
      writ_c.BudgetRef 
      into :new.BudgetRef     from 
      WritExecutionCaption writ_c
      where 
      writ_c.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.Progindex is null) then 
    :new.Progindex := 556;    
  END IF;
  if (:new.FacialAcc_Cls is null) then 
    :new.FacialAcc_Cls := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.RegionCLS is null) then 
    :new.RegionCLS := 0;
  END IF;
  if (:new.Finsource is null) then 
    :new.Finsource := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.DocType is null) then 
    :new.DocType := 0;
  END IF;
  if (:new.SubKesr is null) then 
    :new.SubKesr := 0;
  END IF;
    
  if (:new.Month01 IS NULL) then  
    :new.Month01 := 0;
  END IF;
  if (:new.Month02 IS NULL) then  
    :new.Month02 := 0;
  END IF;
  if (:new.Month03 IS NULL) then  
    :new.Month03 := 0;
  END IF;
  if (:new.Month04 IS NULL) then  
    :new.Month04 := 0;
  END IF;
  if (:new.Month05 IS NULL) then  
    :new.Month05 := 0;
  END IF;
  if (:new.Month06 IS NULL) then  
    :new.Month06 := 0;
  END IF;
  if (:new.Month07 IS NULL) then  
    :new.Month07 := 0;
  END IF;
  if (:new.Month08 IS NULL) then  
    :new.Month08 := 0;
  END IF;
  if (:new.Month09 IS NULL) then  
    :new.Month09 := 0;
  END IF;
  if (:new.Month10 IS NULL) then  
    :new.Month10 := 0;
  END IF;
  if (:new.Month11 IS NULL) then  
    :new.Month11 := 0;
  END IF;
  if (:new.Month12 IS NULL) then  
    :new.Month12 := 0;
  END IF;
    
  if (:new.Quarter1 IS NULL) then  
    :new.Quarter1 := 0;
  END IF;
  if (:new.Quarter2 IS NULL) then  
    :new.Quarter2 := 0;
  END IF;
  if (:new.Quarter3 IS NULL) then  
    :new.Quarter3 := 0;
  END IF;
  if (:new.Quarter4 IS NULL) then  
    :new.Quarter4 := 0;
  END IF;
    
  if (:new.WritExecutionSumma is Null) then 
    :new.WritExecutionSumma := 0; 
  END IF;
  if ((not :new.PROMISE is null) and (not :new.BUDGETPROMISE is null)) then
    BEGIN
      select ps.id     into ScheduleRef1$ from PaymentSchedule ps
      where (ps.InnerPromiseNum = :new.BUDGETPROMISE) and
      (ps.ANumber = :new.PROMISE)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (ScheduleRef1$ <> 0) then
    :new.PScheduleRef := ScheduleRef1$;
      
  else
    :new.PScheduleRef := null;
    
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_WritExecutionDetail_BU_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.KD is NULL) then 
    :new.KD := 0;
  END IF;
  if (:new.ClsType is NULL) then
    if (:new.KD <> 0) then
      :new.ClsType := 2; /*       ClsType */
          
    else
      :new.ClsType := 0;	
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND (:new.KD <> 0)) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.KESR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_WRITEXECUTIONDETAIL_BU_200)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  getintconst(30, 35,ConstCheck1$);
  /* ( )      ,    */
  if ((PromiseMode1$ <> 1) and (ConstCheck1$ = 1)) then
    if ((:new.Promise is not null)and((:old.Promise is null)or(:old.Promise <> :new.Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$        from
      promise_detail pr
      where
      (pr.registrnumber = :new.PROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode1$ = 1) then
    if ((:new.Promise is not null)and((:old.Promise is null)or(:old.Promise <> :new.Promise )) and 
    (:new.BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum1$       from 
      PaymentSchedule 
      where 
      (ANumber = :new.Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        :new.BudgetPromise := BPInnerNum1$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
        
    /*         NULL,    */
    if (:new.Promise is null and ((:new.BudgetPromise is not null and :old.BudgetPromise is null) or
    (:new.BudgetPromise <> :old.BudgetPromise))) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum1$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = :new.BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      :new.Promise := BPInnerNum1$;
          
    END IF;
        
    /*    ,     */
    if ((:new.BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      :new.Promise := null;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_WRITEXECUTIONDETAIL_BU_210)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (:new.Promise is not null and (
    (:old.Promise is null or :old.Promise <> :new.Promise) or
    (:old.ExecDoc is null or :new.ExecDoc is null or :old.ExecDoc <> :new.ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = :new.Promise and ps.InnerPromiseNum = :new.BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_WRITEXECUTIONDETAIL_BU_700)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  if (:new.RVersion is null) then
    :new.RVersion := 1;
  elsif ((:new.RVersion = -1) and (:old.RVersion <> -1)) then
    :new.RVersion := :old.RVersion;
  else
    :new.RVersion := :old.RVersion + 1;
  end if;

END;
/
commit work 
/
ALTER TABLE WritExecutionDetail MODIFY(ClsType NOT NULL)
/
ALTER TABLE WritExecutionDetail MODIFY(KD NOT NULL)
/

-- #########################################################
-- #########################################################
-- Alter_WEN_Description_from_1024_to_4000.sql
-- #########################################################
-- #########################################################

/*     Description  1024   4000   WritExecutionNotify. */
ALTER TABLE WritExecutionNotify ADD (
  Description_Buf VARCHAR2(1024)
)
/
update WritExecutionNotify
  set Description_Buf = Description
/
ALTER TABLE WritExecutionNotify DROP (Description)
/
ALTER TABLE WritExecutionNotify ADD (
  Description VARCHAR2(4000)
)
/
update WritExecutionNotify
  set Description = Description_Buf
/
ALTER TABLE WritExecutionNotify DROP (Description_Buf)
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_WritNotifyCls_add_fields.sql
-- #########################################################
-- #########################################################

/*   AllowDocStates ( ,     
     )  AllowWritTypes (  ,    
      )   WritNotifyCls */
ALTER TABLE WritNotifyCls ADD (
  AllowDocStates VARCHAR2(255),
  AllowWritTypes VARCHAR2(50)
)
/
commit work 
/

-- #########################################################
-- #########################################################
-- alter_Org_add_RecordOwnerOrgRef.sql
-- #########################################################
-- #########################################################

/*    ",    "   .         */
ALTER TABLE TB_Organizations ADD (
  RecordOwnerOrgRef NUMBER(10),
    CHECK((RecordOwnerOrgRef<=2147483647)AND(RecordOwnerOrgRef>-2147483648))
)
/

CREATE OR REPLACE VIEW Organizations (
  ID,
  NAME,
  GOSNI,
  CITY,
  COUNTRY,
  PHONE,
  ADDRESS,
  ORG_CLS,
  INN20,
  SUBINN,
  FACIALACC,
  REGIONCLS,
  DIRNAME,
  BUGNAME,
  DIRPHONE,
  BUGPHONE,
  RCORG,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  INN,
  OKATO,
  EMAIL,
  WEBSITE,
  UFKCODE,
  ADDOKATO,
  SHORTNAME,
  RVERSION,
  SENDERID,
  KVSR,
  OKFS,
  OKOPF,
  OPENDATE,
  CLOSEDATE,
  CHANGEDATE,
  GENERALORG_REF,
  FEDERALREGIONCODE,
  ORG_TYPE,
  BUDGETREF,
  SUPPLIERSTATUS,
  COUNTRYCODE,
  DATECLOSE,
  ORGCODE,
  COSTAUTHORITY,
  INCOMEAUTHORITY,
  DEBTAUTHORITY,
  SVRAUTHORITY,
  CLIENTID,
  DATEOPEN,
  FUID,
  OKPO,
  OKTMO,
  DOCSTATEREF,
  CRYPTOSTATUS,
  OGRN,
  REJECT_CLS,
  REJECTCAUSE,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  REMOTEPBSCODE,
  REMOTENOTPBSCODE,
  USECHECK_CARD,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  RECORDOWNERORGREF)
AS
  SELECT
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    REJECTCAUSE,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF
  FROM TB_Organizations
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_ID
  INSTEAD OF DELETE
  ON ORGANIZATIONS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ORGANIZATIONS_BD)
-- Last update 09.06.2008
-- - - - - - - - - - - - -

  if (:old.ID = 0) then
    RaiseException('ex_CantDelUnknownOrg');
  end if;

  delete from Org_Accounts where org_ref = :old.id;
  delete from Banks where id = :old.id;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ORGANIZATIONS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_ORGANIZATIONS_AD_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

update Organizations set
    GeneralOrg_Ref = id
  where
    GeneralOrg_Ref = :old.id;

-- - - - - - - - - - - - -
-- AD_210 (TR_ORGANIZATIONS_AD_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*       */
  delete 
  from 
  StateJumpHistory
  where 
  DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ORGANIZATIONS_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(27, :old.ID ,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_II
  INSTEAD OF INSERT
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_Organizations_bi)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FUID is null) then 
    new$FUID := new$id;
  END IF;
  if (new$GOSNI is null) then 
    new$GOSNI := 0;
  END IF;
  if (new$Name is null) then 
    new$Name := '  ';
  END IF;
  if (new$City is null) then 
    GetVarcharConst(-1,7,new$City);
  END IF;
  if (new$COUNTRY is null) then 
    new$COUNTRY := '';
  END IF;
  if (new$CountryCode is null) then 
    new$CountryCode := 643;
  END IF;
  if (new$ORG_CLS is NULL) then 
    new$ORG_CLS:= 0;
  END IF;
  if (new$SubINN is null) then 
    new$SubINN:= 0;
  END IF;
  if (new$INN20 is null) then 
    new$INN20:= '';
  END IF;
  if (new$RCOrg is null) then 
    new$RCOrg := 0;
  END IF;
  if (new$RegionCls is null) then 
    new$RegionCls := 0;
  END IF;
  if (new$OKATO is null) then 
    new$OKATO := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$OKFS is null) then 
    new$OKFS := 0;
  END IF;
  if (new$OKOPF is null) then 
    new$OKOPF := 0;
  END IF;
  if (new$FederalRegionCode is null) then
    GetIntConst(-1, 27,new$FederalRegionCode);
  END IF;
  if (new$FederalRegionCode is null) then
    new$FederalRegionCode := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;
  /*    10 ,      */
  if ((new$INN > 9999999999.9) and (new$INN20 <> '') and (new$INN20 is not null)) then
    RaiseException('EX_WRONGKPP');
  END IF;
  check_unique_organization(new$inn,  new$inn20);
  if (new$CostAuthority is null) then 
    new$CostAuthority:= 0;
  END IF;
  if (new$IncomeAuthority is null) then 
    new$IncomeAuthority := 0;
  END IF;
  if (new$DebtAuthority is null) then 
    new$DebtAuthority := 0;
  END IF;
  if (new$SVRAuthority is null) then 
    new$SVRAuthority := 0;
  END IF;
  /*        */
  if (new$Org_Type is not null)
  then 
    if (new$Org_Type between 10100 and 10299) then
      new$CostAuthority:= 1;
    END IF;
    if (new$Org_Type between 10300 and 10399) then
      new$CostAuthority:= 2;
    END IF;
    if (new$Org_Type between 10400 and 10499) then
      new$CostAuthority:= 4;
    END IF;
    if (((new$Org_Type between 10500 and 10599) and (new$CostAuthority<>16)) or
    (((new$Org_Type between 10000 and 10099) or (new$Org_Type between 10600 and 10799))
    and (new$CostAuthority=0))) then
      new$CostAuthority:= 8;
        
    END IF;
  else 
    new$Org_Type := 0;
  END IF;
  if (new$UseCheck_Card is null) then 
    new$UseCheck_Card := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_ORGANIZATIONS_BI_10)
-- Last update 19.10.2006
-- - - - - - - - - - - - -

  if (new$FacialAcc is not null) then
    select count(id) into cnt$ from Organizations where (FacialAcc = new$FacialAcc) AND (ROWNUM = 1);
    if (cnt$ <> 0) then RaiseException('ex_DublicateFacialAcc'); end if;
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_ORGANIZATIONS_BI_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;

    /*       ,     */
    if (new$KVSR = 0) then
      select o.KVSR into new$KVSR
      from Organizations o
      where o.id = new$GeneralOrg_Ref;
    end if;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_ORGANIZATIONS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ORGANIZATIONS (
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    REJECTCAUSE,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF
  ) VALUES (
    new$ID,
    new$NAME,
    new$GOSNI,
    new$CITY,
    new$COUNTRY,
    new$PHONE,
    new$ADDRESS,
    new$ORG_CLS,
    new$INN20,
    new$SUBINN,
    new$FACIALACC,
    new$REGIONCLS,
    new$DIRNAME,
    new$BUGNAME,
    new$DIRPHONE,
    new$BUGPHONE,
    new$RCORG,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$INN,
    new$OKATO,
    new$EMAIL,
    new$WEBSITE,
    new$UFKCODE,
    new$ADDOKATO,
    new$SHORTNAME,
    new$RVERSION,
    new$SENDERID,
    new$KVSR,
    new$OKFS,
    new$OKOPF,
    new$OPENDATE,
    new$CLOSEDATE,
    new$CHANGEDATE,
    new$GENERALORG_REF,
    new$FEDERALREGIONCODE,
    new$ORG_TYPE,
    new$BUDGETREF,
    new$SUPPLIERSTATUS,
    new$COUNTRYCODE,
    new$DATECLOSE,
    new$ORGCODE,
    new$COSTAUTHORITY,
    new$INCOMEAUTHORITY,
    new$DEBTAUTHORITY,
    new$SVRAUTHORITY,
    new$CLIENTID,
    new$DATEOPEN,
    new$FUID,
    new$OKPO,
    new$OKTMO,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$OGRN,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$REMOTEPBSCODE,
    new$REMOTENOTPBSCODE,
    new$USECHECK_CARD,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$RECORDOWNERORGREF);

-- - - - - - - - - - - - -
-- AI_500 (TR_ORGANIZATIONS_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 27) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
--
  CNT$ NUMBER(10);
  c1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$gosni is null) then 
    new$gosni := 0;
  END IF;
  if (new$city is null) then 
    getvarcharconst(-1,7,new$city);
  END IF;
  if (new$country is null) then 
    new$country := '';
  END IF;
  if (new$countrycode is null) then 
    new$countrycode := 643;
  END IF;
  if (new$org_cls is null) then 
    new$org_cls:= 0;
  END IF;
  if (new$inn20 is null) then 
    new$inn20:= '';
  END IF;
  if (new$rcorg is null) then 
    new$rcorg := 0;
  END IF;
  if (new$regioncls is null) then 
    new$regioncls := 0;
  END IF;
  if (new$okato is null) then 
    new$okato := 0;
  END IF;
  if (new$kvsr is null) then 
    new$kvsr := 0;
  END IF;
  if (new$okfs is null) then 
    new$okfs := 0;
  END IF;
  if (new$okopf is null) then 
    new$okopf := 0;
  END IF;
  if (new$federalregioncode is null) then
    getintconst(-1, 27,new$federalregioncode);
  END IF;
  if (new$federalregioncode is null) then
    new$federalregioncode := 0;
  END IF;
  if (new$budgetref is null) then 
    new$budgetref := 0;
  END IF;
  if (new$org_type is null) then 
    new$org_type := 0;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;

  /*    10 ,      */
  if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then 
    if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
      RaiseException('ex_wrongkpp');  
    END IF;
  END IF;
  if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
  or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
  then
    check_unique_organization(new$inn,  new$inn20);
  END IF;
   
  if (new$regioncls <> :old.regioncls) then
    update dfaccountsbuhtable set
    regioncls = new$regioncls
    where id = any (select id from org_accounts where org_ref = new$id);
  END IF;
  /*      */
  if (:old.id = 0) then
    RaiseException('ex_cantmodifyunknownorg');
  END IF;
  /*        */
  if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
  then 
    c1$ := new$costauthority;
    if (new$org_type between 10100 and 10299) then
      new$costauthority:= 1;
    END IF;
    if (new$org_type between 10300 and 10399) then
      new$costauthority:= 2;
    END IF;
    if (new$org_type between 10400 and 10499) then
      new$costauthority:= 4;
    END IF;
    if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
    (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
    and (new$costauthority=0))) then
      new$costauthority:= 8;
    END IF;
    if ((new$org_type=:old.org_type) and (c1$<>new$costauthority)) then
      RaiseException('ex_wrongcostauthority');  
    END IF;
  END IF;
  /*    RegionCls  ,  
         */
  if (new$regioncls <> :old.regioncls) then
    update facialacc_cls fac set
    fac.regioncls = new$regioncls
    where
    new$id = fac.org_ref;
      
  END IF;
  if (new$UseCheck_Card is null) then 
    new$UseCheck_Card := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- COMMENT     


    /*    */
    if ((new$DateClose is not null) and (:old.DateClose is null)) then
      /*         */
      update Org_Accounts set
        CloseCode = CloseCode + 10
      where Org_Ref = new$Id;
    end if;

    /*   /      */
    if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
      /*      / */
      update FacialAcc_Cls set
        DateClose = new$DateClose,
        CloseCode = CloseCode + 10
      where Org_ref = new$Id;
    end if;

    /*    */
    if ((new$DateClose is null) and (:old.DateClose is not null)) then
      update Org_Accounts set
        CloseCode = CloseCode - 10
      where Org_Ref = new$Id;

      /*      / */
      update FacialAcc_Cls set
        DateClose = new$DateClose,
        CloseCode = CloseCode - 10
      where Org_ref = new$Id;
    end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECORDOWNERORGREF = new$RECORDOWNERORGREF
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where                       
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where                       
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
/*       */
CREATE OR REPLACE PROCEDURE CHECK_UNIQUE_ORGANIZATION(    inn$ NUMBER,    inn20$ VARCHAR2)
AS
BEGIN
  NULL;
END;
/
ALTER TRIGGER TR_ORGANIZATIONS_BU_500 DISABLE
/
update Organizations
set RecordOwnerOrgRef = 0
where id <> 0
/
ALTER TRIGGER TR_ORGANIZATIONS_BU_500 ENABLE
/
CREATE OR REPLACE PROCEDURE CHECK_UNIQUE_ORGANIZATION(    inn$ NUMBER,    inn20$ VARCHAR2)
AS
  C$ NUMBER;
  CHECKKIND$ NUMBER;
  CHECKCLOSED$ NUMBER;
BEGIN
  GetIntConst(32, 15,CHECKKIND$);
  GetIntConst(32, 44,CHECKCLOSED$);
  if (CHECKKIND$ is null) then
    CHECKKIND$ := 0;
  END IF;
  if (CHECKCLOSED$ is null) then
    CHECKCLOSED$ := 0;
  END IF;
  if (CHECKKIND$ = 0)
  then 
    if ((inn20$   is null) or (inn20$  is Null))
    then 
      C$ := 0;
            
    else 
      if(CHECKCLOSED$ = 0)
      then
        /*  -     */
        select count(id)            into C$ from Organizations where (INN = inn$) and (INN20=inn20$) and (DateClose is null)
        ;
      END IF;
      if(CHECKCLOSED$ = 1)
      then
        /*  -     */
        select count(id)            into C$ from Organizations where (INN = inn$) and (INN20=inn20$)
        ;
            
      END IF;    
    END IF;
  END IF;
  if (CHECKKIND$ = 1)
  then 
    /*      -*/
    if ((inn20$   is null) or (inn20$  is Null))
    then 
      if (CHECKCLOSED$ = 0) then
        select count(id)             into C$ from Organizations where (INN = inn$) and ((INN20 is Null) or (INN20  is null)) and (DateClose is null)
        ;
      END IF;
      if (CHECKCLOSED$ = 1) then
        select count(id)             into C$ from Organizations where (INN = inn$) and ((INN20 is Null) or (INN20  is null))
        ;
            
      END IF;
    else 
      if (CHECKCLOSED$ = 0) then
        select count(id)             into C$ from Organizations where (INN = inn$) and (INN20=inn20$) and (DateClose is null)
        ;
      END IF;
      if (CHECKCLOSED$ = 1) then
        select count(id)             into C$ from Organizations where (INN = inn$) and (INN20=inn20$)
        ;
            
      END IF;    
    END IF;
  END IF;
  if (CHECKKIND$ = 2)
  then 
    /*     */      
    C$ := 0;
        
  END IF;
  if (C$ <> 0) then 
    RaiseException('ex_DublicateINN');
  END IF;
END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_LayerFieldTypes_RecommendField.sql
-- #########################################################
-- #########################################################


/* <TRANS_COMMAND>
alter table LayerFieldTypes
add RecommendField varchar2(50);

commit work;

*/
-- <TRANS_IGNORE>

DECLARE 
  v_exists integer;
BEGIN
  SELECT count(*) 
    INTO v_exists
    FROM USER_TAB_COLUMNS 
    WHERE TABLE_NAME='LAYERFIELDTYPES' AND COLUMN_NAME='RECOMMENDFIELD';
  IF (v_exists=0) THEN
    EXECUTE IMMEDIATE 'ALTER TABLE LayerFieldTypes
      ADD RecommendField varchar2(50)';
    EXECUTE IMMEDIATE 'COMMIT WORK';
  END IF;
END;
/

commit work;
/


-- #########################################################
-- #########################################################
-- Create_LayerData_RegBK.sql
-- #########################################################
-- #########################################################


/* <TRANS_COMMAND>
CREATE TABLE LayerData_RegBK 
   (	

  	ID NUMBER(10,0) NOT NULL, 
	LAYERREF NUMBER(10,0) NOT NULL, 
	LAYERVERSION NUMBER(10,0), 
	FACIALACCCLS NUMBER(10,0), 
  	SENDERID NUMBER(10,0), 
	SENDERRECORDID NUMBER(10,0), 
  	SENDERID_FORCHECK NUMBER(10,0),
	RVERSION NUMBER(10,0), 
	CREATEDATE DATE NOT NULL, 
	CREATERUSER VARCHAR2(30) NOT NULL, 
	UPDATEDATE DATE NOT NULL, 
	UPDATERUSER VARCHAR2(30) NOT NULL, 
	TASKREF NUMBER(10,0), 
  "PRODUCTREF" NUMBER(10,0), 
	OWNERUSER NUMBER(10,0) DEFAULT null NOT NULL, 
	EXECUTERUSER NUMBER(10,0) DEFAULT null NOT NULL, 
	UPDATESTATUS NUMBER(10,0), 
  UPDATEDRECORDINDEX NUMBER(10,0), 
	UPDATEGROUPINDEX NUMBER(10,0), 
  ACCEPTDATE NUMBER, 
	REJECTDATE NUMBER, 
	REJECTCAUSE VARCHAR2(255), 
	NATURALKEY VARCHAR2(255), 
	DOCSTATEREF NUMBER(10,0), 
	CRYPTOSTATUS NUMBER(10,0), 
	LOCKSTATUS NUMBER(2,0), 
	LOCKINFO VARCHAR2(255), 
	DATEOPEN NUMBER, 
	DATECLOSE NUMBER, 
	BUDGETREF NUMBER(10,0),


 
    INTFIELD00          NUMBER(10,0),
    INTFIELD01          NUMBER(10,0),
    INTFIELD02          NUMBER(10,0),
    INTFIELD03          NUMBER(10,0),
    INTFIELD04          NUMBER(10,0),
    INTFIELD05          NUMBER(10,0),
    INTFIELD06          NUMBER(10,0),
    INTFIELD07          NUMBER(10,0),
    INTFIELD08          NUMBER(10,0),
    INTFIELD09          NUMBER(10,0),
    INTFIELD10          NUMBER(10,0),

    SUMFIELD00          NUMBER(15,2) default null,
    SUMFIELD01          NUMBER(15,2) default null,
    SUMFIELD02          NUMBER(15,2) default null,
    SUMFIELD03          NUMBER(15,2) default null,
    SUMFIELD04          NUMBER(15,2) default null,
    SUMFIELD05          NUMBER(15,2) default null,
    SUMFIELD06          NUMBER(15,2) default null,
    SUMFIELD07          NUMBER(15,2) default null,
    SUMFIELD08          NUMBER(15,2) default null,
    SUMFIELD09          NUMBER(15,2) default null,
    SUMFIELD10          NUMBER(15,2) default null,
    SUMFIELD11          NUMBER(15,2) default null,
    SUMFIELD12          NUMBER(15,2) default null,
    SUMFIELD13          NUMBER(15,2) default null,
    SUMFIELD14          NUMBER(15,2) default null,
    SUMFIELD15          NUMBER(15,2) default null,

    DATEFIELD00         NUMBER,
    DATEFIELD01         NUMBER,
    DATEFIELD02         NUMBER,
    DATEFIELD03         NUMBER,
    DATEFIELD04         NUMBER,
    
    STRFIELD00          VARCHAR2(1024),
    STRFIELD01          VARCHAR2(1024),
    STRFIELD02          VARCHAR2(1024),
    STRFIELD03          VARCHAR2(1024),
    STRFIELD04          VARCHAR2(1024),

    FLOATFIELD00        NUMBER,
    FLOATFIELD01        NUMBER,
    FLOATFIELD02        NUMBER,
    FLOATFIELD03        NUMBER,
    FLOATFIELD04        NUMBER,
    FLOATFIELD05        NUMBER,

    ORG_REF             NUMBER(10,0),
    

    ID_KBK              NUMBER(10,0) NOT NULL,
    REG_DATE            NUMBER NOT NULL,
    YEAR_SUM            NUMBER(10,0) NOT NULL,
    YEAR_PLAN           NUMBER(10,0) NOT NULL,
    ID_DOCUMENT         NUMBER(10,0) NOT NULL,


    KVSR                NUMBER(10,0),
    BA                  NUMBER(10,0),
    
    KFSR                NUMBER(10,0),
    KCSR                VARCHAR2(20),
    KVR                 NUMBER(10,0),
    KESR                NUMBER(10,0),
    SUBKESR             NUMBER(10,0),
    MEANSTYPE           NUMBER(10,0),
    FACT                VARCHAR2(20),
    DIRECTION           VARCHAR2(20),
    SUBSIDY             NUMBER(10,0),
    CS                  NUMBER(10,0),

    REGION              NUMBER(10,0),
    DEPARTMENT          NUMBER(10,0),
    OKPD                NUMBER(10,0),
    
    
    
    CONSTRAINT "PK_LD_REGBK" PRIMARY KEY ("ID"),
    
   CHECK ((ID<=2147483647)AND(ID>-2147483648)) , 
   CHECK ((LayerRef<=2147483647)AND(LayerRef>-2147483648)) , 
	 CHECK ((LayerVersion<=2147483647)AND(LayerVersion>-2147483648)) , 
   CHECK ((CryptoStatus<=2147483647)AND(CryptoStatus>-2147483648)) , 
	 CHECK ((DocStateRef<=2147483647)AND(DocStateRef>-2147483648)) , 
	 CHECK ((ExecuterUser<=2147483647)AND(ExecuterUser>-2147483648)) , 
	 CHECK ((FacialAccCls<=2147483647)AND(FacialAccCls>-2147483648)) ,
   CHECK ((OwnerUser<=2147483647)AND(OwnerUser>-2147483648)) , 
   CHECK ((TASKREF<=2147483647)AND(TASKREF>-2147483648)) , 
	 CHECK ((ProductRef<=2147483647)AND(ProductRef>-2147483648)) ,
   CHECK ((Rversion<=2147483647)AND(Rversion>-2147483648)) , 
	 CHECK ((SenderID<=2147483647)AND(SenderID>-2147483648)) , 
	 CHECK ((SenderRecordID<=2147483647)AND(SenderRecordID>-2147483648)) , 
   CHECK ((UpdatedRecordIndex<=2147483647) and (UpdatedRecordIndex>=-2147483648)) , 
	 CHECK ((UpdateGroupIndex<=2147483647) and (UpdateGroupIndex>=-2147483648)) , 
	 CHECK ((UpdateStatus<=2147483647) and (UpdateStatus>=-2147483648)) , 
   CHECK ((SENDERID_FORCHECK<=2147483647) and (SENDERID_FORCHECK>=-2147483648)) , 
	 CHECK ((BUDGETREF<=2147483647)AND(BUDGETREF>-2147483648)) , 
   	 
	 CHECK ((IntField00<=2147483647)AND(IntField00>-2147483648)) , 
	 CHECK ((IntField01<=2147483647)AND(IntField01>-2147483648)) , 
	 CHECK ((IntField02<=2147483647)AND(IntField02>-2147483648)) , 
	 CHECK ((IntField03<=2147483647)AND(IntField03>-2147483648)) , 
	 CHECK ((IntField04<=2147483647)AND(IntField04>-2147483648)) , 
	 CHECK ((IntField05<=2147483647)AND(IntField05>-2147483648)) , 
	 CHECK ((IntField06<=2147483647)AND(IntField06>-2147483648)) , 
	 CHECK ((IntField07<=2147483647)AND(IntField07>-2147483648)) , 
	 CHECK ((IntField08<=2147483647)AND(IntField08>-2147483648)) , 
	 CHECK ((IntField09<=2147483647)AND(IntField09>-2147483648)) , 
	 CHECK ((IntField10<=2147483647)AND(IntField10>-2147483648)) , 
   
   CHECK ((Org_Ref<=2147483647)AND(Org_Ref>-2147483648)) ,
   
	 CHECK ((KVSR<=2147483647)AND(KVSR>-2147483648)) , 
   CHECK ((BA<=2147483647)AND(BA>-2147483648)) , 
	 CHECK ((KFSR<=2147483647)AND(KFSR>-2147483648)) , 
	 CHECK ((KVR<=2147483647)AND(KVR>-2147483648)) , 
   CHECK ((KESR<=2147483647)AND(KESR>-2147483648)) , 
	 CHECK ((SubKESR<=2147483647)AND(SubKESR>-2147483648)) , 	 
	 CHECK ((MeansType<=2147483647)AND(MeansType>-2147483648)) , 
	 CHECK ((SUBSIDY<=2147483647)AND(SUBSIDY>-2147483648)) , 
   CHECK ((CS<=2147483647)AND(CS>-2147483648)) , 
	 CHECK ((REGION<=2147483647)AND(REGION>-2147483648)) , 
   CHECK ((DEPARTMENT<=2147483647)AND(DEPARTMENT>-2147483648)) , 
	 CHECK ((OKPD<=2147483647)AND(OKPD>-2147483648)) ,
   
   CONSTRAINT FK_LD_RegBK_PRODUCTREF FOREIGN KEY (PRODUCTREF)
	  REFERENCES TENDEROBJECTS (ID) , 
	 CONSTRAINT FK_LD_RegBK_TASKREF FOREIGN KEY (TASKREF)
	  REFERENCES LAYERTASKS (ID) , 
	 CONSTRAINT FK_LD_RegBK_EXECUTER FOREIGN KEY (EXECUTERUSER)
	  REFERENCES TB_DBUSERS (ID) , 
	 CONSTRAINT FK_LD_RegBK_OWNER FOREIGN KEY (OWNERUSER)
	  REFERENCES TB_DBUSERS (ID) , 
	 CONSTRAINT FK_LD_RegBK_LAYERREF FOREIGN KEY (LAYERREF)
	  REFERENCES LAYERS (ID) , 
	 CONSTRAINT FK_LD_RegBK_FACIALACCCLS FOREIGN KEY (FACIALACCCLS)
	  REFERENCES TB_FACIALACC_CLS (ID)    
);


 CREATE INDEX FK_LD_RegBK_BUDGETREF ON LAYERDATA_RegBK (BUDGETREF); 
 CREATE INDEX FK_LD_RegBK_LAYER ON LAYERDATA_RegBK (LAYERREF, LAYERVERSION);

 CREATE INDEX IDX_LD_RegBK_ID_KBK ON LAYERDATA_RegBK (ID_KBK);
 CREATE INDEX IDX_LD_RegBK_REG_DATE ON LAYERDATA_RegBK (REG_DATE);
 CREATE INDEX IDX_LD_RegBK_REG_STATE ON LAYERDATA_RegBK (DOCSTATEREF);
 CREATE INDEX IDX_LD_RegBK_YEAR_SUM ON LAYERDATA_RegBK (YEAR_SUM);
 CREATE INDEX IDX_LD_RegBK_YEAR_PLAN ON LAYERDATA_RegBK (YEAR_PLAN);

 CREATE INDEX IDX_LD_RegBK_KVSR ON LAYERDATA_RegBK (KVSR);
 CREATE INDEX IDX_LD_RegBK_BA ON LAYERDATA_RegBK (BA);
 CREATE INDEX IDX_LD_RegBK_KFSR ON LAYERDATA_RegBK (KFSR);
 CREATE INDEX IDX_LD_RegBK_KCSR ON LAYERDATA_RegBK (KCSR);
 CREATE INDEX IDX_LD_RegBK_KVR ON LAYERDATA_RegBK (KVR);
 CREATE INDEX IDX_LD_RegBK_KESR ON LAYERDATA_RegBK (KESR);
 CREATE INDEX IDX_LD_RegBK_SUBKESR ON LAYERDATA_RegBK (SUBKESR);
 CREATE INDEX IDX_LD_RegBK_MEANSTYPE ON LAYERDATA_RegBK (MEANSTYPE);
 CREATE INDEX IDX_LD_RegBK_FACT ON LAYERDATA_RegBK (FACT);
 CREATE INDEX IDX_LD_RegBK_DIRECTION ON LAYERDATA_RegBK (DIRECTION);
 CREATE INDEX IDX_LD_RegBK_REGIONCLS ON LAYERDATA_RegBK (REGION);
 CREATE INDEX IDX_LD_RegBK_SUBSIDYCLS ON LAYERDATA_RegBK (SUBSIDY);
 CREATE INDEX IDX_LD_RegBK_CS ON LAYERDATA_RegBK (CS);
 CREATE INDEX IDX_LD_RegBK_OKPD ON LAYERDATA_RegBK (OKPD);

 GRANT ALL ON LAYERDATA_RegBK TO PUBLIC;


 COMMIT WORK;
*/
-- <TRANS_IGNORE>

DECLARE
  v_exists INTEGER;
BEGIN

 SELECT count(*) 
    INTO v_exists 
    FROM user_tables 
    WHERE UPPER(Table_Name)='LAYERDATA_REGBK';
    
 IF v_exists=0 THEN

/*             */

/* *****************************************************************************/
/* **                                 Tables                                 ***/
/* *****************************************************************************/

 EXECUTE IMMEDIATE 'CREATE TABLE LayerData_RegBK 
   (	
    /* */
  	ID NUMBER(10,0) NOT NULL, 
	LAYERREF NUMBER(10,0) NOT NULL, 
	LAYERVERSION NUMBER(10,0), 
	FACIALACCCLS NUMBER(10,0), 
  	SENDERID NUMBER(10,0), 
	SENDERRECORDID NUMBER(10,0), 
  	SENDERID_FORCHECK NUMBER(10,0),
	RVERSION NUMBER(10,0), 
	CREATEDATE DATE NOT NULL, 
	CREATERUSER VARCHAR2(30) NOT NULL, 
	UPDATEDATE DATE NOT NULL, 
	UPDATERUSER VARCHAR2(30) NOT NULL, 
	TASKREF NUMBER(10,0), 
  "PRODUCTREF" NUMBER(10,0), 
	OWNERUSER NUMBER(10,0) DEFAULT null NOT NULL, 
	EXECUTERUSER NUMBER(10,0) DEFAULT null NOT NULL, 
	UPDATESTATUS NUMBER(10,0), 
  UPDATEDRECORDINDEX NUMBER(10,0), 
	UPDATEGROUPINDEX NUMBER(10,0), 
  ACCEPTDATE NUMBER, 
	REJECTDATE NUMBER, 
	REJECTCAUSE VARCHAR2(255), 
	NATURALKEY VARCHAR2(255), 
	DOCSTATEREF NUMBER(10,0), 
	CRYPTOSTATUS NUMBER(10,0), 
	LOCKSTATUS NUMBER(2,0), 
	LOCKINFO VARCHAR2(255), 
	DATEOPEN NUMBER, 
	DATECLOSE NUMBER, 
	BUDGETREF NUMBER(10,0),


    /*    */  
    INTFIELD00          NUMBER(10,0),
    INTFIELD01          NUMBER(10,0),
    INTFIELD02          NUMBER(10,0),
    INTFIELD03          NUMBER(10,0),
    INTFIELD04          NUMBER(10,0),
    INTFIELD05          NUMBER(10,0),
    INTFIELD06          NUMBER(10,0),
    INTFIELD07          NUMBER(10,0),
    INTFIELD08          NUMBER(10,0),
    INTFIELD09          NUMBER(10,0),
    INTFIELD10          NUMBER(10,0),

    SUMFIELD00          NUMBER(15,2) default null,
    SUMFIELD01          NUMBER(15,2) default null,
    SUMFIELD02          NUMBER(15,2) default null,
    SUMFIELD03          NUMBER(15,2) default null,
    SUMFIELD04          NUMBER(15,2) default null,
    SUMFIELD05          NUMBER(15,2) default null,
    SUMFIELD06          NUMBER(15,2) default null,
    SUMFIELD07          NUMBER(15,2) default null,
    SUMFIELD08          NUMBER(15,2) default null,
    SUMFIELD09          NUMBER(15,2) default null,
    SUMFIELD10          NUMBER(15,2) default null,
    SUMFIELD11          NUMBER(15,2) default null,
    SUMFIELD12          NUMBER(15,2) default null,
    SUMFIELD13          NUMBER(15,2) default null,
    SUMFIELD14          NUMBER(15,2) default null,
    SUMFIELD15          NUMBER(15,2) default null,

    DATEFIELD00         NUMBER,
    DATEFIELD01         NUMBER,
    DATEFIELD02         NUMBER,
    DATEFIELD03         NUMBER,
    DATEFIELD04         NUMBER,
    
    STRFIELD00          VARCHAR2(1024),
    STRFIELD01          VARCHAR2(1024),
    STRFIELD02          VARCHAR2(1024),
    STRFIELD03          VARCHAR2(1024),
    STRFIELD04          VARCHAR2(1024),

    FLOATFIELD00        NUMBER,
    FLOATFIELD01        NUMBER,
    FLOATFIELD02        NUMBER,
    FLOATFIELD03        NUMBER,
    FLOATFIELD04        NUMBER,
    FLOATFIELD05        NUMBER,

    ORG_REF             NUMBER(10,0),
    
    /*   */
    ID_KBK              NUMBER(10,0) NOT NULL,
    REG_DATE            NUMBER NOT NULL,
    YEAR_SUM            NUMBER(10,0) NOT NULL,
    YEAR_PLAN           NUMBER(10,0) NOT NULL,
    ID_DOCUMENT         NUMBER(10,0) NOT NULL,

    /* */
    /*   */
    KVSR                NUMBER(10,0),
    BA                  NUMBER(10,0),
    
    KFSR                NUMBER(10,0) /* / NUMBER(10,0) = INTEGER */,
    KCSR                VARCHAR2(20)  /*  NOTE20 = VARCHAR(20) */,
    KVR                 NUMBER(10,0) /*  NUMBER(10,0) = INTEGER */,
    KESR                NUMBER(10,0) /*  NUMBER(10,0) = INTEGER */,
    SUBKESR             NUMBER(10,0) /*  NUMBER(10,0) = INTEGER */,
    MEANSTYPE           NUMBER(10,0) /*   NUMBER(10,0) = INTEGER */,
    FACT                VARCHAR2(20)  /*  NOTE20 = VARCHAR(20) */,
    DIRECTION           VARCHAR2(20)  /*   NOTE20 = VARCHAR(20) */,
    SUBSIDY             NUMBER(10,0) /*   NUMBER(10,0) = INTEGER */,
    CS                  NUMBER(10,0) /*   NUMBER(10,0) = INTEGER */,

    REGION              NUMBER(10,0) /*   NUMBER(10,0) = INTEGER */,
    DEPARTMENT          NUMBER(10,0) /*   NUMBER(10,0) = INTEGER */,
    OKPD                NUMBER(10,0) /*  NUMBER(10,0) = INTEGER */,
    
    
    
    CONSTRAINT "PK_LD_REGBK" PRIMARY KEY ("ID"),
    
   CHECK ((ID<=2147483647)AND(ID>-2147483648)) ENABLE, 
   CHECK ((LayerRef<=2147483647)AND(LayerRef>-2147483648)) ENABLE, 
	 CHECK ((LayerVersion<=2147483647)AND(LayerVersion>-2147483648)) ENABLE, 
   CHECK ((CryptoStatus<=2147483647)AND(CryptoStatus>-2147483648)) ENABLE, 
	 CHECK ((DocStateRef<=2147483647)AND(DocStateRef>-2147483648)) ENABLE, 
	 CHECK ((ExecuterUser<=2147483647)AND(ExecuterUser>-2147483648)) ENABLE, 
	 CHECK ((FacialAccCls<=2147483647)AND(FacialAccCls>-2147483648)) ENABLE,
   CHECK ((OwnerUser<=2147483647)AND(OwnerUser>-2147483648)) ENABLE, 
   CHECK ((TASKREF<=2147483647)AND(TASKREF>-2147483648)) ENABLE, 
	 CHECK ((ProductRef<=2147483647)AND(ProductRef>-2147483648)) ENABLE,
   CHECK ((Rversion<=2147483647)AND(Rversion>-2147483648)) ENABLE, 
	 CHECK ((SenderID<=2147483647)AND(SenderID>-2147483648)) ENABLE, 
	 CHECK ((SenderRecordID<=2147483647)AND(SenderRecordID>-2147483648)) ENABLE, 
   CHECK ((UpdatedRecordIndex<=2147483647) and (UpdatedRecordIndex>=-2147483648)) ENABLE, 
	 CHECK ((UpdateGroupIndex<=2147483647) and (UpdateGroupIndex>=-2147483648)) ENABLE, 
	 CHECK ((UpdateStatus<=2147483647) and (UpdateStatus>=-2147483648)) ENABLE, 
   CHECK ((SENDERID_FORCHECK<=2147483647) and (SENDERID_FORCHECK>=-2147483648)) ENABLE, 
	 CHECK ((BUDGETREF<=2147483647)AND(BUDGETREF>-2147483648)) ENABLE, 
   	 
	 CHECK ((IntField00<=2147483647)AND(IntField00>-2147483648)) ENABLE, 
	 CHECK ((IntField01<=2147483647)AND(IntField01>-2147483648)) ENABLE, 
	 CHECK ((IntField02<=2147483647)AND(IntField02>-2147483648)) ENABLE, 
	 CHECK ((IntField03<=2147483647)AND(IntField03>-2147483648)) ENABLE, 
	 CHECK ((IntField04<=2147483647)AND(IntField04>-2147483648)) ENABLE, 
	 CHECK ((IntField05<=2147483647)AND(IntField05>-2147483648)) ENABLE, 
	 CHECK ((IntField06<=2147483647)AND(IntField06>-2147483648)) ENABLE, 
	 CHECK ((IntField07<=2147483647)AND(IntField07>-2147483648)) ENABLE, 
	 CHECK ((IntField08<=2147483647)AND(IntField08>-2147483648)) ENABLE, 
	 CHECK ((IntField09<=2147483647)AND(IntField09>-2147483648)) ENABLE, 
	 CHECK ((IntField10<=2147483647)AND(IntField10>-2147483648)) ENABLE, 
   
   CHECK ((Org_Ref<=2147483647)AND(Org_Ref>-2147483648)) ENABLE,
   
	 CHECK ((KVSR<=2147483647)AND(KVSR>-2147483648)) ENABLE, 
   CHECK ((BA<=2147483647)AND(BA>-2147483648)) ENABLE, 
	 CHECK ((KFSR<=2147483647)AND(KFSR>-2147483648)) ENABLE, 
	 CHECK ((KVR<=2147483647)AND(KVR>-2147483648)) ENABLE, 
   CHECK ((KESR<=2147483647)AND(KESR>-2147483648)) ENABLE, 
	 CHECK ((SubKESR<=2147483647)AND(SubKESR>-2147483648)) ENABLE, 	 
	 CHECK ((MeansType<=2147483647)AND(MeansType>-2147483648)) ENABLE, 
	 CHECK ((SUBSIDY<=2147483647)AND(SUBSIDY>-2147483648)) ENABLE, 
   CHECK ((CS<=2147483647)AND(CS>-2147483648)) ENABLE, 
	 CHECK ((REGION<=2147483647)AND(REGION>-2147483648)) ENABLE, 
   CHECK ((DEPARTMENT<=2147483647)AND(DEPARTMENT>-2147483648)) ENABLE, 
	 CHECK ((OKPD<=2147483647)AND(OKPD>-2147483648)) ENABLE,
   
   CONSTRAINT FK_LD_RegBK_PRODUCTREF FOREIGN KEY (PRODUCTREF)
	  REFERENCES TENDEROBJECTS (ID) ENABLE, 
	 CONSTRAINT FK_LD_RegBK_TASKREF FOREIGN KEY (TASKREF)
	  REFERENCES LAYERTASKS (ID) ENABLE, 
	 CONSTRAINT FK_LD_RegBK_EXECUTER FOREIGN KEY (EXECUTERUSER)
	  REFERENCES TB_DBUSERS (ID) ENABLE, 
	 CONSTRAINT FK_LD_RegBK_OWNER FOREIGN KEY (OWNERUSER)
	  REFERENCES TB_DBUSERS (ID) ENABLE, 
	 CONSTRAINT FK_LD_RegBK_LAYERREF FOREIGN KEY (LAYERREF)
	  REFERENCES LAYERS (ID) ENABLE, 
	 CONSTRAINT FK_LD_RegBK_FACIALACCCLS FOREIGN KEY (FACIALACCCLS)
	  REFERENCES TB_FACIALACC_CLS (ID) ENABLE   
)';

/* *****************************************************************************/
/* **                                Indices                                 ***/
/* *****************************************************************************/

 EXECUTE IMMEDIATE 'CREATE INDEX FK_LD_RegBK_BUDGETREF ON LAYERDATA_RegBK (BUDGETREF)'; 
 EXECUTE IMMEDIATE 'CREATE INDEX FK_LD_RegBK_LAYER ON LAYERDATA_RegBK (LAYERREF, LAYERVERSION)';
/*   */
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_ID_KBK ON LAYERDATA_RegBK (ID_KBK)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_REG_DATE ON LAYERDATA_RegBK (REG_DATE)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_REG_STATE ON LAYERDATA_RegBK (DOCSTATEREF)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_YEAR_SUM ON LAYERDATA_RegBK (YEAR_SUM)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_YEAR_PLAN ON LAYERDATA_RegBK (YEAR_PLAN)';
/*   */
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_KVSR ON LAYERDATA_RegBK (KVSR)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_BA ON LAYERDATA_RegBK (BA)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_KFSR ON LAYERDATA_RegBK (KFSR)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_KCSR ON LAYERDATA_RegBK (KCSR)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_KVR ON LAYERDATA_RegBK (KVR)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_KESR ON LAYERDATA_RegBK (KESR)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_SUBKESR ON LAYERDATA_RegBK (SUBKESR)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_MEANSTYPE ON LAYERDATA_RegBK (MEANSTYPE)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_FACT ON LAYERDATA_RegBK (FACT)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_DIRECTION ON LAYERDATA_RegBK (DIRECTION)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_REGIONCLS ON LAYERDATA_RegBK (REGION)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_SUBSIDYCLS ON LAYERDATA_RegBK (SUBSIDY)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_CS ON LAYERDATA_RegBK (CS)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_RegBK_OKPD ON LAYERDATA_RegBK (OKPD)';

 EXECUTE IMMEDIATE 'GRANT ALL ON LAYERDATA_RegBK TO PUBLIC';
 
 END IF;

END;
/

COMMIT WORK
/


-- #########################################################
-- #########################################################
-- Create_LayerData_RegBK_Triggers.sql
-- #########################################################
-- #########################################################

/* *****************************************************************************//* **                                Triggers                                ***//* *****************************************************************************/
-- CREATE TRIGGER TR_LD_REGBK_AD_500
CREATE OR REPLACE TRIGGER TR_LAYERDATA_RegBK_AD
  AFTER DELETE
  ON LAYERDATA_RegBK
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AD_500 (TR_LD_REGBK_AD_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (174, :old.ID, SYSDATE) ;

END;
/
-- CREATE TRIGGER TR_LD_REGBK_AI_500
CREATE OR REPLACE TRIGGER TR_LAYERDATA_RegBK_AI
  AFTER INSERT
  ON LAYERDATA_RegBK
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AI_500 (TR_LD_REGBK_AI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 174) and (RecordID = :new.ID);

END;
/
-- CREATE TRIGGER TR_LD_REGBK_AU_500
CREATE OR REPLACE TRIGGER TR_LAYERDATA_RegBK_AU
  AFTER UPDATE
  ON LAYERDATA_RegBK
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AU_500 (TR_LD_REGBK_AU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (174, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=174) and (RecordId=:new.ID);
      
  END IF;

END;
/
-- CREATE TRIGGER TR_LD_REGBK_BI
CREATE OR REPLACE TRIGGER TR_LAYERDATA_RegBK_BI
  BEFORE INSERT
  ON LAYERDATA_RegBK
  FOR EACH ROW
DECLARE
  fac$ NUMBER(10);
  stateref$ NUMBER(10);
  vers$ NUMBER(10);
  ad$ NUMBER;
  rd$ NUMBER;
  ou$ NUMBER(10);
  eu$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_LD_REGBK_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.LayerVersion is null) then 
    :new.LayerVersion := 0;
  END IF;
  if (:new.ExecuterUser is null) then 
    :new.ExecuterUser := :new.OwnerUser;
  END IF;
  if ((:new.FacialAccCls is null) and (:new.TaskRef is not null)) then
    BEGIN
      select FacialAccCls into fac$ from LayerTasks where ID = :new.TaskRef ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (fac$ is not null) then
      :new.FacialAccCls := fac$;
        
    END IF;
  END IF;
  if (:new.TaskRef is not null) then
    BEGIN
      select LayerVersion, DocStateRef, AcceptDate, RejectDate, OwnerUser, ExecuterUser           into vers$, stateref$, ad$, rd$, ou$, eu$ from LayerTasks where ID = :new.TaskRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    :new.LayerVersion := vers$;
    :new.DocStateRef := stateref$;
    :new.AcceptDate := ad$;
    :new.RejectDate := rd$;
    :new.OwnerUser := ou$;
    :new.ExecuterUser := eu$;
        
  END IF;

END;
/
-- CREATE TRIGGER TR_LD_REGBK_BI_500
CREATE OR REPLACE TRIGGER TR_LAYERDATA_RegBK_BI
  BEFORE INSERT
  ON LAYERDATA_RegBK
  FOR EACH ROW
DECLARE
  fac$ NUMBER(10);
  stateref$ NUMBER(10);
  vers$ NUMBER(10);
  ad$ NUMBER;
  rd$ NUMBER;
  ou$ NUMBER(10);
  eu$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_LD_REGBK_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.LayerVersion is null) then 
    :new.LayerVersion := 0;
  END IF;
  if (:new.ExecuterUser is null) then 
    :new.ExecuterUser := :new.OwnerUser;
  END IF;
  if ((:new.FacialAccCls is null) and (:new.TaskRef is not null)) then
    BEGIN
      select FacialAccCls into fac$ from LayerTasks where ID = :new.TaskRef ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (fac$ is not null) then
      :new.FacialAccCls := fac$;
        
    END IF;
  END IF;
  if (:new.TaskRef is not null) then
    BEGIN
      select LayerVersion, DocStateRef, AcceptDate, RejectDate, OwnerUser, ExecuterUser           into vers$, stateref$, ad$, rd$, ou$, eu$ from LayerTasks where ID = :new.TaskRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    :new.LayerVersion := vers$;
    :new.DocStateRef := stateref$;
    :new.AcceptDate := ad$;
    :new.RejectDate := rd$;
    :new.OwnerUser := ou$;
    :new.ExecuterUser := eu$;
        
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_LD_REGBK_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER TR_LD_REGBK_BU
CREATE OR REPLACE TRIGGER TR_LAYERDATA_RegBK_BU
  BEFORE UPDATE
  ON LAYERDATA_RegBK
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_LD_REGBK_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.LayerVersion is null) then 
    :new.LayerVersion := 0;
  END IF;
  if (:new.ExecuterUser is null) then 
    :new.ExecuterUser := :new.OwnerUser;
  END IF;

END;
/
-- CREATE TRIGGER TR_LD_REGBK_BU_500
CREATE OR REPLACE TRIGGER TR_LD_REGBK_BU_500
  BEFORE UPDATE
  ON LAYERDATA_REGBK
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_LD_REGBK_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := User;

END;
/
-- CREATE TRIGGER TR_LD_REGBK_BU_700
CREATE OR REPLACE TRIGGER TR_LAYERDATA_RegBK_BU
  BEFORE UPDATE
  ON LAYERDATA_RegBK
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_LD_REGBK_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.LayerVersion is null) then 
    :new.LayerVersion := 0;
  END IF;
  if (:new.ExecuterUser is null) then 
    :new.ExecuterUser := :new.OwnerUser;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_LD_REGBK_BU_700)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.RVersion is null) then
    :new.RVersion:= 1;
     
  else
    if ((:new.RVersion = -1) and (:old.RVersion <> -1)) then
      :new.RVersion:= :old.RVersion;
         
    else
      :new.RVersion:= :old.RVersion+1;
    END IF;
  END IF;

END;
/

COMMIT WORK
/


-- #########################################################
-- #########################################################
-- Alter_All_HandBooks_Triggers_Code.sql
-- #########################################################
-- #########################################################

-- ALTER TRIGGER tr_kcsr_bi_0
CREATE OR REPLACE TRIGGER TR_KCSR_BI
  BEFORE INSERT
  ON KCSR
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KCSR_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KCSR_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER tr_kcsr_bu_0
CREATE OR REPLACE TRIGGER TR_KCSR_BU
  BEFORE UPDATE
  ON KCSR
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KCSR_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER tr_kvsr_bi_0
CREATE OR REPLACE TRIGGER TR_KVSR_BI
  BEFORE INSERT
  ON KVSR
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KVSR_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KVSR_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER tr_kvsr_bu_0
CREATE OR REPLACE TRIGGER TR_KVSR_BU
  BEFORE UPDATE
  ON KVSR
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KVSR_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER tr_kvr_bi_0
CREATE OR REPLACE TRIGGER TR_KVR_BI
  BEFORE INSERT
  ON KVR
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KVR_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KVR_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER tr_kvr_bu_0
CREATE OR REPLACE TRIGGER TR_KVR_BU
  BEFORE UPDATE
  ON KVR
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KVR_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER tr_directioncls_bi_0
CREATE OR REPLACE TRIGGER TR_DIRECTIONCLS_BI
  BEFORE INSERT
  ON DIRECTIONCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_directioncls_bi_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_DIRECTIONCLS_BI_500)
-- - - - - - - - - - - - -

-- Created 28.09.2004
  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;

END;
/
-- ALTER TRIGGER tr_directioncls_bu_0
CREATE OR REPLACE TRIGGER TR_DIRECTIONCLS_BU
  BEFORE UPDATE
  ON DIRECTIONCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_directioncls_bu_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER tr_fact_bi_0
CREATE OR REPLACE TRIGGER TR_FACT_BI
  BEFORE INSERT
  ON FACT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACT_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACT_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER tr_fact_bu_0
CREATE OR REPLACE TRIGGER TR_FACT_BU
  BEFORE UPDATE
  ON FACT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_1 (TR_FACT_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER tr_docbase_bi_0
CREATE OR REPLACE TRIGGER TR_DOCBASE_BI
  BEFORE INSERT
  ON DOCBASE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_DOCBASE_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.KVSR is null) then
    :new.KVSR := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_DOCBASE_BI_500)
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;

END;
/
-- ALTER TRIGGER tr_docbase_bu_0
CREATE OR REPLACE TRIGGER TR_DOCBASE_BU
  BEFORE UPDATE
  ON DOCBASE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_1 (TR_DOCBASE_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.KVSR is null) then
    :new.KVSR := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER tr_fintypediv_bi_0
CREATE OR REPLACE TRIGGER TR_FINTYPE_BI
  BEFORE INSERT
  ON FINTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FINTYPEDIV_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FINTYPE_BI_500)
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;

END;
/
-- ALTER TRIGGER tr_fintypediv_bu_0
CREATE OR REPLACE TRIGGER TR_FINTYPE_BU
  BEFORE UPDATE
  ON FINTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FINTYPEDIV_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER tr_budallocationcls_bi
CREATE OR REPLACE TRIGGER TR_BUDALLOCATIONCLS_BI
  BEFORE INSERT
  ON BUDALLOCATIONCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDALLOCATIONCLS_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDALLOCATIONCLS_BI_500)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER tr_budallocationcls_bu
CREATE OR REPLACE TRIGGER TR_BUDALLOCATIONCLS_BU
  BEFORE UPDATE
  ON BUDALLOCATIONCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDALLOCATIONCLS_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;

END;
/
-- ALTER TRIGGER tr_investobject_bi_0
CREATE OR REPLACE TRIGGER TR_INVESTOBJECT_BI
  BEFORE INSERT
  ON INVESTOBJECT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_InvestObject_bi_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.Code is null) then  
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.OwnerLevel is null) then 
    :new.OwnerLevel := 0;
  END IF;
  if (:new.RegionCls is null) then 
    :new.RegionCls := 0;
  END IF;
  if (:new.BudgetFinSourceLevel is null) then 
    :new.BudgetFinSourceLevel := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if ((not ((:new.MeansType) is null)) and (:new.TargetCls is null)) then
    GetTargetClsOnMeansType(:new.MeansType,:new.TargetCls);
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (tr_InvestObject_bi_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER tr_investobject_bu_0
CREATE OR REPLACE TRIGGER TR_INVESTOBJECT_BU
  BEFORE UPDATE
  ON INVESTOBJECT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_InvestObject_bu_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.Code is null) then  
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.OwnerLevel is null) then 
    :new.OwnerLevel := 0;
  END IF;
  if (:new.RegionCls is null) then 
    :new.RegionCls := 0;
  END IF;
  if (:new.BudgetFinSourceLevel is null) then 
    :new.BudgetFinSourceLevel := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if ((not ((:new.MeansType) is null)) and (:new.TargetCls is null)) then 
    GetTargetClsOnMeansType(:new.MeansType,:new.TargetCls);
  END IF;

END;
/
-- ALTER TRIGGER tr_subsidycls_bi
CREATE OR REPLACE TRIGGER TR_SUBSIDYCLS_BI
  BEFORE INSERT
  ON SUBSIDYCLS
  FOR EACH ROW
DECLARE
  CurrentDate$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_SubsidyCLS_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.SubsidyKind is null) then 
    :new.SubsidyKind := 0;
  END IF;
  if (:new.BelongingKind is null) then
    :new.BelongingKind := 0;
  END IF;
  if (:new.SubsidyYear is null) then
    CurDateToDouble(CurrentDate$);
    :new.SubsidyYear := CurrentDate$ / 10000;
      
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.DocumentCLS is Null) then
    :new.DocumentCLS := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_SubsidyCLS_BI_500)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER tr_subsidycls_bu
CREATE OR REPLACE TRIGGER TR_SUBSIDYCLS_BU
  BEFORE UPDATE
  ON SUBSIDYCLS
  FOR EACH ROW
DECLARE
  CurrentDate$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_SubsidyCLS_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.SubsidyKind is null) then 
    :new.SubsidyKind := 0;
  END IF;
  if (:new.BelongingKind is null) then
    :new.BelongingKind := 0;
  END IF;
  if (:new.SubsidyYear is null) then
    CurDateToDouble(CurrentDate$);
    :new.SubsidyYear := CurrentDate$ / 10000;
      
  END IF;

END;
/
-- ALTER TRIGGER TR_ORGANIZATIONS_BU
CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
--
  CNT$ NUMBER(10);
  c$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$gosni is null) then 
    new$gosni := 0;
  END IF;
  if (new$city is null) then 
    getvarcharconst(-1,7,new$city);
  END IF;
  if (new$country is null) then 
    new$country := '';
  END IF;
  if (new$countrycode is null) then 
    new$countrycode := 643;
  END IF;
  if (new$org_cls is null) then 
    new$org_cls:= 0;
  END IF;
  if (new$inn20 is null) then 
    new$inn20:= '';
  END IF;
  if (new$rcorg is null) then 
    new$rcorg := 0;
  END IF;
  if (new$regioncls is null) then 
    new$regioncls := 0;
  END IF;
  if (new$okato is null) then 
    new$okato := 0;
  END IF;
  if (new$kvsr is null) then 
    new$kvsr := 0;
  END IF;
  if (new$okfs is null) then 
    new$okfs := 0;
  END IF;
  if (new$okopf is null) then 
    new$okopf := 0;
  END IF;
  if (new$federalregioncode is null) then
    getintconst(-1, 27,new$federalregioncode);
  END IF;
  if (new$federalregioncode is null) then
    new$federalregioncode := 0;
  END IF;
  if (new$budgetref is null) then 
    new$budgetref := 0;
  END IF;
  if (new$org_type is null) then 
    new$org_type := 0;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;

  /*    10 ,      */
  if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then 
    if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
      RaiseException('ex_wrongkpp');  
    END IF;
  END IF;
  if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
  or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
  then
    check_unique_organization(new$inn,  new$inn20);
  END IF;
   
  if (new$regioncls <> :old.regioncls) then
    update dfaccountsbuhtable set
    regioncls = new$regioncls
    where id = any (select id from org_accounts where org_ref = new$id);
  END IF;
  /*      */
  if (:old.id = 0) then
    RaiseException('ex_cantmodifyunknownorg');
  END IF;
  /*        */
  if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
  then 
    c$ := new$costauthority;
    if (new$org_type between 10100 and 10299) then
      new$costauthority:= 1;
    END IF;
    if (new$org_type between 10300 and 10399) then
      new$costauthority:= 2;
    END IF;
    if (new$org_type between 10400 and 10499) then
      new$costauthority:= 4;
    END IF;
    if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
    (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
    and (new$costauthority=0))) then
      new$costauthority:= 8;
    END IF;
    if ((new$org_type=:old.org_type) and (c$<>new$costauthority)) then
      RaiseException('ex_wrongcostauthority');  
    END IF;
  END IF;
  /*    RegionCls  ,  
         */
  if (new$regioncls <> :old.regioncls) then
    update facialacc_cls fac set
    fac.regioncls = new$regioncls
    where
    new$id = fac.org_ref;
      
  END IF;
  if (new$UseCheck_Card is null) then 
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then 
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- COMMENT     


    /*    */
    if ((new$DateClose is not null) and (:old.DateClose is null)) then
      /*         */
      update Org_Accounts set
        CloseCode = CloseCode + 10
      where Org_Ref = new$Id;
    end if;

    /*   /      */
    if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
      /*      / */
      update FacialAcc_Cls set
        DateClose = new$DateClose,
        CloseCode = CloseCode + 10
      where Org_ref = new$Id;
    end if;

    /*    */
    if ((new$DateClose is null) and (:old.DateClose is not null)) then
      update Org_Accounts set
        CloseCode = CloseCode - 10
      where Org_Ref = new$Id;

      /*      / */
      update FacialAcc_Cls set
        DateClose = new$DateClose,
        CloseCode = CloseCode - 10
      where Org_ref = new$Id;
    end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECORDOWNERORGREF = new$RECORDOWNERORGREF
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where                       
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where                       
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_ORGANIZATIONS_BI
CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_II
  INSTEAD OF INSERT
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_Organizations_bi)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FUID is null) then 
    new$FUID := new$id;
  END IF;
  if (new$GOSNI is null) then 
    new$GOSNI := 0;
  END IF;
  if (new$Name is null) then 
    new$Name := '  ';
  END IF;
  if (new$City is null) then 
    GetVarcharConst(-1,7,new$City);
  END IF;
  if (new$COUNTRY is null) then 
    new$COUNTRY := '';
  END IF;
  if (new$CountryCode is null) then 
    new$CountryCode := 643;
  END IF;
  if (new$ORG_CLS is NULL) then 
    new$ORG_CLS:= 0;
  END IF;
  if (new$SubINN is null) then 
    new$SubINN:= 0;
  END IF;
  if (new$INN20 is null) then 
    new$INN20:= '';
  END IF;
  if (new$RCOrg is null) then 
    new$RCOrg := 0;
  END IF;
  if (new$RegionCls is null) then 
    new$RegionCls := 0;
  END IF;
  if (new$OKATO is null) then 
    new$OKATO := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$OKFS is null) then 
    new$OKFS := 0;
  END IF;
  if (new$OKOPF is null) then 
    new$OKOPF := 0;
  END IF;
  if (new$FederalRegionCode is null) then
    GetIntConst(-1, 27,new$FederalRegionCode);
  END IF;
  if (new$FederalRegionCode is null) then
    new$FederalRegionCode := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;
  /*    10 ,      */
  if ((new$INN > 9999999999.9) and (new$INN20 <> '') and (new$INN20 is not null)) then
    RaiseException('EX_WRONGKPP');
  END IF;
  check_unique_organization(new$inn,  new$inn20);
  if (new$CostAuthority is null) then 
    new$CostAuthority:= 0;
  END IF;
  if (new$IncomeAuthority is null) then 
    new$IncomeAuthority := 0;
  END IF;
  if (new$DebtAuthority is null) then 
    new$DebtAuthority := 0;
  END IF;
  if (new$SVRAuthority is null) then 
    new$SVRAuthority := 0;
  END IF;
  /*        */
  if (new$Org_Type is not null)
  then 
    if (new$Org_Type between 10100 and 10299) then
      new$CostAuthority:= 1;
    END IF;
    if (new$Org_Type between 10300 and 10399) then
      new$CostAuthority:= 2;
    END IF;
    if (new$Org_Type between 10400 and 10499) then
      new$CostAuthority:= 4;
    END IF;
    if (((new$Org_Type between 10500 and 10599) and (new$CostAuthority<>16)) or
    (((new$Org_Type between 10000 and 10099) or (new$Org_Type between 10600 and 10799))
    and (new$CostAuthority=0))) then
      new$CostAuthority:= 8;
        
    END IF;
  else 
    new$Org_Type := 0;
  END IF;
  if (new$UseCheck_Card is null) then 
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then 
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_ORGANIZATIONS_BI_10)
-- Last update 19.10.2006
-- - - - - - - - - - - - -

  if (new$FacialAcc is not null) then
    select count(id) into cnt$ from Organizations where (FacialAcc = new$FacialAcc) AND (ROWNUM = 1);
    if (cnt$ <> 0) then RaiseException('ex_DublicateFacialAcc'); end if;
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_ORGANIZATIONS_BI_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;

    /*       ,     */
    if (new$KVSR = 0) then
      select o.KVSR into new$KVSR
      from Organizations o
      where o.id = new$GeneralOrg_Ref;
    end if;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_ORGANIZATIONS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ORGANIZATIONS (
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    REJECTCAUSE,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF
  ) VALUES (
    new$ID,
    new$NAME,
    new$GOSNI,
    new$CITY,
    new$COUNTRY,
    new$PHONE,
    new$ADDRESS,
    new$ORG_CLS,
    new$INN20,
    new$SUBINN,
    new$FACIALACC,
    new$REGIONCLS,
    new$DIRNAME,
    new$BUGNAME,
    new$DIRPHONE,
    new$BUGPHONE,
    new$RCORG,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$INN,
    new$OKATO,
    new$EMAIL,
    new$WEBSITE,
    new$UFKCODE,
    new$ADDOKATO,
    new$SHORTNAME,
    new$RVERSION,
    new$SENDERID,
    new$KVSR,
    new$OKFS,
    new$OKOPF,
    new$OPENDATE,
    new$CLOSEDATE,
    new$CHANGEDATE,
    new$GENERALORG_REF,
    new$FEDERALREGIONCODE,
    new$ORG_TYPE,
    new$BUDGETREF,
    new$SUPPLIERSTATUS,
    new$COUNTRYCODE,
    new$DATECLOSE,
    new$ORGCODE,
    new$COSTAUTHORITY,
    new$INCOMEAUTHORITY,
    new$DEBTAUTHORITY,
    new$SVRAUTHORITY,
    new$CLIENTID,
    new$DATEOPEN,
    new$FUID,
    new$OKPO,
    new$OKTMO,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$OGRN,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$REMOTEPBSCODE,
    new$REMOTENOTPBSCODE,
    new$USECHECK_CARD,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$RECORDOWNERORGREF);

-- - - - - - - - - - - - -
-- AI_500 (TR_ORGANIZATIONS_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 27) and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER tr_oktmo_bu_0
CREATE OR REPLACE TRIGGER TR_OKTMO_BU
  BEFORE UPDATE
  ON OKTMO
  FOR EACH ROW
DECLARE
  c2$ VARCHAR2(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_OKTMO_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.RegionCLS is null) then
    :new.RegionCLS := 0;
  END IF;
  if (:new.Code2 is null) then
    :new.Code2 := 0;
  END IF;
  if ((:new.NameOKTMO8 is null) and (:new.Code2 = 0)) then
    :new.NameOKTMO8 := :new.Name;
  END IF;
  if (:new.Code1 is null) then
    :new.Code1 := '00000000';
  END IF;
  if (LENGTH(:new.Code1) < 8) then
    while (LENGTH(:new.Code1) < 8) LOOP
      :new.code1 := '0' || :new.Code1;
    END LOOP;
  END IF;
  c2$ := :new.Code2;
  while (LENGTH(c2$) < 3) LOOP
    c2$ := '0' || c2$;
  END LOOP;
  :new.Code := :new.Code1 || c2$;

END;
/
-- ALTER TRIGGER tr_oktmo_bi_0
CREATE OR REPLACE TRIGGER TR_OKTMO_BI
  BEFORE INSERT
  ON OKTMO
  FOR EACH ROW
DECLARE
  c2$ VARCHAR2(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_OKTMO_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  IF (:new.ID IS NULL) THEN
    select g_shared.nextval into :new.ID from dual;
  END IF;
  if (:new.RegionCLS is null) then
    :new.RegionCLS := 0;
  END IF;
  if (:new.Code2 is null) then
    :new.Code2 := 0;
  END IF;
  if ((:new.NameOKTMO8 is null) and (:new.Code2 = 0)) then
    :new.NameOKTMO8 := :new.Name;
  END IF;
  if (:new.Code1 is null) then
    :new.Code1 := '00000000';
  END IF;
  if (LENGTH(:new.Code1) < 8) then
    while (LENGTH(:new.Code1) < 8) LOOP
      :new.code1 := '0' || :new.Code1;
    END LOOP;
  END IF;
  c2$ := :new.Code2;
  while (LENGTH(c2$) < 3) LOOP
    c2$ := '0' || c2$;
  END LOOP;
  :new.Code := :new.Code1 || c2$;

-- - - - - - - - - - - - -
-- BI_500 (TR_OKTMO_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
commit work
/



-- #########################################################
-- #########################################################
-- Create_LayerData_Backup.sql
-- #########################################################
-- #########################################################


/* <TRANS_COMMAND>
CREATE TABLE LayerData_Backup 
   (	
  	ID NUMBER(10,0) NOT NULL, 
	LAYERREF NUMBER(10,0) NOT NULL, 
	LAYERVERSION NUMBER(10,0), 
	FACIALACCCLS NUMBER(10,0), 
  	SENDERID NUMBER(10,0), 
	SENDERRECORDID NUMBER(10,0), 
  	SENDERID_FORCHECK NUMBER(10,0),
	RVERSION NUMBER(10,0), 
	CREATEDATE DATE NOT NULL, 
	CREATERUSER VARCHAR2(30) NOT NULL, 
	UPDATEDATE DATE NOT NULL, 
	UPDATERUSER VARCHAR2(30) NOT NULL, 
	TASKREF NUMBER(10,0), 
	OWNERUSER NUMBER(10,0) DEFAULT null NOT NULL, 
	EXECUTERUSER NUMBER(10,0) DEFAULT null NOT NULL, 
	UPDATESTATUS NUMBER(10,0), 
  UPDATEDRECORDINDEX NUMBER(10,0), 
	UPDATEGROUPINDEX NUMBER(10,0), 
  ACCEPTDATE NUMBER, 
	REJECTDATE NUMBER, 
	REJECTCAUSE VARCHAR2(255), 
	NATURALKEY VARCHAR2(255), 
	DOCSTATEREF NUMBER(10,0), 
	CRYPTOSTATUS NUMBER(10,0), 
	LOCKSTATUS NUMBER(2,0), 
	LOCKINFO VARCHAR2(255), 
	DATEOPEN NUMBER, 
	DATECLOSE NUMBER, 
	BUDGETREF NUMBER(10,0),
  "PRODUCTREF" NUMBER(10,0),   


    KFSR                NUMBER(10,0),
    KVSR                NUMBER(10,0),
    KESR                NUMBER(10,0),
    KVR                 NUMBER(10,0),
    SUBKESR             NUMBER(10,0),
    FINSOURCE           NUMBER(10,0),
    FACT                NUMBER(10,0),
    DIRECTIONCLS        NUMBER(10,0),
    MEANSTYPE           NUMBER(10,0),
    INTFIELD00          NUMBER(10,0),
    INTFIELD01          NUMBER(10,0),
    INTFIELD02          NUMBER(10,0),
    INTFIELD03          NUMBER(10,0),
    INTFIELD04          NUMBER(10,0),
    INTFIELD05          NUMBER(10,0),
    INTFIELD06          NUMBER(10,0),
    INTFIELD07          NUMBER(10,0),
    INTFIELD08          NUMBER(10,0),
    INTFIELD09          NUMBER(10,0),
    INTFIELD10          NUMBER(10,0),
    INTFIELD11          NUMBER(10,0),
    INTFIELD12          NUMBER(10,0),
    INTFIELD13          NUMBER(10,0),
    INTFIELD14          NUMBER(10,0),
    INTFIELD15          NUMBER(10,0),
    INTFIELD16          NUMBER(10,0),
    INTFIELD17          NUMBER(10,0),
    INTFIELD18          NUMBER(10,0),
    INTFIELD19          NUMBER(10,0),
    INTFIELD20          NUMBER(10,0),
    INTFIELD21          NUMBER(10,0),
    INTFIELD22          NUMBER(10,0),
    INTFIELD23          NUMBER(10,0),
    INTFIELD24          NUMBER(10,0),
    INTFIELD25          NUMBER(10,0),
    INTFIELD26          NUMBER(10,0),
    INTFIELD27          NUMBER(10,0),
    INTFIELD28          NUMBER(10,0),
    INTFIELD29          NUMBER(10,0),
    SUMFIELD00          NUMBER(15,2) default null,
    SUMFIELD01          NUMBER(15,2) default null,
    SUMFIELD02          NUMBER(15,2) default null,
    SUMFIELD03          NUMBER(15,2) default null,
    SUMFIELD04          NUMBER(15,2) default null,
    SUMFIELD05          NUMBER(15,2) default null,
    SUMFIELD06          NUMBER(15,2) default null,
    SUMFIELD07          NUMBER(15,2) default null,
    SUMFIELD08          NUMBER(15,2) default null,
    SUMFIELD09          NUMBER(15,2) default null,
    SUMFIELD10          NUMBER(15,2) default null,
    SUMFIELD11          NUMBER(15,2) default null,
    SUMFIELD12          NUMBER(15,2) default null,
    SUMFIELD13          NUMBER(15,2) default null,
    SUMFIELD14          NUMBER(15,2) default null,
    SUMFIELD15          NUMBER(15,2) default null,
    SUMFIELD16          NUMBER(15,2) default null,
    SUMFIELD17          NUMBER(15,2) default null,
    SUMFIELD18          NUMBER(15,2) default null,
    SUMFIELD19          NUMBER(15,2) default null,
    SUMFIELD20          NUMBER(15,2) default null,
    SUMFIELD21          NUMBER(15,2) default null,
    SUMFIELD22          NUMBER(15,2) default null,
    SUMFIELD23          NUMBER(15,2) default null,
    SUMFIELD24          NUMBER(15,2) default null,
    SUMFIELD25          NUMBER(15,2) default null,
    SUMFIELD26          NUMBER(15,2) default null,
    SUMFIELD27          NUMBER(15,2) default null,
    SUMFIELD28          NUMBER(15,2) default null,
    SUMFIELD29          NUMBER(15,2) default null,
    SUMFIELD30          NUMBER(15,2) default null,
    SUMFIELD31          NUMBER(15,2) default null,
    SUMFIELD32          NUMBER(15,2) default null,
    SUMFIELD33          NUMBER(15,2) default null,
    SUMFIELD34          NUMBER(15,2) default null,
    SUMFIELD35          NUMBER(15,2) default null,
    SUMFIELD36          NUMBER(15,2) default null,
    SUMFIELD37          NUMBER(15,2) default null,
    SUMFIELD38          NUMBER(15,2) default null,
    SUMFIELD39          NUMBER(15,2) default null,
    SUMFIELD40          NUMBER(15,2) default null,
    SUMFIELD41          NUMBER(15,2) default null,
    SUMFIELD42          NUMBER(15,2) default null,
    SUMFIELD43          NUMBER(15,2) default null,
    SUMFIELD44          NUMBER(15,2) default null,
    SUMFIELD45          NUMBER(15,2) default null,
    DATEFIELD00         NUMBER,
    DATEFIELD01         NUMBER,
    DATEFIELD02         NUMBER,
    DATEFIELD03         NUMBER,
    DATEFIELD04         NUMBER,
    DATEFIELD05         NUMBER,
    DATEFIELD06         NUMBER,
    DATEFIELD07         NUMBER,
    DATEFIELD08         NUMBER,
    DATEFIELD09         NUMBER,
    DATEFIELD10         NUMBER,
    DATEFIELD11         NUMBER,
    DATEFIELD12         NUMBER,
    DATEFIELD13         NUMBER,
    DATEFIELD14         NUMBER,
    STRFIELD00          VARCHAR(1024),
    STRFIELD01          VARCHAR(1024),
    STRFIELD02          VARCHAR(1024),
    STRFIELD03          VARCHAR(1024),
    STRFIELD04          VARCHAR(1024),
    STRFIELD05          VARCHAR(1024),
    STRFIELD06          VARCHAR(1024),
    STRFIELD07          VARCHAR(1024),
    STRFIELD08          VARCHAR(1024),
    STRFIELD09          VARCHAR(1024),
    STRFIELD10          VARCHAR(1024),
    STRFIELD11          VARCHAR(1024),
    STRFIELD12          VARCHAR(1024),
    STRFIELD13          VARCHAR(1024),
    STRFIELD14          VARCHAR(1024),
    STRFIELD15          VARCHAR(1024),
    STRFIELD16          VARCHAR(1024),
    STRFIELD17          VARCHAR(1024),
    STRFIELD18          VARCHAR(1024),
    STRFIELD19          VARCHAR(1024),
    STRFIELD20          VARCHAR(1024),
    STRFIELD21          VARCHAR(1024),
    STRFIELD22          VARCHAR(1024),
    STRFIELD23          VARCHAR(1024),
    STRFIELD24          VARCHAR(1024),
    STRFIELD25          VARCHAR(1024),
    STRFIELD26          VARCHAR(1024),
    STRFIELD27          VARCHAR(1024),
    STRFIELD28          VARCHAR(1024),
    STRFIELD29          VARCHAR(1024),
    FLOATFIELD00        NUMBER,
    FLOATFIELD01        NUMBER,
    FLOATFIELD02        NUMBER,
    FLOATFIELD03        NUMBER,
    FLOATFIELD04        NUMBER,
    FLOATFIELD05        NUMBER,
    FLOATFIELD06        NUMBER,
    FLOATFIELD07        NUMBER,
    FLOATFIELD08        NUMBER,
    FLOATFIELD09        NUMBER,
    FLOATFIELD10        NUMBER,
    DEPARTMENTCLS       NUMBER(10,0),
    VARIANT             NUMBER(10,0),
    SUBSIDYCLS          NUMBER(10,0),
    TRANSFERTCLS        NUMBER(10,0),
    REGIONCLS           NUMBER(10,0),
    ORG_REF             NUMBER(10,0),
    KCSR                VARCHAR(20),
    
    DOCUMENTID          NUMBER(10,0),
    BACKUPDATE          DATE,
    SOURCEID            NUMBER(10,0),
        
    
    CONSTRAINT "PK_LD_BK" PRIMARY KEY ("ID"),
    
   CHECK ((ID<=2147483647)AND(ID>-2147483648)), 
   CHECK ((LayerRef<=2147483647)AND(LayerRef>-2147483648)), 
	 CHECK ((LayerVersion<=2147483647)AND(LayerVersion>-2147483648)), 
   CHECK ((CryptoStatus<=2147483647)AND(CryptoStatus>-2147483648)), 
	 CHECK ((DocStateRef<=2147483647)AND(DocStateRef>-2147483648)), 
	 CHECK ((ExecuterUser<=2147483647)AND(ExecuterUser>-2147483648)), 
	 CHECK ((FacialAccCls<=2147483647)AND(FacialAccCls>-2147483648)),
   CHECK ((OwnerUser<=2147483647)AND(OwnerUser>-2147483648)), 
   CHECK ((TASKREF<=2147483647)AND(TASKREF>-2147483648)), 
	 CHECK ((ProductRef<=2147483647)AND(ProductRef>-2147483648)),
   CHECK ((Rversion<=2147483647)AND(Rversion>-2147483648)), 
	 CHECK ((SenderID<=2147483647)AND(SenderID>-2147483648)), 
	 CHECK ((SenderRecordID<=2147483647)AND(SenderRecordID>-2147483648)), 
   CHECK ((UpdatedRecordIndex<=2147483647) and (UpdatedRecordIndex>=-2147483648)), 
	 CHECK ((UpdateGroupIndex<=2147483647) and (UpdateGroupIndex>=-2147483648)), 
	 CHECK ((UpdateStatus<=2147483647) and (UpdateStatus>=-2147483648)), 
   CHECK ((SENDERID_FORCHECK<=2147483647) and (SENDERID_FORCHECK>=-2147483648)), 
	 CHECK ((BUDGETREF<=2147483647)AND(BUDGETREF>-2147483648)), 
   	 
	 CHECK ((IntField00<=2147483647)AND(IntField00>-2147483648)), 
	 CHECK ((IntField01<=2147483647)AND(IntField01>-2147483648)), 
	 CHECK ((IntField02<=2147483647)AND(IntField02>-2147483648)), 
	 CHECK ((IntField03<=2147483647)AND(IntField03>-2147483648)), 
	 CHECK ((IntField04<=2147483647)AND(IntField04>-2147483648)), 
	 CHECK ((IntField05<=2147483647)AND(IntField05>-2147483648)), 
	 CHECK ((IntField06<=2147483647)AND(IntField06>-2147483648)), 
	 CHECK ((IntField07<=2147483647)AND(IntField07>-2147483648)), 
	 CHECK ((IntField08<=2147483647)AND(IntField08>-2147483648)), 
	 CHECK ((IntField09<=2147483647)AND(IntField09>-2147483648)), 
	 CHECK ((IntField10<=2147483647)AND(IntField10>-2147483648)), 
	 CHECK ((IntField11<=2147483647)AND(IntField11>-2147483648)), 
	 CHECK ((IntField12<=2147483647)AND(IntField12>-2147483648)), 
	 CHECK ((IntField13<=2147483647)AND(IntField13>-2147483648)), 
	 CHECK ((IntField14<=2147483647)AND(IntField14>-2147483648)), 
	 CHECK ((IntField15<=2147483647)AND(IntField15>-2147483648)), 
	 CHECK ((IntField16<=2147483647)AND(IntField16>-2147483648)), 
	 CHECK ((IntField17<=2147483647)AND(IntField17>-2147483648)), 
	 CHECK ((IntField18<=2147483647)AND(IntField18>-2147483648)), 
	 CHECK ((IntField19<=2147483647)AND(IntField19>-2147483648)), 
	 CHECK ((IntField20<=2147483647)AND(IntField20>-2147483648)),
	 CHECK ((IntField21<=2147483647)AND(IntField21>-2147483648)), 
	 CHECK ((IntField22<=2147483647)AND(IntField22>-2147483648)), 
	 CHECK ((IntField23<=2147483647)AND(IntField23>-2147483648)), 
	 CHECK ((IntField24<=2147483647)AND(IntField24>-2147483648)), 
	 CHECK ((IntField25<=2147483647)AND(IntField25>-2147483648)), 
	 CHECK ((IntField26<=2147483647)AND(IntField26>-2147483648)), 
	 CHECK ((IntField27<=2147483647)AND(IntField27>-2147483648)), 
	 CHECK ((IntField28<=2147483647)AND(IntField28>-2147483648)), 
	 CHECK ((IntField29<=2147483647)AND(IntField29>-2147483648)), 
   
   CHECK ((Org_Ref<=2147483647)AND(Org_Ref>-2147483648)),
   
	 CHECK ((KVSR<=2147483647)AND(KVSR>-2147483648)), 
	 CHECK ((KFSR<=2147483647)AND(KFSR>-2147483648)), 
	 CHECK ((KVR<=2147483647)AND(KVR>-2147483648)), 
   CHECK ((KESR<=2147483647)AND(KESR>-2147483648)), 
	 CHECK ((SubKESR<=2147483647)AND(SubKESR>-2147483648)), 	 
	 CHECK ((MeansType<=2147483647)AND(MeansType>-2147483648)), 
	 CHECK ((SUBSIDYCLS<=2147483647)AND(SUBSIDYCLS>-2147483648)), 
	 CHECK ((REGIONCLS<=2147483647)AND(REGIONCLS>-2147483648)), 
   CHECK ((DEPARTMENTCLS<=2147483647)AND(DEPARTMENTCLS>-2147483648))
);

 INSERT INTO GENERATORS (NAME,Value) VALUES ('G_LD_BACKUP',1);


 CREATE INDEX IDX_LD_BK_LAYERREF ON LAYERDATA_BACKUP(LAYERREF);
 CREATE INDEX IDX_LD_BK_LAYER ON LAYERDATA_BACKUP(LAYERREF,DOCUMENTID);

 CREATE INDEX IDX_LD_BK_DOCID ON LAYERDATA_BACKUP(DOCUMENTID);

 GRANT ALL ON LAYERDATA_Backup TO PUBLIC;

 COMMIT WORK;
*/
-- <TRANS_IGNORE>


DECLARE
  v_exists INTEGER;
BEGIN

 SELECT count(*) 
    INTO v_exists 
    FROM user_tables 
    WHERE UPPER(Table_Name)='LAYERDATA_BACKUP';
    
 IF v_exists=0 THEN

/*             */

/* *****************************************************************************/
/* **                                 Tables                                 ***/
/* *****************************************************************************/

 EXECUTE IMMEDIATE 'CREATE TABLE LayerData_Backup 
   (	
    /* */
  	ID NUMBER(10,0) NOT NULL, 
	LAYERREF NUMBER(10,0) NOT NULL, 
	LAYERVERSION NUMBER(10,0), 
	FACIALACCCLS NUMBER(10,0), 
  	SENDERID NUMBER(10,0), 
	SENDERRECORDID NUMBER(10,0), 
  	SENDERID_FORCHECK NUMBER(10,0),
	RVERSION NUMBER(10,0), 
	CREATEDATE DATE NOT NULL, 
	CREATERUSER VARCHAR2(30) NOT NULL, 
	UPDATEDATE DATE NOT NULL, 
	UPDATERUSER VARCHAR2(30) NOT NULL, 
	TASKREF NUMBER(10,0), 
	OWNERUSER NUMBER(10,0) DEFAULT null NOT NULL, 
	EXECUTERUSER NUMBER(10,0) DEFAULT null NOT NULL, 
	UPDATESTATUS NUMBER(10,0), 
  UPDATEDRECORDINDEX NUMBER(10,0), 
	UPDATEGROUPINDEX NUMBER(10,0), 
  ACCEPTDATE NUMBER, 
	REJECTDATE NUMBER, 
	REJECTCAUSE VARCHAR2(255), 
	NATURALKEY VARCHAR2(255), 
	DOCSTATEREF NUMBER(10,0), 
	CRYPTOSTATUS NUMBER(10,0), 
	LOCKSTATUS NUMBER(2,0), 
	LOCKINFO VARCHAR2(255), 
	DATEOPEN NUMBER, 
	DATECLOSE NUMBER, 
	BUDGETREF NUMBER(10,0),
  "PRODUCTREF" NUMBER(10,0),   


    /*    */ 
    KFSR                NUMBER(10,0),
    KVSR                NUMBER(10,0),
    KESR                NUMBER(10,0),
    KVR                 NUMBER(10,0),
    SUBKESR             NUMBER(10,0),
    FINSOURCE           NUMBER(10,0),
    FACT                NUMBER(10,0),
    DIRECTIONCLS        NUMBER(10,0),
    MEANSTYPE           NUMBER(10,0),
    INTFIELD00          NUMBER(10,0),
    INTFIELD01          NUMBER(10,0),
    INTFIELD02          NUMBER(10,0),
    INTFIELD03          NUMBER(10,0),
    INTFIELD04          NUMBER(10,0),
    INTFIELD05          NUMBER(10,0),
    INTFIELD06          NUMBER(10,0),
    INTFIELD07          NUMBER(10,0),
    INTFIELD08          NUMBER(10,0),
    INTFIELD09          NUMBER(10,0),
    INTFIELD10          NUMBER(10,0),
    INTFIELD11          NUMBER(10,0),
    INTFIELD12          NUMBER(10,0),
    INTFIELD13          NUMBER(10,0),
    INTFIELD14          NUMBER(10,0),
    INTFIELD15          NUMBER(10,0),
    INTFIELD16          NUMBER(10,0),
    INTFIELD17          NUMBER(10,0),
    INTFIELD18          NUMBER(10,0),
    INTFIELD19          NUMBER(10,0),
    INTFIELD20          NUMBER(10,0),
    INTFIELD21          NUMBER(10,0),
    INTFIELD22          NUMBER(10,0),
    INTFIELD23          NUMBER(10,0),
    INTFIELD24          NUMBER(10,0),
    INTFIELD25          NUMBER(10,0),
    INTFIELD26          NUMBER(10,0),
    INTFIELD27          NUMBER(10,0),
    INTFIELD28          NUMBER(10,0),
    INTFIELD29          NUMBER(10,0),
    SUMFIELD00          NUMBER(15,2) default null,
    SUMFIELD01          NUMBER(15,2) default null,
    SUMFIELD02          NUMBER(15,2) default null,
    SUMFIELD03          NUMBER(15,2) default null,
    SUMFIELD04          NUMBER(15,2) default null,
    SUMFIELD05          NUMBER(15,2) default null,
    SUMFIELD06          NUMBER(15,2) default null,
    SUMFIELD07          NUMBER(15,2) default null,
    SUMFIELD08          NUMBER(15,2) default null,
    SUMFIELD09          NUMBER(15,2) default null,
    SUMFIELD10          NUMBER(15,2) default null,
    SUMFIELD11          NUMBER(15,2) default null,
    SUMFIELD12          NUMBER(15,2) default null,
    SUMFIELD13          NUMBER(15,2) default null,
    SUMFIELD14          NUMBER(15,2) default null,
    SUMFIELD15          NUMBER(15,2) default null,
    SUMFIELD16          NUMBER(15,2) default null,
    SUMFIELD17          NUMBER(15,2) default null,
    SUMFIELD18          NUMBER(15,2) default null,
    SUMFIELD19          NUMBER(15,2) default null,
    SUMFIELD20          NUMBER(15,2) default null,
    SUMFIELD21          NUMBER(15,2) default null,
    SUMFIELD22          NUMBER(15,2) default null,
    SUMFIELD23          NUMBER(15,2) default null,
    SUMFIELD24          NUMBER(15,2) default null,
    SUMFIELD25          NUMBER(15,2) default null,
    SUMFIELD26          NUMBER(15,2) default null,
    SUMFIELD27          NUMBER(15,2) default null,
    SUMFIELD28          NUMBER(15,2) default null,
    SUMFIELD29          NUMBER(15,2) default null,
    SUMFIELD30          NUMBER(15,2) default null,
    SUMFIELD31          NUMBER(15,2) default null,
    SUMFIELD32          NUMBER(15,2) default null,
    SUMFIELD33          NUMBER(15,2) default null,
    SUMFIELD34          NUMBER(15,2) default null,
    SUMFIELD35          NUMBER(15,2) default null,
    SUMFIELD36          NUMBER(15,2) default null,
    SUMFIELD37          NUMBER(15,2) default null,
    SUMFIELD38          NUMBER(15,2) default null,
    SUMFIELD39          NUMBER(15,2) default null,
    SUMFIELD40          NUMBER(15,2) default null,
    SUMFIELD41          NUMBER(15,2) default null,
    SUMFIELD42          NUMBER(15,2) default null,
    SUMFIELD43          NUMBER(15,2) default null,
    SUMFIELD44          NUMBER(15,2) default null,
    SUMFIELD45          NUMBER(15,2) default null,
    DATEFIELD00         NUMBER,
    DATEFIELD01         NUMBER,
    DATEFIELD02         NUMBER,
    DATEFIELD03         NUMBER,
    DATEFIELD04         NUMBER,
    DATEFIELD05         NUMBER,
    DATEFIELD06         NUMBER,
    DATEFIELD07         NUMBER,
    DATEFIELD08         NUMBER,
    DATEFIELD09         NUMBER,
    DATEFIELD10         NUMBER,
    DATEFIELD11         NUMBER,
    DATEFIELD12         NUMBER,
    DATEFIELD13         NUMBER,
    DATEFIELD14         NUMBER,
    STRFIELD00          VARCHAR(1024),
    STRFIELD01          VARCHAR(1024),
    STRFIELD02          VARCHAR(1024),
    STRFIELD03          VARCHAR(1024),
    STRFIELD04          VARCHAR(1024),
    STRFIELD05          VARCHAR(1024),
    STRFIELD06          VARCHAR(1024),
    STRFIELD07          VARCHAR(1024),
    STRFIELD08          VARCHAR(1024),
    STRFIELD09          VARCHAR(1024),
    STRFIELD10          VARCHAR(1024),
    STRFIELD11          VARCHAR(1024),
    STRFIELD12          VARCHAR(1024),
    STRFIELD13          VARCHAR(1024),
    STRFIELD14          VARCHAR(1024),
    STRFIELD15          VARCHAR(1024),
    STRFIELD16          VARCHAR(1024),
    STRFIELD17          VARCHAR(1024),
    STRFIELD18          VARCHAR(1024),
    STRFIELD19          VARCHAR(1024),
    STRFIELD20          VARCHAR(1024),
    STRFIELD21          VARCHAR(1024),
    STRFIELD22          VARCHAR(1024),
    STRFIELD23          VARCHAR(1024),
    STRFIELD24          VARCHAR(1024),
    STRFIELD25          VARCHAR(1024),
    STRFIELD26          VARCHAR(1024),
    STRFIELD27          VARCHAR(1024),
    STRFIELD28          VARCHAR(1024),
    STRFIELD29          VARCHAR(1024),
    FLOATFIELD00        NUMBER,
    FLOATFIELD01        NUMBER,
    FLOATFIELD02        NUMBER,
    FLOATFIELD03        NUMBER,
    FLOATFIELD04        NUMBER,
    FLOATFIELD05        NUMBER,
    FLOATFIELD06        NUMBER,
    FLOATFIELD07        NUMBER,
    FLOATFIELD08        NUMBER,
    FLOATFIELD09        NUMBER,
    FLOATFIELD10        NUMBER,
    DEPARTMENTCLS       NUMBER(10,0),
    VARIANT             NUMBER(10,0),
    SUBSIDYCLS          NUMBER(10,0),
    TRANSFERTCLS        NUMBER(10,0),
    REGIONCLS           NUMBER(10,0),
    ORG_REF             NUMBER(10,0),
    KCSR                VARCHAR(20),
    
    /* */
    DOCUMENTID          NUMBER(10,0),
    BACKUPDATE          DATE,
    SOURCEID            NUMBER(10,0),
        
    
    CONSTRAINT "PK_LD_BK" PRIMARY KEY ("ID"),
    
   CHECK ((ID<=2147483647)AND(ID>-2147483648)) ENABLE, 
   CHECK ((LayerRef<=2147483647)AND(LayerRef>-2147483648)) ENABLE, 
	 CHECK ((LayerVersion<=2147483647)AND(LayerVersion>-2147483648)) ENABLE, 
   CHECK ((CryptoStatus<=2147483647)AND(CryptoStatus>-2147483648)) ENABLE, 
	 CHECK ((DocStateRef<=2147483647)AND(DocStateRef>-2147483648)) ENABLE, 
	 CHECK ((ExecuterUser<=2147483647)AND(ExecuterUser>-2147483648)) ENABLE, 
	 CHECK ((FacialAccCls<=2147483647)AND(FacialAccCls>-2147483648)) ENABLE,
   CHECK ((OwnerUser<=2147483647)AND(OwnerUser>-2147483648)) ENABLE, 
   CHECK ((TASKREF<=2147483647)AND(TASKREF>-2147483648)) ENABLE, 
	 CHECK ((ProductRef<=2147483647)AND(ProductRef>-2147483648)) ENABLE,
   CHECK ((Rversion<=2147483647)AND(Rversion>-2147483648)) ENABLE, 
	 CHECK ((SenderID<=2147483647)AND(SenderID>-2147483648)) ENABLE, 
	 CHECK ((SenderRecordID<=2147483647)AND(SenderRecordID>-2147483648)) ENABLE, 
   CHECK ((UpdatedRecordIndex<=2147483647) and (UpdatedRecordIndex>=-2147483648)) ENABLE, 
	 CHECK ((UpdateGroupIndex<=2147483647) and (UpdateGroupIndex>=-2147483648)) ENABLE, 
	 CHECK ((UpdateStatus<=2147483647) and (UpdateStatus>=-2147483648)) ENABLE, 
   CHECK ((SENDERID_FORCHECK<=2147483647) and (SENDERID_FORCHECK>=-2147483648)) ENABLE, 
	 CHECK ((BUDGETREF<=2147483647)AND(BUDGETREF>-2147483648)) ENABLE, 
   	 
	 CHECK ((IntField00<=2147483647)AND(IntField00>-2147483648)) ENABLE, 
	 CHECK ((IntField01<=2147483647)AND(IntField01>-2147483648)) ENABLE, 
	 CHECK ((IntField02<=2147483647)AND(IntField02>-2147483648)) ENABLE, 
	 CHECK ((IntField03<=2147483647)AND(IntField03>-2147483648)) ENABLE, 
	 CHECK ((IntField04<=2147483647)AND(IntField04>-2147483648)) ENABLE, 
	 CHECK ((IntField05<=2147483647)AND(IntField05>-2147483648)) ENABLE, 
	 CHECK ((IntField06<=2147483647)AND(IntField06>-2147483648)) ENABLE, 
	 CHECK ((IntField07<=2147483647)AND(IntField07>-2147483648)) ENABLE, 
	 CHECK ((IntField08<=2147483647)AND(IntField08>-2147483648)) ENABLE, 
	 CHECK ((IntField09<=2147483647)AND(IntField09>-2147483648)) ENABLE, 
	 CHECK ((IntField10<=2147483647)AND(IntField10>-2147483648)) ENABLE, 
	 CHECK ((IntField11<=2147483647)AND(IntField11>-2147483648)) ENABLE, 
	 CHECK ((IntField12<=2147483647)AND(IntField12>-2147483648)) ENABLE, 
	 CHECK ((IntField13<=2147483647)AND(IntField13>-2147483648)) ENABLE, 
	 CHECK ((IntField14<=2147483647)AND(IntField14>-2147483648)) ENABLE, 
	 CHECK ((IntField15<=2147483647)AND(IntField15>-2147483648)) ENABLE, 
	 CHECK ((IntField16<=2147483647)AND(IntField16>-2147483648)) ENABLE, 
	 CHECK ((IntField17<=2147483647)AND(IntField17>-2147483648)) ENABLE, 
	 CHECK ((IntField18<=2147483647)AND(IntField18>-2147483648)) ENABLE, 
	 CHECK ((IntField19<=2147483647)AND(IntField19>-2147483648)) ENABLE, 
	 CHECK ((IntField20<=2147483647)AND(IntField20>-2147483648)) ENABLE,
	 CHECK ((IntField21<=2147483647)AND(IntField21>-2147483648)) ENABLE, 
	 CHECK ((IntField22<=2147483647)AND(IntField22>-2147483648)) ENABLE, 
	 CHECK ((IntField23<=2147483647)AND(IntField23>-2147483648)) ENABLE, 
	 CHECK ((IntField24<=2147483647)AND(IntField24>-2147483648)) ENABLE, 
	 CHECK ((IntField25<=2147483647)AND(IntField25>-2147483648)) ENABLE, 
	 CHECK ((IntField26<=2147483647)AND(IntField26>-2147483648)) ENABLE, 
	 CHECK ((IntField27<=2147483647)AND(IntField27>-2147483648)) ENABLE, 
	 CHECK ((IntField28<=2147483647)AND(IntField28>-2147483648)) ENABLE, 
	 CHECK ((IntField29<=2147483647)AND(IntField29>-2147483648)) ENABLE, 
   
   CHECK ((Org_Ref<=2147483647)AND(Org_Ref>-2147483648)) ENABLE,
   
	 CHECK ((KVSR<=2147483647)AND(KVSR>-2147483648)) ENABLE, 
	 CHECK ((KFSR<=2147483647)AND(KFSR>-2147483648)) ENABLE, 
	 CHECK ((KVR<=2147483647)AND(KVR>-2147483648)) ENABLE, 
   CHECK ((KESR<=2147483647)AND(KESR>-2147483648)) ENABLE, 
	 CHECK ((SubKESR<=2147483647)AND(SubKESR>-2147483648)) ENABLE, 	 
	 CHECK ((MeansType<=2147483647)AND(MeansType>-2147483648)) ENABLE, 
	 CHECK ((SUBSIDYCLS<=2147483647)AND(SUBSIDYCLS>-2147483648)) ENABLE, 
	 CHECK ((REGIONCLS<=2147483647)AND(REGIONCLS>-2147483648)) ENABLE, 
   CHECK ((DEPARTMENTCLS<=2147483647)AND(DEPARTMENTCLS>-2147483648)) ENABLE
)';

 EXECUTE IMMEDIATE 'INSERT INTO GENERATORS (NAME,Value) VALUES (''G_LD_BACKUP'',1)';


/* *****************************************************************************/
/* **                                Indices                                 ***/
/* *****************************************************************************/

 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_BK_LAYERREF ON LAYERDATA_BACKUP(LAYERREF)';
 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_BK_LAYER ON LAYERDATA_BACKUP(LAYERREF,DOCUMENTID)';

/*   */

 EXECUTE IMMEDIATE 'CREATE INDEX IDX_LD_BK_DOCID ON LAYERDATA_BACKUP(DOCUMENTID)';

 EXECUTE IMMEDIATE 'GRANT ALL ON LAYERDATA_Backup TO PUBLIC';

 END IF;

END;
/

COMMIT WORK
/

 




-- #########################################################
-- #########################################################
-- Create_LayerData_Backup_Triggers.sql
-- #########################################################
-- #########################################################

-- CREATE TRIGGER TR_LD_BK_BI
CREATE OR REPLACE TRIGGER TR_LAYERDATA_BACKUP_BI
  BEFORE INSERT
  ON LAYERDATA_BACKUP
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_LD_BK_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    :new.id := GEN_ID('G_LD_BACKUP',1);
  END IF;
  if (:new.LayerVersion is null) then 
    :new.LayerVersion := 0;
  END IF;
  if (:new.ExecuterUser is null) then 
    :new.ExecuterUser := :new.OwnerUser;
  END IF;

END;
/
-- CREATE TRIGGER TR_LD_BK_BI_500
CREATE OR REPLACE TRIGGER TR_LAYERDATA_BACKUP_BI
  BEFORE INSERT
  ON LAYERDATA_BACKUP
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_LD_BK_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    :new.id := GEN_ID('G_LD_BACKUP',1);
  END IF;
  if (:new.LayerVersion is null) then 
    :new.LayerVersion := 0;
  END IF;
  if (:new.ExecuterUser is null) then 
    :new.ExecuterUser := :new.OwnerUser;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_LD_BK_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.CreateDate is null) then 
    :new.CreateDate := SYSDATE;
  END IF;
  if (:new.BackupDate is null) then 
    :new.BackupDate := SYSDATE;
  END IF;
  if (:new.UpdateDate is null) then 
    :new.UpdateDate := SYSDATE;
  END IF;
  if (:new.CreaterUser is null) then 
    :new.CreaterUser := user;
  END IF;
  if (:new.UpdaterUser is null) then 
    :new.UpdaterUser := user;
  END IF;

END;
/
-- CREATE TRIGGER TR_LD_BK_BU
CREATE OR REPLACE TRIGGER TR_LAYERDATA_BACKUP_BU
  BEFORE UPDATE
  ON LAYERDATA_BACKUP
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_LD_BK_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.LayerVersion is null) then 
    :new.LayerVersion := 0;
  END IF;
  if (:new.ExecuterUser is null) then 
    :new.ExecuterUser := :new.OwnerUser;
  END IF;

END;
/
-- CREATE TRIGGER TR_LD_BK_BU_500
CREATE OR REPLACE TRIGGER TR_LD_BK_BU_500
  BEFORE UPDATE
  ON LAYERDATA_BACKUP
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_LD_BK_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := User;

END;
/
/* *****************************************************************************/
/* **                               Privileges                               ***/
/* *****************************************************************************/


COMMIT WORK
/


-- #########################################################
-- #########################################################
-- IncreaseLen_LayerFieldTypesDetail_Mask.sql
-- #########################################################
-- #########################################################


/*   */
alter table LAYERFIELDTYPESDETAIL
modify (Mask varchar2(50));
/

commit work
/


-- #########################################################
-- #########################################################
-- DeleteLayerUserRights.sql
-- #########################################################
-- #########################################################

-- CREATE TRIGGER TR_DBUSERS_AD_20
CREATE OR REPLACE TRIGGER TR_DBUSERS_ID
  INSTEAD OF DELETE
  ON DBUSERS
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DBUSERS_BD)
-- - - - - - - - - - - - -

        --    SYSDBA
        if (:old.id = 0) then
                RaiseException('EX_CANTDELETETHIS');
        end if;

-- - - - - - - - - - - - -
-- BD_1 (TR_DBUSERS_BD_1)
-- - - - - - - - - - - - -

/*     */
        delete from User_Workplaces     where Users_ref = :old.id;
    delete from ReportsPermissions where Userid = :old.id;
    delete from UsersInGroups  where UserRef = :old.id;
    delete from UsersRights  where UserRef = :old.id;
    delete from DualRights  where (UserRef = :old.id) and (IsGroup = 0);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_DBUSERS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_DBUSERS_AD_10)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*    RemoteClients  DBUsers */  
  if (:old.RemoteClientRef is not null) then
    SELECT COUNT(dbu.ID ) INTO CNT$1
    from DBUsers dbu where (dbu.RemoteClientRef = :old.RemoteClientRef) AND (ROWNUM = 1);
    /*     DBUsers     RemoteClient,   ,     */
    if (not (CNT$1<> 0)) then
      delete from RemoteClient where ID = :old.RemoteClientRef;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AD_20 (TR_DBUSERS_AD_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*         DBUsers */  
  delete from LayerData
  where LayerRef in(select ID from Layers where Alias in('..','..')) and STRFIELD00 = :old.UserName;
  delete from LayerData
  where LayerRef = (select ID from Layers where Alias = '..') and STRFIELD01 = :old.UserName;
  delete from LayerData
  where LayerRef = (select ID from Layers where Alias = '..') and STRFIELD02 = :old.UserName;

-- - - - - - - - - - - - -
-- AD_500 (TR_DBUSERS_AD_500)
-- - - - - - - - - - - - -

/*      */
  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
       values(100,:old.ID, sysdate);

END;
/
-- CREATE TRIGGER TR_DBGROUPS_AD_20
CREATE OR REPLACE TRIGGER TR_DBGROUPS_AD
  AFTER DELETE
  ON DBGROUPS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AD_20 (TR_DBGROUPS_AD_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*         DBGroups */  
  delete from LayerData
  where LayerRef in(select ID from Layers where Alias in('..','..')) and STRFIELD00 = :old.Name;
  delete from LayerData
  where LayerRef = (select ID from Layers where Alias = '..') and STRFIELD01 = :old.Name;

-- - - - - - - - - - - - -
-- AD_500 (TR_DBGROUPS_AD_500)
-- - - - - - - - - - - - -

/*      */
  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
         values(101,:old.ID, sysdate);

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- alter_BuhAccPlan.sql
-- #########################################################
-- #########################################################

/*      EcCls         */
ALTER TABLE BUHACCPLAN DROP CONSTRAINT FK_BUHACCPLAN_KESR
/
DROP INDEX FK_BUHACCPLAN_KESR
/
ALTER TABLE BUHACCPLAN DROP CONSTRAINT UNQ_BUHACCPLAN_ACC_EC DROP INDEX
/
ALTER TABLE BUHACCPLAN ADD (
  ClsType NUMBER(10),
    CHECK((ClsType<=2147483647)AND(ClsType>-2147483648))
)
/
commit work 
/
-- ALTER TRIGGER tr_buhaccplan_bi
CREATE OR REPLACE TRIGGER TR_BUHACCPLAN_BI
  BEFORE INSERT
  ON BUHACCPLAN
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUHACCPLAN_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  IF (:new.ID IS NULL) THEN
    select g_shared.nextval into :new.ID from dual;
  END IF;
  IF (:new.ClsType IS NULL) THEN
    :new.ClsType := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUHACCPLAN_BI_500)
-- Create 27.04.2005
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;

END;
/
ALTER TRIGGER TR_BUHACCPLAN_BU_500 DISABLE
/
commit work 
/
update BUHACCPLAN b set
  ClsType = 2
where
  exists (
    select *
    from KD k
    where
      (k.kesr = b.eccls)
    )
/
update BUHACCPLAN b set
  ClsType = 1
where
  exists (
    select *
    from InnerFinSource k
    where
      (k.KESR = b.eccls)
    )
/
update BUHACCPLAN b set
  ClsType = 0
where
  (ClsType is null) or (EcCls = 0)
/
commit work 
/
ALTER TRIGGER TR_BUHACCPLAN_BU_500 ENABLE
/
ALTER TABLE BUHACCPLAN ADD (
  CONSTRAINT UNQ_BUHACCPLAN_ACC_EC UNIQUE (BUHACC,ECCLS,CLSTYPE)
)
/
commit work 
/
ALTER TABLE BUHACCPLAN MODIFY(ClsType NOT NULL)
/

-- #########################################################
-- #########################################################
-- alter_cls_11.0.sql
-- #########################################################
-- #########################################################

/*   "   ", "   ".
           . */
/*     */
CREATE TABLE AnalyticalGroupKD (
  ID NUMBER(10) NOT NULL,/*   */
    CHECK((ID<=2147483647)AND(ID>-2147483648)),
  CODE VARCHAR2(20) NOT NULL,/*  */
  NAME VARCHAR2(1024),/*  */
  BUDGETREF NUMBER(10) NOT NULL,/*    */
    CHECK((BUDGETREF<=2147483647)AND(BUDGETREF>-2147483648)),
  STARTDATE DATE,/*     */
  DELETEDATE DATE,/*   */
  CREATEDATE DATE NOT NULL,/*   */
  UPDATEDATE DATE NOT NULL,/*   */
  CREATERUSER VARCHAR2(30) NOT NULL,/*  */
  UPDATERUSER VARCHAR2(30) NOT NULL,/*  */
  EXTID VARCHAR2(50),/* UID     ,  GUID */
  EXTOWNER VARCHAR2(50),/*    */
  EXTSYNCDATE DATE
)
/
ALTER TABLE AnalyticalGroupKD ADD (
  CONSTRAINT AnalyticalGroupKD_PK_ID PRIMARY KEY (ID)
)
/
ALTER TABLE AnalyticalGroupKD ADD (
  CONSTRAINT FK_AnalyticalGroupKD_BUDGETREF FOREIGN KEY (BUDGETREF) REFERENCES TB_BUDGETS_S (ID)
)
/
CREATE INDEX FK_AnalyticalGroupKD_BUDGETREF ON AnalyticalGroupKD(BUDGETREF)
/
ALTER TABLE AnalyticalGroupKD ADD (
  CONSTRAINT UQ_AnalyticalGroupKD UNIQUE (CODE, BUDGETREF)
)
/
COMMIT WORK 
/
-- CREATE TRIGGER TR_AnalyticalGroupKD_AD_500
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupKD_AD
  AFTER DELETE
  ON AnalyticalGroupKD
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AD_500 (TR_AnalyticalGroupKD_AD_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(1423,:old.ID,SYSDATE);

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupKD_AI_500
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupKD_AI
  AFTER INSERT
  ON AnalyticalGroupKD
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AI_500 (TR_AnalyticalGroupKD_AI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 1423) and (RecordId = :new.ID);

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupKD_AU_500
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupKD_AU
  AFTER UPDATE
  ON AnalyticalGroupKD
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AU_500 (TR_AnalyticalGroupKD_AU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (1423, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=1423) and (RecordId=:new.ID);
      
  END IF;

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupKD_BI_0
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupKD_BI
  BEFORE INSERT
  ON AnalyticalGroupKD
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AnalyticalGroupKD_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupKD_BI_500
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupKD_BI
  BEFORE INSERT
  ON AnalyticalGroupKD
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AnalyticalGroupKD_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_AnalyticalGroupKD_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupKD_BU_0
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupKD_BU
  BEFORE UPDATE
  ON AnalyticalGroupKD
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_1 (TR_AnalyticalGroupKD_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupKD_BU_500
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupKD_BU_500
  BEFORE UPDATE
  ON ANALYTICALGROUPKD
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_AnalyticalGroupKD_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.Updatedate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
GRANT SELECT, INSERT, UPDATE, DELETE ON AnalyticalGroupKD TO BUDGET_USERS
/
COMMIT WORK 
/
/*     */
CREATE TABLE AnalyticalGroupIFS (
  ID NUMBER(10) NOT NULL,/*   */
    CHECK((ID<=2147483647)AND(ID>-2147483648)),
  CODE VARCHAR2(20) NOT NULL,/*  */
  NAME VARCHAR2(1024),/*  */
  BUDGETREF NUMBER(10) NOT NULL,/*    */
    CHECK((BUDGETREF<=2147483647)AND(BUDGETREF>-2147483648)),
  STARTDATE DATE,/*     */
  DELETEDATE DATE,/*   */
  CREATEDATE DATE NOT NULL,/*   */
  UPDATEDATE DATE NOT NULL,/*   */
  CREATERUSER VARCHAR2(30) NOT NULL,/*  */
  UPDATERUSER VARCHAR2(30) NOT NULL,/*  */
  EXTID VARCHAR2(50),/* UID     ,  GUID */
  EXTOWNER VARCHAR2(50),/*    */
  EXTSYNCDATE DATE
)
/
ALTER TABLE AnalyticalGroupIFS ADD (
  CONSTRAINT AnalyticalGroupIFS_PK_ID PRIMARY KEY (ID)
)
/
ALTER TABLE AnalyticalGroupIFS ADD (
  CONSTRAINT FK_AnalyticalGroupIFS_BUD FOREIGN KEY (BUDGETREF) REFERENCES TB_BUDGETS_S (ID)
)
/
CREATE INDEX FK_AnalyticalGroupIFS_BUD ON AnalyticalGroupIFS(BUDGETREF)
/
ALTER TABLE AnalyticalGroupIFS ADD (
  CONSTRAINT UQ_AnalyticalGroupIFS UNIQUE (CODE, BUDGETREF)
)
/
COMMIT WORK 
/
-- CREATE TRIGGER TR_AnalyticalGroupIFS_AD_500
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupIFS_AD
  AFTER DELETE
  ON AnalyticalGroupIFS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AD_500 (TR_AnalyticalGroupIFS_AD_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(1424,:old.ID,SYSDATE);

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupIFS_AI_500
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupIFS_AI
  AFTER INSERT
  ON AnalyticalGroupIFS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AI_500 (TR_AnalyticalGroupIFS_AI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 1424) and (RecordId = :new.ID);

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupIFS_AU_500
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupIFS_AU
  AFTER UPDATE
  ON AnalyticalGroupIFS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AU_500 (TR_AnalyticalGroupIFS_AU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (1424, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=1424) and (RecordId=:new.ID);
      
  END IF;

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupIFS_BI_0
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupIFS_BI
  BEFORE INSERT
  ON AnalyticalGroupIFS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AnalyticalGroupIFS_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupIFS_BI_500
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupIFS_BI
  BEFORE INSERT
  ON AnalyticalGroupIFS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AnalyticalGroupIFS_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_AnalyticalGroupIFS_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupIFS_BU_0
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupIFS_BU
  BEFORE UPDATE
  ON AnalyticalGroupIFS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_1 (TR_AnalyticalGroupIFS_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- CREATE TRIGGER TR_AnalyticalGroupIFS_BU_500
CREATE OR REPLACE TRIGGER TR_AnalyticalGroupIFS_BU_500
  BEFORE UPDATE
  ON ANALYTICALGROUPIFS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_AnalyticalGroupIFS_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.Updatedate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
GRANT SELECT, INSERT, UPDATE, DELETE ON AnalyticalGroupIFS TO BUDGET_USERS
/
COMMIT WORK 
/

/* *********        **********/


insert into AnalyticalGroupKD (id, Code, Name)
select id, '00' || id, name
from KESR
where
 ((KESR.ISEKD = 1) or
  exists (select * from KD
  where (KD.KESR = KESR.ID))) and 
 (KESR.id < 10)
/
insert into AnalyticalGroupKD (id, Code, Name)
select id, '0' || id, name 
from KESR
where
 ((KESR.ISEKD = 1) or
  exists (select * from KD
  where (KD.KESR = KESR.ID))) and 
 (id >= 10) and (id < 100)
/
insert into AnalyticalGroupKD (id, Code, Name)
select id, id, name 
from KESR
where
 ((KESR.ISEKD = 1) or
  exists (select * from KD
  where (KD.KESR = KESR.ID))) and 
 (id >= 100)
/
insert into AnalyticalGroupIFS (id, Code, Name)
select id, '00' || id, name 
from KESR
where
 ((KESR.ISEKI = 1) or
  exists (select * from InnerFinSource
  where (InnerFinSource.KESR = KESR.ID))) and 
 (id < 10)
/
insert into AnalyticalGroupIFS (id, Code, Name)
select id, '0' || id, name 
from KESR
where
 ((KESR.ISEKI = 1) or
  exists (select * from InnerFinSource
  where (InnerFinSource.KESR = KESR.ID))) and 
 (id >= 10) and (id < 100)
/
insert into AnalyticalGroupIFS (id, Code, Name)
select id, id, name 
from KESR
where
 ((KESR.ISEKI = 1) or
  exists (select * from InnerFinSource
  where (InnerFinSource.KESR = KESR.ID))) and 
 (id >= 100)
/
COMMIT WORK 
/
ALTER TABLE TB_KD ADD (
  AnalyticalGroupKD NUMBER(10)/*     */,
    CHECK((AnalyticalGroupKD<=2147483647)AND(AnalyticalGroupKD>-2147483648))
)
/

CREATE OR REPLACE VIEW KD (
  ID,
  REPCODE,
  CREATEDATE,
  UPDATEDATE,
  KVSR,
  DESCRIPTIONCODE,
  MAINDESCRIPTIONCODE,
  ITEMCODE,
  PROGRAMCODE,
  KESR,
  KDVALUE,
  REMOTEFLAG,
  UNIONFLAG,
  BUDGETREF,
  DELETEDATE,
  NAME,
  KD_LEVEL,
  STARTDATE,
  SHORTNAME,
  CREATERUSER,
  UPDATERUSER,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  ANALYTICALGROUPKD)
AS
  SELECT
    ID,
    REPCODE,
    CREATEDATE,
    UPDATEDATE,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    KDVALUE,
    REMOTEFLAG,
    UNIONFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    KD_LEVEL,
    STARTDATE,
    SHORTNAME,
    CREATERUSER,
    UPDATERUSER,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPKD
  FROM TB_KD
/

CREATE OR REPLACE TRIGGER TR_KD_ID
  INSTEAD OF DELETE
  ON KD
  FOR EACH ROW
DECLARE
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_KD_BD_0)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  --    ,     
  if (:old.kvsr = 0) then
    select count(*) into CNT$
                 from kd kd1
                 where ((kd1.kvsr <> 0) and
                       ((kd1.descriptioncode-:old.descriptioncode>-1) and (kd1.descriptioncode-:old.descriptioncode<1)) and
                       (kd1.programcode = :old.programcode) and
                       (kd1.kesr = :old.kesr)) AND (ROWNUM = 1);
    if (CNT$ > 0) then
      RaiseException('EX_CANTDELBASECODE');
    end if;  
  end if;   

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_KD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_KD_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(80, :old.ID, sysdate);

END;
/

CREATE OR REPLACE TRIGGER TR_KD_II
  INSTEAD OF INSERT
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  CNT$ NUMBER(10);
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sKESR$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KD_BI_0)
-- Version 7.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    BEGIN
      select kd_level into sKDLevel$ from KD where ((KESR = new$KESR) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$kesr = 0) then
    sKESR$ := '000';
        
  else
    if (new$kesr < 10) then
      sKESR$ := '00' || new$kesr;
          
    else
      if (new$kesr < 100) then
        sKESR$ := '0' || new$kesr;
            
      else
        sKESR$ := new$kesr;
      END IF;
    END IF;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sKESR$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KD_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_KD (
    ID,
    REPCODE,
    CREATEDATE,
    UPDATEDATE,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    KDVALUE,
    REMOTEFLAG,
    UNIONFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    KD_LEVEL,
    STARTDATE,
    SHORTNAME,
    CREATERUSER,
    UPDATERUSER,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPKD
  ) VALUES (
    new$ID,
    new$REPCODE,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$KDVALUE,
    new$REMOTEFLAG,
    new$UNIONFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$KD_LEVEL,
    new$STARTDATE,
    new$SHORTNAME,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPKD);

-- - - - - - - - - - - - -
-- AI_100 (TR_KD_AI_100)
-- Create 03.05.2005
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    select count(*) into CNT$
                     from kd kd1
                     where ((kd1.kvsr = 0) and
                           ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
                           (kd1.programcode = new$programcode) and
                           (kd1.kesr = new$kesr)) and (ROWNUM = 1);
    if (CNT$ = 0) then  
        insert into KD (KVSR, DescriptionCode, ProgramCode, KESR, Name, ShortName, RemoteFlag, kd_level)
        values (0, new$DescriptionCode, new$ProgramCode, new$KESR, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
    end if;  
  end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_KD_AI_500)
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 80)  and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sKESR$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 7.00.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  if (new$KVSR <> 0) then
    BEGIN
      select kd_level into sKDLevel$ from KD where ((KESR = new$KESR) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;

  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$kesr = 0) then
    sKESR$ := '000';
        
  else
    if (new$kesr < 10) then
      sKESR$ := '00' || new$kesr;
          
    else
      if (new$kesr < 100) then
        sKESR$ := '0' || new$kesr;
            
      else
        sKESR$ := new$kesr;
      END IF;
    END IF;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sKESR$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.kesr = new$kesr)
    ) AND (ROWNUM = 1)                     ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, KESR, Name, ShortName, RemoteFlag, kd_level)
      values (0, new$DescriptionCode, new$ProgramCode, new$KESR, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
        
    END IF;
  else
    /*   = 0,         ,     */
    update kd kd1 set
    name = new$name,
    ShortName = new$ShortName, 
    kd_level = new$kd_level
    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.kesr = new$kesr);
    /*        */
    if (new$deletedate is not null) then
      update kd kd1 set
      deletedate = new$deletedate
      where
      (kd1.kvsr <> 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.kesr = new$kesr) and
      (kd1.DeleteDate is null);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE TB_KD DROP CONSTRAINT FK_KD_KESR
/
DROP INDEX FK_KD_KESR
/
COMMIT WORK 
/
ALTER TRIGGER TR_KD_BU_500 DISABLE
/
-- ALTER TRIGGER tr_kd_au_100
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sKESR$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 7.00.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  if (new$KVSR <> 0) then
    BEGIN
      select kd_level into sKDLevel$ from KD where ((KESR = new$KESR) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;

  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$kesr = 0) then
    sKESR$ := '000';
        
  else
    if (new$kesr < 10) then
      sKESR$ := '00' || new$kesr;
          
    else
      if (new$kesr < 100) then
        sKESR$ := '0' || new$kesr;
            
      else
        sKESR$ := new$kesr;
      END IF;
    END IF;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sKESR$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$kvsr <> 0) then
--     SELECT COUNT(*) INTO CNT$1
--     from kd kd1
--     where ((kd1.kvsr = 0) and
--     ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
--     (kd1.programcode = new$programcode) and
--     (kd1.kesr = new$kesr)
--     ) AND (ROWNUM = 1)                     ;
--     /*    0,        =0 */
--     if (not (CNT$1<> 0))
--     then
--       insert into KD (KVSR, DescriptionCode, ProgramCode, KESR, Name, ShortName, RemoteFlag, kd_level)
--       values (0, new$DescriptionCode, new$ProgramCode, new$KESR, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
--         
--     END IF;
--   else
--     /*   = 0,         ,     */
--     update kd kd1 set
--     name = new$name,
--     ShortName = new$ShortName, 
--     kd_level = new$kd_level
--     where
--     (kd1.kvsr <> 0) and
--     ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
--     (kd1.programcode = new$programcode) and
--     (kd1.kesr = new$kesr);
--     /*        */
--     if (new$deletedate is not null) then
--       update kd kd1 set
--       deletedate = new$deletedate
--       where
--       (kd1.kvsr <> 0) and
--       ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
--       (kd1.programcode = new$programcode) and
--       (kd1.kesr = new$kesr) and
--       (kd1.DeleteDate is null);
--         
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
COMMIT WORK 
/
update kd set
  AnalyticalGroupKD = KESR
/
COMMIT WORK 
/
ALTER TRIGGER TR_KD_BU_500 ENABLE
/
-- ALTER TRIGGER tr_kd_au_100
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sKESR$ VARCHAR2(3);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 7.00.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  if (new$KVSR <> 0) then
    BEGIN
      select kd_level into sKDLevel$ from KD where ((KESR = new$KESR) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;

  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$kesr = 0) then
    sKESR$ := '000';
        
  else
    if (new$kesr < 10) then
      sKESR$ := '00' || new$kesr;
          
    else
      if (new$kesr < 100) then
        sKESR$ := '0' || new$kesr;
            
      else
        sKESR$ := new$kesr;
      END IF;
    END IF;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sKESR$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.kesr = new$kesr)
    ) AND (ROWNUM = 1)                     ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, KESR, Name, ShortName, RemoteFlag, kd_level)
      values (0, new$DescriptionCode, new$ProgramCode, new$KESR, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
        
    END IF;
  else
    /*   = 0,         ,     */
    update kd kd1 set
    name = new$name,
    ShortName = new$ShortName, 
    kd_level = new$kd_level
    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.kesr = new$kesr);
    /*        */
    if (new$deletedate is not null) then
      update kd kd1 set
      deletedate = new$deletedate
      where
      (kd1.kvsr <> 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.kesr = new$kesr) and
      (kd1.DeleteDate is null);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
COMMIT WORK 
/
ALTER TABLE TB_KD ADD (
  CONSTRAINT FK_KD_AnalyticalGroupKD FOREIGN KEY (AnalyticalGroupKD) REFERENCES AnalyticalGroupKD (ID)
)
/
CREATE INDEX FK_KD_AnalyticalGroupKD ON TB_KD(AnalyticalGroupKD)
/
COMMIT WORK 
/
-- ALTER TRIGGER tr_kd_bi_0
CREATE OR REPLACE TRIGGER TR_KD_II
  INSTEAD OF INSERT
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  CNT$ NUMBER(10);
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  DescrCode11$ NUMBER(10);
  DescrCode21$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sAnalyticalGroupKD$ VARCHAR2(3);
  sKDLevel1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KD_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    BEGIN
      select kd_level into sKDLevel1$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sKDLevel1$ is not null) then
    new$kd_Level := sKDLevel1$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode11$ := tmp_Double$;
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode21$ := tmp_Double$;
      
  if (DescrCode11$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode11$ < 10) then
      sDescrCode1$ := '0000' || DescrCode11$;
          
    else
      if (DescrCode11$ < 100) then
        sDescrCode1$ := '000' || DescrCode11$;
            
      else
        if (DescrCode11$ < 1000) then
          sDescrCode1$ := '00' || DescrCode11$;
              
        else
          if (DescrCode11$ < 10000) then
            sDescrCode1$ := '0' || DescrCode11$;
                
          else
            sDescrCode1$ := DescrCode11$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode21$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode21$ < 10) then
      sDescrCode2$ := '0000' || DescrCode21$;
          
    else
      if (DescrCode21$ < 100) then
        sDescrCode2$ := '000' || DescrCode21$;
            
      else
        if (DescrCode21$ < 1000) then
          sDescrCode2$ := '00' || DescrCode21$;
              
        else
          if (DescrCode21$ < 10000) then
            sDescrCode2$ := '0' || DescrCode21$;
                
          else
            sDescrCode2$ := DescrCode21$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupKD$;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KD_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_KD (
    ID,
    REPCODE,
    CREATEDATE,
    UPDATEDATE,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    KDVALUE,
    REMOTEFLAG,
    UNIONFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    KD_LEVEL,
    STARTDATE,
    SHORTNAME,
    CREATERUSER,
    UPDATERUSER,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPKD
  ) VALUES (
    new$ID,
    new$REPCODE,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$KDVALUE,
    new$REMOTEFLAG,
    new$UNIONFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$KD_LEVEL,
    new$STARTDATE,
    new$SHORTNAME,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPKD);

-- - - - - - - - - - - - -
-- AI_100 (TR_KD_AI_100)
-- Create 03.05.2005
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    select count(*) into CNT$
                     from kd kd1
                     where ((kd1.kvsr = 0) and
                           ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
                           (kd1.programcode = new$programcode) and
                           (kd1.kesr = new$kesr)) and (ROWNUM = 1);
    if (CNT$ = 0) then  
        insert into KD (KVSR, DescriptionCode, ProgramCode, KESR, Name, ShortName, RemoteFlag, kd_level)
        values (0, new$DescriptionCode, new$ProgramCode, new$KESR, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
    end if;  
  end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_KD_AI_500)
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 80)  and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER tr_kd_ai_100
CREATE OR REPLACE TRIGGER TR_KD_II
  INSTEAD OF INSERT
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  DescrCode11$ NUMBER(10);
  DescrCode21$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sAnalyticalGroupKD$ VARCHAR2(3);
  sKDLevel1$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KD_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    BEGIN
      select kd_level into sKDLevel1$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sKDLevel1$ is not null) then
    new$kd_Level := sKDLevel1$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode11$ := tmp_Double$;
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode21$ := tmp_Double$;
      
  if (DescrCode11$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode11$ < 10) then
      sDescrCode1$ := '0000' || DescrCode11$;
          
    else
      if (DescrCode11$ < 100) then
        sDescrCode1$ := '000' || DescrCode11$;
            
      else
        if (DescrCode11$ < 1000) then
          sDescrCode1$ := '00' || DescrCode11$;
              
        else
          if (DescrCode11$ < 10000) then
            sDescrCode1$ := '0' || DescrCode11$;
                
          else
            sDescrCode1$ := DescrCode11$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode21$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode21$ < 10) then
      sDescrCode2$ := '0000' || DescrCode21$;
          
    else
      if (DescrCode21$ < 100) then
        sDescrCode2$ := '000' || DescrCode21$;
            
      else
        if (DescrCode21$ < 1000) then
          sDescrCode2$ := '00' || DescrCode21$;
              
        else
          if (DescrCode21$ < 10000) then
            sDescrCode2$ := '0' || DescrCode21$;
                
          else
            sDescrCode2$ := DescrCode21$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupKD$;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KD_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_KD (
    ID,
    REPCODE,
    CREATEDATE,
    UPDATEDATE,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    KDVALUE,
    REMOTEFLAG,
    UNIONFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    KD_LEVEL,
    STARTDATE,
    SHORTNAME,
    CREATERUSER,
    UPDATERUSER,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPKD
  ) VALUES (
    new$ID,
    new$REPCODE,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$KDVALUE,
    new$REMOTEFLAG,
    new$UNIONFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$KD_LEVEL,
    new$STARTDATE,
    new$SHORTNAME,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPKD);

-- - - - - - - - - - - - -
-- AI_100 (TR_KD_AI_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_KD_AI_500)
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 80)  and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER tr_kd_bu_0
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  DescrCode11$ NUMBER(10);
  DescrCode21$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sAnalyticalGroupKD$ VARCHAR2(3);
  sKDLevel1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    BEGIN
      select kd_level into sKDLevel1$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sKDLevel1$ is not null) then
    new$kd_Level := sKDLevel1$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode11$ := tmp_Double$;
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode21$ := tmp_Double$;
      
  if (DescrCode11$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode11$ < 10) then
      sDescrCode1$ := '0000' || DescrCode11$;
          
    else
      if (DescrCode11$ < 100) then
        sDescrCode1$ := '000' || DescrCode11$;
            
      else
        if (DescrCode11$ < 1000) then
          sDescrCode1$ := '00' || DescrCode11$;
              
        else
          if (DescrCode11$ < 10000) then
            sDescrCode1$ := '0' || DescrCode11$;
                
          else
            sDescrCode1$ := DescrCode11$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode21$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode21$ < 10) then
      sDescrCode2$ := '0000' || DescrCode21$;
          
    else
      if (DescrCode21$ < 100) then
        sDescrCode2$ := '000' || DescrCode21$;
            
      else
        if (DescrCode21$ < 1000) then
          sDescrCode2$ := '00' || DescrCode21$;
              
        else
          if (DescrCode21$ < 10000) then
            sDescrCode2$ := '0' || DescrCode21$;
                
          else
            sDescrCode2$ := DescrCode21$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupKD$;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.kesr = new$kesr)
    ) AND (ROWNUM = 1)                     ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, KESR, Name, ShortName, RemoteFlag, kd_level)
      values (0, new$DescriptionCode, new$ProgramCode, new$KESR, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
        
    END IF;
  else
    /*   = 0,         ,     */
    update kd kd1 set
    name = new$name,
    ShortName = new$ShortName, 
    kd_level = new$kd_level
    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.kesr = new$kesr);
    /*        */
    if (new$deletedate is not null) then
      update kd kd1 set
      deletedate = new$deletedate
      where
      (kd1.kvsr <> 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.kesr = new$kesr) and
      (kd1.DeleteDate is null);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER tr_kd_au_100
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  DescrCode11$ NUMBER(10);
  DescrCode21$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sAnalyticalGroupKD$ VARCHAR2(3);
  sKDLevel1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    BEGIN
      select kd_level into sKDLevel1$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sKDLevel1$ is not null) then
    new$kd_Level := sKDLevel1$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode11$ := tmp_Double$;
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode21$ := tmp_Double$;
      
  if (DescrCode11$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode11$ < 10) then
      sDescrCode1$ := '0000' || DescrCode11$;
          
    else
      if (DescrCode11$ < 100) then
        sDescrCode1$ := '000' || DescrCode11$;
            
      else
        if (DescrCode11$ < 1000) then
          sDescrCode1$ := '00' || DescrCode11$;
              
        else
          if (DescrCode11$ < 10000) then
            sDescrCode1$ := '0' || DescrCode11$;
                
          else
            sDescrCode1$ := DescrCode11$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode21$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode21$ < 10) then
      sDescrCode2$ := '0000' || DescrCode21$;
          
    else
      if (DescrCode21$ < 100) then
        sDescrCode2$ := '000' || DescrCode21$;
            
      else
        if (DescrCode21$ < 1000) then
          sDescrCode2$ := '00' || DescrCode21$;
              
        else
          if (DescrCode21$ < 10000) then
            sDescrCode2$ := '0' || DescrCode21$;
                
          else
            sDescrCode2$ := DescrCode21$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupKD$;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD)
    ) AND (ROWNUM = 1)                     ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
        
    END IF;
  else
    /*   = 0,         ,     */
    update kd kd1 set
    name = new$name,
    ShortName = new$ShortName, 
    kd_level = new$kd_level
    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD);
    /*        */
    if (new$deletedate is not null) then
      update kd kd1 set
      deletedate = new$deletedate
      where
      (kd1.kvsr <> 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
      (kd1.DeleteDate is null);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER tr_kd_bd_0
CREATE OR REPLACE TRIGGER TR_KD_ID
  INSTEAD OF DELETE
  ON KD
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_KD_BD_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*    ,      */
  if (:old.kvsr = 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr <> 0) and
    ((kd1.descriptioncode-:old.descriptioncode>-1) and (kd1.descriptioncode-:old.descriptioncode<1)) and
    (kd1.programcode = :old.programcode) and
    (kd1.AnalyticalGroupKD = :old.AnalyticalGroupKD)
    ) AND (ROWNUM = 1)       ;
    if ((CNT$1<> 0)) 
    then
      RaiseException('EX_CANTDELBASECODE');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_KD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_KD_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(80, :old.ID, sysdate);

END;
/
COMMIT WORK 
/
ALTER TABLE TB_InnerFinSource ADD (
  AnalyticalGroupIFS NUMBER(10)/*     */,
    CHECK((AnalyticalGroupIFS<=2147483647)AND(AnalyticalGroupIFS>-2147483648))
)
/

CREATE OR REPLACE VIEW InnerFinSource (
  ID,
  CREATEDATE,
  UPDATEDATE,
  DIRECTION,
  KVSR,
  DESCRIPTIONCODE,
  MAINDESCRIPTIONCODE,
  ITEMCODE,
  PROGRAMCODE,
  KESR,
  FINSOURCEVALUE,
  UNIONFLAG,
  REMOTEFLAG,
  BUDGETREF,
  DELETEDATE,
  NAME,
  STARTDATE,
  SHORTNAME,
  CLSASPECT,
  CREATERUSER,
  UPDATERUSER,
  IFS_LEVEL,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  ANALYTICALGROUPIFS)
AS
  SELECT
    ID,
    CREATEDATE,
    UPDATEDATE,
    DIRECTION,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    FINSOURCEVALUE,
    UNIONFLAG,
    REMOTEFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    STARTDATE,
    SHORTNAME,
    CLSASPECT,
    CREATERUSER,
    UPDATERUSER,
    IFS_LEVEL,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPIFS
  FROM TB_InnerFinSource
/

CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_ID
  INSTEAD OF DELETE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_INNERFINSOURCE_BD_0)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  --    ,     
  if (:old.kvsr = 0) then
    select count(*) into CNT$
                 from InnerFinSource ifs1
                 where ((ifs1.kvsr <> 0) and
                       ((ifs1.descriptioncode-:old.descriptioncode>-1) and (ifs1.descriptioncode-:old.descriptioncode<1)) and
                       (ifs1.kesr = :old.kesr)) AND (ROWNUM = 1);
    if (CNT$ > 0) then
      RaiseException('EX_CANTDELBASECODE');
    end if;
  end if;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INNERFINSOURCE
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_INNERFINSOURCE_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(145,:old.ID,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_II
  INSTEAD OF INSERT
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  CNT$ NUMBER(10);
  tmp$ NUMBER(15,0);
  DescrCode1 NUMBER(10);
  DescrCode2 NUMBER(10);
  KVSRCode$ NUMBER(10);
  sKVSR VARCHAR2(3);
  sDescrCode1 VARCHAR2(7);
  sDescrCode2 VARCHAR2(7);
  sKESR VARCHAR2(3);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INNERFINSOURCE_BI_0)
-- Last update 27.10.2009
-- - - - - - - - - - - - -

  --  Id,    
  IF (new$ID IS NULL) THEN SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL; END IF;
  IF (new$KVSR IS NULL) THEN new$KVSR := 0; END IF;
  IF (new$KESR IS NULL) THEN new$KESR := 0; END IF;
  IF (new$ClsAspect IS NULL) THEN new$ClsAspect := 0; END IF;
  if (new$UnionFlag is null) then new$UnionFlag := 0; END IF;
  if (new$RemoteFlag is null) then new$RemoteFlag := 0; END IF;
  if (new$BudgetRef is null) then new$BudgetRef := 0; end if;

  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction into sIFSLevel$, sDirection$ from innerfinsource where ((KESR = new$KESR) and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;

  --         
  --   6xx, 8xx - 
  IF (new$Direction IS NULL) THEN
    if ((new$KESR between 300 and 399) or (new$KESR between 500 and 599)or (new$KESR between 800 and 899))
    THEN
      new$Direction := -1;
    ELSE
      new$Direction := 1;
    END IF;
  END IF;

  /*       */ 
  BEGIN
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      KVSRCode$ := NULL;
  END;    

  --  20-   
  --     
  if (KVSRCode$ = 0) then
      sKVSR := '000';
  elsif (KVSRCode$ < 10) then
      sKVSR := '00' || KVSRCode$;
  elsif (KVSRCode$ < 100) then
      sKVSR := '0' || KVSRCode$;
  else
      sKVSR := KVSRCode$;
  END IF;

  --    , , 
  tmp$ := new$DescriptionCode;
  DescrCode1 := TRUNC (tmp$ / 1000000);

  IF (DescrCode1 * 1000000 > tmp$) THEN
    DescrCode1 := DescrCode1 - 1;
  END IF;

  new$MainDescriptionCode := DescrCode1;          --   
  DescrCode2 := tmp$ - DescrCode1 * 1000000;
  DescrCode1 := TRUNC (DescrCode2 / 10000);

  IF (DescrCode1 * 10000 > DescrCode2) THEN
    DescrCode1 := DescrCode1 - 1;
  END IF;

  new$ItemCode := DescrCode1;                                     --
  new$ProgramCode := DescrCode2 - DescrCode1 * 10000;             --
  --      
  DescrCode1 := TRUNC (tmp$ / 10000000);

  IF (DescrCode1 * 10000000 > tmp$) THEN
    DescrCode1 := DescrCode1 - 1;
  END IF;

  DescrCode2 := tmp$ - DescrCode1 * 10000000;

  IF (DescrCode1 = 0) THEN
    sDescrCode1 := '0000000';
  ELSIF (DescrCode1 < 10) THEN
    sDescrCode1 := '000000' || DescrCode1;
  ELSIF (DescrCode1 < 100) THEN
    sDescrCode1 := '00000' || DescrCode1;
  ELSIF (DescrCode1 < 1000) THEN
    sDescrCode1 := '0000' || DescrCode1;
  ELSIF (DescrCode1 < 10000) THEN
    sDescrCode1 := '000' || DescrCode1;
  ELSIF (DescrCode1 < 100000) THEN
    sDescrCode1 := '00' || DescrCode1;
  ELSIF (DescrCode1 < 1000000) THEN
    sDescrCode1 := '0' || DescrCode1;
  ELSE
    sDescrCode1 := DescrCode1;
  END IF;

  IF (DescrCode2 = 0) THEN
    sDescrCode2 := '0000000';
  ELSIF (DescrCode2 < 10) THEN
    sDescrCode2 := '000000' || DescrCode2;
  ELSIF (DescrCode2 < 100) THEN
    sDescrCode2 := '00000' || DescrCode2;
  ELSIF (DescrCode2 < 1000) THEN
    sDescrCode2 := '0000' || DescrCode2;
  ELSIF (DescrCode2 < 10000) THEN
    sDescrCode2 := '000' || DescrCode2;
  ELSIF (DescrCode2 < 100000) THEN
    sDescrCode2 := '00' || DescrCode2;
  ELSIF (DescrCode2 < 1000000) THEN
    sDescrCode2 := '0' || DescrCode2;
  ELSE
    sDescrCode2 := DescrCode2;
  END IF;

  --     
  IF (new$kesr = 0) THEN
    sKESR := '000';
  ELSIF (new$kesr < 10) THEN
    sKESR := '00' || new$kesr;
  ELSIF (new$kesr < 100) THEN
    sKESR := '0' || new$kesr;
  ELSE
    sKESR := new$kesr;
  END IF;

  --     
  new$FinSourceValue := sKVSR || sDescrCode1 || sDescrCode2 || sKESR;

  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000')) then
    RaiseException('ex_CantModify_ZeroIFS');
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_INNERFINSOURCE_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INNERFINSOURCE (
    ID,
    CREATEDATE,
    UPDATEDATE,
    DIRECTION,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    FINSOURCEVALUE,
    UNIONFLAG,
    REMOTEFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    STARTDATE,
    SHORTNAME,
    CLSASPECT,
    CREATERUSER,
    UPDATERUSER,
    IFS_LEVEL,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPIFS
  ) VALUES (
    new$ID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$DIRECTION,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$FINSOURCEVALUE,
    new$UNIONFLAG,
    new$REMOTEFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$STARTDATE,
    new$SHORTNAME,
    new$CLSASPECT,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$IFS_LEVEL,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPIFS);

-- - - - - - - - - - - - -
-- AI_100 (TR_INNERFINSOURCE_AI_100)
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    select count(*) into CNT$
                     from InnerFinSource ifs1
                     where ((ifs1.kvsr = 0) and
                           ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
                           (ifs1.kesr = new$kesr)) AND (ROWNUM = 1);
    if (CNT$ = 0) then
        insert into InnerFinSource (KVSR, DescriptionCode, KESR, Name, ShortName, CLSAspect, RemoteFlag, Direction, IFS_Level)
        values (0, new$DescriptionCode, new$KESR, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$direction, new$IFS_Level);
    end if; 
  end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_INNERFINSOURCE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 145) and (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sKESR$ VARCHAR2(3);
  CNT$1 NUMBER(10);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  
  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction into sIFSLevel$, sDirection$ from innerfinsource where ((KESR = new$KESR) and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;  
  
  /*         
            =3,5,8 */
  if ((new$Direction is null)or(new$kesr <> :old.kesr)) then
    if ((new$KESR between 300 and 399) or (new$KESR between 500 and 599)or (new$KESR between 800 and 899))
    then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
    
  /*  20-    */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$kesr = 0) then
    sKESR$ := '000';
        
  else
    if (new$kesr < 10) then
      sKESR$ := '00' || new$kesr;
          
    else
      if (new$kesr < 100) then
        sKESR$ := '0' || new$kesr;
            
      else
        sKESR$ := new$kesr;
      END IF;
    END IF;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sKESR$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.kesr = new$kesr)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, KESR, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level)
      values (0, new$DescriptionCode, new$KESR, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level);
      
    END IF;
  else
    /*   = 0,         ,     */
    update InnerFinSource ifs1 set
    name = new$name,
    ShortName = new$ShortName,
    ifs_level = new$ifs_level,
    Direction = new$Direction
    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.kesr = new$kesr);
    /*        */
    if (new$deletedate is not null) then
      update InnerFinSource ifs1 set
      deletedate = new$deletedate
      where
      (ifs1.kvsr <> 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.kesr = new$kesr) and
      (ifs1.DeleteDate is null);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE TB_INNERFINSOURCE DROP CONSTRAINT FK_IFS_KESR
/
DROP INDEX FK_IFS_KESR
/
COMMIT WORK 
/
ALTER TRIGGER TR_INNERFINSOURCE_BU_500 DISABLE
/
-- ALTER TRIGGER TR_InnerFinSource_AU_100
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sKESR$ VARCHAR2(3);
  CNT$1 NUMBER(10);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  
  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction into sIFSLevel$, sDirection$ from innerfinsource where ((KESR = new$KESR) and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;  
  
  /*         
            =3,5,8 */
  if ((new$Direction is null)or(new$kesr <> :old.kesr)) then
    if ((new$KESR between 300 and 399) or (new$KESR between 500 and 599)or (new$KESR between 800 and 899))
    then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
    
  /*  20-    */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$kesr = 0) then
    sKESR$ := '000';
        
  else
    if (new$kesr < 10) then
      sKESR$ := '00' || new$kesr;
          
    else
      if (new$kesr < 100) then
        sKESR$ := '0' || new$kesr;
            
      else
        sKESR$ := new$kesr;
      END IF;
    END IF;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sKESR$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$kvsr <> 0) then
--     SELECT COUNT(*) INTO CNT$1
--     from InnerFinSource ifs1
--     where ((ifs1.kvsr = 0) and
--     ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
--     (ifs1.kesr = new$kesr)
--     ) AND (ROWNUM = 1)                   ;
--     if (not (CNT$1<> 0))
--     then  
--       insert into InnerFinSource (KVSR, DescriptionCode, KESR, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level)
--       values (0, new$DescriptionCode, new$KESR, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level);
--       
--     END IF;
--   else
--     /*   = 0,         ,     */
--     update InnerFinSource ifs1 set
--     name = new$name,
--     ShortName = new$ShortName,
--     ifs_level = new$ifs_level,
--     Direction = new$Direction
--     where
--     (ifs1.kvsr <> 0) and
--     ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
--     (ifs1.kesr = new$kesr);
--     /*        */
--     if (new$deletedate is not null) then
--       update InnerFinSource ifs1 set
--       deletedate = new$deletedate
--       where
--       (ifs1.kvsr <> 0) and
--       ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
--       (ifs1.kesr = new$kesr) and
--       (ifs1.DeleteDate is null);
--       
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
COMMIT WORK 
/
update InnerFinSource set
  AnalyticalGroupIFS = KESR
/
COMMIT WORK 
/
ALTER TRIGGER TR_INNERFINSOURCE_BU_500 ENABLE
/
-- ALTER TRIGGER TR_InnerFinSource_AU_100
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sKESR$ VARCHAR2(3);
  CNT$1 NUMBER(10);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  
  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction into sIFSLevel$, sDirection$ from innerfinsource where ((KESR = new$KESR) and (BudgetRef=new$BudgetRef)
      and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;  
  
  /*         
            =3,5,8 */
  if ((new$Direction is null)or(new$kesr <> :old.kesr)) then
    if ((new$KESR between 300 and 399) or (new$KESR between 500 and 599)or (new$KESR between 800 and 899))
    then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
    
  /*  20-    */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*      */
  if (new$kesr = 0) then
    sKESR$ := '000';
        
  else
    if (new$kesr < 10) then
      sKESR$ := '00' || new$kesr;
          
    else
      if (new$kesr < 100) then
        sKESR$ := '0' || new$kesr;
            
      else
        sKESR$ := new$kesr;
      END IF;
    END IF;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sKESR$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.kesr = new$kesr)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, KESR, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level)
      values (0, new$DescriptionCode, new$KESR, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level);
      
    END IF;
  else
    /*   = 0,         ,     */
    update InnerFinSource ifs1 set
    name = new$name,
    ShortName = new$ShortName,
    ifs_level = new$ifs_level,
    Direction = new$Direction
    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.kesr = new$kesr);
    /*        */
    if (new$deletedate is not null) then
      update InnerFinSource ifs1 set
      deletedate = new$deletedate
      where
      (ifs1.kvsr <> 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.kesr = new$kesr) and
      (ifs1.DeleteDate is null);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
COMMIT WORK 
/
ALTER TABLE TB_InnerFinSource ADD (
  CONSTRAINT FK_IFS_AnalyticalGroupIFS FOREIGN KEY (AnalyticalGroupIFS) REFERENCES AnalyticalGroupIFS (ID)
)
/
CREATE INDEX FK_IFS_AnalyticalGroupIFS ON TB_InnerFinSource(AnalyticalGroupIFS)
/
COMMIT WORK 
/
-- ALTER TRIGGER tr_innerfinsource_bi_0
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_II
  INSTEAD OF INSERT
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  CNT$ NUMBER(10);
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  sIFSLevel1$ NUMBER(10);
  sDirection1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INNERFINSOURCE_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction 
      into sIFSLevel1$, sDirection1$     from innerfinsource 
      where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
      (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel1$ is not null) then
    new$IFS_Level := sIFSLevel1$;
  END IF;
  if (sDirection1$ is not null) then
    new$Direction := sDirection1$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupIFS$;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INNERFINSOURCE_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INNERFINSOURCE (
    ID,
    CREATEDATE,
    UPDATEDATE,
    DIRECTION,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    FINSOURCEVALUE,
    UNIONFLAG,
    REMOTEFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    STARTDATE,
    SHORTNAME,
    CLSASPECT,
    CREATERUSER,
    UPDATERUSER,
    IFS_LEVEL,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPIFS
  ) VALUES (
    new$ID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$DIRECTION,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$FINSOURCEVALUE,
    new$UNIONFLAG,
    new$REMOTEFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$STARTDATE,
    new$SHORTNAME,
    new$CLSASPECT,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$IFS_LEVEL,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPIFS);

-- - - - - - - - - - - - -
-- AI_100 (TR_INNERFINSOURCE_AI_100)
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    select count(*) into CNT$
                     from InnerFinSource ifs1
                     where ((ifs1.kvsr = 0) and
                           ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
                           (ifs1.kesr = new$kesr)) AND (ROWNUM = 1);
    if (CNT$ = 0) then
        insert into InnerFinSource (KVSR, DescriptionCode, KESR, Name, ShortName, CLSAspect, RemoteFlag, Direction, IFS_Level)
        values (0, new$DescriptionCode, new$KESR, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$direction, new$IFS_Level);
    end if; 
  end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_INNERFINSOURCE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 145) and (RecordId = new$ID);

END;
/
-- ALTER TRIGGER tr_innerfinsource_ai_100
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_II
  INSTEAD OF INSERT
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  sIFSLevel1$ NUMBER(10);
  sDirection1$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INNERFINSOURCE_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction 
      into sIFSLevel1$, sDirection1$     from innerfinsource 
      where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
      (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel1$ is not null) then
    new$IFS_Level := sIFSLevel1$;
  END IF;
  if (sDirection1$ is not null) then
    new$Direction := sDirection1$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupIFS$;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INNERFINSOURCE_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INNERFINSOURCE (
    ID,
    CREATEDATE,
    UPDATEDATE,
    DIRECTION,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    FINSOURCEVALUE,
    UNIONFLAG,
    REMOTEFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    STARTDATE,
    SHORTNAME,
    CLSASPECT,
    CREATERUSER,
    UPDATERUSER,
    IFS_LEVEL,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPIFS
  ) VALUES (
    new$ID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$DIRECTION,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$FINSOURCEVALUE,
    new$UNIONFLAG,
    new$REMOTEFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$STARTDATE,
    new$SHORTNAME,
    new$CLSASPECT,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$IFS_LEVEL,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPIFS);

-- - - - - - - - - - - - -
-- AI_100 (TR_INNERFINSOURCE_AI_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, Direction, IFS_Level)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$direction, new$IFS_Level);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INNERFINSOURCE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 145) and (RecordId = new$ID);

END;
/
-- ALTER TRIGGER tr_innerfinsource_bu_0
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  CNT$1 NUMBER(10);
  DescrCode11$ NUMBER(10);
  DescrCode21$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  sIFSLevel1$ NUMBER(10);
  sDirection1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction 
      into sIFSLevel1$, sDirection1$     from innerfinsource 
      where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
      (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel1$ is not null) then
    new$IFS_Level := sIFSLevel1$;
  END IF;
  if (sDirection1$ is not null) then
    new$Direction := sDirection1$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode11$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode11$  > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode11$; /*    */
  /*       */    
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode21$ := tmp_Double$;
  tmp_Double$ := DescrCode21$ / 10000;
  DescrCode11$ := tmp_Double$;
  /*      */
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  new$ItemCode := DescrCode11$; /* */
  tmp_Double$ := DescrCode21$ - DescrCode11$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode11$ := tmp_Double$;
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode21$ := tmp_Double$;
  if (DescrCode11$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode11$ < 10) then
      sDescrCode1$ := '000000' || DescrCode11$;
          
    else
      if (DescrCode11$ < 100) then
        sDescrCode1$ := '00000' || DescrCode11$;
            
      else
        if (DescrCode11$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode11$;
              
        else
          if (DescrCode11$ < 10000) then
            sDescrCode1$ := '000' || DescrCode11$;
                
          else
            if (DescrCode11$ < 100000) then
              sDescrCode1$ := '00' || DescrCode11$;
                  
            else
              if (DescrCode11$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode11$;
                    
              else
                sDescrCode1$ := DescrCode11$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode21$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode21$ < 10) then
      sDescrCode2$ := '000000' || DescrCode21$;
          
    else
      if (DescrCode21$ < 100) then
        sDescrCode2$ := '00000' || DescrCode21$;
            
      else
        if (DescrCode21$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode21$;
              
        else
          if (DescrCode21$ < 10000) then
            sDescrCode2$ := '000' || DescrCode21$;
                
          else
            if (DescrCode21$ < 100000) then
              sDescrCode2$ := '00' || DescrCode21$;
                  
            else
              if (DescrCode21$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode21$;
                    
              else
                sDescrCode2$ := DescrCode21$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupIFS$;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.kesr = new$kesr)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, KESR, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level)
      values (0, new$DescriptionCode, new$KESR, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level);
      
    END IF;
  else
    /*   = 0,         ,     */
    update InnerFinSource ifs1 set
    name = new$name,
    ShortName = new$ShortName,
    ifs_level = new$ifs_level,
    Direction = new$Direction
    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.kesr = new$kesr);
    /*        */
    if (new$deletedate is not null) then
      update InnerFinSource ifs1 set
      deletedate = new$deletedate
      where
      (ifs1.kvsr <> 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.kesr = new$kesr) and
      (ifs1.DeleteDate is null);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER tr_innerfinsource_au_100
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  CNT$1 NUMBER(10);
  DescrCode11$ NUMBER(10);
  DescrCode21$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  sIFSLevel1$ NUMBER(10);
  sDirection1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction 
      into sIFSLevel1$, sDirection1$     from innerfinsource 
      where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
      (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel1$ is not null) then
    new$IFS_Level := sIFSLevel1$;
  END IF;
  if (sDirection1$ is not null) then
    new$Direction := sDirection1$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode11$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode11$  > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode11$; /*    */
  /*       */    
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode21$ := tmp_Double$;
  tmp_Double$ := DescrCode21$ / 10000;
  DescrCode11$ := tmp_Double$;
  /*      */
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  new$ItemCode := DescrCode11$; /* */
  tmp_Double$ := DescrCode21$ - DescrCode11$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode11$ := tmp_Double$;
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode21$ := tmp_Double$;
  if (DescrCode11$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode11$ < 10) then
      sDescrCode1$ := '000000' || DescrCode11$;
          
    else
      if (DescrCode11$ < 100) then
        sDescrCode1$ := '00000' || DescrCode11$;
            
      else
        if (DescrCode11$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode11$;
              
        else
          if (DescrCode11$ < 10000) then
            sDescrCode1$ := '000' || DescrCode11$;
                
          else
            if (DescrCode11$ < 100000) then
              sDescrCode1$ := '00' || DescrCode11$;
                  
            else
              if (DescrCode11$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode11$;
                    
              else
                sDescrCode1$ := DescrCode11$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode21$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode21$ < 10) then
      sDescrCode2$ := '000000' || DescrCode21$;
          
    else
      if (DescrCode21$ < 100) then
        sDescrCode2$ := '00000' || DescrCode21$;
            
      else
        if (DescrCode21$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode21$;
              
        else
          if (DescrCode21$ < 10000) then
            sDescrCode2$ := '000' || DescrCode21$;
                
          else
            if (DescrCode21$ < 100000) then
              sDescrCode2$ := '00' || DescrCode21$;
                  
            else
              if (DescrCode21$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode21$;
                    
              else
                sDescrCode2$ := DescrCode21$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupIFS$;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level);
      
    END IF;
  else
    /*   = 0,         ,     */
    update InnerFinSource ifs1 set
    name = new$name,
    ShortName = new$ShortName,
    ifs_level = new$ifs_level,
    Direction = new$Direction
    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS);
    /*        */
    if (new$deletedate is not null) then
      update InnerFinSource ifs1 set
      deletedate = new$deletedate
      where
      (ifs1.kvsr <> 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
      (ifs1.DeleteDate is null);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER tr_innerfinsource_bd_0
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_ID
  INSTEAD OF DELETE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_INNERFINSOURCE_BD_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*    ,      */
  if (:old.kvsr = 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-:old.descriptioncode>-1) and (ifs1.descriptioncode-:old.descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = :old.AnalyticalGroupIFS)
    ) AND (ROWNUM = 1)       ;
    if ((CNT$1<> 0)) 
    then
      RaiseException('EX_CANTDELBASECODE');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INNERFINSOURCE
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_INNERFINSOURCE_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(145,:old.ID,SYSDATE);

END;
/
COMMIT WORK 
/
update permissions set
  name = '  '
where
  upper(name) = ' '
/
update permissions set
  name = '   '
where
  upper(name) = '  '
/
update AnalyticalGroupKD set
  name = '    '
where
  id = 0
/
update AnalyticalGroupIFS set
  name = '    '
where
  id = 0
/
COMMIT WORK 
/
ALTER TABLE TB_KD MODIFY(AnalyticalGroupKD NOT NULL)
/
ALTER TABLE TB_InnerFinSource MODIFY(AnalyticalGroupIFS NOT NULL)
/

-- #########################################################
-- #########################################################
-- Add_DontSignAttachedFiles_to_StateJumps.sql
-- #########################################################
-- #########################################################

/*        */
ALTER TABLE State_Jumps ADD (
  DontSignAttachedFiles NUMBER(10),
    CHECK((DontSignAttachedFiles<=2147483647)AND(DontSignAttachedFiles>-2147483648))
)
/
-- ALTER TRIGGER TR_STATE_JUMPS_BI_0
CREATE OR REPLACE TRIGGER TR_STATE_JUMPS_BI
  BEFORE INSERT
  ON STATE_JUMPS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_STATE_JUMPS_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.CanAttachFiles is null) then 
    :new.CanAttachFiles := 0;
  END IF;
  if (:new.CanDetacthFiles is null) then 
    :new.CanDetacthFiles := 0;
  END IF;
  if (:new.CanRejectAttachedFiles is null) then 
    :new.CanRejectAttachedFiles := 0;
  END IF;
  if (:new.DontSignAttachedFiles is null) then 
    :new.DontSignAttachedFiles := 0;
  END IF;
  if (:new.IsActive is null) then 
    :new.IsActive := 1;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_STATE_JUMPS_BI_500)
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;  

END;
/
-- ALTER TRIGGER TR_STATE_JUMPS_BU_0
CREATE OR REPLACE TRIGGER TR_STATE_JUMPS_BU
  BEFORE UPDATE
  ON STATE_JUMPS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_STATE_JUMPS_BU_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.CanAttachFiles is null) then 
    :new.CanAttachFiles := 0;
  END IF;
  if (:new.CanDetacthFiles is null) then 
    :new.CanDetacthFiles := 0;
  END IF;
  if (:new.CanRejectAttachedFiles is null) then 
    :new.CanRejectAttachedFiles := 0;
  END IF;
  if (:new.DontSignAttachedFiles is null) then 
    :new.DontSignAttachedFiles := 0;
  END IF;
  if (:new.IsActive is null) then 
    :new.IsActive := 1;
  END IF;

END;
/
commit work 
/
ALTER TRIGGER TR_STATE_JUMPS_BU_500 DISABLE
/
update State_Jumps set
  DontSignAttachedFiles = 0
/
ALTER TRIGGER TR_STATE_JUMPS_BU_500 ENABLE
/
commit work 
/

ALTER TABLE State_Jumps MODIFY(DontSignAttachedFiles NOT NULL)
/

-- #########################################################
-- #########################################################
-- Add_Signers_to_UnionNotifyCaption.sql
-- #########################################################
-- #########################################################

/*    Signers   UnionNotifyCaption */
ALTER TABLE UnionNotifyCaption ADD (
  Signers VARCHAR2(1000)
)
/
commit work 
/

-- #########################################################
-- #########################################################
-- Create_TB_StoredAttr_Det_Cpt.sql
-- #########################################################
-- #########################################################

/*     (  5101)*/

CREATE TABLE STOREDATTRIBUTESCAPTION (
  ID NUMBER(10) NOT NULL,
    CHECK((ID<=2147483647)AND(ID>-2147483648)),
  DOCREF NUMBER(10) NOT NULL,/*     */
    CHECK((DOCREF<=2147483647)AND(DOCREF>-2147483648)),
  DOCPARAM VARCHAR2(255),/*   */
  DATEOPEN NUMBER,/*       */
  DATECLOSE NUMBER,/*       */
  ISACTIVE NUMBER(10) NOT NULL,/*      */
    CHECK((ISACTIVE<=2147483647)AND(ISACTIVE>-2147483648)),
  PREVVERSIONREF NUMBER(10),/*      */
    CHECK((PREVVERSIONREF<=2147483647)AND(PREVVERSIONREF>-2147483648)),
  CREATEDATE DATE NOT NULL,/* OLDDATE = TIMESTAMP */
  UPDATEDATE DATE NOT NULL,/* OLDDATE = TIMESTAMP */
  CREATERUSER VARCHAR2(30) NOT NULL,/* DBUSER32 = VARCHAR(30) */
  UPDATERUSER VARCHAR2(30) NOT NULL
)
/
/* *****************************************************************************//* ***                             Primary Keys                             ****//* *****************************************************************************/
ALTER TABLE STOREDATTRIBUTESCAPTION ADD (
  CONSTRAINT PK_STOREDATTRCPT_ID PRIMARY KEY (ID)
)
/
/*     (  5102)*/

CREATE TABLE STOREDATTRIBUTESDETAIL (
  ID NUMBER(10) NOT NULL,
    CHECK((ID<=2147483647)AND(ID>-2147483648)),
  CONTAINER_REF NUMBER(10) NOT NULL,/*   -  DocumentFields */
    CHECK((CONTAINER_REF<=2147483647)AND(CONTAINER_REF>-2147483648)),
  ATTRIBUTE_REF NUMBER(10) NOT NULL,/*   -  DocumentFields */
    CHECK((ATTRIBUTE_REF<=2147483647)AND(ATTRIBUTE_REF>-2147483648)),
  FIELDTYPE NUMBER(10) NOT NULL,/*  : 0 - ; 1 - ; 2 - ; 3 -  */
    CHECK((FIELDTYPE<=2147483647)AND(FIELDTYPE>-2147483648)),
  FIELDSIZE NUMBER(10) NOT NULL,/*    ( FieldType=1)*/
    CHECK((FIELDSIZE<=2147483647)AND(FIELDSIZE>-2147483648)),
  NAME VARCHAR2(50),/*    */
  SOURCEFIELD NUMBER(10),/* -   */
    CHECK((SOURCEFIELD<=2147483647)AND(SOURCEFIELD>-2147483648)),
  FIELDORDER NUMBER(10),/*     */
    CHECK((FIELDORDER<=2147483647)AND(FIELDORDER>-2147483648)),
  FORMULA VARCHAR2(1024),/*   () */
  READONLY NUMBER(10),/*     */
    CHECK((READONLY<=2147483647)AND(READONLY>-2147483648)),
  PREVVERSIONREF NUMBER(10),/*      */
    CHECK((PREVVERSIONREF<=2147483647)AND(PREVVERSIONREF>-2147483648)),
  CREATEDATE DATE NOT NULL,
  UPDATEDATE DATE NOT NULL,
  CREATERUSER VARCHAR2(30) NOT NULL,
  UPDATERUSER VARCHAR2(30) NOT NULL,
  RECORDINDEX NUMBER(10) NOT NULL,
    CHECK((RECORDINDEX<=2147483647)AND(RECORDINDEX>-2147483648))
)
/
/* *****************************************************************************//* ***                             Primary Keys                             ****//* *****************************************************************************/
ALTER TABLE STOREDATTRIBUTESDETAIL ADD (
  CONSTRAINT PK_STOREDATTRDET_ID PRIMARY KEY (ID)
)
/
/* *****************************************************************************//* ***                             Foreign Keys                             ****//* *****************************************************************************/
ALTER TABLE STOREDATTRIBUTESDETAIL ADD (
  CONSTRAINT FK_STOREDATTRDET_ATTRIBUTE FOREIGN KEY (ATTRIBUTE_REF) REFERENCES TB_DOCUMENTFIELDS (ID)
)
/
CREATE INDEX FK_STOREDATTRDET_ATTRIBUTE ON STOREDATTRIBUTESDETAIL(ATTRIBUTE_REF)
/
ALTER TABLE STOREDATTRIBUTESDETAIL ADD (
  CONSTRAINT FK_STOREDATTRDET_CONTAINER FOREIGN KEY (CONTAINER_REF) REFERENCES TB_DOCUMENTFIELDS (ID)
)
/
CREATE INDEX FK_STOREDATTRDET_CONTAINER ON STOREDATTRIBUTESDETAIL(CONTAINER_REF)
/
ALTER TABLE STOREDATTRIBUTESDETAIL ADD (
  CONSTRAINT FK_STOREDATTRDET_RECORDINDEX FOREIGN KEY (RECORDINDEX) REFERENCES STOREDATTRIBUTESCAPTION (ID)
)
/
CREATE INDEX FK_STOREDATTRDET_RECORDINDEX ON STOREDATTRIBUTESDETAIL(RECORDINDEX)
/
ALTER TABLE STOREDATTRIBUTESDETAIL ADD (
  CONSTRAINT FK_STOREDATTRDET_SOURCEFIELD FOREIGN KEY (SOURCEFIELD) REFERENCES TB_DOCUMENTFIELDS (ID)
)
/
CREATE INDEX FK_STOREDATTRDET_SOURCEFIELD ON STOREDATTRIBUTESDETAIL(SOURCEFIELD)
/
/* *****************************************************************************/
/* ***                               Indices                                ****/
/* *****************************************************************************/

CREATE INDEX IDX_STOREDATTDET_FIELDTYPE ON STOREDATTRIBUTESDETAIL (FIELDTYPE)
/
CREATE INDEX IDX_STOREDATTDET_FIELDSIZE ON STOREDATTRIBUTESDETAIL (FIELDSIZE)
/
CREATE INDEX IDX_STOREDATTDET_ORDER ON STOREDATTRIBUTESDETAIL (FIELDORDER)
/
CREATE INDEX IDX_STOREDATTDET_READONLY ON STOREDATTRIBUTESDETAIL (READONLY)
/
-- CREATE TRIGGER TR_STOREDATTRDET_AD_500
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESDETAIL_AD
  AFTER DELETE
  ON STOREDATTRIBUTESDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AD_500 (TR_STOREDATTRDET_AD_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(5102,:old.ID,SYSDATE);

END;
/
-- CREATE TRIGGER TR_STOREDATTRDET_AI_500
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESDETAIL_AI
  AFTER INSERT
  ON STOREDATTRIBUTESDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AI_500 (TR_STOREDATTRDET_AI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 5102) and (RecordID = :new.ID);

END;
/
-- CREATE TRIGGER TR_STOREDATTRDET_AU_500
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESDETAIL_AU
  AFTER UPDATE
  ON STOREDATTRIBUTESDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AU_500 (TR_STOREDATTRDET_AU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5102, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5102) and (RecordId=:new.ID);
      
  END IF;

END;
/
-- CREATE TRIGGER TR_STOREDATTRDET_BI_0
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESDETAIL_BI
  BEFORE INSERT
  ON STOREDATTRIBUTESDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_STOREDATTRDET_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.container_ref is null) then 
    :new.container_ref := 0;
  END IF;
  if (:new.attribute_ref is null) then 
    :new.attribute_ref := 0;
  END IF;
  if (:new.fieldtype is null) then 
    :new.fieldtype := 0;
  END IF;
  if ((:new.fieldsize is null) and (:new.fieldtype=1)) then 
    :new.fieldsize := 255; /*       255*/
  END IF;

END;
/
-- CREATE TRIGGER TR_STOREDATTRDET_BI_500
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESDETAIL_BI
  BEFORE INSERT
  ON STOREDATTRIBUTESDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_STOREDATTRDET_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.container_ref is null) then 
    :new.container_ref := 0;
  END IF;
  if (:new.attribute_ref is null) then 
    :new.attribute_ref := 0;
  END IF;
  if (:new.fieldtype is null) then 
    :new.fieldtype := 0;
  END IF;
  if ((:new.fieldsize is null) and (:new.fieldtype=1)) then 
    :new.fieldsize := 255; /*       255*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_STOREDATTRDET_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.createdate := SYSDATE;
  :new.updatedate := :new.createdate;
  :new.createruser := user;
  :new.updateruser := user;

END;
/
-- CREATE TRIGGER TR_STOREDATTRDET_BU_500
CREATE OR REPLACE TRIGGER TR_STOREDATTRDET_BU_500
  BEFORE UPDATE
  ON STOREDATTRIBUTESDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_STOREDATTRDET_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.Updatedate := SYSDATE;
  :new.UpdaterUser := User;

END;
/
/* *****************************************************************************/
/* ***                              Privileges                              ****/
/* *****************************************************************************/


/* Privileges of users */
GRANT SELECT, INSERT, UPDATE, DELETE ON STOREDATTRIBUTESDETAIL TO BUDGET_USERS
/
/* *****************************************************************************//* ***                             Foreign Keys                             ****//* *****************************************************************************/
ALTER TABLE STOREDATTRIBUTESCAPTION ADD (
  CONSTRAINT FK_STOREDATTRCPT_DOCREF FOREIGN KEY (DOCREF) REFERENCES DOCUMENTTYPES (ID)
)
/
CREATE INDEX FK_STOREDATTRCPT_DOCREF ON STOREDATTRIBUTESCAPTION(DOCREF)
/
/* *****************************************************************************/
/* ***                               Indices                                ****/
/* *****************************************************************************/

CREATE INDEX IDX_STOREDATTRCPT_DATECLOSE ON STOREDATTRIBUTESCAPTION (DATECLOSE)
/
CREATE INDEX IDX_STOREDATTRCPT_DATEOPEN ON STOREDATTRIBUTESCAPTION (DATEOPEN)
/
CREATE INDEX IDX_STOREDATTRCPT_ISACTIVE ON STOREDATTRIBUTESCAPTION (ISACTIVE)
/
-- CREATE TRIGGER TR_STOREDATTRCPT_AD_500
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESCAPTION_AD
  AFTER DELETE
  ON STOREDATTRIBUTESCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AD_500 (TR_STOREDATTRCPT_AD_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(5101,:old.ID,SYSDATE);

END;
/
-- CREATE TRIGGER TR_STOREDATTRCPT_AI_500
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESCAPTION_AI
  AFTER INSERT
  ON STOREDATTRIBUTESCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AI_500 (TR_STOREDATTRCPT_AI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 5101) and (RecordID = :new.ID);

END;
/
-- CREATE TRIGGER TR_STOREDATTRCPT_AU_500
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESCAPTION_AU
  AFTER UPDATE
  ON STOREDATTRIBUTESCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AU_500 (TR_STOREDATTRCPT_AU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5101, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5101) and (RecordId=:new.ID);
      
  END IF;

END;
/
-- CREATE TRIGGER TR_STOREDATTRCPT_BD
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESCAPTION_BD
  BEFORE DELETE
  ON STOREDATTRIBUTESCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_STOREDATTRCPT_BD)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*   */
  delete 
  from StoredAttributesDetail
  where 
  (RecordIndex = :old.id);

END;
/
-- CREATE TRIGGER TR_STOREDATTRCPT_BI_0
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESCAPTION_BI
  BEFORE INSERT
  ON STOREDATTRIBUTESCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_STOREDATTRCPT_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.docref is null) then 
    :new.docref := 0;
  END IF;
  if (:new.isactive is null) then 
    :new.isactive := 1;
  END IF;

END;
/
-- CREATE TRIGGER TR_STOREDATTRCPT_BI_500
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESCAPTION_BI
  BEFORE INSERT
  ON STOREDATTRIBUTESCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_STOREDATTRCPT_BI_0)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.docref is null) then 
    :new.docref := 0;
  END IF;
  if (:new.isactive is null) then 
    :new.isactive := 1;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_STOREDATTRCPT_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.createdate := SYSDATE;
  :new.updatedate := :new.createdate;
  :new.createruser := user;
  :new.updateruser := user;

END;
/
-- CREATE TRIGGER TR_STOREDATTRCPT_BU_500
CREATE OR REPLACE TRIGGER TR_STOREDATTRCPT_BU_500
  BEFORE UPDATE
  ON STOREDATTRIBUTESCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_STOREDATTRCPT_BU_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.Updatedate := SYSDATE;
  :new.UpdaterUser := User;

END;
/
/* *****************************************************************************/
/* ***                              Privileges                              ****/
/* *****************************************************************************/

/* Privileges of users */
GRANT SELECT, INSERT, UPDATE, DELETE ON STOREDATTRIBUTESCAPTION TO BUDGET_USERS
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_CorDet_ChangeOrgName_from_255_to_1000.sql
-- #########################################################
-- #########################################################

/*     ChangeOrgName  255  1000   CorrectionDetail */
ALTER TABLE TB_CorrectionDetail ADD (
  ChangeOrgName_Buf VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW CorrectionDetail (
  ID,
  PARENTID,
  BUDGETREF,
  SUMMA,
  CLSTYPE,
  FACIALACC_CLS,
  KVSR,
  KFSR,
  KCSR,
  KVR,
  KESR,
  DIRECTIONCLS,
  MEANSTYPE,
  FACT,
  REGIONCLS,
  FINSOURCE,
  FINTYPE,
  DOCTYPE,
  SUBKESR,
  FUNDSSOURCE,
  KD,
  IFS,
  BUHOPERATIONCLS,
  CHANGEACC_REF,
  CHANGEACC,
  CHANGEORGNAME,
  CHANGEORGINN,
  CHANGEORGINN20,
  PROGINDEX,
  RECORDINDEX,
  DOCUMENTPROGINDEX,
  DOCUMENTRECORDINDEX,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SENDERID,
  SENDERRECORDID,
  RVERSION,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  NOTE,
  ISCLSCHANGED,
  PROMISE,
  BUDGETPROMISE,
  EXECDOC,
  OKATO,
  ADDOKATO,
  TRANSFERTCLS,
  ORIGINALCLSSUMMA,
  NOTECLS,
  OPERATIONTYPE,
  REVERSEFLAG,
  EXECINNERNUMBER,
  CLSFIELFCHANGED,
  FAORGTYPE,
  SUBSIDYCLS,
  BUDALLOCATIONCLS,
  PAYPROMISECLS,
  NOTEQUALEX,
  OKTMO,
  UINCODE,
  INVESTOBJECT,
  CHANGEORGNAME_BUF)
AS
  SELECT
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGNAME,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME_BUF
  FROM TB_CorrectionDetail
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_ID
  INSTEAD OF DELETE
  ON CORRECTIONDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_CORRECTIONDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update CorrectionCaption set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_CORRECTIONDETAIL
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_CORRECTIONDETAIL_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate, ProgIndex, SUMMA) values(5504,:old.ID,SYSDATE,:old.ProgIndex, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_II
  INSTEAD OF INSERT
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME_BUF CORRECTIONDETAIL.CHANGEORGNAME_BUF%TYPE := :NEW.CHANGEORGNAME_BUF;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  vOperationTypeS1$ NUMBER(10);
  vOperationTypeD1$ NUMBER(10);
  vOperationType1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_CORRECTIONDETAIL_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;  
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS1$, vOperationTypeD1$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType1$ := vOperationTypeS1$;
          
    ELSE 
      vOperationType1$ := vOperationTypeD1$;
    END IF;
    new$OperationType := vOperationType1$;
      
  END IF;
  BEGIN

    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN FacialAcc_Cls fac  ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_100 (tr_correctiondetail_bi_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$progindex = 316) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_CORRECTIONDETAIL_BI_120)
-- Create 13.08.2007
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
      else
        if (new$ClsType is null)
          then new$ClsType := 0; /*  -  */
        end if;
    end if;
  end if;
 
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
 
  IF ( (new$ClsType = 1) AND (
       (new$KVSR <> 0) OR (new$KFSR <> 0) OR
       (new$KCSR <> 0) OR (new$KVR <> 0) OR
       (new$KESR <> 0) OR (new$KD <> 0)
     ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
 
  IF ((new$ClsType = 2) AND (
      (new$KVSR <> 0) OR (new$KFSR <> 0) OR
      (new$KCSR <> 0) OR (new$KVR <> 0) OR
      (new$KESR <> 0) OR
      (new$IFS <> 0)
    ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_CORRECTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (new$Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null) and (new$BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
    /*    ,   ,   */
    if ((new$BudgetPromise is not null) and (new$Promise is null)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_CORRECTIONDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$ExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_CORRECTIONDETAIL_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update CorrectionCaption set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CORRECTIONDETAIL (
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGNAME,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME_BUF
  ) VALUES (
    new$ID,
    new$PARENTID,
    new$BUDGETREF,
    new$SUMMA,
    new$CLSTYPE,
    new$FACIALACC_CLS,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$DIRECTIONCLS,
    new$MEANSTYPE,
    new$FACT,
    new$REGIONCLS,
    new$FINSOURCE,
    new$FINTYPE,
    new$DOCTYPE,
    new$SUBKESR,
    new$FUNDSSOURCE,
    new$KD,
    new$IFS,
    new$BUHOPERATIONCLS,
    new$CHANGEACC_REF,
    new$CHANGEACC,
    new$CHANGEORGNAME,
    new$CHANGEORGINN,
    new$CHANGEORGINN20,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$DOCUMENTPROGINDEX,
    new$DOCUMENTRECORDINDEX,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SENDERID,
    new$SENDERRECORDID,
    new$RVERSION,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$NOTE,
    new$ISCLSCHANGED,
    new$PROMISE,
    new$BUDGETPROMISE,
    new$EXECDOC,
    new$OKATO,
    new$ADDOKATO,
    new$TRANSFERTCLS,
    new$ORIGINALCLSSUMMA,
    new$NOTECLS,
    new$OPERATIONTYPE,
    new$REVERSEFLAG,
    new$EXECINNERNUMBER,
    new$CLSFIELFCHANGED,
    new$FAORGTYPE,
    new$SUBSIDYCLS,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$NOTEQUALEX,
    new$OKTMO,
    new$UINCODE,
    new$INVESTOBJECT,
    new$CHANGEORGNAME_BUF);

-- - - - - - - - - - - - -
-- AI_500 (TR_CORRECTIONDETAIL_AI_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

 delete from DelRecIndexes where (TableID =5504 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_IU
  INSTEAD OF UPDATE
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME_BUF CORRECTIONDETAIL.CHANGEORGNAME_BUF%TYPE := :NEW.CHANGEORGNAME_BUF;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  AccRef_Caption$ NUMBER(10);
  vOperationTypeS$ NUMBER(10);
  vOperationTypeD$ NUMBER(10);
  vOperationType$ NUMBER(10);
  AccRef$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_CORRECTIONDETAIL_BU)
-- Version 7.01.00.2
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS$, vOperationTypeD$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType$ := vOperationTypeS$;
          
    ELSE 
      vOperationType$ := vOperationTypeD$;
    END IF;
    new$OperationType := vOperationType$;
      
  END IF;
  /*         ,        */
  if (
  ((not new$changeacc is null) and (new$changeacc <> '')) 
  and 
  ((:old.changeacc <> new$changeacc) or (:old.changeacc is null))
  and 
  ((new$changeacc_ref = :old.changeacc_ref) or (new$changeacc_ref is null))
  )
  THEN
    BEGIN
      SELECT cor_c.OriginalAcceptorAcc_Ref
      INTO AccRef_Caption$     FROM correctioncaption cor_c
      LEFT JOIN CorrectionDetail cor_d ON ((cor_c.Id = cor_d.RecordIndex) AND (cor_d.ProgIndex = 316))
      WHERE cor_d.id = :old.id
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (NOT AccRef_Caption$ IS NULL) THEN
      new$changeacc_ref := AccRef_Caption$;
          
    ELSE
      BEGIN
        SELECT dfat.id
        INTO AccRef$       FROM dfAccountsBuhTable dfat
        LEFT JOIN Org_Accounts oa ON (dfat.id =  oa.id)
        WHERE (oa.acc = new$changeacc) AND (dfat.iscommon = 1) AND (dfat.isforbudget = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (NOT AccRef$ IS NULL) THEN
        new$changeacc_ref := AccRef$;
          
      END IF;  
    END IF;
  END IF;
  /*     \*/
  IF ((new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType IS NULL)) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  ON (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (tr_correctiondetail_bu_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$buhoperationcls <> :old.buhoperationcls) and (new$progindex = 316)) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_CORRECTIONDETAIL_BU_120)
-- Create 13.08.2007
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
      else
        if (new$ClsType is null)
          then new$ClsType := 0; /*  -  */
        end if;
    end if;
  end if;
        
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
  
  IF ( (new$ClsType = 1) AND (
       (new$KVSR <> 0) OR (new$KFSR <> 0) OR
       (new$KCSR <> 0) OR (new$KVR <> 0) OR
       (new$KESR <> 0) OR (new$KD <> 0)
     ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
  
  IF ((new$ClsType = 2) AND (
      (new$KVSR <> 0) OR (new$KFSR <> 0) OR
      (new$KCSR <> 0) OR (new$KVR <> 0) OR
      (new$KESR <> 0) OR
      (new$IFS <> 0)
    ))     
  THEN /*   */
    Raiseexception('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_CORRECTIONDETAIL_BU_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise )) and 
    (new$BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
        
    /*    ,   */
    if (((new$BudgetPromise is not null) and (:old.BudgetPromise is null)) or 
    (new$BudgetPromise <> :old.BudgetPromise)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
          
    END IF;
        
    /*    ,     */
    if ((new$BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      new$Promise := null;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_CORRECTIONDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null and (
    (:old.Promise is null or :old.Promise <> new$Promise) or
    (:old.ExecDoc is null or new$ExecDoc is null or :old.ExecDoc <> new$ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$ExecDoc is null or :old.ExecDoc is null or new$ExecDoc <> :old.ExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_CORRECTIONDETAIL_BU_700)
-- Create 13.08.2007
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 else
   if ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
     new$RVersion:=:Old.RVersion;
   else
     new$RVersion:=:Old.RVersion+1;
   end if;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CORRECTIONDETAIL SET
    ID = new$ID,
    PARENTID = new$PARENTID,
    BUDGETREF = new$BUDGETREF,
    SUMMA = new$SUMMA,
    CLSTYPE = new$CLSTYPE,
    FACIALACC_CLS = new$FACIALACC_CLS,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    FACT = new$FACT,
    REGIONCLS = new$REGIONCLS,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    DOCTYPE = new$DOCTYPE,
    SUBKESR = new$SUBKESR,
    FUNDSSOURCE = new$FUNDSSOURCE,
    KD = new$KD,
    IFS = new$IFS,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CHANGEACC_REF = new$CHANGEACC_REF,
    CHANGEACC = new$CHANGEACC,
    CHANGEORGNAME = new$CHANGEORGNAME,
    CHANGEORGINN = new$CHANGEORGINN,
    CHANGEORGINN20 = new$CHANGEORGINN20,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    DOCUMENTPROGINDEX = new$DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX = new$DOCUMENTRECORDINDEX,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    RVERSION = new$RVERSION,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    NOTE = new$NOTE,
    ISCLSCHANGED = new$ISCLSCHANGED,
    PROMISE = new$PROMISE,
    BUDGETPROMISE = new$BUDGETPROMISE,
    EXECDOC = new$EXECDOC,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    TRANSFERTCLS = new$TRANSFERTCLS,
    ORIGINALCLSSUMMA = new$ORIGINALCLSSUMMA,
    NOTECLS = new$NOTECLS,
    OPERATIONTYPE = new$OPERATIONTYPE,
    REVERSEFLAG = new$REVERSEFLAG,
    EXECINNERNUMBER = new$EXECINNERNUMBER,
    CLSFIELFCHANGED = new$CLSFIELFCHANGED,
    FAORGTYPE = new$FAORGTYPE,
    SUBSIDYCLS = new$SUBSIDYCLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    NOTEQUALEX = new$NOTEQUALEX,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    INVESTOBJECT = new$INVESTOBJECT,
    CHANGEORGNAME_BUF = new$CHANGEORGNAME_BUF
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_CORRECTIONDETAIL_AU_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5504, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5504) and (RecordId=new$ID);
  end if;

END;
/
update CorrectionDetail
  set ChangeOrgName_Buf = ChangeOrgName
/
ALTER TABLE TB_CorrectionDetail DROP (ChangeOrgName)
/
ALTER TABLE TB_CorrectionDetail ADD (
  ChangeOrgName VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW CorrectionDetail (
  ID,
  PARENTID,
  BUDGETREF,
  SUMMA,
  CLSTYPE,
  FACIALACC_CLS,
  KVSR,
  KFSR,
  KCSR,
  KVR,
  KESR,
  DIRECTIONCLS,
  MEANSTYPE,
  FACT,
  REGIONCLS,
  FINSOURCE,
  FINTYPE,
  DOCTYPE,
  SUBKESR,
  FUNDSSOURCE,
  KD,
  IFS,
  BUHOPERATIONCLS,
  CHANGEACC_REF,
  CHANGEACC,
  CHANGEORGINN,
  CHANGEORGINN20,
  PROGINDEX,
  RECORDINDEX,
  DOCUMENTPROGINDEX,
  DOCUMENTRECORDINDEX,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SENDERID,
  SENDERRECORDID,
  RVERSION,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  NOTE,
  ISCLSCHANGED,
  PROMISE,
  BUDGETPROMISE,
  EXECDOC,
  OKATO,
  ADDOKATO,
  TRANSFERTCLS,
  ORIGINALCLSSUMMA,
  NOTECLS,
  OPERATIONTYPE,
  REVERSEFLAG,
  EXECINNERNUMBER,
  CLSFIELFCHANGED,
  FAORGTYPE,
  SUBSIDYCLS,
  BUDALLOCATIONCLS,
  PAYPROMISECLS,
  NOTEQUALEX,
  OKTMO,
  UINCODE,
  INVESTOBJECT,
  CHANGEORGNAME_BUF,
  CHANGEORGNAME)
AS
  SELECT
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME_BUF,
    CHANGEORGNAME
  FROM TB_CorrectionDetail
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_ID
  INSTEAD OF DELETE
  ON CORRECTIONDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_CORRECTIONDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update CorrectionCaption set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_CORRECTIONDETAIL
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_CORRECTIONDETAIL_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate, ProgIndex, SUMMA) values(5504,:old.ID,SYSDATE,:old.ProgIndex, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_II
  INSTEAD OF INSERT
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME_BUF CORRECTIONDETAIL.CHANGEORGNAME_BUF%TYPE := :NEW.CHANGEORGNAME_BUF;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  vOperationTypeS1$ NUMBER(10);
  vOperationTypeD1$ NUMBER(10);
  vOperationType1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_CORRECTIONDETAIL_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;  
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS1$, vOperationTypeD1$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType1$ := vOperationTypeS1$;
          
    ELSE 
      vOperationType1$ := vOperationTypeD1$;
    END IF;
    new$OperationType := vOperationType1$;
      
  END IF;
  BEGIN

    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN FacialAcc_Cls fac  ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_100 (tr_correctiondetail_bi_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$progindex = 316) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_CORRECTIONDETAIL_BI_120)
-- Create 13.08.2007
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
      else
        if (new$ClsType is null)
          then new$ClsType := 0; /*  -  */
        end if;
    end if;
  end if;
 
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
 
  IF ( (new$ClsType = 1) AND (
       (new$KVSR <> 0) OR (new$KFSR <> 0) OR
       (new$KCSR <> 0) OR (new$KVR <> 0) OR
       (new$KESR <> 0) OR (new$KD <> 0)
     ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
 
  IF ((new$ClsType = 2) AND (
      (new$KVSR <> 0) OR (new$KFSR <> 0) OR
      (new$KCSR <> 0) OR (new$KVR <> 0) OR
      (new$KESR <> 0) OR
      (new$IFS <> 0)
    ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_CORRECTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (new$Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null) and (new$BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
    /*    ,   ,   */
    if ((new$BudgetPromise is not null) and (new$Promise is null)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_CORRECTIONDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$ExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_CORRECTIONDETAIL_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update CorrectionCaption set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CORRECTIONDETAIL (
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME_BUF,
    CHANGEORGNAME
  ) VALUES (
    new$ID,
    new$PARENTID,
    new$BUDGETREF,
    new$SUMMA,
    new$CLSTYPE,
    new$FACIALACC_CLS,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$DIRECTIONCLS,
    new$MEANSTYPE,
    new$FACT,
    new$REGIONCLS,
    new$FINSOURCE,
    new$FINTYPE,
    new$DOCTYPE,
    new$SUBKESR,
    new$FUNDSSOURCE,
    new$KD,
    new$IFS,
    new$BUHOPERATIONCLS,
    new$CHANGEACC_REF,
    new$CHANGEACC,
    new$CHANGEORGINN,
    new$CHANGEORGINN20,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$DOCUMENTPROGINDEX,
    new$DOCUMENTRECORDINDEX,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SENDERID,
    new$SENDERRECORDID,
    new$RVERSION,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$NOTE,
    new$ISCLSCHANGED,
    new$PROMISE,
    new$BUDGETPROMISE,
    new$EXECDOC,
    new$OKATO,
    new$ADDOKATO,
    new$TRANSFERTCLS,
    new$ORIGINALCLSSUMMA,
    new$NOTECLS,
    new$OPERATIONTYPE,
    new$REVERSEFLAG,
    new$EXECINNERNUMBER,
    new$CLSFIELFCHANGED,
    new$FAORGTYPE,
    new$SUBSIDYCLS,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$NOTEQUALEX,
    new$OKTMO,
    new$UINCODE,
    new$INVESTOBJECT,
    new$CHANGEORGNAME_BUF,
    new$CHANGEORGNAME);

-- - - - - - - - - - - - -
-- AI_500 (TR_CORRECTIONDETAIL_AI_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

 delete from DelRecIndexes where (TableID =5504 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_IU
  INSTEAD OF UPDATE
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME_BUF CORRECTIONDETAIL.CHANGEORGNAME_BUF%TYPE := :NEW.CHANGEORGNAME_BUF;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  AccRef_Caption$ NUMBER(10);
  vOperationTypeS$ NUMBER(10);
  vOperationTypeD$ NUMBER(10);
  vOperationType$ NUMBER(10);
  AccRef$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_CORRECTIONDETAIL_BU)
-- Version 7.01.00.2
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS$, vOperationTypeD$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType$ := vOperationTypeS$;
          
    ELSE 
      vOperationType$ := vOperationTypeD$;
    END IF;
    new$OperationType := vOperationType$;
      
  END IF;
  /*         ,        */
  if (
  ((not new$changeacc is null) and (new$changeacc <> '')) 
  and 
  ((:old.changeacc <> new$changeacc) or (:old.changeacc is null))
  and 
  ((new$changeacc_ref = :old.changeacc_ref) or (new$changeacc_ref is null))
  )
  THEN
    BEGIN
      SELECT cor_c.OriginalAcceptorAcc_Ref
      INTO AccRef_Caption$     FROM correctioncaption cor_c
      LEFT JOIN CorrectionDetail cor_d ON ((cor_c.Id = cor_d.RecordIndex) AND (cor_d.ProgIndex = 316))
      WHERE cor_d.id = :old.id
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (NOT AccRef_Caption$ IS NULL) THEN
      new$changeacc_ref := AccRef_Caption$;
          
    ELSE
      BEGIN
        SELECT dfat.id
        INTO AccRef$       FROM dfAccountsBuhTable dfat
        LEFT JOIN Org_Accounts oa ON (dfat.id =  oa.id)
        WHERE (oa.acc = new$changeacc) AND (dfat.iscommon = 1) AND (dfat.isforbudget = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (NOT AccRef$ IS NULL) THEN
        new$changeacc_ref := AccRef$;
          
      END IF;  
    END IF;
  END IF;
  /*     \*/
  IF ((new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType IS NULL)) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  ON (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (tr_correctiondetail_bu_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$buhoperationcls <> :old.buhoperationcls) and (new$progindex = 316)) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_CORRECTIONDETAIL_BU_120)
-- Create 13.08.2007
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
      else
        if (new$ClsType is null)
          then new$ClsType := 0; /*  -  */
        end if;
    end if;
  end if;
        
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
  
  IF ( (new$ClsType = 1) AND (
       (new$KVSR <> 0) OR (new$KFSR <> 0) OR
       (new$KCSR <> 0) OR (new$KVR <> 0) OR
       (new$KESR <> 0) OR (new$KD <> 0)
     ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
  
  IF ((new$ClsType = 2) AND (
      (new$KVSR <> 0) OR (new$KFSR <> 0) OR
      (new$KCSR <> 0) OR (new$KVR <> 0) OR
      (new$KESR <> 0) OR
      (new$IFS <> 0)
    ))     
  THEN /*   */
    Raiseexception('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_CORRECTIONDETAIL_BU_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise )) and 
    (new$BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
        
    /*    ,   */
    if (((new$BudgetPromise is not null) and (:old.BudgetPromise is null)) or 
    (new$BudgetPromise <> :old.BudgetPromise)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
          
    END IF;
        
    /*    ,     */
    if ((new$BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      new$Promise := null;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_CORRECTIONDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null and (
    (:old.Promise is null or :old.Promise <> new$Promise) or
    (:old.ExecDoc is null or new$ExecDoc is null or :old.ExecDoc <> new$ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$ExecDoc is null or :old.ExecDoc is null or new$ExecDoc <> :old.ExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_CORRECTIONDETAIL_BU_700)
-- Create 13.08.2007
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 else
   if ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
     new$RVersion:=:Old.RVersion;
   else
     new$RVersion:=:Old.RVersion+1;
   end if;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CORRECTIONDETAIL SET
    ID = new$ID,
    PARENTID = new$PARENTID,
    BUDGETREF = new$BUDGETREF,
    SUMMA = new$SUMMA,
    CLSTYPE = new$CLSTYPE,
    FACIALACC_CLS = new$FACIALACC_CLS,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    FACT = new$FACT,
    REGIONCLS = new$REGIONCLS,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    DOCTYPE = new$DOCTYPE,
    SUBKESR = new$SUBKESR,
    FUNDSSOURCE = new$FUNDSSOURCE,
    KD = new$KD,
    IFS = new$IFS,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CHANGEACC_REF = new$CHANGEACC_REF,
    CHANGEACC = new$CHANGEACC,
    CHANGEORGINN = new$CHANGEORGINN,
    CHANGEORGINN20 = new$CHANGEORGINN20,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    DOCUMENTPROGINDEX = new$DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX = new$DOCUMENTRECORDINDEX,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    RVERSION = new$RVERSION,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    NOTE = new$NOTE,
    ISCLSCHANGED = new$ISCLSCHANGED,
    PROMISE = new$PROMISE,
    BUDGETPROMISE = new$BUDGETPROMISE,
    EXECDOC = new$EXECDOC,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    TRANSFERTCLS = new$TRANSFERTCLS,
    ORIGINALCLSSUMMA = new$ORIGINALCLSSUMMA,
    NOTECLS = new$NOTECLS,
    OPERATIONTYPE = new$OPERATIONTYPE,
    REVERSEFLAG = new$REVERSEFLAG,
    EXECINNERNUMBER = new$EXECINNERNUMBER,
    CLSFIELFCHANGED = new$CLSFIELFCHANGED,
    FAORGTYPE = new$FAORGTYPE,
    SUBSIDYCLS = new$SUBSIDYCLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    NOTEQUALEX = new$NOTEQUALEX,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    INVESTOBJECT = new$INVESTOBJECT,
    CHANGEORGNAME_BUF = new$CHANGEORGNAME_BUF,
    CHANGEORGNAME = new$CHANGEORGNAME
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_CORRECTIONDETAIL_AU_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5504, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5504) and (RecordId=new$ID);
  end if;

END;
/
update CorrectionDetail
  set ChangeOrgName = ChangeOrgName_Buf
/
ALTER TABLE TB_CorrectionDetail DROP (ChangeOrgName_Buf)
/

CREATE OR REPLACE VIEW CorrectionDetail (
  ID,
  PARENTID,
  BUDGETREF,
  SUMMA,
  CLSTYPE,
  FACIALACC_CLS,
  KVSR,
  KFSR,
  KCSR,
  KVR,
  KESR,
  DIRECTIONCLS,
  MEANSTYPE,
  FACT,
  REGIONCLS,
  FINSOURCE,
  FINTYPE,
  DOCTYPE,
  SUBKESR,
  FUNDSSOURCE,
  KD,
  IFS,
  BUHOPERATIONCLS,
  CHANGEACC_REF,
  CHANGEACC,
  CHANGEORGINN,
  CHANGEORGINN20,
  PROGINDEX,
  RECORDINDEX,
  DOCUMENTPROGINDEX,
  DOCUMENTRECORDINDEX,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SENDERID,
  SENDERRECORDID,
  RVERSION,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  NOTE,
  ISCLSCHANGED,
  PROMISE,
  BUDGETPROMISE,
  EXECDOC,
  OKATO,
  ADDOKATO,
  TRANSFERTCLS,
  ORIGINALCLSSUMMA,
  NOTECLS,
  OPERATIONTYPE,
  REVERSEFLAG,
  EXECINNERNUMBER,
  CLSFIELFCHANGED,
  FAORGTYPE,
  SUBSIDYCLS,
  BUDALLOCATIONCLS,
  PAYPROMISECLS,
  NOTEQUALEX,
  OKTMO,
  UINCODE,
  INVESTOBJECT,
  CHANGEORGNAME)
AS
  SELECT
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME
  FROM TB_CorrectionDetail
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_ID
  INSTEAD OF DELETE
  ON CORRECTIONDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_CORRECTIONDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update CorrectionCaption set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_CORRECTIONDETAIL
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_CORRECTIONDETAIL_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate, ProgIndex, SUMMA) values(5504,:old.ID,SYSDATE,:old.ProgIndex, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_II
  INSTEAD OF INSERT
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  vOperationTypeS1$ NUMBER(10);
  vOperationTypeD1$ NUMBER(10);
  vOperationType1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_CORRECTIONDETAIL_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;  
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS1$, vOperationTypeD1$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType1$ := vOperationTypeS1$;
          
    ELSE 
      vOperationType1$ := vOperationTypeD1$;
    END IF;
    new$OperationType := vOperationType1$;
      
  END IF;
  BEGIN

    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN FacialAcc_Cls fac  ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_100 (tr_correctiondetail_bi_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$progindex = 316) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_CORRECTIONDETAIL_BI_120)
-- Create 13.08.2007
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
      else
        if (new$ClsType is null)
          then new$ClsType := 0; /*  -  */
        end if;
    end if;
  end if;
 
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
 
  IF ( (new$ClsType = 1) AND (
       (new$KVSR <> 0) OR (new$KFSR <> 0) OR
       (new$KCSR <> 0) OR (new$KVR <> 0) OR
       (new$KESR <> 0) OR (new$KD <> 0)
     ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
 
  IF ((new$ClsType = 2) AND (
      (new$KVSR <> 0) OR (new$KFSR <> 0) OR
      (new$KCSR <> 0) OR (new$KVR <> 0) OR
      (new$KESR <> 0) OR
      (new$IFS <> 0)
    ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_CORRECTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (new$Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null) and (new$BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
    /*    ,   ,   */
    if ((new$BudgetPromise is not null) and (new$Promise is null)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_CORRECTIONDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$ExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_CORRECTIONDETAIL_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update CorrectionCaption set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CORRECTIONDETAIL (
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME
  ) VALUES (
    new$ID,
    new$PARENTID,
    new$BUDGETREF,
    new$SUMMA,
    new$CLSTYPE,
    new$FACIALACC_CLS,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$DIRECTIONCLS,
    new$MEANSTYPE,
    new$FACT,
    new$REGIONCLS,
    new$FINSOURCE,
    new$FINTYPE,
    new$DOCTYPE,
    new$SUBKESR,
    new$FUNDSSOURCE,
    new$KD,
    new$IFS,
    new$BUHOPERATIONCLS,
    new$CHANGEACC_REF,
    new$CHANGEACC,
    new$CHANGEORGINN,
    new$CHANGEORGINN20,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$DOCUMENTPROGINDEX,
    new$DOCUMENTRECORDINDEX,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SENDERID,
    new$SENDERRECORDID,
    new$RVERSION,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$NOTE,
    new$ISCLSCHANGED,
    new$PROMISE,
    new$BUDGETPROMISE,
    new$EXECDOC,
    new$OKATO,
    new$ADDOKATO,
    new$TRANSFERTCLS,
    new$ORIGINALCLSSUMMA,
    new$NOTECLS,
    new$OPERATIONTYPE,
    new$REVERSEFLAG,
    new$EXECINNERNUMBER,
    new$CLSFIELFCHANGED,
    new$FAORGTYPE,
    new$SUBSIDYCLS,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$NOTEQUALEX,
    new$OKTMO,
    new$UINCODE,
    new$INVESTOBJECT,
    new$CHANGEORGNAME);

-- - - - - - - - - - - - -
-- AI_500 (TR_CORRECTIONDETAIL_AI_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

 delete from DelRecIndexes where (TableID =5504 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_IU
  INSTEAD OF UPDATE
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  AccRef_Caption$ NUMBER(10);
  vOperationTypeS$ NUMBER(10);
  vOperationTypeD$ NUMBER(10);
  vOperationType$ NUMBER(10);
  AccRef$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_CORRECTIONDETAIL_BU)
-- Version 7.01.00.2
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS$, vOperationTypeD$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType$ := vOperationTypeS$;
          
    ELSE 
      vOperationType$ := vOperationTypeD$;
    END IF;
    new$OperationType := vOperationType$;
      
  END IF;
  /*         ,        */
  if (
  ((not new$changeacc is null) and (new$changeacc <> '')) 
  and 
  ((:old.changeacc <> new$changeacc) or (:old.changeacc is null))
  and 
  ((new$changeacc_ref = :old.changeacc_ref) or (new$changeacc_ref is null))
  )
  THEN
    BEGIN
      SELECT cor_c.OriginalAcceptorAcc_Ref
      INTO AccRef_Caption$     FROM correctioncaption cor_c
      LEFT JOIN CorrectionDetail cor_d ON ((cor_c.Id = cor_d.RecordIndex) AND (cor_d.ProgIndex = 316))
      WHERE cor_d.id = :old.id
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (NOT AccRef_Caption$ IS NULL) THEN
      new$changeacc_ref := AccRef_Caption$;
          
    ELSE
      BEGIN
        SELECT dfat.id
        INTO AccRef$       FROM dfAccountsBuhTable dfat
        LEFT JOIN Org_Accounts oa ON (dfat.id =  oa.id)
        WHERE (oa.acc = new$changeacc) AND (dfat.iscommon = 1) AND (dfat.isforbudget = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (NOT AccRef$ IS NULL) THEN
        new$changeacc_ref := AccRef$;
          
      END IF;  
    END IF;
  END IF;
  /*     \*/
  IF ((new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType IS NULL)) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  ON (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (tr_correctiondetail_bu_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$buhoperationcls <> :old.buhoperationcls) and (new$progindex = 316)) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_CORRECTIONDETAIL_BU_120)
-- Create 13.08.2007
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
      else
        if (new$ClsType is null)
          then new$ClsType := 0; /*  -  */
        end if;
    end if;
  end if;
        
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
  
  IF ( (new$ClsType = 1) AND (
       (new$KVSR <> 0) OR (new$KFSR <> 0) OR
       (new$KCSR <> 0) OR (new$KVR <> 0) OR
       (new$KESR <> 0) OR (new$KD <> 0)
     ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  end if;
  
  IF ((new$ClsType = 2) AND (
      (new$KVSR <> 0) OR (new$KFSR <> 0) OR
      (new$KCSR <> 0) OR (new$KVR <> 0) OR
      (new$KESR <> 0) OR
      (new$IFS <> 0)
    ))     
  THEN /*   */
    Raiseexception('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_CORRECTIONDETAIL_BU_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise )) and 
    (new$BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
        
    /*    ,   */
    if (((new$BudgetPromise is not null) and (:old.BudgetPromise is null)) or 
    (new$BudgetPromise <> :old.BudgetPromise)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
          
    END IF;
        
    /*    ,     */
    if ((new$BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      new$Promise := null;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_CORRECTIONDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null and (
    (:old.Promise is null or :old.Promise <> new$Promise) or
    (:old.ExecDoc is null or new$ExecDoc is null or :old.ExecDoc <> new$ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$ExecDoc is null or :old.ExecDoc is null or new$ExecDoc <> :old.ExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_CORRECTIONDETAIL_BU_700)
-- Create 13.08.2007
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 else
   if ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
     new$RVersion:=:Old.RVersion;
   else
     new$RVersion:=:Old.RVersion+1;
   end if;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CORRECTIONDETAIL SET
    ID = new$ID,
    PARENTID = new$PARENTID,
    BUDGETREF = new$BUDGETREF,
    SUMMA = new$SUMMA,
    CLSTYPE = new$CLSTYPE,
    FACIALACC_CLS = new$FACIALACC_CLS,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    FACT = new$FACT,
    REGIONCLS = new$REGIONCLS,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    DOCTYPE = new$DOCTYPE,
    SUBKESR = new$SUBKESR,
    FUNDSSOURCE = new$FUNDSSOURCE,
    KD = new$KD,
    IFS = new$IFS,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CHANGEACC_REF = new$CHANGEACC_REF,
    CHANGEACC = new$CHANGEACC,
    CHANGEORGINN = new$CHANGEORGINN,
    CHANGEORGINN20 = new$CHANGEORGINN20,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    DOCUMENTPROGINDEX = new$DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX = new$DOCUMENTRECORDINDEX,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    RVERSION = new$RVERSION,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    NOTE = new$NOTE,
    ISCLSCHANGED = new$ISCLSCHANGED,
    PROMISE = new$PROMISE,
    BUDGETPROMISE = new$BUDGETPROMISE,
    EXECDOC = new$EXECDOC,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    TRANSFERTCLS = new$TRANSFERTCLS,
    ORIGINALCLSSUMMA = new$ORIGINALCLSSUMMA,
    NOTECLS = new$NOTECLS,
    OPERATIONTYPE = new$OPERATIONTYPE,
    REVERSEFLAG = new$REVERSEFLAG,
    EXECINNERNUMBER = new$EXECINNERNUMBER,
    CLSFIELFCHANGED = new$CLSFIELFCHANGED,
    FAORGTYPE = new$FAORGTYPE,
    SUBSIDYCLS = new$SUBSIDYCLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    NOTEQUALEX = new$NOTEQUALEX,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    INVESTOBJECT = new$INVESTOBJECT,
    CHANGEORGNAME = new$CHANGEORGNAME
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_CORRECTIONDETAIL_AU_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5504, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5504) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_WriteExecutionDetail_Note.sql
-- #########################################################
-- #########################################################

/*      WritExecutionDetail */
ALTER TABLE WritExecutionDetail ADD (
  Note VARCHAR2(1024)
)
/
commit work 
/


-- #########################################################
-- #########################################################
-- Add_DayKind_to_UnlockDates_ora.sql
-- #########################################################
-- #########################################################


/*   UnlokDates   ,   */

/* <TRANS_COMMAND>
ALTER TABLE UnlockDates ADD (DayKind NUMBER)
/
*/
-- <TRANS_IGNORE>
DECLARE
  v_exists INTEGER;
BEGIN
  SELECT COUNT(*)
  INTO v_exists
  FROM USER_TAB_COLUMNS
  WHERE TABLE_NAME = 'TB_UNLOCKDATES'
  AND COLUMN_NAME = 'DAYKIND';
  IF (v_exists = 0) THEN
    EXECUTE IMMEDIATE 'ALTER TABLE TB_UNLOCKDATES ADD (
      DAYKIND NUMBER(10, 0))';
  END IF;
END;
/

COMMIT WORK
/

CREATE OR REPLACE VIEW UNLOCKDATES(
  ID, 
  BUDGETREF, 
  UNLOCKDATE, 
  UNLOCK, 
  NOTE, 
  JNUMBER, 
  CREATEDATE, 
  CREATERUSER, 
  UPDATEDATE, 
  UPDATERUSER, 
  RVERSION, 
  JOURNALFLAG, 
  DOCSTATEREF, 
  CRYPTOSTATUS,
  DAYKIND)
AS
SELECT
    ID,
    BUDGETREF,
    UNLOCKDATE,
    UNLOCK,
    NOTE,
    JNUMBER,
    CREATEDATE,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER,
    RVERSION,
    JOURNALFLAG,
    DOCSTATEREF,
    CRYPTOSTATUS,
    DAYKIND
  FROM TB_unlockdates
/

CREATE OR REPLACE TRIGGER TR_UNLOCKDATES_II
  INSTEAD OF INSERT
  ON UNLOCKDATES
DECLARE
  new$ID UNLOCKDATES.ID%TYPE := :NEW.ID;
  new$BUDGETREF UNLOCKDATES.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$UNLOCKDATE UNLOCKDATES.UNLOCKDATE%TYPE := :NEW.UNLOCKDATE;
  new$UNLOCK UNLOCKDATES.UNLOCK%TYPE := :NEW.UNLOCK;
  new$NOTE UNLOCKDATES.NOTE%TYPE := :NEW.NOTE;
  new$JNUMBER UNLOCKDATES.JNUMBER%TYPE := :NEW.JNUMBER;
  new$CREATEDATE UNLOCKDATES.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER UNLOCKDATES.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE UNLOCKDATES.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER UNLOCKDATES.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$RVERSION UNLOCKDATES.RVERSION%TYPE := :NEW.RVERSION;
  new$JOURNALFLAG UNLOCKDATES.JOURNALFLAG%TYPE := :NEW.JOURNALFLAG;
  new$DOCSTATEREF UNLOCKDATES.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS UNLOCKDATES.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$DAYKIND UNLOCKDATES.DAYKIND%TYPE := :NEW.DAYKIND;
--
  cnt$ Number(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_UNLOCKDATES_BI)
-- Create 17.06.2008
-- - - - - - - - - - - - -

  if (new$ID is null) then
    select G_SHARED.NEXTVAL into new$ID from DUAL;
  end if;
  if (new$JournalFlag is null) then new$JournalFlag := 0; end if;
  if (new$jnumber is null) then new$jnumber := 0; end if;
  if (new$BUDGETREF is null) then new$budgetref := 0; end if;
  if (new$DAYKIND is null) then new$DAYKIND := 0; end if;

-- - - - - - - - - - - - -
-- BI_100 (TR_UNLOCKDATES_BI_100)
-- Create 18.06.2008
-- - - - - - - - - - - - -

  IF (New$JournalFlag = 0) then
    cnt$ := 0;
    Select
      Count(ID)
    into
      cnt$
    from
      UnLockDates
    where
      (UnLockDate = new$UnLockDate) and (BudgetRef = new$BudgetRef) 
      and (JournalFlag = 0) and (DayKind = new$DayKind) and (ROWNUM = 1);
    If (cnt$ > 0) then RaiseException('EX_UNLOCKDATES_DATE'); end if;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_UNLOCKDATES_BI_500)
-- Create 17.06.2008
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_UNLOCKDATES (
    ID,
    BUDGETREF,
    UNLOCKDATE,
    UNLOCK,
    NOTE,
    JNUMBER,
    CREATEDATE,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER,
    RVERSION,
    JOURNALFLAG,
    DOCSTATEREF,
    CRYPTOSTATUS,
    DAYKIND
  ) VALUES (
    new$ID,
    new$BUDGETREF,
    new$UNLOCKDATE,
    new$UNLOCK,
    new$NOTE,
    new$JNUMBER,
    new$CREATEDATE,
    new$CREATERUSER,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$RVERSION,
    new$JOURNALFLAG,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$DAYKIND);

END;
/

CREATE OR REPLACE TRIGGER TR_UNLOCKDATES_IU
  INSTEAD OF UPDATE
  ON UNLOCKDATES
DECLARE
  new$ID UNLOCKDATES.ID%TYPE := :NEW.ID;
  new$BUDGETREF UNLOCKDATES.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$UNLOCKDATE UNLOCKDATES.UNLOCKDATE%TYPE := :NEW.UNLOCKDATE;
  new$UNLOCK UNLOCKDATES.UNLOCK%TYPE := :NEW.UNLOCK;
  new$NOTE UNLOCKDATES.NOTE%TYPE := :NEW.NOTE;
  new$JNUMBER UNLOCKDATES.JNUMBER%TYPE := :NEW.JNUMBER;
  new$CREATEDATE UNLOCKDATES.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER UNLOCKDATES.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE UNLOCKDATES.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER UNLOCKDATES.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$RVERSION UNLOCKDATES.RVERSION%TYPE := :NEW.RVERSION;
  new$JOURNALFLAG UNLOCKDATES.JOURNALFLAG%TYPE := :NEW.JOURNALFLAG;
  new$DOCSTATEREF UNLOCKDATES.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS UNLOCKDATES.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$DAYKIND UNLOCKDATES.DAYKIND%TYPE := :NEW.DAYKIND;
--
  MAXNUMBER$ Number(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_UNLOCKDATES_BU)
-- Create 17.06.2008
-- - - - - - - - - - - - -

  IF (new$JournalFlag IS NULL) THEN new$JournalFlag := 0; END IF;
  IF (new$JNUMBER IS NULL) THEN new$JNUMBER := 0; END IF;
  IF (new$BUDGETREF IS NULL) THEN new$budgetref := 0; END IF;
  IF (new$DAYKIND IS NULL) THEN new$DAYKIND := 0; END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_UNLOCKDATES_BU_100)
-- Create 17.06.2008
-- - - - - - - - - - - - -

-- Comment      


  if ((new$BUDGETREF <> :OLD.BUDGETREF) OR (new$UNLOCK <> :OLD.UNLOCK)) then
    SELECT MAX(UD.JNUMBER)
    INTO MAXNUMBER$
    FROM UNLOCKDATES UD
    WHERE (UD.UNLOCKDATE = :OLD.UNLOCKDATE) AND (UD.JournalFlag = 1);
    if (maxnumber$ is null) then
      MaxNumber$ := 0;
    else
      MAXNUMBER$ := MAXNUMBER$ + 1;
    end if;
    INSERT INTO UNLOCKDATES
      (BUDGETREF,UNLOCKDATE,UNLOCK,NOTE,JournalFlag,JNUMBER,CREATEDATE,CREATERUSER,
      UPDATEDATE,UPDATERUSER,DAYKIND)
    VALUES
      (:OLD.BUDGETREF,:OLD.UNLOCKDATE,:OLD.UNLOCK,:OLD.NOTE,1,MAXNUMBER$,new$CREATEDATE,
      new$CREATERUSER,:OLD.UPDATEDATE,:OLD.UPDATERUSER,:OLD.DAYKIND);
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_UNCLOCKDATES_BU_200)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$DocStateRef <> :old.DocStateRef) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_UNLOCKDATES_BU_700)
-- Create 18.06.2008
-- - - - - - - - - - - - -

 If (New$JournalFlag = 0) then
   if (New$RVersion is null) then
     New$RVersion := 1;
   else
     if ((New$RVersion = -1) and (:Old.RVersion <> -1)) then
       New$RVersion := :Old.RVersion;
     else
       New$RVersion := :Old.RVersion+1;
     end if;
   end if;
 end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_UNLOCKDATES SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    UNLOCKDATE = new$UNLOCKDATE,
    UNLOCK = new$UNLOCK,
    NOTE = new$NOTE,
    JNUMBER = new$JNUMBER,
    CREATEDATE = new$CREATEDATE,
    CREATERUSER = new$CREATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    RVERSION = new$RVERSION,
    JOURNALFLAG = new$JOURNALFLAG,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    DAYKIND = new$DAYKIND
  WHERE     ID = :old.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

END;
/

COMMIT WORK
/

update UNLOCKDATES set
  DayKind = 0
where
  DayKind is null
/

COMMIT WORK
/



-- #########################################################
-- #########################################################
-- alter_TR_FacialFinDetail_110.sql
-- #########################################################
-- #########################################################

/*   tr_FacialFinDetail_bi_110, tr_FacialFinDetail_bu_110.
    ProgIndex=76    SourceSubsidyCls, SourceTransfertCLS, SourceBudAllocationCls, SourcePayPromiseCls */
-- ALTER TRIGGER tr_FacialFinDetail_bi_110
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CapBuhOperationCLS$ NUMBER(10);
  CapClsType$ NUMBER(10);
  CapAcceptDate$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  PromiseAcceptDate$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Last update 12.01.2009
-- - - - - - - - - - - - -

 /*  ,    */
   BEGIN

     select
       ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate,
       ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
     into new$BudgetRef, CapBuhOperationCls$, CapClsType$, CapAcceptDate$,
       new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause
     from
       FacialFinCaption ffc
     where
       ffc.id = new$RecordIndex;
     
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       new$BudgetRef := NULL;
       CapBuhOperationCls$ := NULL;
       CapClsType$ := NULL;
       CapAcceptDate$ := NULL;
   END;

   /*      */
   if (new$BuhOperationCls is null) then new$BuhOperationCls := CapBuhOperationCls$; end if;

   /*      */
   if (new$ClsType is null) then new$ClsType := CapClsType$; end if;

   if (new$DestClsType is null) then new$DestClsType := new$ClsType; end if;
   
   /*      */
   if (new$AcceptDate is null) then new$AcceptDate := CapAcceptDate$; end if;

   /*      */
   if ((new$SourceFacialAcc_CLS is null) or (new$DestFacialAcc_CLS is null)) then
     BEGIN
       select SourceFacialAcc_CLS, DestFacialAcc_CLS
         into SourceFacialAcc_CLS$, DestFacialAcc_CLS$
       from FacialFinCaption
       where new$RecordIndex = id;
     EXCEPTION
       WHEN NO_DATA_FOUND THEN
         SourceFacialAcc_CLS$ := NULL;
         DestFacialAcc_CLS$ := NULL;
     END;

     if (new$SourceFacialAcc_CLS is null) then new$SourceFacialAcc_CLS := SourceFacialAcc_CLS$; end if;
     if (new$DestFacialAcc_CLS is null) then new$DestFacialAcc_CLS := DestFacialAcc_CLS$; end if;
   end if;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype1$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype1$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype1$  ;
     
  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN 
    IF (i_fintype1$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype1$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype1$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND(new$DestPromise IS NOT NULL)AND
        (new$SourcePromise=new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Create 28.04.2005
-- Last update 15.12.2008
-- - - - - - - - - - - - -

    /*  60 :  '   .'; source
        61 :  '      '; dest
        62 :  '   ';dest
        63 :  '    '; source
        64 :  '   '; source
        65 :  ' , ';dest
        66 :  '  ,  - '; source dest
        67 :  '   ';source
        68 :  '  \ ';dest
        69 :  '   \ '; dest
        70 :  '  \ ';source
        71 :  '   \ '; dest */

  /*ClsType*/
  if ((New$ClsType is NULL) and 
        ( 
          ((New$SourceIFS <> 0) and (New$ProgIndex in (63,64,66,67,68,70))) or
          (New$ProgIndex = 60)
        )) then
    New$ClsType := 1; /*       ClsType */
  elsif ((New$ClsType is NULL) and (New$SourceKD <> 0) and
        (New$ProgIndex in (63,64,66,67,68,70))) then
    New$ClsType := 2; /*        ClsType */
  elsif (new$ClsType is null) then
    new$ClsType := 0; /*  -  */
  end if;  

  IF ((new$ClsType = 0) AND 
      (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
      (new$ProgIndex in (63,64,66,67,68,70)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;
  IF ((new$ClsType = 1) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;
  IF ((new$ClsType = 2) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  /*DestClsType*/
  if ((new$DestClsType is NULL) and
        ( 
          ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
        )) then
    new$DestClsType := 1; /*       ClsType */
  elsif ((new$DestClsType is NULL) and
          ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
        ) then
    new$DestClsType := 2; /*        ClsType */
  elsif (new$DestClsType is null) then
    new$DestClsType := 0; /*  -  */
  end if;      

  IF ((new$DestClsType = 0) AND
      (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
      (new$ProgIndex in (61,62,65,69,71)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;
  IF ((new$DestClsType = 1) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 2) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode1$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;    
    END IF;
  END IF;
  if (PromiseMode1$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .    */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* source    ,   ,   */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /* dest */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER tr_FacialFinDetail_bu_110
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype1$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype1$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype1$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype1$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype1$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype1$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Create 28.04.2005
-- Last update 12.01.2009
-- - - - - - - - - - - - -

    /*  60 :  '   .'; source
        61 :  '      '; dest
        62 :  '   ';dest
        63 :  '    '; source
        64 :  '   '; source
        65 :  ' , ';dest
        66 :  '  ,  - '; source dest
        67 :  '   ';source
        68 :  '  \ ';dest
        69 :  '   \ '; dest
        70 :  '  \ ';source
        71 :  '   \ '; dest */

  /*ClsType*/
  if ((new$ClsType is NULL) and 
        ( 
          ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
          (new$ProgIndex = 60)
        )) then
    new$ClsType := 1; /*       ClsType */
  elsif ((new$ClsType is NULL) and (new$SourceKD <> 0) and
        (new$ProgIndex in (63,64,66,67,68,70))) then
    new$ClsType := 2; /*        ClsType */
  elsif (new$ClsType is null) then
    new$ClsType := 0; /*  -  */
  end if;  

  IF ((new$ClsType = 0) AND 
      (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
      (new$ProgIndex in (63,64,66,67,68,70)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 1) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$ClsType = 2) AND (
    (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
    (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
    (new$SourceKESR <> 0) OR
    ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  /*DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  end if;  

  IF ((new$DestClsType = 0) AND
      (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
      (new$ProgIndex in (61,62,65,69,71)))
     ) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 1) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;  

  IF ((new$DestClsType = 2) AND (
    (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
    (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
    (new$DestKESR <> 0) or
    ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    )) THEN /*   */
    RaiseEXCEPTION('EX_WRONGBUDCLS');
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- create_statehis_index.sql
-- #########################################################
-- #########################################################

/*  StateJumpHistory(CreateDate)        */
CREATE INDEX idx_StateJumpHis_CreateDate ON StateJumpHistory(CreateDate)
/
commit work
/


-- #########################################################
-- #########################################################
-- alter_budgetdata_add_kvrcorr.sql
-- #########################################################
-- #########################################################

/*    BudgetData  KvrCorr */
ALTER TABLE BudgetData ADD (
  KvrCorr NUMBER(10),
    CHECK((KvrCorr<=2147483647)AND(KvrCorr>-2147483648))
)
/
ALTER TABLE BUDGETDATA ADD (
  CONSTRAINT FK_BUDGETDATA_KVRCORR FOREIGN KEY (KVRCORR) REFERENCES KVR (ID)
)
/
CREATE INDEX FK_BUDGETDATA_KVRCORR ON BUDGETDATA(KVRCORR)
/
commit work 
/
-- ALTER TRIGGER tr_budgetdata_bi
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BI
  BEFORE INSERT
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  OrgRefByAcc$ NUMBER(10);
  CapClsType$ NUMBER(10);
  AutoKesrCorr$ NUMBER(10);
  doubleUse$ NUMBER(10);
  BALBOFlag$ NUMBER(10);
  AllowDivideBA$ NUMBER(10);
  StimateKind$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDGETDATA_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  IF (:new.id IS NULL) THEN 
    select g_shared.nextval into :new.id from dual;
  END IF;
  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KESRCorr IS NULL) THEN 
    :new.KESRCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN 
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .      */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  BEGIN

    /*  .   */
    SELECT bn.BudgetRef      INTO :new.BudgetRef FROM BudNotify bn
    WHERE bn.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind$);
    IF ((StimateKind$  = 0) OR (StimateKind$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;/* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
      SELECT Organizations FROM REGIONCLS
        WHERE NEW.REGIONCLS = ID
      INTO NEW.TransfertOrg_Ref;
  */
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_BudgetData_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.SenderID is null) then
    :new.SenderIDKey := -1;
        
  else
    :new.SenderIDKey := :new.SenderID;
  END IF;
      
  if (:new.SenderRecordID is null) then
    :new.SenderRecordIDKey := :new.ID;
        
  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_BUDGETDATA_BI_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.KESR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_BUDGETDATA_BI_200)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-   */
  if (:new.ProgIndex in (32, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             ():
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0    .*/
    GetIntConst(32, 25,AutoKesrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKesrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKesrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKesrCorr$  = 2)) then  /* ()*/
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else 
        :new.KesrCorr := :new.Kesr; /*         */
      END IF;  
    END IF;
  else
    /*       215-, 264-, 265-, 267-, 271-   */
    if (:new.ProgIndex in (215, 264, 265, 267, 271)) then
      /*     (215   ())
             ():
           =0     ,
           =1  .  2   .
                 */
      GetIntConst(32, 26,AutoKesrCorr$);
      if (((AutoKesrCorr$  = 0)and(:new.ProgIndex=215))or(:new.ProgIndex<>215)) then
        BEGIN
          select
          ifs.KESR
          into
          :new.KesrCorr       from
          InnerFinSource ifs
          where
          ifs.id = :new.ifs
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;  
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDGETDATA_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

  Update BudNotify set
  DocChangeDate = :new.UpdateDate,
  RVersion = -1
  where id = :new.recordindex;

END;
/
-- ALTER TRIGGER tr_budgetdata_bu
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  OrgRefByAcc$ NUMBER(10);
  CapClsType$ NUMBER(10);
  AutoKesrCorr$ NUMBER(10);
  doubleUse$ NUMBER(10);
  BALBOFlag$ NUMBER(10);
  AllowDivideBA$ NUMBER(10);
  StimateKind$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KesrCorr IS NULL) THEN 
    :new.KesrCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN  
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .        */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  /*     */
  IF (:new.BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind$);
    IF ((StimateKind$  = 0) OR (StimateKind$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;/* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
       SELECT Organizations FROM REGIONCLS
         WHERE NEW.REGIONCLS = ID
       INTO NEW.TransfertOrg_Ref;
  */
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.KESR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-   */
  if (:new.ProgIndex in (32, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             ():
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0    .*/
    GetIntConst(32, 25,AutoKesrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKesrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKesrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKesrCorr$  = 2)) then  /* ()*/
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else 
        :new.KesrCorr := :new.Kesr; /*         */
      END IF;  
    END IF;
  else
    /*       215-, 264-, 265-, 267-, 271-   */
    if (:new.ProgIndex in (215, 264, 265, 267, 271)) then
      /*     (215   ())
             ():
           =0     ,
           =1  .  2   .
                 */
      GetIntConst(32, 26,AutoKesrCorr$);
      if (((AutoKesrCorr$  = 0)and(:new.ProgIndex=215))or(:new.ProgIndex<>215)) then
        BEGIN
          select
          ifs.KESR
          into
          :new.KesrCorr       from
          InnerFinSource ifs
          where
          ifs.id = :new.ifs
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;  
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (:NEW.RVersion IS NULL) THEN
     :NEW.RVersion := 1;
  ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
     :NEW.RVersion := :OLD.RVersion;
  ELSE
     :NEW.RVersion := :OLD.RVersion + 1;
  END IF;

END;
/
-- ALTER TRIGGER tr_budgetdata_bi_200
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BI
  BEFORE INSERT
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  OrgRefByAcc$ NUMBER(10);
  CapClsType$ NUMBER(10);
  doubleUse$ NUMBER(10);
  BALBOFlag$ NUMBER(10);
  AllowDivideBA$ NUMBER(10);
  StimateKind$ NUMBER(10);
  AutoKvrCorr$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDGETDATA_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  IF (:new.id IS NULL) THEN 
    select g_shared.nextval into :new.id from dual;
  END IF;
  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KESRCorr IS NULL) THEN 
    :new.KESRCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN 
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .      */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  BEGIN

    /*  .   */
    SELECT bn.BudgetRef      INTO :new.BudgetRef FROM BudNotify bn
    WHERE bn.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind$);
    IF ((StimateKind$  = 0) OR (StimateKind$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;/* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
      SELECT Organizations FROM REGIONCLS
        WHERE NEW.REGIONCLS = ID
      INTO NEW.TransfertOrg_Ref;
  */
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_BudgetData_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.SenderID is null) then
    :new.SenderIDKey := -1;
        
  else
    :new.SenderIDKey := :new.SenderID;
  END IF;
      
  if (:new.SenderRecordID is null) then
    :new.SenderRecordIDKey := :new.ID;
        
  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_BUDGETDATA_BI_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.KESR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_BUDGETDATA_BI_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else 
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDGETDATA_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

  Update BudNotify set
  DocChangeDate = :new.UpdateDate,
  RVersion = -1
  where id = :new.recordindex;

END;
/
-- ALTER TRIGGER tr_budgetdata_bu_200
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  OrgRefByAcc$ NUMBER(10);
  CapClsType$ NUMBER(10);
  doubleUse$ NUMBER(10);
  BALBOFlag$ NUMBER(10);
  AllowDivideBA$ NUMBER(10);
  StimateKind$ NUMBER(10);
  AutoKvrCorr$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KesrCorr IS NULL) THEN 
    :new.KesrCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN  
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .        */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  /*     */
  IF (:new.BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind$);
    IF ((StimateKind$  = 0) OR (StimateKind$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;/* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
       SELECT Organizations FROM REGIONCLS
         WHERE NEW.REGIONCLS = ID
       INTO NEW.TransfertOrg_Ref;
  */
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.KESR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (:NEW.RVersion IS NULL) THEN
     :NEW.RVersion := 1;
  ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
     :NEW.RVersion := :OLD.RVersion;
  ELSE
     :NEW.RVersion := :OLD.RVersion + 1;
  END IF;

END;
/
commit work 
/
ALTER TRIGGER TR_BUDGETDATA_BU_500 DISABLE
/
/*  ,       */
update BudgetData set
  ID = ID
/
commit work 
/
ALTER TRIGGER TR_BUDGETDATA_BU_500 ENABLE
/
commit work 
/
ALTER TABLE BudgetData MODIFY(KvrCorr NOT NULL)
/

-- #########################################################
-- #########################################################
-- Alter_TenderCaption_Add_PurchaseCode.sql
-- #########################################################
-- #########################################################

/*    TenderCaption  PurchaseCode -    (36 ) */
ALTER TABLE TB_TenderCaption ADD (
  PurchaseCode VARCHAR2(50)/*    (36 )*/
)
/

CREATE OR REPLACE VIEW TenderCaption (
  ID,
  BUDGETREF,
  FACIALACCCLS,
  MULTIPURPOSE,
  DOCUMENTDATE,
  ACCEPTDATE,
  PERIOD,
  ACCEPTSUMMA,
  SALETYPE,
  REJECTCLS,
  REJECTCAUSE,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCSTATEREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  LASTADJUSTMENT,
  LASTACCEPTED,
  ADJUSTMENTREF,
  ACCEPTED,
  EXPORTDATE,
  YEARACCEPTSUMMA,
  TENDEROPTION,
  TENDERTARGET,
  RVERSION,
  ALLOWANCE,
  REFINEMENTCAUSE,
  PREFERENCE,
  PREFERENCESIZE,
  SECURITY,
  UNKNOWNAMOUNT,
  PERIODYEAR,
  SUPPORTUNDERTAKER,
  AYEAR,
  REWORKCAUSE,
  NOTE,
  REALID,
  INNERNUMBER,
  ADJUSTMENTNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  PROTOCOLREASON,
  PROGINDEX,
  DOCNUMBER,
  SECURITYTSIZE,
  SECURITYASIZE,
  AVANSSIZE,
  PREFERENCECRIPPLE,
  PREFERENCERUSPRODUCT,
  PREFERENCEPRISON,
  PURCHASESOCIALNKO,
  AGREEMENTEXECUTIONDATE,
  PURCHASECODE)
AS
  SELECT
    ID,
    BUDGETREF,
    FACIALACCCLS,
    MULTIPURPOSE,
    DOCUMENTDATE,
    ACCEPTDATE,
    PERIOD,
    ACCEPTSUMMA,
    SALETYPE,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    LASTADJUSTMENT,
    LASTACCEPTED,
    ADJUSTMENTREF,
    ACCEPTED,
    EXPORTDATE,
    YEARACCEPTSUMMA,
    TENDEROPTION,
    TENDERTARGET,
    RVERSION,
    ALLOWANCE,
    REFINEMENTCAUSE,
    PREFERENCE,
    PREFERENCESIZE,
    SECURITY,
    UNKNOWNAMOUNT,
    PERIODYEAR,
    SUPPORTUNDERTAKER,
    AYEAR,
    REWORKCAUSE,
    NOTE,
    REALID,
    INNERNUMBER,
    ADJUSTMENTNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    PROTOCOLREASON,
    PROGINDEX,
    DOCNUMBER,
    SECURITYTSIZE,
    SECURITYASIZE,
    AVANSSIZE,
    PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT,
    PREFERENCEPRISON,
    PURCHASESOCIALNKO,
    AGREEMENTEXECUTIONDATE,
    PURCHASECODE
  FROM TB_TenderCaption
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_ID
  INSTEAD OF DELETE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  cnt$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_TENDERCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   5.1 */
  select count(ID) into cnt$ from TenderCaption where (AdjustmentRef = :old.ID) ;
  /*    ,    */
  if (cnt$ = 0) then
    delete from TenderSupDocument where (RecordIndex = :old.ID);
    delete from TenderYardsticks where (RecordIndex = :old.ID);
    delete from TenderSourceOrg where (RecordIndex = :old.ID);
    delete from TenderContacts where (RecordIndex = :old.ID);
    delete from TenderSupplements where (RecordIndex = :old.ID);        
    delete from TenderProduct where (RecordIndex = :old.ID);
    delete from TenderLot where (RecordIndex = :old.ID);
        
  else
    RaiseException('EX_Ten_CantDelAdjustmented');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_TENDERCAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_0 (TR_TenderCaption_AD)
-- Last update 06.08.2010
-- - - - - - - - - - - - -

  delete from TENDERPRODUCT where (RecordIndex = :old.ID);
  delete from TenderSourceOrg where (RecordIndex = :old.ID);

-- - - - - - - - - - - - -
-- AD_10 (TR_TENDERCAPTION_AD_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*   LastAdjustment     */
  if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
    update TenderCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_TENDERCAPTION_AD_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*         */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_TENDERCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, ProgIndex) values (139, :old.ID, SYSDATE, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_II
  INSTEAD OF INSERT
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  CurVal$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TENDERCAPTION_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FacialAccCls is null) then 
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then 
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then 
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then 
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then 
    new$Allowance := 0;
  END IF;
      
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef       into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAccCls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    GetIntConst(-1,3,new$BudgetRef);
  END IF;
      
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$SaleType is null) then 
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then 
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then 
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then 
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then 
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then 
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then 
    new$SupportUndertaker := 0;
  END IF;
  if (new$PurchaseSocialNKO is null) then 
    new$PurchaseSocialNKO := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_TENDERCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_TENDERCAPTION_BI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
      
  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_Ten_InnerNumsIsNull');
  END IF;
      
  /*    */  
  select max(AdjustmentNumber)
  into Tmp$         from TenderCaption 
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/   
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp$ + 1;    
  END IF;
      
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
      
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then 
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
          
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID) 
    into Tmp$, AdjID$             from TenderCaption 
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */    
    if (Tmp$ <> 1) then 
      RaiseException('EX_Ten_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID) 
    into Tmp$             from TenderCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then 
      RaiseException('EX_Ten_AdjustDuplicate');
    END IF;
    /* ,    ,    */        
    new$AdjustmentRef := AdjID$;
        
  else /*     */
    /*       (    )*/        
    new$AdjustmentRef := null;
        
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_TENDERCAPTION_BI_40)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$senderId is null) then 
    new$senderIdKey := -1;
      
  else 
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
      
  else 
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_50 (TR_TENDERCAPTION_BI_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TENDERCAPTION_BI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (tendercaption_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then 
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TENDERCAPTION (
    ID,
    BUDGETREF,
    FACIALACCCLS,
    MULTIPURPOSE,
    DOCUMENTDATE,
    ACCEPTDATE,
    PERIOD,
    ACCEPTSUMMA,
    SALETYPE,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    LASTADJUSTMENT,
    LASTACCEPTED,
    ADJUSTMENTREF,
    ACCEPTED,
    EXPORTDATE,
    YEARACCEPTSUMMA,
    TENDEROPTION,
    TENDERTARGET,
    RVERSION,
    ALLOWANCE,
    REFINEMENTCAUSE,
    PREFERENCE,
    PREFERENCESIZE,
    SECURITY,
    UNKNOWNAMOUNT,
    PERIODYEAR,
    SUPPORTUNDERTAKER,
    AYEAR,
    REWORKCAUSE,
    NOTE,
    REALID,
    INNERNUMBER,
    ADJUSTMENTNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    PROTOCOLREASON,
    PROGINDEX,
    DOCNUMBER,
    SECURITYTSIZE,
    SECURITYASIZE,
    AVANSSIZE,
    PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT,
    PREFERENCEPRISON,
    PURCHASESOCIALNKO,
    AGREEMENTEXECUTIONDATE,
    PURCHASECODE
  ) VALUES (
    new$ID,
    new$BUDGETREF,
    new$FACIALACCCLS,
    new$MULTIPURPOSE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$PERIOD,
    new$ACCEPTSUMMA,
    new$SALETYPE,
    new$REJECTCLS,
    new$REJECTCAUSE,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCSTATEREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$ADJUSTMENTREF,
    new$ACCEPTED,
    new$EXPORTDATE,
    new$YEARACCEPTSUMMA,
    new$TENDEROPTION,
    new$TENDERTARGET,
    new$RVERSION,
    new$ALLOWANCE,
    new$REFINEMENTCAUSE,
    new$PREFERENCE,
    new$PREFERENCESIZE,
    new$SECURITY,
    new$UNKNOWNAMOUNT,
    new$PERIODYEAR,
    new$SUPPORTUNDERTAKER,
    new$AYEAR,
    new$REWORKCAUSE,
    new$NOTE,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$PROTOCOLREASON,
    new$PROGINDEX,
    new$DOCNUMBER,
    new$SECURITYTSIZE,
    new$SECURITYASIZE,
    new$AVANSSIZE,
    new$PREFERENCECRIPPLE,
    new$PREFERENCERUSPRODUCT,
    new$PREFERENCEPRISON,
    new$PURCHASESOCIALNKO,
    new$AGREEMENTEXECUTIONDATE,
    new$PURCHASECODE);

-- - - - - - - - - - - - -
-- AI_10 (TR_TENDERCAPTION_AI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*      */
  if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);            
    if (new$LastAccepted = 1) then
      update TenderCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_TENDERCAPTION_AI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   DELETE FROM delrecindexes
         WHERE (tableid = 139) AND (recordid = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
--
  CurVal$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$FacialAccCls is null) then 
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then 
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then 
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then 
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then 
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then 
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then 
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then 
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then 
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then 
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then 
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then 
    new$SupportUndertaker := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_TENDERCAPTION_BU_3)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*             */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_CHANGEINNERNUMS');
  END IF;
      
  /*   !!!*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    RaiseException('EX_RollbackCancel');
  END IF;
      
  /*  ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or 
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_Ten_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_Ten_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or 
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_Ten_ChangeStateAdjust');    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_TENDERCAPTION_BU_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then 
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE,
    PURCHASECODE = new$PURCHASECODE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.1*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
          
  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and 
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_OrgAcc_Close.sql
-- #########################################################
-- #########################################################

/*        .   
    */
-- CREATE TRIGGER TR_ORGANIZATIONS_BU_100
CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
--
  CNT$ NUMBER(10);
  c$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$gosni is null) then 
    new$gosni := 0;
  END IF;
  if (new$city is null) then 
    getvarcharconst(-1,7,new$city);
  END IF;
  if (new$country is null) then 
    new$country := '';
  END IF;
  if (new$countrycode is null) then 
    new$countrycode := 643;
  END IF;
  if (new$org_cls is null) then 
    new$org_cls:= 0;
  END IF;
  if (new$inn20 is null) then 
    new$inn20:= '';
  END IF;
  if (new$rcorg is null) then 
    new$rcorg := 0;
  END IF;
  if (new$regioncls is null) then 
    new$regioncls := 0;
  END IF;
  if (new$okato is null) then 
    new$okato := 0;
  END IF;
  if (new$kvsr is null) then 
    new$kvsr := 0;
  END IF;
  if (new$okfs is null) then 
    new$okfs := 0;
  END IF;
  if (new$okopf is null) then 
    new$okopf := 0;
  END IF;
  if (new$federalregioncode is null) then
    getintconst(-1, 27,new$federalregioncode);
  END IF;
  if (new$federalregioncode is null) then
    new$federalregioncode := 0;
  END IF;
  if (new$budgetref is null) then 
    new$budgetref := 0;
  END IF;
  if (new$org_type is null) then 
    new$org_type := 0;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;

  /*    10 ,      */
  if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then 
    if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
      RaiseException('ex_wrongkpp');  
    END IF;
  END IF;
  if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
  or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
  then
    check_unique_organization(new$inn,  new$inn20);
  END IF;
   
  if (new$regioncls <> :old.regioncls) then
    update dfaccountsbuhtable set
    regioncls = new$regioncls
    where id = any (select id from org_accounts where org_ref = new$id);
  END IF;
  /*      */
  if (:old.id = 0) then
    RaiseException('ex_cantmodifyunknownorg');
  END IF;
  /*        */
  if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
  then 
    c$ := new$costauthority;
    if (new$org_type between 10100 and 10299) then
      new$costauthority:= 1;
    END IF;
    if (new$org_type between 10300 and 10399) then
      new$costauthority:= 2;
    END IF;
    if (new$org_type between 10400 and 10499) then
      new$costauthority:= 4;
    END IF;
    if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
    (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
    and (new$costauthority=0))) then
      new$costauthority:= 8;
    END IF;
    if ((new$org_type=:old.org_type) and (c$<>new$costauthority)) then
      RaiseException('ex_wrongcostauthority');  
    END IF;
  END IF;
  /*    RegionCls  ,  
         */
  if (new$regioncls <> :old.regioncls) then
    update facialacc_cls fac set
    fac.regioncls = new$regioncls
    where
    new$id = fac.org_ref;
      
  END IF;
  if (new$UseCheck_Card is null) then 
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then 
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*   */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then 
    /*        */
    update Org_Accounts set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_Ref = new$Id;
      
  END IF;
  /*  /      */
  if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_ref = new$Id;
  END IF;
  /*   */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then 
    update Org_Accounts set
    CloseCode = CloseCode - 10
    where Org_Ref = new$Id;

    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode - 10
    where Org_ref = new$Id;
      
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECORDOWNERORGREF = new$RECORDOWNERORGREF
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where                       
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where                       
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
-- CREATE TRIGGER TR_ORG_ACCOUNTS_BU_100
CREATE OR REPLACE TRIGGER TR_ORG_ACCOUNTS_IU
  INSTEAD OF UPDATE
  ON ORG_ACCOUNTS
  FOR EACH ROW
DECLARE
  new$ID ORG_ACCOUNTS.ID%TYPE := :NEW.ID;
  new$ORG_REF ORG_ACCOUNTS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$BANK_REF ORG_ACCOUNTS.BANK_REF%TYPE := :NEW.BANK_REF;
  new$ACC ORG_ACCOUNTS.ACC%TYPE := :NEW.ACC;
  new$ACC_CLS ORG_ACCOUNTS.ACC_CLS%TYPE := :NEW.ACC_CLS;
  new$FINTYPE ORG_ACCOUNTS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$CREATERUSER ORG_ACCOUNTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORG_ACCOUNTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORG_ACCOUNTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORG_ACCOUNTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CLOSED ORG_ACCOUNTS.CLOSED%TYPE := :NEW.CLOSED;
  new$ACCDEFAULT ORG_ACCOUNTS.ACCDEFAULT%TYPE := :NEW.ACCDEFAULT;
  new$BANKDEPNUMBER ORG_ACCOUNTS.BANKDEPNUMBER%TYPE := :NEW.BANKDEPNUMBER;
  new$FACIALCODE ORG_ACCOUNTS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$SERVICE_ORG_REF ORG_ACCOUNTS.SERVICE_ORG_REF%TYPE := :NEW.SERVICE_ORG_REF;
  new$ACOMMENT ORG_ACCOUNTS.ACOMMENT%TYPE := :NEW.ACOMMENT;
  new$ISDEFAULT ORG_ACCOUNTS.ISDEFAULT%TYPE := :NEW.ISDEFAULT;
  new$RVERSION ORG_ACCOUNTS.RVERSION%TYPE := :NEW.RVERSION;
  new$SERVICE_ACC_REF ORG_ACCOUNTS.SERVICE_ACC_REF%TYPE := :NEW.SERVICE_ACC_REF;
  new$CLOSECODE ORG_ACCOUNTS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$SERVICEACC ORG_ACCOUNTS.SERVICEACC%TYPE := :NEW.SERVICEACC;
  new$FACIALACC_CLS ORG_ACCOUNTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$DATEOPEN ORG_ACCOUNTS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$DATECLOSE ORG_ACCOUNTS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$EXTID ORG_ACCOUNTS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORG_ACCOUNTS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORG_ACCOUNTS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
--
  vOrgType$ NUMBER(10);
  ADate$ NUMBER;
  DiffCode1$ NUMBER(10);
  Code11$ NUMBER(10);
  Code21$ NUMBER(10);
  Code31$ NUMBER(10);
  Code41$ NUMBER(10);
  Code5$ NUMBER(10);
  AFlag1$ NUMBER(10);
  vOrgType2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ORG_ACCOUNTS_BU)
-- Version 7.02.00.3
-- - - - - - - - - - - - -

  if (new$ACC_CLS is null) then 
    new$ACC_CLS:= 0;
  END IF;
  if (new$AccDefault is null) then 
    new$AccDefault:= 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType:= 0;
  END IF;
  if ((new$AComment is null) or (new$AComment  is null) 
  or (new$AComment = :old.AComment) and (:old.AComment = :old.Acc)) then
    new$AComment := new$Acc;
  END IF;
  if ((new$IsDefault is not Null) and (new$IsDefault <> 0)
  and ((:old.IsDefault is Null) or (:old.IsDefault = 0))) then
    update ORG_ACCOUNTS set
    IsDefault = 0
    where ORG_REF = new$ORG_REF
    and IsDefault is not Null
    and IsDefault <> 0;
  END IF;
  if ((new$SERVICE_ORG_REF is null)and(new$SERVICE_ACC_REF is not null)) then
    BEGIN
      select
      oa.Org_Ref
      into
      new$SERVICE_ORG_REF    from
      org_accounts oa
      where
      (oa.id = new$SERVICE_ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*               */
  if (new$ACC_CLS <> :old.ACC_CLS) then
    BEGIN
      select SERVICETYPE into new$ServiceAcc from ACC_CLS where (id = new$ACC_CLS) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*      ,       */
  if (:old.ServiceAcc is not null and new$ServiceAcc = 0 and :old.ServiceAcc <> new$ServiceAcc) then
    new$service_acc_ref := null;
    new$service_org_ref := null;
     
  END IF;
  /*       NULL,   0() */
  if (new$ServiceAcc is null) then
    new$ServiceAcc := 0;
    if (new$SERVICE_ORG_REF is not null) then
      BEGIN
        select
        o.Org_Type
        into vOrgType$      from
        Organizations o
        where
        (o.id = new$SERVICE_ORG_REF)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if ((vOrgType$  > 10099)and(vOrgType$  < 10200)) then
        new$ServiceAcc := 3;
             
      else
        if ((vOrgType$  > 39999)and(vOrgType$  < 50000)) then
          new$ServiceAcc := 1;
        END IF;   
      END IF; 
    END IF;
  END IF;
  /*            */
  if (new$Acc <> :old.Acc) then
    update facialacc_cls set
    FACIALCODE = new$Acc
    where
    FCACCOUNT = new$id;
     
  END IF;
  /*      . .   .  ,   ,
       ,     .  */
  if ((new$Service_Acc_Ref is not null) and (new$ServiceAcc <> 0)
  and (new$Service_Acc_Ref <> :old.Service_Acc_Ref)) then
    BEGIN
      select
      Bank_Ref, Acc
      into new$Bank_Ref, new$FacialCode    from
      Org_Accounts
      where
      new$Service_Acc_Ref = Id
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   */
  /*     ,        
       .  ,        */
  /*    ,          .  */
  if (((new$Bank_Ref <> :old.Bank_Ref) or (new$Acc <> :old.Acc)) and (:old.id <> new$id)) then
    update Org_Accounts
    set Bank_Ref = new$Bank_Ref,
    FacialCode = new$Acc
    where Service_Acc_Ref = new$ID;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORG_ACCOUNTS_BU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$CloseCode is null) then 
    new$CloseCode := 0;
  END IF;
  CloseOrgCls_Div(:old.CloseCode,Code11$, Code21$, Code31$, Code41$, Code5$);
    
  /* ??         */
    
  /*   ,        ,      */
  if ((new$Bank_ref <> :old.Bank_ref) and (Code41$ = 1)) then 
    BEGIN
      select DateClose into ADate$ from Banks where ID = new$Bank_ref ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (ADate$ is null) then 
      Code41$ := 0; /*    ,       . . */
      new$CloseCode := :old.CloseCode - 1000;
          
    else 
      if (new$DateClose > ADate$) then
        new$DateClose := ADate$;
      END IF;  
    END IF;
  END IF;
    
  /*    ,       . . -   */
  if ((new$Service_Acc_ref <> :old.Service_Acc_Ref) and (Code31$ = 1)) then 
    BEGIN
      select Closed, DateClose into AFlag1$, ADate$ from Org_Accounts where ID = new$Service_Acc_Ref ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (AFlag1$ is null) then 
      Code31$ := 0;
      new$CloseCode := :old.CloseCode - 100;
          
    else 
      if (new$DateClose > ADate$) then
        new$DateClose := ADate$;
      END IF;  
    END IF;
  END IF;
  /* ??   facialacc_cls    */

  /*  /  ??     ??   AU   */
  if (((new$Closed is null) and not(:old.Closed is null)) or
  (not(new$Closed is null) and (:old.Closed is null)))
  then 
    if (new$ORG_REF is not null and  new$facialacc_cls is not null)
    then
      BEGIN
        select o.Org_Type       into vOrgType2$ from Organizations o where (o.id = new$ORG_REF)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*      / ??    */
      if ((vOrgType2$  >= 10800)and(vOrgType2$  <= 10900))
      then
        if (new$Closed = 1)
        then
          /*    */
          if (new$DateClose is null) then
            CurDateToDouble(new$DateClose);
          END IF;

          update facialacc_cls set
          dateclose = new$DateClose,
          CloseCode = CloseCode + 10000
          where id = new$facialacc_cls;
                  
        END IF;
        if (new$Closed is null)
        then
          /*    */
          update facialacc_cls set 
          dateclose = null,
          CloseCode = CloseCode - 10000
          where id = new$facialacc_cls;
              
        END IF;    
      END IF;
    END IF;
    if (new$Closed = 1) then 
      new$CloseCode := 1;
    END IF;
    if (new$Closed is null) then 
      new$CloseCode := 0;
      
    END IF;
  END IF;
    
  /*  /   */
  if (new$CloseCode <> :old.CloseCode) then 
    DiffCode1$ := new$CloseCode - :old.CloseCode; /* >0 -  , <0 -  */
        
    /*   "" */
    if (DiffCode1$ = 1) then 
      Code11$ := 1;
    END IF;
    if (DiffCode1$ = 10) then 
      Code21$ := 1;
    END IF;
    if (DiffCode1$ = 100) then 
      Code31$ := 1;
    END IF;
    if (DiffCode1$ = 1000) then 
      Code41$ := 1;
    END IF;
    if (DiffCode1$ = 10000) then 
      Code5$ := 1;
    END IF;
    if (DiffCode1$ = -1) then 
      Code11$ := 0;
    END IF;
    if (DiffCode1$ = -10) then 
      Code21$ := 0;
    END IF;
    if (DiffCode1$ = -100) then 
      Code31$ := 0;
    END IF;
    if (DiffCode1$ = -1000) then 
      Code41$ := 0;
    END IF;
    if (DiffCode1$ = -10000) then 
      Code5$ := 0;
    END IF;
    new$CloseCode := Code11$ + Code21$*10 + Code31$*100 + Code41$*1000 + Code5$*10000;
        
    if (new$CloseCode = 0) then 
      new$Closed := null; 
      new$DateClose := null;
          
    else 
      new$Closed := 1;
      if (new$DateClose is null) then
        CurDateToDouble(new$DateClose);
      END IF;
      /*     ??      -  - !*/
      if (new$DateClose >= :old.DateClose) then
        new$DateClose := :old.DateClose;
          
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORG_ACCOUNTS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (New$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORG_ACCOUNTS SET
    ID = new$ID,
    ORG_REF = new$ORG_REF,
    BANK_REF = new$BANK_REF,
    ACC = new$ACC,
    ACC_CLS = new$ACC_CLS,
    FINTYPE = new$FINTYPE,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    CLOSED = new$CLOSED,
    ACCDEFAULT = new$ACCDEFAULT,
    BANKDEPNUMBER = new$BANKDEPNUMBER,
    FACIALCODE = new$FACIALCODE,
    SERVICE_ORG_REF = new$SERVICE_ORG_REF,
    ACOMMENT = new$ACOMMENT,
    ISDEFAULT = new$ISDEFAULT,
    RVERSION = new$RVERSION,
    SERVICE_ACC_REF = new$SERVICE_ACC_REF,
    CLOSECODE = new$CLOSECODE,
    SERVICEACC = new$SERVICEACC,
    FACIALACC_CLS = new$FACIALACC_CLS,
    DATEOPEN = new$DATEOPEN,
    DATECLOSE = new$DATECLOSE,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_0 (TR_ORG_ACCOUNTS_AU)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  /*     ,      "  ".    */
  if (new$CloseCode <> :old.CloseCode)
  then 
    if (new$CloseCode = 0) then
      update Org_Accounts set
      CloseCode = CloseCode - 100,
      RVersion = -1
      where Service_Acc_Ref = :old.ID;
          
    else
      update Org_Accounts set
      CloseCode = CloseCode + 100,
      DateClose = new$DateClose,
      RVersion = -1
      where Service_Acc_Ref = :old.ID;
      
    END IF;
  END IF;
  /*    FACIAL_CODE   */  
  if (new$acc <> :old.acc) then
    update org_accounts t set 
    t.facialcode = new$acc
    where 
    t.service_acc_ref = new$id and t.service_org_ref = new$org_ref
    ;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORG_ACCOUNTS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (21, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=21) and (RecordId=new$ID);
  end if;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- buhoperationcls
-- #########################################################
-- #########################################################


DROP TRIGGER TR_BUHOPERATIONCLS_BI
/
DROP TRIGGER TR_BUHOPERATIONCLS_BU
/
DROP TRIGGER TR_BUHOPERATIONCLS_BU_500
/
DROP TRIGGER TR_BUHOPERATIONCLS_AD
/
DROP TRIGGER TR_BUHOPERATIONCLS_AI
/
DROP TRIGGER TR_BUHOPERATIONCLS_AU
/

RENAME buhoperationcls TO TB_buhoperationcls
/
CREATE OR REPLACE TRIGGER TR_BUHOPERATIONCLS_BU_500
  BEFORE UPDATE
  ON TB_buhoperationcls
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_BUHOPERATIONCLS_BU_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  :new.Updatedate := SYSDATE;
  :new.DocChangeDate := :new.UpdateDate;
  :new.UpdaterUser := User;

END;
/

CREATE OR REPLACE VIEW buhoperationcls (
  ID,
  CREATEDATE,
  UPDATEDATE,
  CORRECTIONFLAG,
  NAME,
  CREATERUSER,
  UPDATERUSER,
  STARTDATE,
  DELETEDATE,
  COUNTDETAILRECORDS,
  DOCCHANGEDATE)
AS
  SELECT
    ID,
    CREATEDATE,
    UPDATEDATE,
    CORRECTIONFLAG,
    NAME,
    CREATERUSER,
    UPDATERUSER,
    STARTDATE,
    DELETEDATE,
    COUNTDETAILRECORDS,
    DOCCHANGEDATE
  FROM TB_buhoperationcls
/

GRANT SELECT, INSERT, UPDATE, DELETE ON buhoperationcls TO BUDGET_USERS
/
CREATE OR REPLACE TRIGGER TR_buhoperationcls_II
  INSTEAD OF INSERT
  ON buhoperationcls
  FOR EACH ROW
DECLARE
  new$ID buhoperationcls.ID%TYPE := :NEW.ID;
  new$CREATEDATE buhoperationcls.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE buhoperationcls.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CORRECTIONFLAG buhoperationcls.CORRECTIONFLAG%TYPE := :NEW.CORRECTIONFLAG;
  new$NAME buhoperationcls.NAME%TYPE := :NEW.NAME;
  new$CREATERUSER buhoperationcls.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER buhoperationcls.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$STARTDATE buhoperationcls.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE buhoperationcls.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$COUNTDETAILRECORDS buhoperationcls.COUNTDETAILRECORDS%TYPE := :NEW.COUNTDETAILRECORDS;
  new$DOCCHANGEDATE buhoperationcls.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUHOPERATIONCLS_BI)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$CorrectionFlag is null) then
    new$CorrectionFlag := 0;
  END IF;
  /*       0*/  
  new$CountDetailRecords := 0;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUHOPERATIONCLS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_buhoperationcls (
    ID,
    CREATEDATE,
    UPDATEDATE,
    CORRECTIONFLAG,
    NAME,
    CREATERUSER,
    UPDATERUSER,
    STARTDATE,
    DELETEDATE,
    COUNTDETAILRECORDS,
    DOCCHANGEDATE
  ) VALUES (
    new$ID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$CORRECTIONFLAG,
    new$NAME,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$STARTDATE,
    new$DELETEDATE,
    new$COUNTDETAILRECORDS,
    new$DOCCHANGEDATE);

-- - - - - - - - - - - - -
-- AI_500 (TR_BUHOPERATIONCLS_AI_500)
-- Last update 28.04.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 147) and (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_buhoperationcls_IU
  INSTEAD OF UPDATE
  ON buhoperationcls
  FOR EACH ROW
DECLARE
  new$ID buhoperationcls.ID%TYPE := :NEW.ID;
  new$CREATEDATE buhoperationcls.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE buhoperationcls.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CORRECTIONFLAG buhoperationcls.CORRECTIONFLAG%TYPE := :NEW.CORRECTIONFLAG;
  new$NAME buhoperationcls.NAME%TYPE := :NEW.NAME;
  new$CREATERUSER buhoperationcls.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER buhoperationcls.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$STARTDATE buhoperationcls.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE buhoperationcls.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$COUNTDETAILRECORDS buhoperationcls.COUNTDETAILRECORDS%TYPE := :NEW.COUNTDETAILRECORDS;
  new$DOCCHANGEDATE buhoperationcls.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUHOPERATIONCLS_BU)
-- Create 13.05.2005
-- - - - - - - - - - - - -

  IF (new$CorrectionFlag IS NULL) THEN new$CorrectionFlag := 0; end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_BUHOPERATIONCLS_BU_100)
-- Create 06.10.2009
-- - - - - - - - - - - - -

  /*    ,  ID (BuhOperationCLS ) */
  if ((new$Name <> :old.Name) and (new$ID = :old.ID)) then
    /*        ,      */
    update buhacccorr bac set
      bac.Name=new$Name
    where
      new$ID = bac.buhoperationcls and
      :old.Name = bac.Name;

    /*        ,      */
    update buhacccorr bac set
      bac.BackName=new$Name
    where
      new$ID = bac.buhoperationcls and
      :old.Name = bac.BackName;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_buhoperationcls SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    CORRECTIONFLAG = new$CORRECTIONFLAG,
    NAME = new$NAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    COUNTDETAILRECORDS = new$COUNTDETAILRECORDS,
    DOCCHANGEDATE = new$DOCCHANGEDATE
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUHOPERATIONCLS_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (147, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=147) and (RecordId=new$ID);
  end if;

END;
/

CREATE OR REPLACE TRIGGER TR_buhoperationcls_ID
  INSTEAD OF DELETE
  ON buhoperationcls
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_buhoperationcls
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_BUHOPERATIONCLS_AD_500)
-- Last update 28.04.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(147,:old.ID,SYSDATE);

END;
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- CloseAccFix.sql
-- #########################################################
-- #########################################################

/*   DateClose          */
CREATE OR REPLACE procedure CloseAccFix
AS
  YY$ VARCHAR2(4);
  MM$ VARCHAR2(2);
  DD$ VARCHAR2(2);
BEGIN
  FOR REC$1 IN (select id AS id, UpdateDate  AS UDate from org_accounts
  where Closed = 1 and DateClose is null
  )
  LOOP
    YY$ := (Extract (Year from REC$1.UDate));
    MM$ := (Extract (Month from REC$1.UDate));
    DD$ := (Extract (Day from REC$1.UDate));
    if (MM$ like '_') then
      MM$ := '0'||MM$;
    END IF;
    if (DD$ like '_') then
      DD$ := '0'||DD$;
    END IF;

    update org_accounts set
    DateClose = YY$||MM$||DD$

    where
    id = REC$1.id;
      
  END LOOP;
END;
/
ALTER TRIGGER TR_ORG_ACCOUNTS_BU_500 DISABLE
/
CALL CloseAccFix()
/
ALTER TRIGGER TR_ORG_ACCOUNTS_BU_500 ENABLE
/
drop procedure CloseAccFix
/
commit work 
/

-- #########################################################
-- #########################################################
-- Add_DontSignDocs_Rights.sql
-- #########################################################
-- #########################################################

/*     */
insert into RightKind(id, name) values (16, '  ')
/
insert into DBRights(RightKindRef, ObjectKindRef) values (16, 16000000)
/
commit work 
/


-- #########################################################
-- #########################################################
-- FillAppliedTypeRecommendField.sql
-- #########################################################
-- #########################################################

update LayerFieldTypes
	set RecommendField = 'DIRECTIONCLS'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'FACT'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'FINTYPE'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'INVESTOBJECT'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'KCSR'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'KESR'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'KFSR'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'KVR'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'KVSR'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'MEANSTYPE'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'OKPD'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'SUBSIDYCLS'
where Alias = '..'
/
update LayerFieldTypes
	set RecommendField = 'TRANSFERTCLS'
where Alias = '..'
/
commit work
/

-- #########################################################
-- #########################################################
-- DBVersion.sql
-- #########################################################
-- #########################################################

INSERT INTO DataBaseVersion(VERSION, Major, Minor, AComment)
  VALUES ('10.30.00', 1030, 00, ' 10.3')
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Index_Fix.sql
-- #########################################################
-- #########################################################

--      INDX
DECLARE
  CURSOR C$ IS
    select INDEX_NAME from DBA_INDEXES
    where OWNER = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      and TABLESPACE_NAME <> 'INDX'
      and INDEX_TYPE LIKE '%NORMAL%';
  CNT$ NUMBER(10);    
BEGIN
  BEGIN
    select count(*) into CNT$ from V$TABLESPACE
    where name = 'INDX';
  EXCEPTION
    WHEN OTHERS THEN
      CNT$ := 1;
  END;
  IF CNT$ = 1 THEN
    FOR R$ IN C$ LOOP
      EXECUTE IMMEDIATE 'ALTER INDEX ' || R$.INDEX_NAME || ' REBUILD TABLESPACE INDX';
    END LOOP;
  END IF;
END;
/

-- #########################################################
-- #########################################################
-- compile_scr.sql
-- #########################################################
-- #########################################################

--      , 
--  -  
--  DBMS_UTILITY.COMPILE_SCHEMA(user, TRUE);

DECLARE
  CURSOR C$ IS
    SELECT 'ALTER ' || object_type || ' ' || owner || '.' || object_name || ' COMPILE' AS str,
      object_type, object_name
    FROM SYS.ALL_OBJECTS
    WHERE owner = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      AND object_type IN ('VIEW', 'PROCEDURE', 'TRIGGER')
      AND status = 'INVALID'
      AND object_name not like 'BIN$%'
    ORDER BY DECODE(object_type, 'VIEW', 1, 'PROCEDURE', 2, 'TRIGGER', 3), object_name;
  S VARCHAR2(100);
BEGIN
  FOR R$ IN C$ LOOP
    BEGIN
      S := R$.object_type || ' ' || R$.object_name;
      EXECUTE IMMEDIATE R$.str;
    EXCEPTION
      WHEN OTHERS THEN 
        --DBMS_OUTPUT.PUT_LINE(S);
        RAISE_APPLICATION_ERROR(-20000, '    ' || S);
    END;
  END LOOP;
END;
/

-- #########################################################
-- #########################################################
-- dbms_stats_scr.sql
-- #########################################################
-- #########################################################

ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.,'
/

BEGIN
  DBMS_STATS.GATHER_SCHEMA_STATS(
    SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA'),
    DBMS_STATS.AUTO_SAMPLE_SIZE,
    false,
    'FOR ALL COLUMNS SIZE AUTO',
    cascade=>TRUE
  );
END;
/

exit
