-- #########################################################
-- #########################################################
-- ConfigEnv.sql
-- #########################################################
-- #########################################################

SPOOL spool.txt
WHENEVER SQLERROR EXIT FAILURE ROLLBACK
WHENEVER OSERROR EXIT FAILURE ROLLBACK

-- #########################################################
-- #########################################################
-- VersionCheck.sql
-- #########################################################
-- #########################################################

declare
  Major$ NUMBER(10);
  Minor$ NUMBER(10);
begin
  select max(Major) into Major$ from DatabaseVersion;
  select max(Minor) into Minor$ from DatabaseVersion where Major = Major$;
  if (Major$ <> 1030) or (Minor$ <> 00) then
    raise_application_error(-20000, '  [' || TO_CHAR(Major$) || '.' || TO_CHAR(Minor$, 'FM00') || ']    [1030.00]');
  end if;
end;
/

-- #########################################################
-- #########################################################
-- Add_PostInfo_to_ED_OUTPAYDOC.sql
-- #########################################################
-- #########################################################

/*        ed_outpaydoc*/
ALTER TABLE ed_outpaydoc ADD (
  SenderKod VARCHAR2(10),
  SenderName VARCHAR2(2000),
  GeterKod VARCHAR2(10),
  GeterName VARCHAR2(2000),
  BudgetLevel VARCHAR2(10)
)
/
commit work 
/

-- #########################################################
-- #########################################################
-- Create_TR_WritExecutionNotify_AD_500.sql
-- #########################################################
-- #########################################################

-- CREATE TRIGGER tr_writexecutionnotify_ad_500
CREATE OR REPLACE TRIGGER TR_writexecutionnotify_AD
  AFTER DELETE
  ON writexecutionnotify
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AD_500 (tr_writexecutionnotify_ad_500)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
  values(5203,:old.ID,SYSDATE);

END;
/
COMMIT WORK
/




-- #########################################################
-- #########################################################
-- ProtocolReason8990_oracle.sql
-- #########################################################
-- #########################################################


/* ***************************************
  ''
****************************************/
/*      */
alter trigger TR_ProtocolReason_BI disable
/

alter trigger TR_ProtocolReason_BU disable
/

create or replace procedure AddProtocolReason(ID$ Number, Name$ VarChar2)
as
  cnt$ Number(10);
begin
    select count(*) into cnt$
    from ProtocolReason
    where ID = ID$;

    if cnt$ = 0 then
      insert into ProtocolReason(ID, Name, CreateDate, UpdateDate) values(ID$, Name$, SYSDATE, SYSDATE);
    else
      update ProtocolReason set
        Name = Name$
      where 
        ID = ID$;
    end if;
end;
/

call AddProtocolReason(89, '. 93 . 1 . 44 44-  05.04.2013.')
/

call AddProtocolReason(90, '. 93 . 1 . 45 44-  05.04.2013.')
/

alter trigger TR_ProtocolReason_BI enable
/

alter trigger TR_ProtocolReason_BU enable
/

commit work
/



-- #########################################################
-- #########################################################
-- Alter_BS_SourceKCSR_to_NOTE10.sql
-- #########################################################
-- #########################################################

/*     SourceKCSR (  -> )
   bankexch_substitution  NOTE10*/
ALTER TABLE bankexch_substitution MODIFY (SourceKCSR VARCHAR2(10))
/
COMMIT WORK
/


-- #########################################################
-- #########################################################
-- alter_triggers_KESR.sql
-- #########################################################
-- #########################################################

/*       - KESR     */
-- ALTER TRIGGER TR_BUDGETDATA_BI_100
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BI
  BEFORE INSERT
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  doubleUse$ NUMBER(10);
  BALBOFlag$ NUMBER(10);
  AllowDivideBA$ NUMBER(10);
  StimateKind$ NUMBER(10);
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDGETDATA_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  IF (:new.id IS NULL) THEN 
    select g_shared.nextval into :new.id from dual;
  END IF;
  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KESRCorr IS NULL) THEN 
    :new.KESRCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN 
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .      */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  BEGIN

    /*  .   */
    SELECT bn.BudgetRef      INTO :new.BudgetRef FROM BudNotify bn
    WHERE bn.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind$);
    IF ((StimateKind$  = 0) OR (StimateKind$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;/* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
      SELECT Organizations FROM REGIONCLS
        WHERE NEW.REGIONCLS = ID
      INTO NEW.TransfertOrg_Ref;
  */
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_BudgetData_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.SenderID is null) then
    :new.SenderIDKey := -1;
        
  else
    :new.SenderIDKey := :new.SenderID;
  END IF;
      
  if (:new.SenderRecordID is null) then
    :new.SenderRecordIDKey := :new.ID;
        
  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_BUDGETDATA_BI_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType1$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType1$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType1$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc1$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc1$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_BUDGETDATA_BI_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else 
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDGETDATA_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

  Update BudNotify set
  DocChangeDate = :new.UpdateDate,
  RVersion = -1
  where id = :new.recordindex;

END;
/
-- ALTER TRIGGER TR_BUDGETDATA_BU_100
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  doubleUse$ NUMBER(10);
  BALBOFlag$ NUMBER(10);
  AllowDivideBA$ NUMBER(10);
  StimateKind$ NUMBER(10);
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KesrCorr IS NULL) THEN 
    :new.KesrCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN  
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .        */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  /*     */
  IF (:new.BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind$);
    IF ((StimateKind$  = 0) OR (StimateKind$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse$);
    GetIntConst(32, 40,AllowDivideBA$);
    IF ((doubleUse$=1) AND ((BALBOFlag$  <> 1) OR (AllowDivideBA$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;/* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
       SELECT Organizations FROM REGIONCLS
         WHERE NEW.REGIONCLS = ID
       INTO NEW.TransfertOrg_Ref;
  */
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType1$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType1$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType1$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc1$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc1$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (:NEW.RVersion IS NULL) THEN
     :NEW.RVersion := 1;
  ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
     :NEW.RVersion := :OLD.RVersion;
  ELSE
     :NEW.RVersion := :OLD.RVersion + 1;
  END IF;

END;
/
-- ALTER TRIGGER TR_FINDOCDETAIL_BI_120
CREATE OR REPLACE TRIGGER TR_FINDOCDETAIL_II
  INSTEAD OF INSERT
  ON FINDOCDETAIL
  FOR EACH ROW
DECLARE
  new$ID FINDOCDETAIL.ID%TYPE := :NEW.ID;
  new$KFSR FINDOCDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR FINDOCDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVSR FINDOCDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KVR FINDOCDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR FINDOCDETAIL.KESR%TYPE := :NEW.KESR;
  new$SUBKESR FINDOCDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FACT FINDOCDETAIL.FACT%TYPE := :NEW.FACT;
  new$FINSOURCE FINDOCDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$REGIONCLS FINDOCDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DOCTYPE FINDOCDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$FINTYPE FINDOCDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$CURRENCYCLS FINDOCDETAIL.CURRENCYCLS%TYPE := :NEW.CURRENCYCLS;
  new$MEANSTYPE FINDOCDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$DFACCOUNT FINDOCDETAIL.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$ACCOUNTREF FINDOCDETAIL.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ACCEPTDATE FINDOCDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$BUDGETREF FINDOCDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA FINDOCDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CREDIT FINDOCDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT FINDOCDETAIL.DEBIT%TYPE := :NEW.DEBIT;
  new$NOTE FINDOCDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$USERFLAG FINDOCDETAIL.USERFLAG%TYPE := :NEW.USERFLAG;
  new$SOURCEDOCNUM FINDOCDETAIL.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PROGINDEX FINDOCDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FINDOCDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FINDOCDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FINDOCDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FINDOCDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FINDOCDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$ACCEPTORACCREF FINDOCDETAIL.ACCEPTORACCREF%TYPE := :NEW.ACCEPTORACCREF;
  new$FACIALACC_CLS FINDOCDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECORDINDEX2 FINDOCDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$BUHPAYMENTCLS FINDOCDETAIL.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$REQUESTSINDEX FINDOCDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$PLANDATE FINDOCDETAIL.PLANDATE%TYPE := :NEW.PLANDATE;
  new$PROMISE FINDOCDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$RECORDINDEX3 FINDOCDETAIL.RECORDINDEX3%TYPE := :NEW.RECORDINDEX3;
  new$RECORDDATE FINDOCDETAIL.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF FINDOCDETAIL.TOTALREF%TYPE := :NEW.TOTALREF;
  new$DOCUMENTBASETYPE FINDOCDETAIL.DOCUMENTBASETYPE%TYPE := :NEW.DOCUMENTBASETYPE;
  new$TAXNOTE FINDOCDETAIL.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$CURRENCYSUMMA FINDOCDETAIL.CURRENCYSUMMA%TYPE := :NEW.CURRENCYSUMMA;
  new$RVERSION FINDOCDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FINDOCDETAIL.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$DIRECTIONCLS FINDOCDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ELDOCREF FINDOCDETAIL.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 FINDOCDETAIL.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$DOCNUMBER FINDOCDETAIL.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$BUHOPERATIONCLS FINDOCDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS FINDOCDETAIL.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR FINDOCDETAIL.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE FINDOCDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FINDOCDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$TRANSFERTCLS FINDOCDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
--
  cnt$ NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FINDOCDETAIL_BI)
-- Last update 30.11.2006
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   /*   */
   IF (new$kfsr IS NULL) THEN new$kfsr := 0; END IF;
   IF (new$kvsr IS NULL) THEN new$kvsr := 0; END IF;
   IF (new$kvr IS NULL) THEN new$kvr := 0; END IF;
   IF (new$kcsr IS NULL) THEN new$kcsr := 0; END IF;
   IF (new$KESR IS NULL) THEN new$KESR := 0; END IF;
   IF (new$subkesr IS NULL) THEN new$subkesr := 0; END IF;
 
   IF (new$DirectionCls IS NULL) THEN new$DirectionCls := 0; END IF;
 
   IF (new$fintype IS NULL) THEN new$fintype := 200; END IF;
   IF (new$finsource IS NULL) THEN new$finsource := 0; END IF; /*    */
   IF (new$fact IS NULL) THEN new$fact := 0; END IF;
   IF (new$currencycls IS NULL) THEN getintconst (19, 4, new$currencycls); END IF; /*  */
   IF (new$regioncls IS NULL) THEN new$regioncls := 0; END IF;
   IF (new$acceptoraccref IS NULL) THEN new$acceptoraccref := new$accountref; END IF;
   IF (new$accountref IS NULL) THEN new$accountref := new$acceptoraccref; END IF;
   IF (new$facialacc_cls IS NULL) THEN new$facialacc_cls := 0; END IF;
   IF (new$buhpaymentcls IS NULL) THEN new$buhpaymentcls := 0; END IF;
   IF (new$meanstype IS NULL) THEN new$meanstype := 0; END IF;
   IF (new$credit IS NULL) THEN new$credit := 0; END IF;
   IF (new$debit IS NULL) THEN new$debit := 0; END IF;
   IF (new$summa IS NULL) THEN new$summa := 0; END IF;
 
   /*   .        */
   IF (new$IFS IS NULL) THEN new$IFS := 0; END IF;
   IF (new$IFS_CORR IS NULL) THEN new$Ifs_Corr := 0; END IF;
   IF (new$BuhOperationCLS IS NULL) THEN
     GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;

   /*  .    ,    */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      BEGIN
         SELECT fdc.BudgetRef
           INTO NEW$BudgetRef
           FROM FinDocCaption fdc
          WHERE fdc.ID = NEW$RecordIndex;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            NEW$BudgetRef := NULL;
      END;
   END IF;

   /*  .  ,     */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO NEW$BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            NEW$BudgetRef := NULL;
      END;
   END IF;

   /*  ,    */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      GetIntConst (-1, 3, NEW$BudgetRef);
   END IF;

   IF (new$dfaccount IS NULL) THEN GetDefDFAccRefForBudget(new$BudgetRef, new$DFAccount); END IF;

   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCRETITVALUE');
   END IF;

   IF ((new$credit < 0) OR (new$debit < 0)) THEN
      /*          */
      IF (new$doctype BETWEEN 1010 AND 1019) THEN
         RaiseException ('EX_CREATEDOCSTORN');
      END IF;
      IF (new$doctype IS NULL) THEN new$doctype := 0; END IF;
   ELSIF (new$doctype IS NULL) THEN
      new$doctype := 1010;                                           /*  */
   END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_FINDOCDETAIL_BI_1)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   SELECT COUNT (ID)
     INTO cnt$
     FROM findoccaption
    WHERE (progindex = new$progindex) AND (ID = new$recordindex);

   IF (cnt$ = 1) THEN
      SELECT dfaccount, acceptdate, anumber
        INTO new$dfaccount, new$acceptdate, new$sourcedocnum
        FROM findoccaption
       WHERE (progindex = new$progindex) AND (ID = new$recordindex);
   ELSIF (cnt$ > 1) THEN
      RaiseException ('DATABASEERROR');
   END IF;

   IF (new$progindex = 8) THEN
     BEGIN
       SELECT acceptdate, num_accord
         INTO new$acceptdate, new$sourcedocnum
         FROM bill_accorddoc
         WHERE (ID = new$recordindex);
     EXCEPTION
        WHEN NO_DATA_FOUND THEN
          new$acceptdate := NULL;
          new$sourcedocnum := NULL;
     END;
   END IF;

-- - - - - - - - - - - - -
-- BI_2 (TR_FINDOCDETAIL_BI_2)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$summa IS NULL) OR (new$summa = 0) AND ((new$debit <> 0) OR (new$credit <> 0))) THEN
     new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
     new$credit := new$summa;
     new$debit := 0;
   ELSE
     new$credit := 0;
     new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BI_9 (TR_FINDOCDETAIL_BI_VZ)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$progindex = 9) THEN
     /*   */
     getintconst (9, 1, new$dfaccount);

     /*      */
     BEGIN
      SELECT acceptdate, budgetref
        INTO new$acceptdate, new$budgetref
        FROM vz_offset
       WHERE (ID = new$recordindex);
     EXCEPTION
        WHEN NO_DATA_FOUND THEN
          new$acceptdate := NULL;
          new$budgetref := NULL;
     END;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_FINDOCDETAIL_BI_10)
-- Create 26.08.2004
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   /*   ,      */
   IF (new$progindex IN (223, 23)) THEN
      SELECT COUNT (ID)
        INTO Cnt$
        FROM findoccaption c
       WHERE (c.ID = new$recordindex) AND (ROWNUM = 1);

      IF (Cnt$ = 0) THEN
         RaiseException ('EX_CAPTIONNOTEXISTS');
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_FINDOCDETALE_BI_20)
-- Last update 01.12.2005
-- - - - - - - - - - - - -

   IF (new$doctype BETWEEN 1010 AND 1019) THEN
      IF (    (new$acceptdate IS NOT NULL)
          AND ((new$credit > 0) OR (new$debit > 0))
         ) THEN
         /*    */
         INSERT INTO paydoc32
                     (budgetRef, accountref, acceptorattrref,
                      payerattrref, inputdate, credit, debit,
                      currency, cursum, textnote,
                      progindex, recordindex, facialacc_cls,
                      sourcedocnumber, taxnote
                     )
              VALUES (new$BudgetRef, new$accountref, new$acceptoraccref,
                      new$dfaccount, new$acceptdate, new$credit, new$debit,
                      new$currencycls, new$currencysumma, new$note,
                      new$progindex, new$ID, new$facialacc_cls,
                      new$sourcedocnum, new$taxnote
                     );
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_FINDOCDETAIL_BI_30)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   /*     ,    */
   IF ((new$RecordDate IS NULL) AND (NOT (new$AcceptDate IS NULL))) THEN
      /*    ,        */
      SELECT COUNT (recordindex)
        INTO cnt$
        FROM paydoc32
       WHERE (recordindex = new$id) AND (ROWNUM = 1);

      IF (cnt$ = 0) THEN
         new$RecordDate := new$AcceptDate;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_FINDOCDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if (new$ClsType is null) then
      new$ClsType := 0; /*  -  */
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND (new$IFS <> 0)) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0))) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType <> 0) AND (new$ClsType <> 1)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FINDOCDETAIL_BI_500)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FINDOCDETAIL (
    ID,
    KFSR,
    KCSR,
    KVSR,
    KVR,
    KESR,
    SUBKESR,
    FACT,
    FINSOURCE,
    REGIONCLS,
    DOCTYPE,
    FINTYPE,
    CURRENCYCLS,
    MEANSTYPE,
    DFACCOUNT,
    ACCOUNTREF,
    ACCEPTDATE,
    BUDGETREF,
    SUMMA,
    CREDIT,
    DEBIT,
    NOTE,
    USERFLAG,
    SOURCEDOCNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    ACCEPTORACCREF,
    FACIALACC_CLS,
    RECORDINDEX2,
    BUHPAYMENTCLS,
    REQUESTSINDEX,
    PLANDATE,
    PROMISE,
    RECORDINDEX3,
    RECORDDATE,
    TOTALREF,
    DOCUMENTBASETYPE,
    TAXNOTE,
    CURRENCYSUMMA,
    RVERSION,
    FEDERALFUNDSREF,
    DIRECTIONCLS,
    ELDOCREF,
    REQUESTSINDEX2,
    DOCNUMBER,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    UNIONNOTIFYREF,
    TRANSFERTCLS
  ) VALUES (
    new$ID,
    new$KFSR,
    new$KCSR,
    new$KVSR,
    new$KVR,
    new$KESR,
    new$SUBKESR,
    new$FACT,
    new$FINSOURCE,
    new$REGIONCLS,
    new$DOCTYPE,
    new$FINTYPE,
    new$CURRENCYCLS,
    new$MEANSTYPE,
    new$DFACCOUNT,
    new$ACCOUNTREF,
    new$ACCEPTDATE,
    new$BUDGETREF,
    new$SUMMA,
    new$CREDIT,
    new$DEBIT,
    new$NOTE,
    new$USERFLAG,
    new$SOURCEDOCNUM,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$ACCEPTORACCREF,
    new$FACIALACC_CLS,
    new$RECORDINDEX2,
    new$BUHPAYMENTCLS,
    new$REQUESTSINDEX,
    new$PLANDATE,
    new$PROMISE,
    new$RECORDINDEX3,
    new$RECORDDATE,
    new$TOTALREF,
    new$DOCUMENTBASETYPE,
    new$TAXNOTE,
    new$CURRENCYSUMMA,
    new$RVERSION,
    new$FEDERALFUNDSREF,
    new$DIRECTIONCLS,
    new$ELDOCREF,
    new$REQUESTSINDEX2,
    new$DOCNUMBER,
    new$BUHOPERATIONCLS,
    new$IFS,
    new$IFS_CORR,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$TRANSFERTCLS);

-- - - - - - - - - - - - -
-- AI_500 (TR_FINDOCDETAIL_AI_500)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 24) AND (RecordID = new$ID);

END;
/
-- ALTER TRIGGER TR_FINDOCDETAIL_BU_120
CREATE OR REPLACE TRIGGER TR_FINDOCDETAIL_IU
  INSTEAD OF UPDATE
  ON FINDOCDETAIL
  FOR EACH ROW
DECLARE
  new$ID FINDOCDETAIL.ID%TYPE := :NEW.ID;
  new$KFSR FINDOCDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR FINDOCDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVSR FINDOCDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KVR FINDOCDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR FINDOCDETAIL.KESR%TYPE := :NEW.KESR;
  new$SUBKESR FINDOCDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FACT FINDOCDETAIL.FACT%TYPE := :NEW.FACT;
  new$FINSOURCE FINDOCDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$REGIONCLS FINDOCDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DOCTYPE FINDOCDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$FINTYPE FINDOCDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$CURRENCYCLS FINDOCDETAIL.CURRENCYCLS%TYPE := :NEW.CURRENCYCLS;
  new$MEANSTYPE FINDOCDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$DFACCOUNT FINDOCDETAIL.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$ACCOUNTREF FINDOCDETAIL.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ACCEPTDATE FINDOCDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$BUDGETREF FINDOCDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA FINDOCDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CREDIT FINDOCDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT FINDOCDETAIL.DEBIT%TYPE := :NEW.DEBIT;
  new$NOTE FINDOCDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$USERFLAG FINDOCDETAIL.USERFLAG%TYPE := :NEW.USERFLAG;
  new$SOURCEDOCNUM FINDOCDETAIL.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PROGINDEX FINDOCDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FINDOCDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FINDOCDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FINDOCDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FINDOCDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FINDOCDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$ACCEPTORACCREF FINDOCDETAIL.ACCEPTORACCREF%TYPE := :NEW.ACCEPTORACCREF;
  new$FACIALACC_CLS FINDOCDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECORDINDEX2 FINDOCDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$BUHPAYMENTCLS FINDOCDETAIL.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$REQUESTSINDEX FINDOCDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$PLANDATE FINDOCDETAIL.PLANDATE%TYPE := :NEW.PLANDATE;
  new$PROMISE FINDOCDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$RECORDINDEX3 FINDOCDETAIL.RECORDINDEX3%TYPE := :NEW.RECORDINDEX3;
  new$RECORDDATE FINDOCDETAIL.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF FINDOCDETAIL.TOTALREF%TYPE := :NEW.TOTALREF;
  new$DOCUMENTBASETYPE FINDOCDETAIL.DOCUMENTBASETYPE%TYPE := :NEW.DOCUMENTBASETYPE;
  new$TAXNOTE FINDOCDETAIL.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$CURRENCYSUMMA FINDOCDETAIL.CURRENCYSUMMA%TYPE := :NEW.CURRENCYSUMMA;
  new$RVERSION FINDOCDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FINDOCDETAIL.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$DIRECTIONCLS FINDOCDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ELDOCREF FINDOCDETAIL.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 FINDOCDETAIL.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$DOCNUMBER FINDOCDETAIL.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$BUHOPERATIONCLS FINDOCDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS FINDOCDETAIL.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR FINDOCDETAIL.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE FINDOCDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FINDOCDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$TRANSFERTCLS FINDOCDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
--
  CNT$ NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FINDOCDETALE_BU_10)
-- Last update 30.11.2006
-- - - - - - - - - - - - -

   /*     */
   if ((new$BudgetRef <> :old.BudgetRef) and (not new$RecordIndex is null)) then
     if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
        RaiseException('Ex_CantModufyBudget');
     end if;   
   end if;
   /*   */
   IF (new$kfsr IS NULL) THEN new$kfsr := 0; END IF;
   IF (new$kvsr IS NULL) THEN new$kvsr := 0; END IF;
   IF (new$kvr IS NULL) THEN new$kvr := 0; END IF;
   IF (new$kcsr IS NULL) THEN new$kcsr := 0; END IF;
   IF (new$KESR IS NULL) THEN new$KESR := 0; END IF;
   IF (new$subkesr IS NULL) THEN new$subkesr := 0; END IF;
   
   IF (new$DirectionCls IS NULL) THEN new$DirectionCls := 0; END IF;
   
   IF (new$fintype IS NULL) THEN new$fintype := 200; END IF;
   IF (new$finsource IS NULL) THEN new$finsource := 0; END IF; /*    */
   IF (new$fact IS NULL) THEN new$fact := 0; END IF;
   IF (new$currencycls IS NULL) THEN getintconst (19, 4, new$currencycls); END IF; /*  */
   IF (new$regioncls IS NULL) THEN new$regioncls := 0; END IF;
   IF (new$DFAccount IS NULL) THEN GetDefaultDFAccountRef (new$DFAccount); END IF;
   IF (new$AcceptorAccRef IS NULL) THEN new$AcceptorAccRef := new$AccountRef; END IF;
   IF (new$AccountRef IS NULL) THEN new$AccountRef := new$AcceptorAccRef; END IF;
   IF (new$FacialAcc_CLS IS NULL) THEN new$FacialAcc_CLS := 0; END IF;
   IF (new$BuhPaymentCLS IS NULL) THEN new$BuhPaymentCLS := 0; END IF;
   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;
   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
   IF (new$Debit IS NULL) THEN new$Debit := 0; END IF;   
   IF (new$Summa IS NULL) THEN new$Summa := 0; END IF;
   
   /*   .        */
   IF (new$IFS IS NULL) THEN new$IFS := 0; END IF;
   IF (new$IFS_CORR IS NULL) THEN new$Ifs_Corr := 0; END IF;
   IF (new$BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;

   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCRETITVALUE');
   END IF;

   IF ((new$credit < 0) OR (new$debit < 0)) THEN
      /*          */
      IF (new$doctype BETWEEN 1010 AND 1019) THEN
         RaiseException ('EX_CREATEDOCSTORN');
      END IF;
      IF (new$doctype IS NULL) THEN new$doctype := 0; END IF;
   ELSE
      IF (new$doctype IS NULL) THEN
         new$doctype := 1010;
      END IF;                                                         /*  */
   END IF;

-- - - - - - - - - - - - -
-- BU_12 (TR_FINDOCDETAIL_BU_12)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$summa = :OLD.summa) THEN
     new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
     new$credit := new$summa;
     new$debit := 0;
   ELSE
     new$credit := 0;
     new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_FINDOCDETALE_BU_20)
-- Last update 01.12.2005
-- - - - - - - - - - - - -

   /*      */
   IF (    (new$doctype BETWEEN 1010 AND 1019)
       AND (new$acceptdate IS NOT NULL)
       AND ((new$credit > 0) OR (new$debit > 0))
      ) THEN
      /*
              
                
          
      */

      /*   ,   ,    */
      SELECT COUNT (RecordIndex)
        INTO CNT$
        FROM PayDoc32
       WHERE (RecordIndex = :OLD.ID);

      /*           
           */
      IF (   (:OLD.acceptdate IS NULL)
          OR NOT (:OLD.doctype BETWEEN 1010 AND 1019)
          OR (CNT$ = 0)
         ) THEN
         /*    */
         INSERT INTO paydoc32
                     (budgetRef, accountref, acceptorattrref,
                      payerattrref, inputdate, credit, debit,
                      currency, cursum, textnote,
                      progindex, recordindex, facialacc_cls,
                      sourcedocnumber, taxnote
                     )
              VALUES (new$BudgetRef, new$accountref, new$acceptoraccref,
                      new$dfaccount, new$acceptdate, new$credit, new$debit,
                      new$currencycls, new$currencysumma, new$note,
                      new$progindex, new$ID, new$facialacc_cls,
                      new$sourcedocnum, new$taxnote
                     );
      ELSE
         /*
                 ,   
             /
         */

         /*       / */
         IF (    (CNT$ > 1)
             AND ((new$Credit <> :OLD.Credit) OR (new$Debit <> :OLD.Debit))
            ) THEN
            RaiseException ('ex_CannotDeleteDivDoc');
         END IF;

         /*     */
         /*  Note   SourceDocNumber   NULL */
         IF (    (new$AcceptorAccRef = :OLD.AcceptorAccRef)
             AND (new$DfAccount = :OLD.DfAccount)
             AND (new$CurrencyCLS = :OLD.CurrencyCLS)
             AND (   (new$Note = :OLD.Note)
                  OR ((new$Note IS NULL) AND (:OLD.Note IS NULL))
                 )
             AND (   (new$SourceDocNum = :OLD.SourceDocNum)
                  OR (    (new$SourceDocNum IS NULL)
                      AND (:OLD.SourceDocNum IS NULL)
                     )
                 )
             AND (new$AccountRef = :OLD.AccountRef)
             AND (new$FacialAcc_Cls = :OLD.FacialAcc_Cls)
             AND (new$Summa = :OLD.Summa)
             AND (new$AcceptDate = :OLD.AcceptDate)
             AND (new$BudgetRef = :OLD.BudgetRef)
             AND (   (new$TaxNote = :OLD.TaxNote)
                  OR ((new$TaxNote IS NULL) AND (:OLD.TaxNote IS NULL))
                 )
            ) THEN
            new$AcceptorAccRef := new$AcceptorAccRef;
         ELSE
            UPDATE PayDoc32
               SET AcceptorAttrRef = new$AcceptorAccRef,
                   PayerAttrRef = new$DfAccount,
                   Currency = new$CurrencyCLS,
                   AccountRef = new$AccountRef,
                   FacialAcc_Cls = new$FacialAcc_Cls,
                   TextNote = new$Note,
                   Credit = new$Credit,
                   Debit = new$Debit,
                   InputDate = new$AcceptDate,
                   SourceDocNumber = new$SourceDocNum,
                   TaxNote = New$TaxNote,
                   BudgetRef = New$BudgetRef
             WHERE (RecordIndex = :OLD.ID) AND (ProgIndex = :OLD.ProgIndex);
         END IF;
      END IF;
   ELSE
      /*
                  
         ,    
      */
      DELETE FROM PayDoc32
            WHERE (ProgIndex = new$ProgIndex)
              AND (RecordIndex = new$id)
              AND (:OLD.DocType BETWEEN 1010 AND 1019);
   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_FINDOCDETAIL_BU_30)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$RecordDate IS NULL) AND (NOT (new$AcceptDate IS NULL))) THEN
      /*    ,        */
      SELECT COUNT (recordindex)
        INTO CNT$
        FROM paydoc32
       WHERE (recordindex = new$ID) AND (ROWNUM = 1);

      IF (CNT$ = 0) THEN
         new$RecordDate := new$AcceptDate;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FINDOCDETAIL_BU_70)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   --      ,   , 
--     
   UPDATE guarantee
      SET acceptdate = new$acceptdate
    WHERE subrecordindex = new$ID;

-- - - - - - - - - - - - -
-- BU_120 (TR_FINDOCDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if (new$ClsType is null) then
      new$ClsType := 0; /*  -  */
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND (new$IFS <> 0)) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0))) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType <> 0) AND (new$ClsType <> 1)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FINDOCDETAIL_BU_700)
-- Create 17.09.2004
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FINDOCDETAIL SET
    ID = new$ID,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVSR = new$KVSR,
    KVR = new$KVR,
    KESR = new$KESR,
    SUBKESR = new$SUBKESR,
    FACT = new$FACT,
    FINSOURCE = new$FINSOURCE,
    REGIONCLS = new$REGIONCLS,
    DOCTYPE = new$DOCTYPE,
    FINTYPE = new$FINTYPE,
    CURRENCYCLS = new$CURRENCYCLS,
    MEANSTYPE = new$MEANSTYPE,
    DFACCOUNT = new$DFACCOUNT,
    ACCOUNTREF = new$ACCOUNTREF,
    ACCEPTDATE = new$ACCEPTDATE,
    BUDGETREF = new$BUDGETREF,
    SUMMA = new$SUMMA,
    CREDIT = new$CREDIT,
    DEBIT = new$DEBIT,
    NOTE = new$NOTE,
    USERFLAG = new$USERFLAG,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    ACCEPTORACCREF = new$ACCEPTORACCREF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECORDINDEX2 = new$RECORDINDEX2,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    REQUESTSINDEX = new$REQUESTSINDEX,
    PLANDATE = new$PLANDATE,
    PROMISE = new$PROMISE,
    RECORDINDEX3 = new$RECORDINDEX3,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    DOCUMENTBASETYPE = new$DOCUMENTBASETYPE,
    TAXNOTE = new$TAXNOTE,
    CURRENCYSUMMA = new$CURRENCYSUMMA,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    DOCNUMBER = new$DOCNUMBER,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    TRANSFERTCLS = new$TRANSFERTCLS
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FINDOCDETAIL_AU_500)
-- Create 28.04.2005
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
         VALUES (24, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 24) AND (RecordId = new$ID);
   END IF;

END;
/
-- ALTER TRIGGER TR_LIMITFINDETAIL_BI_100
CREATE OR REPLACE TRIGGER TR_LIMITFINDETAIL_BI
  BEFORE INSERT
  ON LIMITFINDETAIL
  FOR EACH ROW
DECLARE
  DFAcc NUMBER (10);
  SFacialAcc NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_LIMITFINDETAIL_BI)
-- Last update 07.06.2008
-- - - - - - - - - - - - -

   /*   (   ) */
   IF (    (:NEW.ProgIndex = 56)
       AND ((:NEW.DFAccount IS NULL) OR (:NEW.SourceFacialAcc IS NULL))
      ) THEN
      BEGIN
         SELECT DFAccount, SourceFacialAcc
           INTO DFAcc, SFacialAcc
           FROM RequestFinCaption
          WHERE (ID = :NEW.RecordIndex);
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            DFAcc := NULL;
            SFacialAcc := NULL;
      END;

      IF (:NEW.DFAccount IS NULL) THEN
         :NEW.DFAccount := DFAcc;
      END IF;

      IF (:NEW.SourceFacialAcc IS NULL) THEN
         :NEW.SourceFacialAcc := SFacialAcc;
      END IF;
   END IF;

   /*      */
   IF (    (:NEW.ProgIndex = 57)
       AND ((:NEW.DFAccount IS NULL) OR (:NEW.SourceFacialAcc IS NULL))
      ) THEN
      BEGIN
         SELECT DFAccount, SourceFacialAcc
           INTO DFAcc, SFacialAcc
           FROM LimitNotifyCaption
          WHERE (ID = :NEW.RecordIndex);
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            DFAcc := NULL;
            SFacialAcc := NULL;
      END;

      IF (:NEW.DFAccount IS NULL) THEN
         :NEW.DFAccount := DFAcc;
      END IF;

      IF (:NEW.SourceFacialAcc IS NULL) THEN
         :NEW.SourceFacialAcc := SFacialAcc;
      END IF;
   END IF;

/*        , */
   BEGIN
      SELECT AcceptDate
        INTO :NEW.AcceptDate
        FROM LimitNotifyCaption
       WHERE (ID = :NEW.RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         :NEW.AcceptDate := NULL;
   END;

   /*  1 - ., 2 - ., 3 -  . */
   IF (:NEW.RequestFlag IS NULL) THEN
      :NEW.RequestFlag := 3;
   END IF;

   IF (:NEW.Summa IS NULL) THEN
      :NEW.Summa := 0;
   END IF;

   IF (:NEW.AcceptSumma IS NULL) THEN
      :NEW.AcceptSumma := 0;
   END IF;

   IF (:NEW.AcceptDate IS NOT NULL) THEN
      IF ((:NEW.RequestFlag = 3) AND (:NEW.AcceptSumma = 0)) THEN
         :NEW.AcceptSumma := :NEW.Summa;
      END IF;

      IF (:NEW.RequestFlag = 3) THEN
         :NEW.RequestFlag := 2;
      END IF;
   END IF;

   IF (:NEW.ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL
        INTO :NEW.ID
        FROM DUAL;
   END IF;

   IF (:NEW.KVSR IS NULL) THEN
      :NEW.KVSR := 0;
   END IF;

   IF (:NEW.KCSR IS NULL) THEN
      :NEW.KCSR := 0;
   END IF;

   IF (:NEW.KFSR IS NULL) THEN
      :NEW.KFSR := 0;
   END IF;

   IF (:NEW.KVR IS NULL) THEN
      :NEW.KVR := 0;
   END IF;

   IF (:NEW.KESR IS NULL) THEN
      :NEW.KESR := 0;
   END IF;

   IF (:NEW.SubKESR IS NULL) THEN
      :NEW.SubKESR := 0;
   END IF;

   IF (:NEW.DirectionCls IS NULL) THEN
      :NEW.DirectionCls := 0;
   END IF;

   /*     */
   IF (:new.FundsSource IS NULL) THEN
     :NEW.FundsSource := 0;
   END IF;
   
   IF (:NEW.FacialAcc IS NULL) THEN
      :NEW.FacialAcc := 0;
   END IF;

   if (:new.RegionCLS is null) then
     select fac.RegionCLS
     into :new.regioncls
     from facialacc_cls fac
     where fac.id = :new.facialacc;
   end if;
 
   IF (:NEW.FINSOURCE IS NULL) THEN
      :NEW.FINSOURCE := 0;
   END IF;

   IF (:NEW.FINType IS NULL) THEN
      :NEW.FINType := 0;
   END IF;

   IF (:NEW.Fact IS NULL) THEN
      :NEW.Fact := 0;
   END IF;

   IF (:NEW.DocTypes IS NULL) THEN
      :NEW.DocTypes := 0;
   END IF;

   IF (:NEW.MeansType IS NULL) THEN
      :NEW.MeansType := 0;
   END IF;

   IF (:NEW.SourceFacialAcc IS NULL) THEN
      :NEW.SourceFacialAcc := 0;
   END IF;

   /*    .     */
   IF (:NEW.IFS IS NULL) THEN
      :NEW.IFS := 0;
   END IF;

   IF (:NEW.BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, :NEW.BuhOperationCLS);
   END IF;

/*   .    ,    */
   IF ((:NEW.BudgetRef IS NULL) OR (:NEW.BudgetRef = 0)) THEN
      BEGIN
         SELECT c.BudgetRef
           INTO :NEW.BudgetRef
           FROM LimitFinCaption c
          WHERE c.ID = :NEW.RecordIndex;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            :NEW.BudgetRef := NULL;
      END;
   END IF;

   /*   .  ,     */
   IF ((:NEW.BudgetRef IS NULL) OR (:NEW.BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO :NEW.BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = :NEW.FacialAcc;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            :NEW.BudgetRef := NULL;
      END;
   END IF;

   /*   ,    */
   IF ((:NEW.BudgetRef IS NULL) OR (:NEW.BudgetRef = 0)) THEN
      GetIntConst (-1, 3, :NEW.BudgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_LIMITFINDETAIL_BI_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((:new.ClsType is NULL) and (:new.IFS <> 0)) then
    :new.ClsType := 1; /*       ClsType */
      
  else
    if (:new.ClsType is null) then
      :new.ClsType := 0; /*  -  */
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND (:new.IFS <> 0)) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType = 1) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_LIMITFINDETAIL_BI_500)
-- Last update 29.06.2005
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
-- ALTER TRIGGER TR_LIMITFINDETAIL_BU_100
CREATE OR REPLACE TRIGGER TR_LIMITFINDETAIL_BU
  BEFORE UPDATE
  ON LIMITFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_LIMITFINDETAIL_BU)
-- Last update 07.12.2005
-- - - - - - - - - - - - -

   IF (:NEW.KVSR IS NULL) THEN :NEW.KVSR := 0; END IF;
   IF (:NEW.KCSR IS NULL) THEN :NEW.KCSR := 0; END IF;
   IF (:NEW.KFSR IS NULL) THEN :NEW.KFSR := 0; END IF;
   IF (:NEW.KVR IS NULL) THEN :NEW.KVR := 0; END IF;
   IF (:NEW.KESR IS NULL) THEN :NEW.KESR := 0; END IF;
   IF (:NEW.SubKESR IS NULL) THEN :NEW.SubKESR := 0; END IF;
   IF (:NEW.DirectionCls IS NULL) THEN :NEW.DirectionCls := 0; END IF;
   /*    */
   IF (:new.FundsSource IS NULL) THEN :NEW.FundsSource := 0; END IF;


   IF (:NEW.Summa IS NULL) THEN :NEW.Summa := 0; END IF;
   IF (:NEW.AcceptSumma IS NULL) THEN :NEW.AcceptSumma := 0; END IF;
   IF (:NEW.RequestFlag IS NULL) THEN :NEW.RequestFlag := 3; END IF; /*1- ., 2- ., 3-  .*/
   IF (:NEW.FacialAcc IS NULL) THEN :NEW.FacialAcc := 0; END IF;
   
   if (:new.RegionCLS is null) then
     select fac.RegionCLS
     into :new.regioncls
     from facialacc_cls fac
     where fac.id = :new.facialacc;
   end if;
   
   IF (:NEW.FINSOURCE IS NULL) THEN :NEW.FINSOURCE := 0; END IF;
   IF (:NEW.FINType IS NULL) THEN :NEW.FINType := 0; END IF;
   IF (:NEW.Fact IS NULL) THEN :NEW.Fact := 0; END IF;
   IF (:NEW.DocTypes IS NULL) THEN :NEW.DocTypes := 0; END IF;
   IF (:NEW.MeansType IS NULL) THEN :NEW.MeansType := 0; END IF;
   IF (:NEW.SourceFacialAcc IS NULL) THEN :NEW.SourceFacialAcc := 0; END IF;

/*----*/
  /*   .     */
   IF (:NEW.IFS IS NULL) THEN :NEW.IFS := 0; END IF;
   IF (:NEW.BuhOperationCLS IS NULL) THEN GetIntConst (60, 15, :NEW.BuhOperationCLS); END IF;

   /*     */
   IF     (:NEW.BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((:NEW.BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_LIMITFINDETAIL_BU_10)
-- Last update 14.02.2006
-- - - - - - - - - - - - -

  if ((:new.AcceptDate is null) and (:old.AcceptDate is not null)) then
    if ((:new.RequestFlag=2) and (:new.AcceptSumma = :new.Summa)) then :new.AcceptSumma := 0; end if;
    if (:new.RequestFlag=2) then :new.RequestFlag := 3; end if;
  end if;

  if ((:new.AcceptDate is not null) and (:new.RequestFlag = 3)) then
    :new.RequestFlag := 2;
  end if;
  if ((:new.AcceptDate is not null) and (:new.RequestFlag = 2) and (:new.AcceptSumma = 0)) then
     :new.AcceptSumma := :new.Summa;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_LIMITFINDETAIL_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((:new.ClsType is NULL) and (:new.IFS <> 0)) then
    :new.ClsType := 1; /*       ClsType */
      
  else
    if (:new.ClsType is null) then
      :new.ClsType := 0; /*  -  */
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND (:new.IFS <> 0)) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType = 1) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_LIMITFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (:NEW.RVersion IS NULL) THEN
      :NEW.RVersion := 1;
   ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      :NEW.RVersion := :OLD.RVersion;
   ELSE
      :NEW.RVersion := :OLD.RVersion + 1;
   END IF;

END;
/
-- ALTER TRIGGER TR_FACIALFINCAPTION_AU_300
CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  UseFax$ NUMBER(10);
  DocNumber$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is not null) then 
    /*      */
    GetIntConst(30, 19,UseFax$);
    if ((new$BidNumber is null) and (UseFax$ = 1)) then 
      new$BidNumber:= new$DocNumber;
      
    END IF;
  END IF;
  if (new$credit is null)then 
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then 
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then 
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then 
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then 
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then 
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then 
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then 
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;
          
    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;
              
      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;
                  
        else
          new$SourceType := -1;
          new$DestType := -1;
                  
        END IF;
      END IF;  
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$); 
    if (DocNumber$ is null) then 
      new$DepartmentCls:= 0;
          
    else 
      new$DepartmentCls:= DocNumber$;
      
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))                                             
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */
      
  else 
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where 
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
        
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(CodeFormat<>50)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_FACIALFINCAPTION_BU_10)
-- Create 16.03.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$IntegratedDocRef IS NOT NULL) THEN
        /*           ,       
      /*    */
      IF (    (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND (   (new$Reject_CLS = :OLD.Reject_CLS)
               OR ((new$Reject_CLS IS NULL) AND (:OLD.Reject_CLS IS NULL))
              )
          AND (   (new$RejectCause = :OLD.RejectCause)
               OR ((new$RejectCause IS NULL) AND (:OLD.RejectCause IS NULL))
              )
          AND (   (new$TREASUARYDOCSTATECLS = :OLD.TREASUARYDOCSTATECLS)
               OR (    (new$TREASUARYDOCSTATECLS IS NULL)
                   AND (:OLD.TREASUARYDOCSTATECLS IS NULL)
                  )
              )
          AND (   (new$DOCSTATEREF = :OLD.DOCSTATEREF)
               OR ((new$DOCSTATEREF IS NULL) AND (:OLD.DOCSTATEREF IS NULL))
              )
          AND (   (new$REESTR_REF = :OLD.REESTR_REF)
               OR ((new$REESTR_REF IS NULL) AND (:OLD.REESTR_REF IS NULL))
              )
          AND (new$SOURCEACCOUNT = :OLD.SOURCEACCOUNT)
          AND (new$DESTACCOUNT = :OLD.DESTACCOUNT)
         ) THEN
         new$AcceptDate := :OLD.AcceptDate;
      ELSE
         FOR R$ IN (SELECT fc.AcceptDate, fc.Reject_CLS, fc.RejectCause,
                           fc.TREASUARYDOCSTATECLS, fc.DOCSTATEREF,
                           fc.REESTR_REF, fc.SOURCEACCOUNT, fc.DESTACCOUNT
                      FROM FacialFinCaption fc
                     WHERE (fc.ID = :NEW.IntegratedDocRef)) LOOP
            IF (    (   (new$AcceptDate = R$.AcceptDate)
                     OR ((new$AcceptDate IS NULL) AND (R$.AcceptDate IS NULL)
                        )
                    )
                AND (   (new$Reject_CLS = R$.Reject_CLS)
                     OR ((new$Reject_CLS IS NULL) AND (R$.Reject_CLS IS NULL)
                        )
                    )
                AND (   (new$RejectCause = R$.RejectCause)
                     OR (    (new$RejectCause IS NULL)
                         AND (R$.RejectCause IS NULL)
                        )
                    )
                AND (   (new$TREASUARYDOCSTATECLS = R$.TREASUARYDOCSTATECLS)
                     OR (    (new$TREASUARYDOCSTATECLS IS NULL)
                         AND (R$.TREASUARYDOCSTATECLS IS NULL)
                        )
                    )
                AND (   (new$DOCSTATEREF = R$.DOCSTATEREF)
                     OR (    (new$DOCSTATEREF IS NULL)
                         AND (R$.DOCSTATEREF IS NULL)
                        )
                    )
                AND (   (new$REESTR_REF = R$.REESTR_REF)
                     OR ((new$REESTR_REF IS NULL) AND (R$.REESTR_REF IS NULL)
                        )
                    )
                AND (new$SOURCEACCOUNT = R$.SOURCEACCOUNT)
                AND (new$DESTACCOUNT = R$.DESTACCOUNT)
               ) THEN
               new$AcceptDate := R$.AcceptDate;
            ELSE
               RaiseException ('EX_CANNOTUPDATECHILDDOC');
            END IF;
         END LOOP;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;
      
  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);
      
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_FACIALFINCAPTION_AU_10)
-- Create 05.03.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 72) THEN                       /*   */
      IF (    (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND (   (new$Reject_CLS = :OLD.Reject_CLS)
               OR ((new$Reject_CLS IS NULL) AND (:OLD.Reject_CLS IS NULL))
              )
          AND (   (new$RejectCause = :OLD.RejectCause)
               OR ((new$RejectCause IS NULL) AND (:OLD.RejectCause IS NULL))
              )
          AND (   (new$TREASUARYDOCSTATECLS = :OLD.TREASUARYDOCSTATECLS)
               OR (    (new$TREASUARYDOCSTATECLS IS NULL)
                   AND (:OLD.TREASUARYDOCSTATECLS IS NULL)
                  )
              )
          AND (   (new$DOCSTATEREF = :OLD.DOCSTATEREF)
               OR ((new$DOCSTATEREF IS NULL) AND (:OLD.DOCSTATEREF IS NULL))
              )
          AND (   (new$REESTR_REF = :OLD.REESTR_REF)
               OR ((new$REESTR_REF IS NULL) AND (:OLD.REESTR_REF IS NULL))
              )
          AND (new$SOURCEACCOUNT = :OLD.SOURCEACCOUNT)
          AND (new$DESTACCOUNT = :OLD.DESTACCOUNT)
         ) THEN
         NULL;                /*      new$AcceptDate := :old.AcceptDate;   */
      ELSE
         /*    ,      */
         UPDATE TB_FacialFinCaption
            SET AcceptDate = new$AcceptDate,
                Reject_CLS = new$Reject_CLS,
                RejectCause = new$RejectCause,
                TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
                DOCSTATEREF = new$DOCSTATEREF,
                REESTR_REF = new$REESTR_REF,
                SOURCEACCOUNT = new$SOURCEACCOUNT,
                DESTACCOUNT = new$DESTACCOUNT
          WHERE IntegratedDocRef = new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*          ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
      
    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BI_120
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CapBuhOperationCLS$ NUMBER(10);
  CapClsType$ NUMBER(10);
  CapAcceptDate$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  PromiseAcceptDate$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Last update 12.01.2009
-- - - - - - - - - - - - -

 /*  ,    */
   BEGIN

     select
       ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate,
       ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
     into new$BudgetRef, CapBuhOperationCls$, CapClsType$, CapAcceptDate$,
       new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause
     from
       FacialFinCaption ffc
     where
       ffc.id = new$RecordIndex;
     
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       new$BudgetRef := NULL;
       CapBuhOperationCls$ := NULL;
       CapClsType$ := NULL;
       CapAcceptDate$ := NULL;
   END;

   /*      */
   if (new$BuhOperationCls is null) then new$BuhOperationCls := CapBuhOperationCls$; end if;

   /*      */
   if (new$ClsType is null) then new$ClsType := CapClsType$; end if;

   if (new$DestClsType is null) then new$DestClsType := new$ClsType; end if;
   
   /*      */
   if (new$AcceptDate is null) then new$AcceptDate := CapAcceptDate$; end if;

   /*      */
   if ((new$SourceFacialAcc_CLS is null) or (new$DestFacialAcc_CLS is null)) then
     BEGIN
       select SourceFacialAcc_CLS, DestFacialAcc_CLS
         into SourceFacialAcc_CLS$, DestFacialAcc_CLS$
       from FacialFinCaption
       where new$RecordIndex = id;
     EXCEPTION
       WHEN NO_DATA_FOUND THEN
         SourceFacialAcc_CLS$ := NULL;
         DestFacialAcc_CLS$ := NULL;
     END;

     if (new$SourceFacialAcc_CLS is null) then new$SourceFacialAcc_CLS := SourceFacialAcc_CLS$; end if;
     if (new$DestFacialAcc_CLS is null) then new$DestFacialAcc_CLS := DestFacialAcc_CLS$; end if;
   end if;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype1$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype1$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype1$  ;
     
  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN 
    IF (i_fintype1$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype1$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype1$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND(new$DestPromise IS NOT NULL)AND
        (new$SourcePromise=new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode1$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;    
    END IF;
  END IF;
  if (PromiseMode1$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .    */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* source    ,   ,   */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /* dest */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_120
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype1$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype1$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype1$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype1$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype1$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype1$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_Requests_BI_120
CREATE OR REPLACE TRIGGER TR_REQUESTS_II
  INSTEAD OF INSERT
  ON REQUESTS
  FOR EACH ROW
DECLARE
  new$ID REQUESTS.ID%TYPE := :NEW.ID;
  new$BUDGET REQUESTS.BUDGET%TYPE := :NEW.BUDGET;
  new$KFSR REQUESTS.KFSR%TYPE := :NEW.KFSR;
  new$KVSR REQUESTS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR REQUESTS.KCSR%TYPE := :NEW.KCSR;
  new$KVR REQUESTS.KVR%TYPE := :NEW.KVR;
  new$KESR REQUESTS.KESR%TYPE := :NEW.KESR;
  new$SUBKESR REQUESTS.SUBKESR%TYPE := :NEW.SUBKESR;
  new$USERNOTE REQUESTS.USERNOTE%TYPE := :NEW.USERNOTE;
  new$FACIALACC_CLS REQUESTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$SOURCEACCOUNT REQUESTS.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$DESTACCOUNT REQUESTS.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$FACT REQUESTS.FACT%TYPE := :NEW.FACT;
  new$FINSOURCE REQUESTS.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE REQUESTS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$REGIONCLS REQUESTS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$BUHPAYMENTCLS REQUESTS.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$DOCTYPE REQUESTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$PAYDATE REQUESTS.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYPRIORITY REQUESTS.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$SUMMAREQUESTED REQUESTS.SUMMAREQUESTED%TYPE := :NEW.SUMMAREQUESTED;
  new$SUMMATOFINANCE REQUESTS.SUMMATOFINANCE%TYPE := :NEW.SUMMATOFINANCE;
  new$REQUESTTYPE REQUESTS.REQUESTTYPE%TYPE := :NEW.REQUESTTYPE;
  new$MEANSTYPE REQUESTS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYSYMBOLCLS REQUESTS.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$CREATERUSER REQUESTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE REQUESTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER REQUESTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE REQUESTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$ANUMBER REQUESTS.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PROMISE REQUESTS.PROMISE%TYPE := :NEW.PROMISE;
  new$DOCUMENTBASETYPE REQUESTS.DOCUMENTBASETYPE%TYPE := :NEW.DOCUMENTBASETYPE;
  new$INPUTDATE REQUESTS.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$DFACCOUNT REQUESTS.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$PROGINDEX REQUESTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$PROGINDEX2 REQUESTS.PROGINDEX2%TYPE := :NEW.PROGINDEX2;
  new$RECORDINDEX REQUESTS.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$INNERFINSOURCE REQUESTS.INNERFINSOURCE%TYPE := :NEW.INNERFINSOURCE;
  new$OUTERFINSOURCE REQUESTS.OUTERFINSOURCE%TYPE := :NEW.OUTERFINSOURCE;
  new$KD REQUESTS.KD%TYPE := :NEW.KD;
  new$SUBKD REQUESTS.SUBKD%TYPE := :NEW.SUBKD;
  new$PLANDATE REQUESTS.PLANDATE%TYPE := :NEW.PLANDATE;
  new$CURRENCYCLS REQUESTS.CURRENCYCLS%TYPE := :NEW.CURRENCYCLS;
  new$REQUESTSDOCSTATE REQUESTS.REQUESTSDOCSTATE%TYPE := :NEW.REQUESTSDOCSTATE;
  new$TAXNOTE REQUESTS.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$GOSNI REQUESTS.GOSNI%TYPE := :NEW.GOSNI;
  new$CURRENCYSUMMA REQUESTS.CURRENCYSUMMA%TYPE := :NEW.CURRENCYSUMMA;
  new$RVERSION REQUESTS.RVERSION%TYPE := :NEW.RVERSION;
  new$DIRECTIONCLS REQUESTS.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$DOCSTATEREF REQUESTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS REQUESTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$FEDERALFUNDSREF REQUESTS.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS REQUESTS.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS_CORR REQUESTS.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE REQUESTS.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$REESTRDATE REQUESTS.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$AMONTH REQUESTS.AMONTH%TYPE := :NEW.AMONTH;
  new$AYEAR REQUESTS.AYEAR%TYPE := :NEW.AYEAR;
  new$EXECSUMMA REQUESTS.EXECSUMMA%TYPE := :NEW.EXECSUMMA;
  new$SUBSIDYCLS REQUESTS.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$TRANSFERTCLS REQUESTS.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$PAYPROMISECLS REQUESTS.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$BUDALLOCATIONCLS REQUESTS.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
--
  CNT$ number(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (CHECK_PROMISE_REF)
-- - - - - - - - - - - - -

  SELECT count(REGISTRNUMBER) into CNT$
  FROM promise_detail pd
  WHERE (pd.REGISTRNUMBER=NEW$PROMISE)and(pd.CloseDate is null) AND (ROWNUM=1);

  IF (CNT$ = 0) AND (NOT NEW$PROMISE IS NULL) THEN
    RaiseException('EX_PROMISEN_NOT_EXIST');
  end if;

-- - - - - - - - - - - - -
-- BI_0 (TR_REQUESTS_BI)
-- Last update 20.10.2009
-- - - - - - - - - - - - -

  IF (NEW$ID IS NULL) THEN
    SELECT g_Shared.NEXTVAL INTO NEW$ID FROM DUAL;
  END IF;

  IF (NEW$KFSR IS NULL) THEN NEW$KFSR := 0; END IF;
  IF (NEW$KVSR IS NULL) THEN NEW$KVSR := 0; END IF;
  IF (NEW$KCSR IS NULL) THEN NEW$KCSR := 0; END IF;
  IF (NEW$KVR IS NULL) THEN NEW$KVR := 0; END IF;
  IF (NEW$KESR IS NULL) THEN NEW$KESR := 0; END IF;
  IF (NEW$SubKesr IS NULL) THEN NEW$SubKESR := 0; END IF;
  IF (NEW$DirectionCls IS NULL) THEN NEW$DirectionCls := 0; END IF;
   
  IF (NEW$SummaRequested IS NULL) THEN NEW$SummaRequested := 0; END IF;
  IF (NEW$DocType IS NULL) THEN NEW$DocType := 0; END IF;
  IF (NEW$MeansType IS NULL) THEN NEW$MeansType := 0; END IF;
  IF (NEW$Fact IS NULL) THEN NEW$Fact := 0; END IF;
  IF (NEW$InnerFinSource IS NULL) THEN NEW$InnerFinSource := 0; END IF;
  IF (NEW$OuterFinSource IS NULL) THEN NEW$OuterFinSource := 0; END IF;
  IF (NEW$KD IS NULL) THEN NEW$KD := 0; END IF;
  IF (NEW$SubKD IS NULL) THEN NEW$SubKD := 0; END IF;
  if (NEW$ExecSumma is null) then NEW$ExecSumma := 0; end if;

  /*     -  */
  IF (NEW$ProgIndex IS NULL) THEN NEW$ProgIndex := 221; END IF;

  /*      -   ""*/
  IF (NEW$CurrencyCLS IS NULL) THEN
    GetIntConst (19, 4, NEW$CurrencyCLS);
  END IF;

  IF (NEW$REQUESTSDOCSTATE IS NULL) THEN NEW$REQUESTSDOCSTATE := 2; END IF;
  IF (NEW$GOSNI IS NULL) THEN NEW$GOSNI := 0; END IF;
  /*    .        */
  IF (NEW$IFS_CORR IS NULL) THEN NEW$Ifs_Corr := 0; END IF;
  IF (NEW$BuhOperationCLS IS NULL) THEN GetIntConst (60, 15, NEW$BuhOperationCLS); END IF;
  IF (NEW$FacialAcc_Cls IS NULL) THEN NEW$FacialAcc_Cls := 0; END IF;

  /*   .  ,     */
  IF ((NEW$Budget IS NULL) OR (NEW$Budget = 0)) THEN
    BEGIN
      SELECT fa.BudgetRef
        INTO NEW$Budget
        FROM FacialAcc_Cls fa
      WHERE fa.ID = NEW$FacialAcc_Cls;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NEW$Budget := NULL;
    END;
  END IF;

  /*   ,    */
  IF ((NEW$Budget IS NULL) OR (NEW$Budget = 0)) THEN
    GetIntConst (-1, 3, NEW$Budget);
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_REQUESTS_BI_10)
-- Last update 15.09.2005
-- - - - - - - - - - - - -

  /*       - */
  /*       -    */
  IF (NEW$ProgIndex = 222) THEN
    IF ((NEW$SOURCEACCOUNT IS NULL) AND (NEW$DESTACCOUNT IS NOT NULL)) THEN
      NEW$SOURCEACCOUNT := NEW$DESTACCOUNT;
    ELSE
      IF ((NEW$SOURCEACCOUNT IS NOT NULL) AND (NEW$DESTACCOUNT IS NULL)) THEN
        NEW$DESTACCOUNT := NEW$SOURCEACCOUNT;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_REQUESTS_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$INNERFINSOURCE <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF (((new$ClsType = 0)or((new$ClsType = 2))) AND (new$INNERFINSOURCE <> 0)) THEN
    /*  ,     */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF (((new$ClsType = 1)or(new$ClsType = 2)) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0))) THEN
    /*  ,     */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF (((new$ClsType = 0)or((new$ClsType = 1))) AND (new$KD <> 0)) THEN
    /*  ,     */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_REQUESTS_BI_500)
-- Last update 15.09.2005
-- - - - - - - - - - - - -

  NEW$CreateDate := SYSDATE;
  NEW$UpdateDate := NEW$CreateDate;
  NEW$CreaterUser := USER;
  NEW$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_REQUESTS (
    ID,
    BUDGET,
    KFSR,
    KVSR,
    KCSR,
    KVR,
    KESR,
    SUBKESR,
    USERNOTE,
    FACIALACC_CLS,
    SOURCEACCOUNT,
    DESTACCOUNT,
    FACT,
    FINSOURCE,
    FINTYPE,
    REGIONCLS,
    BUHPAYMENTCLS,
    DOCTYPE,
    PAYDATE,
    PAYPRIORITY,
    SUMMAREQUESTED,
    SUMMATOFINANCE,
    REQUESTTYPE,
    MEANSTYPE,
    PAYSYMBOLCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    ANUMBER,
    PROMISE,
    DOCUMENTBASETYPE,
    INPUTDATE,
    DFACCOUNT,
    PROGINDEX,
    PROGINDEX2,
    RECORDINDEX,
    INNERFINSOURCE,
    OUTERFINSOURCE,
    KD,
    SUBKD,
    PLANDATE,
    CURRENCYCLS,
    REQUESTSDOCSTATE,
    TAXNOTE,
    GOSNI,
    CURRENCYSUMMA,
    RVERSION,
    DIRECTIONCLS,
    DOCSTATEREF,
    CRYPTOSTATUS,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS_CORR,
    CLSTYPE,
    REESTRDATE,
    AMONTH,
    AYEAR,
    EXECSUMMA,
    SUBSIDYCLS,
    TRANSFERTCLS,
    PAYPROMISECLS,
    BUDALLOCATIONCLS
  ) VALUES (
    new$ID,
    new$BUDGET,
    new$KFSR,
    new$KVSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$SUBKESR,
    new$USERNOTE,
    new$FACIALACC_CLS,
    new$SOURCEACCOUNT,
    new$DESTACCOUNT,
    new$FACT,
    new$FINSOURCE,
    new$FINTYPE,
    new$REGIONCLS,
    new$BUHPAYMENTCLS,
    new$DOCTYPE,
    new$PAYDATE,
    new$PAYPRIORITY,
    new$SUMMAREQUESTED,
    new$SUMMATOFINANCE,
    new$REQUESTTYPE,
    new$MEANSTYPE,
    new$PAYSYMBOLCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$ANUMBER,
    new$PROMISE,
    new$DOCUMENTBASETYPE,
    new$INPUTDATE,
    new$DFACCOUNT,
    new$PROGINDEX,
    new$PROGINDEX2,
    new$RECORDINDEX,
    new$INNERFINSOURCE,
    new$OUTERFINSOURCE,
    new$KD,
    new$SUBKD,
    new$PLANDATE,
    new$CURRENCYCLS,
    new$REQUESTSDOCSTATE,
    new$TAXNOTE,
    new$GOSNI,
    new$CURRENCYSUMMA,
    new$RVERSION,
    new$DIRECTIONCLS,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$FEDERALFUNDSREF,
    new$BUHOPERATIONCLS,
    new$IFS_CORR,
    new$CLSTYPE,
    new$REESTRDATE,
    new$AMONTH,
    new$AYEAR,
    new$EXECSUMMA,
    new$SUBSIDYCLS,
    new$TRANSFERTCLS,
    new$PAYPROMISECLS,
    new$BUDALLOCATIONCLS);

END;
/
-- ALTER TRIGGER TR_Requests_BU_120
CREATE OR REPLACE TRIGGER TR_REQUESTS_IU
  INSTEAD OF UPDATE
  ON REQUESTS
  FOR EACH ROW
DECLARE
  new$ID REQUESTS.ID%TYPE := :NEW.ID;
  new$BUDGET REQUESTS.BUDGET%TYPE := :NEW.BUDGET;
  new$KFSR REQUESTS.KFSR%TYPE := :NEW.KFSR;
  new$KVSR REQUESTS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR REQUESTS.KCSR%TYPE := :NEW.KCSR;
  new$KVR REQUESTS.KVR%TYPE := :NEW.KVR;
  new$KESR REQUESTS.KESR%TYPE := :NEW.KESR;
  new$SUBKESR REQUESTS.SUBKESR%TYPE := :NEW.SUBKESR;
  new$USERNOTE REQUESTS.USERNOTE%TYPE := :NEW.USERNOTE;
  new$FACIALACC_CLS REQUESTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$SOURCEACCOUNT REQUESTS.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$DESTACCOUNT REQUESTS.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$FACT REQUESTS.FACT%TYPE := :NEW.FACT;
  new$FINSOURCE REQUESTS.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE REQUESTS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$REGIONCLS REQUESTS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$BUHPAYMENTCLS REQUESTS.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$DOCTYPE REQUESTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$PAYDATE REQUESTS.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYPRIORITY REQUESTS.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$SUMMAREQUESTED REQUESTS.SUMMAREQUESTED%TYPE := :NEW.SUMMAREQUESTED;
  new$SUMMATOFINANCE REQUESTS.SUMMATOFINANCE%TYPE := :NEW.SUMMATOFINANCE;
  new$REQUESTTYPE REQUESTS.REQUESTTYPE%TYPE := :NEW.REQUESTTYPE;
  new$MEANSTYPE REQUESTS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYSYMBOLCLS REQUESTS.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$CREATERUSER REQUESTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE REQUESTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER REQUESTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE REQUESTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$ANUMBER REQUESTS.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PROMISE REQUESTS.PROMISE%TYPE := :NEW.PROMISE;
  new$DOCUMENTBASETYPE REQUESTS.DOCUMENTBASETYPE%TYPE := :NEW.DOCUMENTBASETYPE;
  new$INPUTDATE REQUESTS.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$DFACCOUNT REQUESTS.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$PROGINDEX REQUESTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$PROGINDEX2 REQUESTS.PROGINDEX2%TYPE := :NEW.PROGINDEX2;
  new$RECORDINDEX REQUESTS.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$INNERFINSOURCE REQUESTS.INNERFINSOURCE%TYPE := :NEW.INNERFINSOURCE;
  new$OUTERFINSOURCE REQUESTS.OUTERFINSOURCE%TYPE := :NEW.OUTERFINSOURCE;
  new$KD REQUESTS.KD%TYPE := :NEW.KD;
  new$SUBKD REQUESTS.SUBKD%TYPE := :NEW.SUBKD;
  new$PLANDATE REQUESTS.PLANDATE%TYPE := :NEW.PLANDATE;
  new$CURRENCYCLS REQUESTS.CURRENCYCLS%TYPE := :NEW.CURRENCYCLS;
  new$REQUESTSDOCSTATE REQUESTS.REQUESTSDOCSTATE%TYPE := :NEW.REQUESTSDOCSTATE;
  new$TAXNOTE REQUESTS.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$GOSNI REQUESTS.GOSNI%TYPE := :NEW.GOSNI;
  new$CURRENCYSUMMA REQUESTS.CURRENCYSUMMA%TYPE := :NEW.CURRENCYSUMMA;
  new$RVERSION REQUESTS.RVERSION%TYPE := :NEW.RVERSION;
  new$DIRECTIONCLS REQUESTS.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$DOCSTATEREF REQUESTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS REQUESTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$FEDERALFUNDSREF REQUESTS.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS REQUESTS.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS_CORR REQUESTS.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE REQUESTS.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$REESTRDATE REQUESTS.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$AMONTH REQUESTS.AMONTH%TYPE := :NEW.AMONTH;
  new$AYEAR REQUESTS.AYEAR%TYPE := :NEW.AYEAR;
  new$EXECSUMMA REQUESTS.EXECSUMMA%TYPE := :NEW.EXECSUMMA;
  new$SUBSIDYCLS REQUESTS.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$TRANSFERTCLS REQUESTS.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$PAYPROMISECLS REQUESTS.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$BUDALLOCATIONCLS REQUESTS.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (CHECK_PROMISE_REF_UP)
-- - - - - - - - - - - - -

  SELECT count(REGISTRNUMBER) into CNT$
  FROM promise_detail pd
  WHERE (pd.REGISTRNUMBER=NEW$PROMISE)and(pd.CloseDate is null) AND (ROWNUM=1);

  IF (CNT$ = 0) AND (NOT NEW$PROMISE IS NULL) THEN
    RaiseException('EX_PROMISEN_NOT_EXIST');
  end if;

-- - - - - - - - - - - - -
-- BU_0 (TR_REQUESTS_BU)
-- Last update 20.10.2009
-- - - - - - - - - - - - -

  IF (NEW$KFSR IS NULL) THEN NEW$KFSR := 0; END IF;
  IF (NEW$KVSR IS NULL) THEN NEW$KVSR := 0; END IF;
  IF (NEW$KCSR IS NULL) THEN NEW$KCSR := 0; END IF;
  IF (NEW$KVR IS NULL) THEN NEW$KVR := 0; END IF;
  IF (NEW$KESR IS NULL) THEN NEW$KESR := 0; END IF;
  if (NEW$SubKesr is null) then NEW$SubKESR := 0; end if;

  IF (NEW$DirectionCls IS NULL) THEN NEW$DirectionCls := 0; END IF;

  IF (NEW$SummaRequested IS NULL) THEN NEW$SummaRequested := 0; END IF;
  IF (NEW$DocType IS NULL) THEN NEW$DocType := 0; END IF;
  IF (NEW$MeansType IS NULL) THEN NEW$MeansType := 0; END IF;
  IF (NEW$Fact IS NULL) THEN NEW$Fact := 0; END IF;
  IF (NEW$InnerFinSource IS NULL) THEN NEW$InnerFinSource := 0; END IF;
  IF (NEW$OuterFinSource IS NULL) THEN NEW$OuterFinSource := 0; END IF;
  IF (NEW$KD IS NULL) THEN NEW$KD := 0; END IF;
  IF (NEW$SubKD IS NULL) THEN NEW$SubKD := 0; END IF;
  if (NEW$ExecSumma is null) then NEW$ExecSumma := 0;  end if;
  /*     -  */
  IF (NEW$ProgIndex IS NULL) THEN NEW$ProgIndex := 221; END IF;
  /*      -   ""*/
  IF (NEW$CurrencyCLS IS NULL) THEN GetIntConst (19, 4, NEW$CurrencyCLS); END IF;
  IF (NEW$REQUESTSDOCSTATE IS NULL) THEN NEW$REQUESTSDOCSTATE := 2; END IF;
  IF (NEW$GOSNI IS NULL) THEN NEW$GOSNI := 0; END IF;

  /*    .        */
  if (NEW$IFS_CORR is null) then NEW$Ifs_Corr := 0; end if;
  if (NEW$BuhOperationCLS is null) then GetIntConst(60, 15, NEW$BuhOperationCLS); end if;

-- - - - - - - - - - - - -
-- BU_10 (TR_REQUESTS_BU_10)
-- Last update 15.09.2005
-- - - - - - - - - - - - -

   /*       - */
   /*       -    */
  IF (NEW$ProgIndex = 222) THEN
    IF ( (NEW$SOURCEACCOUNT IS NULL) AND (NEW$DESTACCOUNT IS NOT NULL) ) THEN
      NEW$SOURCEACCOUNT := NEW$DESTACCOUNT;
    ELSE
      IF ( (NEW$SOURCEACCOUNT IS NOT NULL) AND (NEW$DESTACCOUNT IS NULL) ) THEN
        NEW$DESTACCOUNT := NEW$SOURCEACCOUNT;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_REQUESTS_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$INNERFINSOURCE <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  /*    ,     */
  if (new$ClsType <> :old.ClsType) then
    if (new$ClsType = 0) then
      new$KD := 0;
      new$INNERFINSOURCE := 0;
          
    END IF;
    if (new$ClsType = 1) then
      new$KD := 0;
      new$KVSR := 0;
      new$KFSR := 0;
      new$KCSR := 0;
      new$KVR := 0;
          
    END IF;
    if (new$ClsType = 2) then
      new$KVSR := 0;
      new$KFSR := 0;
      new$KCSR := 0;
      new$KVR := 0;
      new$INNERFINSOURCE := 0;
      
    END IF;
  END IF;
  IF (((new$ClsType = 0)or((new$ClsType = 2))) AND (new$INNERFINSOURCE <> 0)) THEN
    /*  ,     */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF (((new$ClsType = 1)or(new$ClsType = 2)) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0))) THEN
    /*  ,     */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF (((new$ClsType = 0)or((new$ClsType = 1))) AND (new$KD <> 0)) THEN
    /*  ,     */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_REQUESTS_BU_200)
-- Last update 15.09.2005
-- - - - - - - - - - - - -

  /*      */
  if (:old.DOCSTATEREF <> NEW$DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      values(NEW$id, :old.DOCSTATEREF, NEW$DOCSTATEREF);
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_REQUESTS_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (NEW$RVersion IS NULL) THEN
    NEW$RVersion := 1;
  ELSIF ( (NEW$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    NEW$RVersion := :OLD.RVersion;
  ELSE
    NEW$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_REQUESTS SET
    ID = new$ID,
    BUDGET = new$BUDGET,
    KFSR = new$KFSR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    SUBKESR = new$SUBKESR,
    USERNOTE = new$USERNOTE,
    FACIALACC_CLS = new$FACIALACC_CLS,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    DESTACCOUNT = new$DESTACCOUNT,
    FACT = new$FACT,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    REGIONCLS = new$REGIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    DOCTYPE = new$DOCTYPE,
    PAYDATE = new$PAYDATE,
    PAYPRIORITY = new$PAYPRIORITY,
    SUMMAREQUESTED = new$SUMMAREQUESTED,
    SUMMATOFINANCE = new$SUMMATOFINANCE,
    REQUESTTYPE = new$REQUESTTYPE,
    MEANSTYPE = new$MEANSTYPE,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    ANUMBER = new$ANUMBER,
    PROMISE = new$PROMISE,
    DOCUMENTBASETYPE = new$DOCUMENTBASETYPE,
    INPUTDATE = new$INPUTDATE,
    DFACCOUNT = new$DFACCOUNT,
    PROGINDEX = new$PROGINDEX,
    PROGINDEX2 = new$PROGINDEX2,
    RECORDINDEX = new$RECORDINDEX,
    INNERFINSOURCE = new$INNERFINSOURCE,
    OUTERFINSOURCE = new$OUTERFINSOURCE,
    KD = new$KD,
    SUBKD = new$SUBKD,
    PLANDATE = new$PLANDATE,
    CURRENCYCLS = new$CURRENCYCLS,
    REQUESTSDOCSTATE = new$REQUESTSDOCSTATE,
    TAXNOTE = new$TAXNOTE,
    GOSNI = new$GOSNI,
    CURRENCYSUMMA = new$CURRENCYSUMMA,
    RVERSION = new$RVERSION,
    DIRECTIONCLS = new$DIRECTIONCLS,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    REESTRDATE = new$REESTRDATE,
    AMONTH = new$AMONTH,
    AYEAR = new$AYEAR,
    EXECSUMMA = new$EXECSUMMA,
    SUBSIDYCLS = new$SUBSIDYCLS,
    TRANSFERTCLS = new$TRANSFERTCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS
  WHERE ID = :OLD.ID;

END;
/
-- ALTER TRIGGER TR_CorrectionDetail_BI_120
CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_II
  INSTEAD OF INSERT
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  vOperationTypeS1$ NUMBER(10);
  vOperationTypeD1$ NUMBER(10);
  vOperationType1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_CORRECTIONDETAIL_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;  
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS1$, vOperationTypeD1$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType1$ := vOperationTypeS1$;
          
    ELSE 
      vOperationType1$ := vOperationTypeD1$;
    END IF;
    new$OperationType := vOperationType1$;
      
  END IF;
  BEGIN

    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN FacialAcc_Cls fac  ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_100 (tr_correctiondetail_bi_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$progindex = 316) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_CORRECTIONDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
            
    else
      if (new$ClsType is null)
      then 
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_CORRECTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (new$Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null) and (new$BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
    /*    ,   ,   */
    if ((new$BudgetPromise is not null) and (new$Promise is null)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_CORRECTIONDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$ExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_CORRECTIONDETAIL_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update CorrectionCaption set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CORRECTIONDETAIL (
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME
  ) VALUES (
    new$ID,
    new$PARENTID,
    new$BUDGETREF,
    new$SUMMA,
    new$CLSTYPE,
    new$FACIALACC_CLS,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$DIRECTIONCLS,
    new$MEANSTYPE,
    new$FACT,
    new$REGIONCLS,
    new$FINSOURCE,
    new$FINTYPE,
    new$DOCTYPE,
    new$SUBKESR,
    new$FUNDSSOURCE,
    new$KD,
    new$IFS,
    new$BUHOPERATIONCLS,
    new$CHANGEACC_REF,
    new$CHANGEACC,
    new$CHANGEORGINN,
    new$CHANGEORGINN20,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$DOCUMENTPROGINDEX,
    new$DOCUMENTRECORDINDEX,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SENDERID,
    new$SENDERRECORDID,
    new$RVERSION,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$NOTE,
    new$ISCLSCHANGED,
    new$PROMISE,
    new$BUDGETPROMISE,
    new$EXECDOC,
    new$OKATO,
    new$ADDOKATO,
    new$TRANSFERTCLS,
    new$ORIGINALCLSSUMMA,
    new$NOTECLS,
    new$OPERATIONTYPE,
    new$REVERSEFLAG,
    new$EXECINNERNUMBER,
    new$CLSFIELFCHANGED,
    new$FAORGTYPE,
    new$SUBSIDYCLS,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$NOTEQUALEX,
    new$OKTMO,
    new$UINCODE,
    new$INVESTOBJECT,
    new$CHANGEORGNAME);

-- - - - - - - - - - - - -
-- AI_500 (TR_CORRECTIONDETAIL_AI_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

 delete from DelRecIndexes where (TableID =5504 ) and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER TR_CorrectionDetail_BU_120
CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_IU
  INSTEAD OF UPDATE
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  AccRef_Caption$ NUMBER(10);
  vOperationTypeS$ NUMBER(10);
  vOperationTypeD$ NUMBER(10);
  vOperationType$ NUMBER(10);
  AccRef$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_CORRECTIONDETAIL_BU)
-- Version 7.01.00.2
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS$, vOperationTypeD$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType$ := vOperationTypeS$;
          
    ELSE 
      vOperationType$ := vOperationTypeD$;
    END IF;
    new$OperationType := vOperationType$;
      
  END IF;
  /*         ,        */
  if (
  ((not new$changeacc is null) and (new$changeacc <> '')) 
  and 
  ((:old.changeacc <> new$changeacc) or (:old.changeacc is null))
  and 
  ((new$changeacc_ref = :old.changeacc_ref) or (new$changeacc_ref is null))
  )
  THEN
    BEGIN
      SELECT cor_c.OriginalAcceptorAcc_Ref
      INTO AccRef_Caption$     FROM correctioncaption cor_c
      LEFT JOIN CorrectionDetail cor_d ON ((cor_c.Id = cor_d.RecordIndex) AND (cor_d.ProgIndex = 316))
      WHERE cor_d.id = :old.id
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (NOT AccRef_Caption$ IS NULL) THEN
      new$changeacc_ref := AccRef_Caption$;
          
    ELSE
      BEGIN
        SELECT dfat.id
        INTO AccRef$       FROM dfAccountsBuhTable dfat
        LEFT JOIN Org_Accounts oa ON (dfat.id =  oa.id)
        WHERE (oa.acc = new$changeacc) AND (dfat.iscommon = 1) AND (dfat.isforbudget = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (NOT AccRef$ IS NULL) THEN
        new$changeacc_ref := AccRef$;
          
      END IF;  
    END IF;
  END IF;
  /*     \*/
  IF ((new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType IS NULL)) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  ON (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (tr_correctiondetail_bu_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$buhoperationcls <> :old.buhoperationcls) and (new$progindex = 316)) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_CORRECTIONDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
            
    else
      if (new$ClsType is null)
      then 
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_CORRECTIONDETAIL_BU_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise )) and 
    (new$BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
        
    /*    ,   */
    if (((new$BudgetPromise is not null) and (:old.BudgetPromise is null)) or 
    (new$BudgetPromise <> :old.BudgetPromise)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
          
    END IF;
        
    /*    ,     */
    if ((new$BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      new$Promise := null;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_CORRECTIONDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null and (
    (:old.Promise is null or :old.Promise <> new$Promise) or
    (:old.ExecDoc is null or new$ExecDoc is null or :old.ExecDoc <> new$ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$ExecDoc is null or :old.ExecDoc is null or new$ExecDoc <> :old.ExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_CORRECTIONDETAIL_BU_700)
-- Create 13.08.2007
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 else
   if ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
     new$RVersion:=:Old.RVersion;
   else
     new$RVersion:=:Old.RVersion+1;
   end if;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CORRECTIONDETAIL SET
    ID = new$ID,
    PARENTID = new$PARENTID,
    BUDGETREF = new$BUDGETREF,
    SUMMA = new$SUMMA,
    CLSTYPE = new$CLSTYPE,
    FACIALACC_CLS = new$FACIALACC_CLS,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    FACT = new$FACT,
    REGIONCLS = new$REGIONCLS,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    DOCTYPE = new$DOCTYPE,
    SUBKESR = new$SUBKESR,
    FUNDSSOURCE = new$FUNDSSOURCE,
    KD = new$KD,
    IFS = new$IFS,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CHANGEACC_REF = new$CHANGEACC_REF,
    CHANGEACC = new$CHANGEACC,
    CHANGEORGINN = new$CHANGEORGINN,
    CHANGEORGINN20 = new$CHANGEORGINN20,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    DOCUMENTPROGINDEX = new$DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX = new$DOCUMENTRECORDINDEX,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    RVERSION = new$RVERSION,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    NOTE = new$NOTE,
    ISCLSCHANGED = new$ISCLSCHANGED,
    PROMISE = new$PROMISE,
    BUDGETPROMISE = new$BUDGETPROMISE,
    EXECDOC = new$EXECDOC,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    TRANSFERTCLS = new$TRANSFERTCLS,
    ORIGINALCLSSUMMA = new$ORIGINALCLSSUMMA,
    NOTECLS = new$NOTECLS,
    OPERATIONTYPE = new$OPERATIONTYPE,
    REVERSEFLAG = new$REVERSEFLAG,
    EXECINNERNUMBER = new$EXECINNERNUMBER,
    CLSFIELFCHANGED = new$CLSFIELFCHANGED,
    FAORGTYPE = new$FAORGTYPE,
    SUBSIDYCLS = new$SUBSIDYCLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    NOTEQUALEX = new$NOTEQUALEX,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    INVESTOBJECT = new$INVESTOBJECT,
    CHANGEORGNAME = new$CHANGEORGNAME
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_CORRECTIONDETAIL_AU_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5504, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5504) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_BudNotify_AU_300
CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_IU
  INSTEAD OF UPDATE
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
--
  IsReject$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDNOTIFY_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$NotifyType is null) then 
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then 
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then 
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then 
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;
      
  else
    if (new$PlanDocType > 199) then
      new$AType := 1;
    END IF;
  END IF;
  if (new$PlanDocType is null) then
    if (new$AType = 1) then
      new$PlanDocType := 200;
          
    else
      new$PlanDocType := 100;
      
    END IF;
  END IF;
  /*    */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)              into DetCount$ from BudgetData where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then 
        RaiseException('Ex_CantModufyBudget');        
      END IF;
    END IF;
  END IF;
  if (new$FacialAccCls is null) then 
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then 
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then 
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> :old.FacialAccCLS)
  and(new$FacialAccCLS <> 0)) then
    BEGIN
      /*     -    \   
             - \  ,
           ,   \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*        */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDNOTIFY_BU_200)
-- Create 08.02.2005
-- - - - - - - - - - - - -

   --     
  IF (:OLD.DOCSTATEREF <> NEW$DOCSTATEREF) THEN
    INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      VALUES (NEW$ID, :OLD.DOCSTATEREF, NEW$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_BUDNOTIFY_BU_300)
-- Create 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from BudgetData d where d.RecordIndex = :new.id));
  end if;    

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDNOTIFY_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (NEW$RVersion IS NULL) THEN
    NEW$RVersion := 1;
  ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
    NEW$RVersion := :OLD.RVersion;
  ELSE
    NEW$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BUDNOTIFY SET
    ID = new$ID,
    DAT = new$DAT,
    DOCDAT = new$DOCDAT,
    NOTE1 = new$NOTE1,
    NOTIFYTYPE = new$NOTIFYTYPE,
    BUDGETREF = new$BUDGETREF,
    DOCBASE = new$DOCBASE,
    VARIANT = new$VARIANT,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    ANUMBER = new$ANUMBER,
    ATYPE = new$ATYPE,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    DATEINPUT = new$DATEINPUT,
    ORGREF = new$ORGREF,
    REJECTCLS = new$REJECTCLS,
    REJECTNOTE = new$REJECTNOTE,
    PLANDOCTYPE = new$PLANDOCTYPE,
    RECORDINDEX = new$RECORDINDEX,
    STIMATEID = new$STIMATEID,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    RVERSION = new$RVERSION,
    DOCSTATEREF = new$DOCSTATEREF,
    DOCNUMBER = new$DOCNUMBER,
    FACIALACCCLS = new$FACIALACCCLS,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    PLANKIND = new$PLANKIND,
    ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE,
    BA_LBO_FLAG = new$BA_LBO_FLAG,
    KPPERIOD = new$KPPERIOD,
    CLSTYPE = new$CLSTYPE,
    DATE_UTV_PP = new$DATE_UTV_PP,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    NOTE2 = new$NOTE2,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    SIGNERS = new$SIGNERS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXTID = new$EXTID,
    EXTROOTID = new$EXTROOTID
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_300 (TR_BudNotify_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType <> :old.ClsType)and(new$ClsType <> 3)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update BudgetData set
      KD = 0,
      IFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update BudgetData set
      KD = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update BudgetData set
      IFS = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
      
    END IF;
  END IF;
  if ((new$ProgIndex in (252, 253))and(new$FacialAccCLS <> :old.FacialAccCLS)) then
    update BudgetData set
    facialacc_cls = new$FacialAccCLS
    where
    RecordIndex = new$id;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUDNOTIFY_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (NEW$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (28, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=28) and (RecordId=NEW$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_UNIONNOTIFYDETAIL_BI_120
CREATE OR REPLACE TRIGGER TR_UNIONNOTIFYDETAIL_BI
  BEFORE INSERT
  ON UNIONNOTIFYDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_UNIONNOTIFYDETAIL_BI)
-- Version 10.00.00.3
-- - - - - - - - - - - - -

  IF (:new.ID IS NULL) THEN
    select g_shared.nextval into :new.ID from dual;
  END IF;
  if (:new.kesr is null) then
    :new.kesr := 0;
  END IF;
  if (:new.kvsr is null) then
    :new.kvsr := 0;
  END IF;
  if (:new.kcsr is null) then
    :new.kcsr := 0;
  END IF;
  if (:new.kfsr is null) then
    :new.kfsr := 0;
  END IF;
  if (:new.kvr is null) then
    :new.kvr := 0;
  END IF;
  if (:new.ifs is null) then
    :new.ifs := 0;
  END IF;
  if (:new.ActivityKind is null) then
    :new.ActivityKind := 0;
  END IF;
  if (:new.Fact is null) then
    :new.Fact := 0;
  END IF;
  if (:new.MeansType is null) then
    :new.MeansType := 0;
  END IF;
  if (:new.DirectionCLS is null) then
    :new.DirectionCLS := 0;
  END IF;
  if (:new.RegionCLS is null) then
    :new.RegionCLS := 0;
  END IF;
  if (:new.SubKESR is null) then
    :new.SubKESR := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN
    :new.FinType := 0;
  END IF;
  if (:new.summalimit is null) then
    :new.summalimit := 0;
  END IF;
  if (:new.summaassignment is null) then
    :new.summaassignment := 0;
  END IF;
  if (:new.summafin is null) then
    :new.summafin := 0;
  END IF;
  if (:new.SummaLimitYear is null) then
    :new.SummaLimitYear := 0;
  END IF;
  if (:new.SummaAssignmentYear is null) then
    :new.SummaAssignmentYear := 0;
  END IF;
  if (:new.SummaFinYear is null) then
    :new.SummaFinYear := 0;
  END IF;
  if (:new.SummaYear1 is null) then
    :new.SummaYear1 := 0;
  END IF;
  if (:new.SummaYear2 is null) then
    :new.SummaYear2 := 0;
  END IF;
  if (:new.SummaYear3 is null) then
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0;
  END IF;
  if (:new.BA_LBO_Flag is null) then
    :new.BA_LBO_Flag := 0;
  END IF;
  if (:new.BuhOperationCLS is null) then
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  if (:new.ClsType is null) then
    BEGIN
      select
      c.ClsType
      into :new.ClsType     from
      UnionNotifyCaption c
      where
      (c.id = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_UNIONNOTIFYDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is null) then
    if (:new.IFS <> 0) then
      :new.ClsType := 1;
          
    else
      :new.ClsType := 0;
      
    END IF;
  END IF;
  if ((:new.ClsType = 0)and(:new.IFS <> 0)) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if ((:new.ClsType = 1)and((:new.KVSR <> 0)or(:new.KCSR <> 0)or(:new.KVR <> 0)or
  (:new.KFSR <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_UNIONNOTIFYDETAIL_BI_500)
-- Create 15.02.2006
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
-- ALTER TRIGGER TR_UNIONNOTIFYDETAIL_BU_120
CREATE OR REPLACE TRIGGER TR_UNIONNOTIFYDETAIL_BU
  BEFORE UPDATE
  ON UNIONNOTIFYDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_UNIONNOTIFYDETAIL_BU)
-- Version 10.00.00.3
-- - - - - - - - - - - - -

  if (:new.kesr is null) then
    :new.kesr := 0;
  END IF;
  if (:new.kvsr is null) then
    :new.kvsr := 0;
  END IF;
  if (:new.kcsr is null) then
    :new.kcsr := 0;
  END IF;
  if (:new.kfsr is null) then
    :new.kfsr := 0;
  END IF;
  if (:new.kvr is null) then
    :new.kvr := 0;
  END IF;
  if (:new.ifs is null) then
    :new.ifs := 0;
  END IF;
  if (:new.ActivityKind is null) then
    :new.ActivityKind := 0;
  END IF;
  if (:new.Fact is null) then
    :new.Fact := 0;
  END IF;
  if (:new.MeansType is null) then
    :new.MeansType := 0;
  END IF;
  if (:new.DirectionCLS is null) then
    :new.DirectionCLS := 0;
  END IF;
  if (:new.RegionCLS is null) then
    :new.RegionCLS := 0;
  END IF;
  if (:new.SubKESR is null) then
    :new.SubKESR := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN
    :new.FinType := 0;
  END IF;
  if (:new.summalimit is null) then
    :new.summalimit := 0;
  END IF;
  if (:new.summaassignment is null) then
    :new.summaassignment := 0;
  END IF;
  if (:new.summafin is null) then
    :new.summafin := 0;
  END IF;
  if (:new.SummaLimitYear is null) then
    :new.SummaLimitYear := 0;
  END IF;
  if (:new.SummaAssignmentYear is null) then
    :new.SummaAssignmentYear := 0;
  END IF;
  if (:new.SummaFinYear is null) then
    :new.SummaFinYear := 0;
  END IF;
  if (:new.SummaYear1 is null) then
    :new.SummaYear1 := 0;
  END IF;
  if (:new.SummaYear2 is null) then
    :new.SummaYear2 := 0;
  END IF;
  if (:new.SummaYear3 is null) then
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0;
  END IF;
  if (:new.BA_LBO_Flag is null) then
    :new.BA_LBO_Flag := 0;
  END IF;
  if (:new.BuhOperationCLS is null) then
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_UNIONNOTIFYDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is null) then
    if (:new.IFS <> 0) then
      :new.ClsType := 1;
          
    else
      :new.ClsType := 0;
      
    END IF;
  END IF;
  if ((:new.ClsType = 0)and(:new.IFS <> 0)) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if ((:new.ClsType = 1)and((:new.KVSR <> 0)or(:new.KCSR <> 0)or(:new.KVR <> 0)or
  (:new.KFSR <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_UNIONNOTIFYDETAIL_BU_700)
-- Create 15.02.2006
-- - - - - - - - - - - - -

  if (:New.RVersion is null) then
    :New.RVersion := 1;
  elsif ((:New.RVersion = -1) and (:Old.RVersion <> -1)) then
    :New.RVersion := :Old.RVersion;
  else
    :New.RVersion := :Old.RVersion + 1;
  end if;

END;
/
-- ALTER TRIGGER tr_orgoperat_bu_100
CREATE OR REPLACE TRIGGER ORGOPERAT_BU
  BEFORE UPDATE
  ON ORGOPERAT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_10 (TR_ORGOPERAT_BU_10)
-- Last update 28.09.2004
-- - - - - - - - - - - - -

  if (:new.KFSR is null) then :new.KFSR := 0; end if;
  if (:new.KVSR is null) then :new.KVSR := 0; end if;
  if (:new.KVR is null) then :new.KVR := 0; end if;
  if (:new.KCSR is null) then :new.KCSR := 0; end if;
  if (:new.SubKCSR is null) then :new.SubKCSR := 0; end if;
  if (:new.SubKESR is null) then :new.SubKESR := 0; end if;
  if (:new.DirectionCls is null) then :new.DirectionCls := 0; end if;
  if (:new.KESR is null) then :new.KESR := 0; end if;
  if (:new.RegionCLS is null) then :new.RegionCLS := 0; end if;
  if (:new.GroupInf is null) then :new.GroupInf := 0; end if;
  if (:new.FinSource is null) then :new.FinSource := 0; end if;
  if (:new.FinType is null) then :new.FinType := 0; end if;
  if (:new.MeansType is null) then :new.MeansType := 0; end if;
  if (:new.YearReport is null) then :new.YearReport := 0; end if;
  if (:new.MonthReport is null) then :new.MonthReport := 0; end if;
  if (:new.Quarter1 is null) then :new.Quarter1 := 0; end if;
  if (:new.Quarter2 is null) then :new.Quarter2 := 0; end if;
  if (:new.Quarter3 is null) then :new.Quarter3 := 0; end if;
  if (:new.Quarter4 is null) then :new.Quarter4 := 0; end if;
  if (:new.Summa is null) then :new.Summa := 0; end if;
  if (:new.Summa1 is null) then :new.Summa1 := 0; end if;
  if (:new.FacialAcc_Cls is null) then :new.FacialAcc_Cls := 0; end if;
  if (:new.Fact is null) then :new.Fact := 0; end if;
  if (:new.IFS is null) then :new.IFS := 0; end if;

-- - - - - - - - - - - - -
-- BU_100 (tr_orgoperat_bu_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*     ,  
         */
  if ((:new.ClsType is null) and (:new.IFS <> 0)) then
    :new.ClsType := 1; /*    -  */
      
  else
    if (:new.ClsType is null) then
      :new.ClsType := 0;/*   */
    END IF;
  END IF;
  /*    - ,    */
  if ((:new.ClsType = 0) and (:new.IFS <> 0)) then
    RaiseException('ex_wrongbudcls');
  END IF;
  /*    - ,     */
  if ((:new.ClsType = 1) and (
  (:new.KVSR <> 0) or (:new.KFSR <> 0) or
  (:new.KCSR <> 0) or (:new.KVR <> 0))) then
    RaiseException('ex_wrongbudcls');
  END IF;

END;
/
-- ALTER TRIGGER tr_orgoperat_bi_100
CREATE OR REPLACE TRIGGER ORGOPERAT_BI
  BEFORE INSERT
  ON ORGOPERAT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ORGOPERAT_BI)
-- Last update 28.09.2004
-- - - - - - - - - - - - -

        if (:new.ID is null) then select g_Shared.NextVal into :new.ID from dual; end if;
        if (:new.KFSR is null) then :new.KFSR := 0; end if;
        if (:new.KVSR is null) then :new.KVSR := 0; end if;
        if (:new.KVR is null) then :new.KVR := 0; end if;
        if (:new.KCSR is null) then :new.KCSR := 0; end if;
    if (:new.SubKCSR is null) then :new.SubKCSR := 0; end if;
        if (:new.SubKESR is null) then :new.SubKESR := 0; end if;
        if (:new.DirectionCls is null) then :new.DirectionCls := 0; end if;
        if (:new.KESR is null) then :new.KESR := 0; end if;
        if (:new.RegionCLS is null) then :new.RegionCLS := 0; end if;
        if (:new.GroupInf is null) then :new.GroupInf := 0; end if;
        if (:new.FinSource is null) then :new.FinSource := 0; end if;
        if (:new.FinType is null) then :new.FinType := 0; end if;
        if (:new.MeansType is null) then :new.MeansType := 0; end if;
        if (:new.YearReport is null) then :new.YearReport := 0; end if;
        if (:new.MonthReport is null) then :new.MonthReport := 0; end if;
        if (:new.Quarter1 is null) then :new.Quarter1 := 0; end if;
        if (:new.Quarter2 is null) then :new.Quarter2 := 0; end if;
        if (:new.Quarter3 is null) then :new.Quarter3 := 0; end if;
        if (:new.Quarter4 is null) then :new.Quarter4 := 0; end if;
        if (:new.Summa is null) then :new.Summa := 0; end if;
        if (:new.Summa1 is null) then :new.Summa1 := 0; end if;
        if (:new.FacialAcc_Cls is null) then :new.FacialAcc_Cls := 0; end if;
        if (:new.Fact is null) then :new.Fact := 0; end if;
        if (:new.IFS is null) then :new.IFS := 0; end if;

-- - - - - - - - - - - - -
-- BI_100 (tr_orgoperat_bi_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*     ,  
         */
  if ((:new.ClsType is null) and (:new.IFS <> 0)) then
    :new.ClsType := 1; /*    -  */
      
  else
    if (:new.ClsType is null) then
      :new.ClsType := 0;/*   */
    END IF;
  END IF;
  /*    - ,    */
  if ((:new.ClsType = 0) and (:new.IFS <> 0)) then
    RaiseException('ex_wrongbudcls');
  END IF;
  /*    - ,     */
  if ((:new.ClsType = 1) and (
  (:new.KVSR <> 0) or (:new.KFSR <> 0) or
  (:new.KCSR <> 0) or (:new.KVR <> 0))) then
    RaiseException('ex_wrongbudcls');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (ORGOPERAT_BI_500)
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
-- ALTER TRIGGER TR_REPLCLSDETINFO_BI_120
CREATE OR REPLACE TRIGGER TR_REPLACEMENTCLSDETAILINFO_BI
  BEFORE INSERT
  ON REPLACEMENTCLSDETAILINFO
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_RepClsDetailInfo_BI)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_REPCLSDETINFO_BI_10)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    select 
    rep_c.BudgetRef
    into
    :new.BudgetRef   from 
    ReplacementClsCaption rep_c
    where
    rep_c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_120 (TR_REPLCLSDETINFO_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((:new.ClsType is NULL) and (:new.IFS <> 0)) then
    :new.ClsType := 1; 
      
  else
    if ((:new.ClsType is NULL) and (:new.KD <> 0)) then
      :new.ClsType := 2; 
          
    else
      if (:new.ClsType is null) then
        :new.ClsType := 0; 
      END IF;
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0) or (:new.KD <> 0)))THEN 
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (:new.ClsType = 1) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.KD <> 0)
  )) 
  THEN 
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType = 2) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.IFS <> 0)
  )) 
  THEN 
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_RepClsDetailInfo_BI_500)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_REPLCLSDETINFO_BU_120
CREATE OR REPLACE TRIGGER TR_REPLACEMENTCLSDETAILINFO_BU
  BEFORE UPDATE
  ON REPLACEMENTCLSDETAILINFO
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_RepClsDetailInfo_BU)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_REPLCLSDETINFO_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((:new.ClsType is NULL) and (:new.IFS <> 0)) then
    :new.ClsType := 1; 
      
  else
    if ((:new.ClsType is NULL) and (:new.KD <> 0)) then
      :new.ClsType := 2; 
          
    else
      if (:new.ClsType is null) then
        :new.ClsType := 0;
      END IF;
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0) or (:new.KD <> 0)))THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (:new.ClsType = 1) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.KD <> 0)
  )) 
  THEN 
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType = 2) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.IFS <> 0)
  )) 
  THEN 
    RaiseException('EX_WRONGBUDCLS');
  END IF;

END;
/
-- ALTER TRIGGER TR_WritExecutionDetail_BI_110
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONDETAIL_BI
  BEFORE INSERT
  ON WRITEXECUTIONDETAIL
  FOR EACH ROW
DECLARE
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  ScheduleRef1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_WRITEXECUTIONDETAIL_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.BudgetRef is null) then
    BEGIN
      select 
      writ_c.BudgetRef 
      into :new.BudgetRef     from 
      WritExecutionCaption writ_c
      where 
      writ_c.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
    
  if (:new.Progindex is null) then 
    :new.Progindex := 556;  
  END IF;
  if (:new.FacialAcc_Cls is null) then 
    :new.FacialAcc_Cls := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.RegionCLS is null) then 
    :new.RegionCLS := 0;
  END IF;
  if (:new.Finsource is null) then 
    :new.Finsource := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.DocType is null) then 
    :new.DocType := 0;
  END IF;
  if (:new.SubKesr is null) then 
    :new.SubKesr := 0;
  END IF;
    
  if (:new.Month01 IS NULL) then  
    :new.Month01 := 0;
  END IF;
  if (:new.Month02 IS NULL) then  
    :new.Month02 := 0;
  END IF;
  if (:new.Month03 IS NULL) then  
    :new.Month03 := 0;
  END IF;
  if (:new.Month04 IS NULL) then  
    :new.Month04 := 0;
  END IF;
  if (:new.Month05 IS NULL) then  
    :new.Month05 := 0;
  END IF;
  if (:new.Month06 IS NULL) then  
    :new.Month06 := 0;
  END IF;
  if (:new.Month07 IS NULL) then  
    :new.Month07 := 0;
  END IF;
  if (:new.Month08 IS NULL) then  
    :new.Month08 := 0;
  END IF;
  if (:new.Month09 IS NULL) then  
    :new.Month09 := 0;
  END IF;
  if (:new.Month10 IS NULL) then  
    :new.Month10 := 0;
  END IF;
  if (:new.Month11 IS NULL) then  
    :new.Month11 := 0;
  END IF;
  if (:new.Month12 IS NULL) then  
    :new.Month12 := 0;
  END IF;
    
  if (:new.Quarter1 IS NULL) then  
    :new.Quarter1 := 0;
  END IF;
  if (:new.Quarter2 IS NULL) then  
    :new.Quarter2 := 0;
  END IF;
  if (:new.Quarter3 IS NULL) then  
    :new.Quarter3 := 0;
  END IF;
  if (:new.Quarter4 IS NULL) then  
    :new.Quarter4 := 0;
  END IF;
    
  if (:new.WritExecutionSumma is Null) then 
    :new.WritExecutionSumma := 0; 
  END IF;
  if ((not :new.PROMISE is null) and (not :new.BUDGETPROMISE is null)) then
    BEGIN
      select ps.id     into ScheduleRef1$ from PaymentSchedule ps
      where (ps.InnerPromiseNum = :new.BUDGETPROMISE) and
      (ps.ANumber = :new.PROMISE)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (ScheduleRef1$ <> 0) then
    :new.PScheduleRef := ScheduleRef1$;
      
  else
    :new.PScheduleRef := null;
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_WritExecutionDetail_BI_110)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.KD is NULL) then 
    :new.KD := 0;
  END IF;
    
  if (:new.ClsType is NULL) then
    if (:new.KD <> 0) then
      :new.ClsType := 2; /*       ClsType */
          
    else
      :new.ClsType := 0;	
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND (:new.KD <> 0)) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_WRITEXECUTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (:new.Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = :new.PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((:new.Promise is not null) and (:new.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = :new.Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        :new.BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
    /*    ,   ,   */
    if ((:new.BudgetPromise is not null) and (:new.Promise is null)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = :new.BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      :new.Promise := BPInnerNum$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_WRITEXECUTIONDETAIL_BI_210)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (:new.Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = :new.Promise and ps.InnerPromiseNum = :new.BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_WRITEXECUTIONDETAIL_BI_500)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_WritExecutionDetail_BU_110
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONDETAIL_BU
  BEFORE UPDATE
  ON WRITEXECUTIONDETAIL
  FOR EACH ROW
DECLARE
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  ConstCheck1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  ScheduleRef1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_WRITEXECUTIONDETAIL_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (:new.BudgetRef is null) then
    BEGIN
      select 
      writ_c.BudgetRef 
      into :new.BudgetRef     from 
      WritExecutionCaption writ_c
      where 
      writ_c.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.Progindex is null) then 
    :new.Progindex := 556;    
  END IF;
  if (:new.FacialAcc_Cls is null) then 
    :new.FacialAcc_Cls := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.RegionCLS is null) then 
    :new.RegionCLS := 0;
  END IF;
  if (:new.Finsource is null) then 
    :new.Finsource := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.DocType is null) then 
    :new.DocType := 0;
  END IF;
  if (:new.SubKesr is null) then 
    :new.SubKesr := 0;
  END IF;
    
  if (:new.Month01 IS NULL) then  
    :new.Month01 := 0;
  END IF;
  if (:new.Month02 IS NULL) then  
    :new.Month02 := 0;
  END IF;
  if (:new.Month03 IS NULL) then  
    :new.Month03 := 0;
  END IF;
  if (:new.Month04 IS NULL) then  
    :new.Month04 := 0;
  END IF;
  if (:new.Month05 IS NULL) then  
    :new.Month05 := 0;
  END IF;
  if (:new.Month06 IS NULL) then  
    :new.Month06 := 0;
  END IF;
  if (:new.Month07 IS NULL) then  
    :new.Month07 := 0;
  END IF;
  if (:new.Month08 IS NULL) then  
    :new.Month08 := 0;
  END IF;
  if (:new.Month09 IS NULL) then  
    :new.Month09 := 0;
  END IF;
  if (:new.Month10 IS NULL) then  
    :new.Month10 := 0;
  END IF;
  if (:new.Month11 IS NULL) then  
    :new.Month11 := 0;
  END IF;
  if (:new.Month12 IS NULL) then  
    :new.Month12 := 0;
  END IF;
    
  if (:new.Quarter1 IS NULL) then  
    :new.Quarter1 := 0;
  END IF;
  if (:new.Quarter2 IS NULL) then  
    :new.Quarter2 := 0;
  END IF;
  if (:new.Quarter3 IS NULL) then  
    :new.Quarter3 := 0;
  END IF;
  if (:new.Quarter4 IS NULL) then  
    :new.Quarter4 := 0;
  END IF;
    
  if (:new.WritExecutionSumma is Null) then 
    :new.WritExecutionSumma := 0; 
  END IF;
  if ((not :new.PROMISE is null) and (not :new.BUDGETPROMISE is null)) then
    BEGIN
      select ps.id     into ScheduleRef1$ from PaymentSchedule ps
      where (ps.InnerPromiseNum = :new.BUDGETPROMISE) and
      (ps.ANumber = :new.PROMISE)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (ScheduleRef1$ <> 0) then
    :new.PScheduleRef := ScheduleRef1$;
      
  else
    :new.PScheduleRef := null;
    
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_WritExecutionDetail_BU_110)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.KD is NULL) then 
    :new.KD := 0;
  END IF;
  if (:new.ClsType is NULL) then
    if (:new.KD <> 0) then
      :new.ClsType := 2; /*       ClsType */
          
    else
      :new.ClsType := 0;	
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND (:new.KD <> 0)) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_WRITEXECUTIONDETAIL_BU_200)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  getintconst(30, 35,ConstCheck1$);
  /* ( )      ,    */
  if ((PromiseMode1$ <> 1) and (ConstCheck1$ = 1)) then
    if ((:new.Promise is not null)and((:old.Promise is null)or(:old.Promise <> :new.Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$        from
      promise_detail pr
      where
      (pr.registrnumber = :new.PROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode1$ = 1) then
    if ((:new.Promise is not null)and((:old.Promise is null)or(:old.Promise <> :new.Promise )) and 
    (:new.BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum1$       from 
      PaymentSchedule 
      where 
      (ANumber = :new.Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        :new.BudgetPromise := BPInnerNum1$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
        
    /*         NULL,    */
    if (:new.Promise is null and ((:new.BudgetPromise is not null and :old.BudgetPromise is null) or
    (:new.BudgetPromise <> :old.BudgetPromise))) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum1$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = :new.BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      :new.Promise := BPInnerNum1$;
          
    END IF;
        
    /*    ,     */
    if ((:new.BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      :new.Promise := null;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_WRITEXECUTIONDETAIL_BU_210)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (:new.Promise is not null and (
    (:old.Promise is null or :old.Promise <> :new.Promise) or
    (:old.ExecDoc is null or :new.ExecDoc is null or :old.ExecDoc <> :new.ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = :new.Promise and ps.InnerPromiseNum = :new.BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_WRITEXECUTIONDETAIL_BU_700)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  if (:new.RVersion is null) then
    :new.RVersion := 1;
  elsif ((:new.RVersion = -1) and (:old.RVersion <> -1)) then
    :new.RVersion := :old.RVersion;
  else
    :new.RVersion := :old.RVersion + 1;
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_Trigger_CORRECTIONDETAIL_BI.sql
-- #########################################################
-- #########################################################

INSERT INTO SqlExceptions(Name, Code, Text) VALUES ('EX_ORGANIZATION_UNKNOWN', -20358, '       ')
/
-- ALTER TRIGGER TR_CORRECTIONDETAIL_BI
CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_II
  INSTEAD OF INSERT
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  vOperationTypeS$ NUMBER(10);
  vOperationTypeD$ NUMBER(10);
  vOperationType$ NUMBER(10);
  AccRef$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_CORRECTIONDETAIL_BI)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;  
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS$, vOperationTypeD$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType$ := vOperationTypeS$;
          
    ELSE 
      vOperationType$ := vOperationTypeD$;
    END IF;
    new$OperationType := vOperationType$;
      
  END IF;
  BEGIN

    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN FacialAcc_Cls fac  ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  IF ((NOT new$ChangeACC IS NULL) and (new$ChangeACC <> '')) THEN
    SELECT MAX(oa.id)       INTO
    AccRef$ FROM Organizations org
    LEFT JOIN Org_Accounts oa ON (org.id =  oa.org_ref)
    WHERE
    (org.INN = new$ChangeOrgINN) AND (org.INN20 = new$ChangeOrgINN20)
    AND (oa.ACC = new$ChangeACC)
    ;
    IF (NOT AccRef$ IS NULL) THEN
      new$changeacc_ref := AccRef$;
          
    ELSE
      SELECT MAX(oa.id)         INTO
      AccRef$ FROM Organizations org
      LEFT JOIN Org_Accounts oa ON (org.id =  oa.org_ref)
      WHERE
      (org.INN = new$ChangeOrgINN) AND (oa.ACC = new$ChangeACC)
      ;
    END IF;
    IF (NOT AccRef$ IS NULL) THEN
      new$changeacc_ref := AccRef$;
          
    ELSE
      SELECT MAX(oa.id)         INTO
      AccRef$ FROM Organizations org
      LEFT JOIN Org_Accounts oa ON (org.id =  oa.org_ref)
      WHERE
      (oa.ACC = new$ChangeACC)
      ;
    END IF;
    IF (NOT AccRef$ IS NULL) THEN
      new$changeacc_ref := AccRef$;
          
    ELSE
      RaiseException('EX_ORGANIZATION_UNKNOWN');  
    END IF;
  ELSE
    BEGIN
      SELECT CorCap.OriginalAcceptorAcc_Ref
      INTO
      AccRef$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (NOT AccRef$ IS NULL) THEN
      new$changeacc_ref := AccRef$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (tr_correctiondetail_bi_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$progindex = 316) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_CORRECTIONDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
            
    else
      if (new$ClsType is null)
      then 
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_CORRECTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (new$Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null) and (new$BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
    /*    ,   ,   */
    if ((new$BudgetPromise is not null) and (new$Promise is null)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_CORRECTIONDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$ExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_CORRECTIONDETAIL_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update CorrectionCaption set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CORRECTIONDETAIL (
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME
  ) VALUES (
    new$ID,
    new$PARENTID,
    new$BUDGETREF,
    new$SUMMA,
    new$CLSTYPE,
    new$FACIALACC_CLS,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$DIRECTIONCLS,
    new$MEANSTYPE,
    new$FACT,
    new$REGIONCLS,
    new$FINSOURCE,
    new$FINTYPE,
    new$DOCTYPE,
    new$SUBKESR,
    new$FUNDSSOURCE,
    new$KD,
    new$IFS,
    new$BUHOPERATIONCLS,
    new$CHANGEACC_REF,
    new$CHANGEACC,
    new$CHANGEORGINN,
    new$CHANGEORGINN20,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$DOCUMENTPROGINDEX,
    new$DOCUMENTRECORDINDEX,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SENDERID,
    new$SENDERRECORDID,
    new$RVERSION,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$NOTE,
    new$ISCLSCHANGED,
    new$PROMISE,
    new$BUDGETPROMISE,
    new$EXECDOC,
    new$OKATO,
    new$ADDOKATO,
    new$TRANSFERTCLS,
    new$ORIGINALCLSSUMMA,
    new$NOTECLS,
    new$OPERATIONTYPE,
    new$REVERSEFLAG,
    new$EXECINNERNUMBER,
    new$CLSFIELFCHANGED,
    new$FAORGTYPE,
    new$SUBSIDYCLS,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$NOTEQUALEX,
    new$OKTMO,
    new$UINCODE,
    new$INVESTOBJECT,
    new$CHANGEORGNAME);

-- - - - - - - - - - - - -
-- AI_500 (TR_CORRECTIONDETAIL_AI_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

 delete from DelRecIndexes where (TableID =5504 ) and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER TR_CORRECTIONDETAIL_BU
CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_IU
  INSTEAD OF UPDATE
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  vOperationTypeS1$ NUMBER(10);
  vOperationTypeD1$ NUMBER(10);
  vOperationType1$ NUMBER(10);
  AccRef1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_CORRECTIONDETAIL_BU)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS1$, vOperationTypeD1$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType1$ := vOperationTypeS1$;
          
    ELSE 
      vOperationType1$ := vOperationTypeD1$;
    END IF;
    new$OperationType := vOperationType1$;
      
  END IF;
  /*         ,        */
  if (
  ((:old.ChangeORGINN20 <> new$ChangeORGINN20) or (:old.ChangeORGINN <> new$ChangeORGINN) or
  (:old.changeacc <> new$changeacc) or (:old.changeacc is null))
  and
  ((new$changeacc_ref = :old.changeacc_ref) or (new$changeacc_ref is null))
  )
  THEN
    IF ((NOT new$ChangeACC IS NULL) and (new$ChangeACC <> '')) THEN
      SELECT MAX(oa.id)         INTO
      AccRef1$ FROM Organizations org
      LEFT JOIN Org_Accounts oa ON (org.id =  oa.org_ref)
      WHERE
      (org.INN = new$ChangeOrgINN) AND (org.INN20 = new$ChangeOrgINN20)
      AND (oa.ACC = new$ChangeACC)
      ;
      IF (NOT AccRef1$ IS NULL) THEN
        new$changeacc_ref := AccRef1$;
              
      ELSE
        SELECT MAX(oa.id)           INTO
        AccRef1$ FROM Organizations org
        LEFT JOIN Org_Accounts oa ON (org.id =  oa.org_ref)
        WHERE
        (org.INN = new$ChangeOrgINN) AND (oa.ACC = new$ChangeACC)
        ;
      END IF;
      IF (NOT AccRef1$ IS NULL) THEN
        new$changeacc_ref := AccRef1$;
              
      ELSE
        SELECT MAX(oa.id)           INTO
        AccRef1$ FROM Organizations org
        LEFT JOIN Org_Accounts oa ON (org.id =  oa.org_ref)
        WHERE
        (oa.ACC = new$ChangeACC)
        ;
      END IF;
      IF (NOT AccRef1$ IS NULL) THEN
        new$changeacc_ref := AccRef1$;
              
      ELSE
        RaiseException('EX_ORGANIZATION_UNKNOWN');    
      END IF;
    ELSE
      BEGIN
        SELECT CorCap.OriginalAcceptorAcc_Ref
        INTO
        AccRef1$         FROM correctioncaption CorCap
        WHERE
        (CorCap.id = new$recordindex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (NOT AccRef1$ IS NULL) THEN
        new$changeacc_ref := AccRef1$;
          
      END IF;  
    END IF;
  END IF;
  /*     \*/
  IF ((new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType IS NULL)) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  ON (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (tr_correctiondetail_bu_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$buhoperationcls <> :old.buhoperationcls) and (new$progindex = 316)) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_CORRECTIONDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
            
    else
      if (new$ClsType is null)
      then 
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_CORRECTIONDETAIL_BU_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise )) and 
    (new$BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
        
    /*    ,   */
    if (((new$BudgetPromise is not null) and (:old.BudgetPromise is null)) or 
    (new$BudgetPromise <> :old.BudgetPromise)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
          
    END IF;
        
    /*    ,     */
    if ((new$BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      new$Promise := null;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_CORRECTIONDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null and (
    (:old.Promise is null or :old.Promise <> new$Promise) or
    (:old.ExecDoc is null or new$ExecDoc is null or :old.ExecDoc <> new$ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$ExecDoc is null or :old.ExecDoc is null or new$ExecDoc <> :old.ExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_CORRECTIONDETAIL_BU_700)
-- Create 13.08.2007
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 else
   if ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
     new$RVersion:=:Old.RVersion;
   else
     new$RVersion:=:Old.RVersion+1;
   end if;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CORRECTIONDETAIL SET
    ID = new$ID,
    PARENTID = new$PARENTID,
    BUDGETREF = new$BUDGETREF,
    SUMMA = new$SUMMA,
    CLSTYPE = new$CLSTYPE,
    FACIALACC_CLS = new$FACIALACC_CLS,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    FACT = new$FACT,
    REGIONCLS = new$REGIONCLS,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    DOCTYPE = new$DOCTYPE,
    SUBKESR = new$SUBKESR,
    FUNDSSOURCE = new$FUNDSSOURCE,
    KD = new$KD,
    IFS = new$IFS,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CHANGEACC_REF = new$CHANGEACC_REF,
    CHANGEACC = new$CHANGEACC,
    CHANGEORGINN = new$CHANGEORGINN,
    CHANGEORGINN20 = new$CHANGEORGINN20,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    DOCUMENTPROGINDEX = new$DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX = new$DOCUMENTRECORDINDEX,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    RVERSION = new$RVERSION,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    NOTE = new$NOTE,
    ISCLSCHANGED = new$ISCLSCHANGED,
    PROMISE = new$PROMISE,
    BUDGETPROMISE = new$BUDGETPROMISE,
    EXECDOC = new$EXECDOC,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    TRANSFERTCLS = new$TRANSFERTCLS,
    ORIGINALCLSSUMMA = new$ORIGINALCLSSUMMA,
    NOTECLS = new$NOTECLS,
    OPERATIONTYPE = new$OPERATIONTYPE,
    REVERSEFLAG = new$REVERSEFLAG,
    EXECINNERNUMBER = new$EXECINNERNUMBER,
    CLSFIELFCHANGED = new$CLSFIELFCHANGED,
    FAORGTYPE = new$FAORGTYPE,
    SUBSIDYCLS = new$SUBSIDYCLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    NOTEQUALEX = new$NOTEQUALEX,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    INVESTOBJECT = new$INVESTOBJECT,
    CHANGEORGNAME = new$CHANGEORGNAME
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_CORRECTIONDETAIL_AU_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5504, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5504) and (RecordId=new$ID);
  end if;

END;
/
COMMIT WORK 
/



-- #########################################################
-- #########################################################
-- Alter_KD_IFS_Triggers.sql
-- #########################################################
-- #########################################################

-- ALTER TRIGGER TR_KD_BI_0
CREATE OR REPLACE TRIGGER TR_KD_II
  INSTEAD OF INSERT
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  CNT$1 NUMBER(10);
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KD_BI_0)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
    and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupKD$;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KD_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_KD (
    ID,
    REPCODE,
    CREATEDATE,
    UPDATEDATE,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    KDVALUE,
    REMOTEFLAG,
    UNIONFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    KD_LEVEL,
    STARTDATE,
    SHORTNAME,
    CREATERUSER,
    UPDATERUSER,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPKD
  ) VALUES (
    new$ID,
    new$REPCODE,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$KDVALUE,
    new$REMOTEFLAG,
    new$UNIONFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$KD_LEVEL,
    new$STARTDATE,
    new$SHORTNAME,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPKD);

-- - - - - - - - - - - - -
-- AI_100 (TR_KD_AI_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_KD_AI_500)
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 80)  and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER TR_KD_BU_0
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
    and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupKD$;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD)
    ) AND (ROWNUM = 1)                     ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level);
        
    END IF;
  else
    /*   = 0,         ,     */
    update kd kd1 set
    name = new$name,
    ShortName = new$ShortName, 
    kd_level = new$kd_level
    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD);
    /*        */
    if (new$deletedate is not null) then
      update kd kd1 set
      deletedate = new$deletedate
      where
      (kd1.kvsr <> 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
      (kd1.DeleteDate is null);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_INNERFINSOURCE_BI_0
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_II
  INSTEAD OF INSERT
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  CNT$1 NUMBER(10);
  DescrCode11$ NUMBER(10);
  DescrCode21$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INNERFINSOURCE_BI_0)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    select max(IFS_Level), max(Direction)
    into sIFSLevel$, sDirection$     from innerfinsource 
    where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
    (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
    ;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode11$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode11$  > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode11$; /*    */
  /*       */    
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode21$ := tmp_Double$;
  tmp_Double$ := DescrCode21$ / 10000;
  DescrCode11$ := tmp_Double$;
  /*      */
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  new$ItemCode := DescrCode11$; /* */
  tmp_Double$ := DescrCode21$ - DescrCode11$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode11$ := tmp_Double$;
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode21$ := tmp_Double$;
  if (DescrCode11$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode11$ < 10) then
      sDescrCode1$ := '000000' || DescrCode11$;
          
    else
      if (DescrCode11$ < 100) then
        sDescrCode1$ := '00000' || DescrCode11$;
            
      else
        if (DescrCode11$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode11$;
              
        else
          if (DescrCode11$ < 10000) then
            sDescrCode1$ := '000' || DescrCode11$;
                
          else
            if (DescrCode11$ < 100000) then
              sDescrCode1$ := '00' || DescrCode11$;
                  
            else
              if (DescrCode11$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode11$;
                    
              else
                sDescrCode1$ := DescrCode11$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode21$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode21$ < 10) then
      sDescrCode2$ := '000000' || DescrCode21$;
          
    else
      if (DescrCode21$ < 100) then
        sDescrCode2$ := '00000' || DescrCode21$;
            
      else
        if (DescrCode21$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode21$;
              
        else
          if (DescrCode21$ < 10000) then
            sDescrCode2$ := '000' || DescrCode21$;
                
          else
            if (DescrCode21$ < 100000) then
              sDescrCode2$ := '00' || DescrCode21$;
                  
            else
              if (DescrCode21$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode21$;
                    
              else
                sDescrCode2$ := DescrCode21$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupIFS$;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INNERFINSOURCE_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INNERFINSOURCE (
    ID,
    CREATEDATE,
    UPDATEDATE,
    DIRECTION,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    FINSOURCEVALUE,
    UNIONFLAG,
    REMOTEFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    STARTDATE,
    SHORTNAME,
    CLSASPECT,
    CREATERUSER,
    UPDATERUSER,
    IFS_LEVEL,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPIFS
  ) VALUES (
    new$ID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$DIRECTION,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$FINSOURCEVALUE,
    new$UNIONFLAG,
    new$REMOTEFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$STARTDATE,
    new$SHORTNAME,
    new$CLSASPECT,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$IFS_LEVEL,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPIFS);

-- - - - - - - - - - - - -
-- AI_100 (TR_INNERFINSOURCE_AI_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, Direction, IFS_Level)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$direction, new$IFS_Level);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INNERFINSOURCE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 145) and (RecordId = new$ID);

END;
/
-- ALTER TRIGGER TR_INNERFINSOURCE_BU_0
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  CNT$1 NUMBER(10);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction 
      into sIFSLevel$, sDirection$     from innerfinsource 
      where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
      (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupIFS$;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level);
      
    END IF;
  else
    /*   = 0,         ,     */
    update InnerFinSource ifs1 set
    name = new$name,
    ShortName = new$ShortName,
    ifs_level = new$ifs_level,
    Direction = new$Direction
    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS);
    /*        */
    if (new$deletedate is not null) then
      update InnerFinSource ifs1 set
      deletedate = new$deletedate
      where
      (ifs1.kvsr <> 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
      (ifs1.DeleteDate is null);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/


commit work
/



-- #########################################################
-- #########################################################
-- Delete_Interfaces_OKDP.sql
-- #########################################################
-- #########################################################

delete from Permissions per where per.InterfaceRef in (select id from Interfaces ifs where ifs.GUID = '{0BDF2CC1-085F-4B40-A685-7CE6616C3CC4}')
/
commit work
/
delete from Interfaces Ifs where Ifs.GUID = '{0BDF2CC1-085F-4B40-A685-7CE6616C3CC4}'
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_KCSR_11.00.sql
-- #########################################################
-- #########################################################

/*  KCSR.DIRECTIONEXPENCE
*/
ALTER TABLE KCSR DROP (DIRECTIONEXPENCE)
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_FacialAcc_Cls_FacialCodeEx.sql
-- #########################################################
-- #########################################################

/* 
         
     
*/
-- drop trigger TR_FACIALACC_CLS_BI_300
CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_II
  INSTEAD OF INSERT
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  new$ID FACIALACC_CLS.ID%TYPE := :NEW.ID;
  new$CODE1 FACIALACC_CLS.CODE1%TYPE := :NEW.CODE1;
  new$CODE2 FACIALACC_CLS.CODE2%TYPE := :NEW.CODE2;
  new$CODE3 FACIALACC_CLS.CODE3%TYPE := :NEW.CODE3;
  new$CODE4 FACIALACC_CLS.CODE4%TYPE := :NEW.CODE4;
  new$KVSR FACIALACC_CLS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR FACIALACC_CLS.KCSR%TYPE := :NEW.KCSR;
  new$KFSR FACIALACC_CLS.KFSR%TYPE := :NEW.KFSR;
  new$KVR FACIALACC_CLS.KVR%TYPE := :NEW.KVR;
  new$KESR FACIALACC_CLS.KESR%TYPE := :NEW.KESR;
  new$FINTYPE FACIALACC_CLS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$ORG_REF FACIALACC_CLS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$DATEOPEN FACIALACC_CLS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$SERVICEACCOUNT FACIALACC_CLS.SERVICEACCOUNT%TYPE := :NEW.SERVICEACCOUNT;
  new$STATUSACCOUNT FACIALACC_CLS.STATUSACCOUNT%TYPE := :NEW.STATUSACCOUNT;
  new$HARACTERACCOUNT FACIALACC_CLS.HARACTERACCOUNT%TYPE := :NEW.HARACTERACCOUNT;
  new$REGIONCLS FACIALACC_CLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATEDATE FACIALACC_CLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALACC_CLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$FACIALCODE FACIALACC_CLS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$MEANSTYPE FACIALACC_CLS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$GENERALORG_REF FACIALACC_CLS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$DEPARTMENTCLS FACIALACC_CLS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$RVERSION FACIALACC_CLS.RVERSION%TYPE := :NEW.RVERSION;
  new$CLOSEDOCNUMBER FACIALACC_CLS.CLOSEDOCNUMBER%TYPE := :NEW.CLOSEDOCNUMBER;
  new$HIGHERORG_REF FACIALACC_CLS.HIGHERORG_REF%TYPE := :NEW.HIGHERORG_REF;
  new$BUDGETREF FACIALACC_CLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FCACCOUNT FACIALACC_CLS.FCACCOUNT%TYPE := :NEW.FCACCOUNT;
  new$CLOSECODE FACIALACC_CLS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$DATECLOSE FACIALACC_CLS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$CREATERUSER FACIALACC_CLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER FACIALACC_CLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE FACIALACC_CLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME FACIALACC_CLS.NAME%TYPE := :NEW.NAME;
  new$FACIALCODEEX FACIALACC_CLS.FACIALCODEEX%TYPE := :NEW.FACIALCODEEX;
  new$ISRBS FACIALACC_CLS.ISRBS%TYPE := :NEW.ISRBS;
  new$ISPBS FACIALACC_CLS.ISPBS%TYPE := :NEW.ISPBS;
  new$ISBU FACIALACC_CLS.ISBU%TYPE := :NEW.ISBU;
  new$ISSEPARATEBU FACIALACC_CLS.ISSEPARATEBU%TYPE := :NEW.ISSEPARATEBU;
  new$ISPROXY FACIALACC_CLS.ISPROXY%TYPE := :NEW.ISPROXY;
  new$OPENDOCNUMBER FACIALACC_CLS.OPENDOCNUMBER%TYPE := :NEW.OPENDOCNUMBER;
  new$ISOMS FACIALACC_CLS.ISOMS%TYPE := :NEW.ISOMS;
  new$CHANGEDOCNUMBER FACIALACC_CLS.CHANGEDOCNUMBER%TYPE := :NEW.CHANGEDOCNUMBER;
  new$DATECHANGE FACIALACC_CLS.DATECHANGE%TYPE := :NEW.DATECHANGE;
  new$GENERALORGFACIALACC FACIALACC_CLS.GENERALORGFACIALACC%TYPE := :NEW.GENERALORGFACIALACC;
  new$GRANTEEORG_REF FACIALACC_CLS.GRANTEEORG_REF%TYPE := :NEW.GRANTEEORG_REF;
  new$PREVCLS FACIALACC_CLS.PREVCLS%TYPE := :NEW.PREVCLS;
--
  OrgDateClose$ Number;
  id_org$ NUMBER(10);
  id_reg$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALACC_CLS_BI_0)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  facialacc_clsdiv(new$id,new$code1,new$code2,new$code3,new$code4);
  if (new$kvsr is null) then 
    new$kvsr := 0;
  END IF;
  if (new$kcsr is null) then 
    new$kcsr := 0;
  END IF;
  if (new$kfsr is null) then 
    new$kfsr := 0;
  END IF;
  if (new$kvr is null) then 
    new$kvr := 0;
  END IF;
  if (new$kesr is null) then 
    new$kesr := 0;
  END IF;
  if (new$fintype is null) then 
    new$fintype := 0;
  END IF;
  if (new$meanstype is null) then 
    new$meanstype := 0;
  END IF;
  if (new$haracteraccount is null) then 
    new$haracteraccount := 0;
  END IF;
  if (new$org_ref is null) then 
    new$org_ref := 0; -- ,   select min (...)
  END IF;
  BEGIN

    --     
    select o.generalorg_ref
    into id_org$     from organizations o
    where o.id = new$org_ref
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (id_org$  is null) then 
    id_org$ := new$org_ref;
  END IF;
  new$generalorg_ref := id_org$;
  BEGIN

    --      
    --  -
    --   --------------------------
    select o.RegionCLS
    into id_reg$     from Organizations o
    where o.ID = new$Org_Ref
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  new$regioncls := id_reg$;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALACC_CLS_BI_100)
-- Create 01.12.2005
-- - - - - - - - - - - - -

/*    -    */
   IF (    (   (new$ID = 0)
            OR (new$serviceaccount = 0)
            OR (new$serviceaccount IS NULL)
           )
       AND (new$budgetref IS NULL)
      ) THEN
      new$budgetRef := 0;
   END IF;

   IF (    (new$ID <> 0)
       AND (new$serviceaccount = 1)
       AND ((new$budgetref IS NULL) OR (new$budgetref = 0))
      ) THEN
      getintconst (-1, 3, new$budgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALACC_CLS_BI_200)
-- Create 27.07.2007
-- - - - - - - - - - - - -

    if (new$Org_Ref is not null) then
      select DateClose into OrgDateClose$ from organizations where Id = new$Org_ref;
      if (OrgDateClose$ is not null) then
         if ((new$DateClose is null) or (new$DateClose > OrgDateClose$)) then
           new$DateClose := OrgDateClose$;
         end if;
         new$StatusAccount := 1;
         new$CloseCode := 10; /*   */
      end if;
    end if;
 
    if ((new$DateClose is not null) and (new$StatusAccount = 0)) then
      new$StatusAccount := 1;
      new$CloseCode := 1;
    end if;
 
    if (new$CloseCode is null) then new$CloseCode := 0; end if;

-- - - - - - - - - - - - -
-- BI_400 (TR_FACIALACC_CLS_BI_400)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$IsRBS is null) then
    if (new$HaracterAccount in (1, 2)) then
      new$IsRBS := 1;
          
    else
      new$IsRBS := 0;
      
    END IF;
  END IF;
  if (new$IsPBS is null) then
    if (new$HaracterAccount in (0, 2)) then
      new$IsPBS := 1;
          
    else
      new$IsPBS := 0;
      
    END IF;
  END IF;
  if (new$IsBU is null) then
    new$IsBU := 0;
  END IF;
  if (new$IsOMS is null) then
    new$IsOMS := 0;
  END IF;
  if (new$IsSeparateBU is null) then
    new$IsSeparateBU := 0;
  END IF;
  if (new$IsProxy is null) then
    new$IsProxy := 0;
  END IF;
  if ((new$IsRBS + new$IsPBS + new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) = 0) then
    new$HaracterAccount := 3;
      
  else
    if ((new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) > 0) then
      new$HaracterAccount := 0;
          
    else
      if (new$IsRBS = 1) then
        new$HaracterAccount := new$IsRBS + new$IsPBS;
              
      else
        new$HaracterAccount := 0;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALACC_CLS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALACC_CLS (
    ID,
    CODE1,
    CODE2,
    CODE3,
    CODE4,
    KVSR,
    KCSR,
    KFSR,
    KVR,
    KESR,
    FINTYPE,
    ORG_REF,
    DATEOPEN,
    SERVICEACCOUNT,
    STATUSACCOUNT,
    HARACTERACCOUNT,
    REGIONCLS,
    CREATEDATE,
    UPDATEDATE,
    FACIALCODE,
    MEANSTYPE,
    GENERALORG_REF,
    DEPARTMENTCLS,
    RVERSION,
    CLOSEDOCNUMBER,
    HIGHERORG_REF,
    BUDGETREF,
    FCACCOUNT,
    CLOSECODE,
    DATECLOSE,
    CREATERUSER,
    UPDATERUSER,
    NOTE,
    NAME,
    FACIALCODEEX,
    ISRBS,
    ISPBS,
    ISBU,
    ISSEPARATEBU,
    ISPROXY,
    OPENDOCNUMBER,
    ISOMS,
    CHANGEDOCNUMBER,
    DATECHANGE,
    GENERALORGFACIALACC,
    GRANTEEORG_REF,
    PREVCLS
  ) VALUES (
    new$ID,
    new$CODE1,
    new$CODE2,
    new$CODE3,
    new$CODE4,
    new$KVSR,
    new$KCSR,
    new$KFSR,
    new$KVR,
    new$KESR,
    new$FINTYPE,
    new$ORG_REF,
    new$DATEOPEN,
    new$SERVICEACCOUNT,
    new$STATUSACCOUNT,
    new$HARACTERACCOUNT,
    new$REGIONCLS,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$FACIALCODE,
    new$MEANSTYPE,
    new$GENERALORG_REF,
    new$DEPARTMENTCLS,
    new$RVERSION,
    new$CLOSEDOCNUMBER,
    new$HIGHERORG_REF,
    new$BUDGETREF,
    new$FCACCOUNT,
    new$CLOSECODE,
    new$DATECLOSE,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$NOTE,
    new$NAME,
    new$FACIALCODEEX,
    new$ISRBS,
    new$ISPBS,
    new$ISBU,
    new$ISSEPARATEBU,
    new$ISPROXY,
    new$OPENDOCNUMBER,
    new$ISOMS,
    new$CHANGEDOCNUMBER,
    new$DATECHANGE,
    new$GENERALORGFACIALACC,
    new$GRANTEEORG_REF,
    new$PREVCLS);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALACC_CLS_AI_500)
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 19) AND (RecordID = new$ID);

END;
/
-- drop trigger TR_FACIALACC_CLS_BU_300
CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_IU
  INSTEAD OF UPDATE
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  new$ID FACIALACC_CLS.ID%TYPE := :NEW.ID;
  new$CODE1 FACIALACC_CLS.CODE1%TYPE := :NEW.CODE1;
  new$CODE2 FACIALACC_CLS.CODE2%TYPE := :NEW.CODE2;
  new$CODE3 FACIALACC_CLS.CODE3%TYPE := :NEW.CODE3;
  new$CODE4 FACIALACC_CLS.CODE4%TYPE := :NEW.CODE4;
  new$KVSR FACIALACC_CLS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR FACIALACC_CLS.KCSR%TYPE := :NEW.KCSR;
  new$KFSR FACIALACC_CLS.KFSR%TYPE := :NEW.KFSR;
  new$KVR FACIALACC_CLS.KVR%TYPE := :NEW.KVR;
  new$KESR FACIALACC_CLS.KESR%TYPE := :NEW.KESR;
  new$FINTYPE FACIALACC_CLS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$ORG_REF FACIALACC_CLS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$DATEOPEN FACIALACC_CLS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$SERVICEACCOUNT FACIALACC_CLS.SERVICEACCOUNT%TYPE := :NEW.SERVICEACCOUNT;
  new$STATUSACCOUNT FACIALACC_CLS.STATUSACCOUNT%TYPE := :NEW.STATUSACCOUNT;
  new$HARACTERACCOUNT FACIALACC_CLS.HARACTERACCOUNT%TYPE := :NEW.HARACTERACCOUNT;
  new$REGIONCLS FACIALACC_CLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATEDATE FACIALACC_CLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALACC_CLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$FACIALCODE FACIALACC_CLS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$MEANSTYPE FACIALACC_CLS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$GENERALORG_REF FACIALACC_CLS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$DEPARTMENTCLS FACIALACC_CLS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$RVERSION FACIALACC_CLS.RVERSION%TYPE := :NEW.RVERSION;
  new$CLOSEDOCNUMBER FACIALACC_CLS.CLOSEDOCNUMBER%TYPE := :NEW.CLOSEDOCNUMBER;
  new$HIGHERORG_REF FACIALACC_CLS.HIGHERORG_REF%TYPE := :NEW.HIGHERORG_REF;
  new$BUDGETREF FACIALACC_CLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FCACCOUNT FACIALACC_CLS.FCACCOUNT%TYPE := :NEW.FCACCOUNT;
  new$CLOSECODE FACIALACC_CLS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$DATECLOSE FACIALACC_CLS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$CREATERUSER FACIALACC_CLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER FACIALACC_CLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE FACIALACC_CLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME FACIALACC_CLS.NAME%TYPE := :NEW.NAME;
  new$FACIALCODEEX FACIALACC_CLS.FACIALCODEEX%TYPE := :NEW.FACIALCODEEX;
  new$ISRBS FACIALACC_CLS.ISRBS%TYPE := :NEW.ISRBS;
  new$ISPBS FACIALACC_CLS.ISPBS%TYPE := :NEW.ISPBS;
  new$ISBU FACIALACC_CLS.ISBU%TYPE := :NEW.ISBU;
  new$ISSEPARATEBU FACIALACC_CLS.ISSEPARATEBU%TYPE := :NEW.ISSEPARATEBU;
  new$ISPROXY FACIALACC_CLS.ISPROXY%TYPE := :NEW.ISPROXY;
  new$OPENDOCNUMBER FACIALACC_CLS.OPENDOCNUMBER%TYPE := :NEW.OPENDOCNUMBER;
  new$ISOMS FACIALACC_CLS.ISOMS%TYPE := :NEW.ISOMS;
  new$CHANGEDOCNUMBER FACIALACC_CLS.CHANGEDOCNUMBER%TYPE := :NEW.CHANGEDOCNUMBER;
  new$DATECHANGE FACIALACC_CLS.DATECHANGE%TYPE := :NEW.DATECHANGE;
  new$GENERALORGFACIALACC FACIALACC_CLS.GENERALORGFACIALACC%TYPE := :NEW.GENERALORGFACIALACC;
  new$GRANTEEORG_REF FACIALACC_CLS.GRANTEEORG_REF%TYPE := :NEW.GRANTEEORG_REF;
  new$PREVCLS FACIALACC_CLS.PREVCLS%TYPE := :NEW.PREVCLS;
--
  id_org$ NUMBER(10);
  vOrgType$ NUMBER(10);
  id_org1$ NUMBER(10);
  id_reg1$ NUMBER(10);
  DiffCode$ NUMBER(10);
  Code1$ NUMBER(10);
  Code2$ NUMBER(10);
  Code51$ NUMBER(10);
  CodeX$ NUMBER(10);
  vOrgType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALACC_CLS_BU_0)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$id <> :old.id) then 
    facialacc_clsdiv(new$id,new$code1,new$code2,new$code3,new$code4);
  END IF;
  if (new$kvsr is null) then 
    new$kvsr := 0;
  END IF;
  if (new$kcsr is null) then 
    new$kcsr := 0;
  END IF;
  if (new$kfsr is null) then 
    new$kfsr := 0;
  END IF;
  if (new$kvr is null) then 
    new$kvr := 0;
  END IF;
  if (new$kesr is null) then 
    new$kesr := 0;
  END IF;
  if (new$fintype is null) then 
    new$fintype := 0;
  END IF;
  if (new$regioncls is null) then 
    new$regioncls := 0;
  END IF;
  if (new$meanstype is null) then 
    new$meanstype := 0;
  END IF;
  if (new$haracteraccount is null) then 
    new$haracteraccount := 0;
  END IF;
  if (new$org_ref is null) then 
    new$org_ref := 0; -- ,   select min (...)
  END IF;
  if ((new$org_ref <> :old.org_ref) and not(new$fcaccount is null)) then
    BEGIN
      select org_ref      into id_org1$ from org_accounts
      where id = new$fcaccount
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (id_org1$ <> new$org_ref) then 
      new$fcaccount := null;
     
    END IF;
  END IF;
  if (:old.Org_Ref <> new$Org_Ref) then 
    BEGIN
      --   --------------------------
      select o.RegionCLS
      into id_reg1$        from Organizations o
      where o.ID = new$Org_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    --   -----------------
       
    new$regioncls := id_reg1$;
    BEGIN
      --       /----
      select o.Org_Type
      into vOrgType$      from Organizations o
      where o.ID = :old.Org_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((vOrgType$  >= 10800)and(vOrgType$  <= 10900)) then
      update org_accounts
      set facialacc_cls = null
      where facialacc_cls = :old.id;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_FACIALACC_CLS_BU_100)
-- Create 01.12.2005
-- - - - - - - - - - - - -

   IF (    (   (new$ID = 0)
            OR (new$serviceaccount = 0)
            OR (new$serviceaccount IS NULL)
           )
       AND (new$budgetref IS NULL)
      ) THEN
      new$budgetRef := 0;
   END IF;

   IF (    (new$ID <> 0)
       AND (new$serviceaccount = 1)
       AND ((new$budgetref IS NULL) OR (new$budgetref = 0))
      ) THEN
      getintconst (-1, 3, new$budgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALACC_CLS_BU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /* /  ??     ??   AU   */
  if ((((new$DateClose is not null) and (:old.DateClose is null)) or
  ((new$DateClose is null) and (:old.DateClose is not null)))
  and (new$CloseCode = :old.CloseCode))
  then 
    BEGIN
      /*      /    .
                / ??    ?
          */
      select o.Org_Type     into vOrgType1$ from Organizations o where o.id = new$org_ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((vOrgType1$  >= 10800)and(vOrgType1$  <= 10900)) then
      if (new$DateClose is not null or (new$statusaccount = 1 and :old.statusaccount=0))
      then
        update org_accounts set
        CloseCode = CloseCode + 10000,
        DateClose = new$DateClose
        where facialacc_cls = new$id;
              
      END IF;
      if (new$DateClose is null or (new$statusaccount = 0 and :old.statusaccount=1))
      then
        update org_accounts set
        CloseCode = CloseCode - 10000
        where facialacc_cls = new$id;
          
      END IF;
    END IF;
    if (new$DateClose is not null) then 
      new$CloseCode := 1;
    END IF;
    if (new$DateClose is null) then 
      new$CloseCode := 0;
      
    END IF;
  END IF;
    
  /* /   (only      ) */
  if (new$CloseCode <> :old.CloseCode)
  then 
    DiffCode$ := new$CloseCode - :old.CloseCode; /* >0 -  , <0 -  */
    CloseOrgCls_Div(:old.CloseCode,Code1$, Code2$, CodeX$, CodeX$, Code51$);
        
    /*   "" */
    if (DiffCode$ = 1) then 
      Code1$ := 1;
    END IF;
    if (DiffCode$ = 10) then 
      Code2$ := 1;
    END IF;
    if (DiffCode$ = 10000) then 
      Code51$ := 1;
    END IF;
    if (DiffCode$ = -1) then 
      Code1$ := 0;
    END IF;
    if (DiffCode$ = -10) then 
      Code2$ := 0;
    END IF;
    if (DiffCode$ = -10000) then 
      Code51$ := 0;
    END IF;
    new$CloseCode := Code1$ + Code2$*10 + Code51$*10000;
        
    if (new$CloseCode <> 0) then 
      new$StatusAccount := 1;
    END IF;
        
    /*     ??      -  - !*/
    if (((new$CloseCode <> 0) and (new$DateClose is null)) or (new$DateClose >= :old.DateClose)) then
      new$DateClose := :old.DateClose;
          
    else 
      if (new$CloseCode = 0) then 
        new$DateClose := null;
        if (new$StatusAccount <> 0) then
          new$StatusAccount := 0;
            
        END IF;
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_FACIALACC_CLS_BU_400)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$IsRBS is null) then
    if (new$HaracterAccount in (1, 2)) then
      new$IsRBS := 1;
          
    else
      new$IsRBS := 0;
      
    END IF;
  END IF;
  if (new$IsPBS is null) then
    if (new$HaracterAccount in (0, 2)) then
      new$IsPBS := 1;
          
    else
      new$IsPBS := 0;
      
    END IF;
  END IF;
  if (new$IsBU is null) then
    new$IsBU := 0;
  END IF;
  if (new$IsOMS is null) then
    new$IsOMS := 0;
  END IF;
  if (new$IsSeparateBU is null) then
    new$IsSeparateBU := 0;
  END IF;
  if (new$IsProxy is null) then
    new$IsProxy := 0;
  END IF;
  if ((new$IsRBS + new$IsPBS + new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) = 0) then
    new$HaracterAccount := 3;
      
  else
    if ((new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) > 0) then
      new$HaracterAccount := 0;
          
    else
      if (new$IsRBS = 1) then
        new$HaracterAccount := new$IsRBS + new$IsPBS;
              
      else
        new$HaracterAccount := 0;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_550 (TR_FACIALACC_CLS_BU_550)
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF ((new$GeneralOrg_ref IS NULL)or(new$Org_Ref <> :old.Org_Ref)) THEN
     select
       o.GeneralOrg_Ref
     into
       id_org$
     from
       Organizations o
     where
       o.id = new$Org_Ref;
      /*      */
     if (id_org$ is Null)
       then id_org$ := new$Org_Ref;
     end if;  
     new$GeneralOrg_ref := id_org$;

   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALACC_CLS_BU_700)
-- Create 19.09.2004
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF (NEW$RVersion IS NULL) THEN
      NEW$RVersion := 1;
   ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      NEW$RVersion := :OLD.RVersion;
   ELSE
      NEW$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALACC_CLS SET
    ID = new$ID,
    CODE1 = new$CODE1,
    CODE2 = new$CODE2,
    CODE3 = new$CODE3,
    CODE4 = new$CODE4,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KFSR = new$KFSR,
    KVR = new$KVR,
    KESR = new$KESR,
    FINTYPE = new$FINTYPE,
    ORG_REF = new$ORG_REF,
    DATEOPEN = new$DATEOPEN,
    SERVICEACCOUNT = new$SERVICEACCOUNT,
    STATUSACCOUNT = new$STATUSACCOUNT,
    HARACTERACCOUNT = new$HARACTERACCOUNT,
    REGIONCLS = new$REGIONCLS,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    FACIALCODE = new$FACIALCODE,
    MEANSTYPE = new$MEANSTYPE,
    GENERALORG_REF = new$GENERALORG_REF,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    RVERSION = new$RVERSION,
    CLOSEDOCNUMBER = new$CLOSEDOCNUMBER,
    HIGHERORG_REF = new$HIGHERORG_REF,
    BUDGETREF = new$BUDGETREF,
    FCACCOUNT = new$FCACCOUNT,
    CLOSECODE = new$CLOSECODE,
    DATECLOSE = new$DATECLOSE,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    NAME = new$NAME,
    FACIALCODEEX = new$FACIALCODEEX,
    ISRBS = new$ISRBS,
    ISPBS = new$ISPBS,
    ISBU = new$ISBU,
    ISSEPARATEBU = new$ISSEPARATEBU,
    ISPROXY = new$ISPROXY,
    OPENDOCNUMBER = new$OPENDOCNUMBER,
    ISOMS = new$ISOMS,
    CHANGEDOCNUMBER = new$CHANGEDOCNUMBER,
    DATECHANGE = new$DATECHANGE,
    GENERALORGFACIALACC = new$GENERALORGFACIALACC,
    GRANTEEORG_REF = new$GRANTEEORG_REF,
    PREVCLS = new$PREVCLS
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALACC_CLS_AU_500)
-- Create 28.04.2005
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (19, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 19) AND (RecordId = new$ID);
   END IF;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- UpdDocFields_11.00.00_Ora.sql
-- #########################################################
-- #########################################################


--  : 100000 - 110000.     12.12.2015 17:09:59.
CREATE OR REPLACE PROCEDURE ImportDocType (
   ID_               NUMBER,
   PROGINDEX_        NUMBER,
   NAME_             VARCHAR2,
   USESTATE_         NUMBER,
   DBTABLE_          VARCHAR2,
   NEEDEDS_          NUMBER,
   LOCKMASK_         NUMBER,
   DEFAULTACTIONMACROSNAME_ VARCHAR2,
   DOCUMENTKIND_     NUMBER,
   SHORTNAME_         VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentTypes
    WHERE (ID = ID_);

  IF (IDExists$ = 0) THEN
     INSERT INTO DocumentTypes
                 (ID, PROGINDEX, NAME, USESTATE, DBTABLE, NEEDEDS, LOCKMASK, DEFAULTACTIONMACROSNAME, DOCUMENTKIND, SHORTNAME)
          VALUES (ID_, PROGINDEX_, NAME_, USESTATE_, DBTABLE_, NEEDEDS_, LOCKMASK_, DEFAULTACTIONMACROSNAME_, DOCUMENTKIND_, SHORTNAME_);
  else
      Update documenttypes set
        Name=Name_,
		    DBTABLE=DBTABLE_,
        LockMask=LockMask_,
        DEFAULTACTIONMACROSNAME=DEFAULTACTIONMACROSNAME_,
        DOCUMENTKIND=DOCUMENTKIND_,
        SHORTNAME=SHORTNAME_,
	      PROGINDEX=PROGINDEX_
      where (id=ID_)
        and (
          (Name<>Name_) or
          ((LockMask is null) and (LockMask_ is not null)) or
          ((LockMask is not null) and (LockMask_ is null)) or
          ((LockMask is not null) and (LockMask_ is not null) and (LockMask <> LockMask_)) or
          (DEFAULTACTIONMACROSNAME is null) or
          (DOCUMENTKIND<>DOCUMENTKIND_) or 
          (SHORTNAME is null) or 
          (SHORTNAME<>SHORTNAME_) or
          (PROGINDEX <> PROGINDEX_) or 
          ((DBTABLE is null) and (DBTABLE_ is not null)) or
          ((DBTABLE is not null) and (DBTABLE_ is null)) or
          ((DBTABLE is not null) and (DBTABLE_ is not null) and (DBTABLE <> DBTABLE_))
        );
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE UPDATEINTERFACES (
  CLS_   NUMBER,
  NOTE_  VARCHAR2,
  GUID_  VARCHAR2,
  PARAM_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT (ID)
   INTO IDEXISTS$
   FROM INTERFACES
  WHERE (GUID=GUID_);
  
  IF (IDExists$ = 0)  THEN
    INSERT INTO INTERFACES
      (CLS,NOTE,GUID,PARAM)
    VALUES
      (CLS_,NOTE_,GUID_,PARAM_);
  ELSE
    IF ((PARAM_ ='')OR(PARAM_ IS NULL)) THEN 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    ELSE 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND (PARAM=PARAM_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    END IF;
  END IF;
END;
/

--   
CALL ImportDocType(0, 0, ' ', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(101, 223, '   ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(200, 0, '  ()', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(201, 32, '   ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(202, 260, ' ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(203, 261, '  ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(204, 262, ' , ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(205, 263, '', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'') ;

CALL ImportDocType(206, 268, '   ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'__') ;

CALL ImportDocType(207, 272, '  ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(208, 273, '   ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'__') ;

CALL ImportDocType(209, 274, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(209, ' ', '{DA309359-EF6B-4D29-AC0D-309040B5CDB6}', '') ;

CALL ImportDocType(210, 252, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(210, ' ', '{2EF0F811-E21F-4ADB-BC7E-A3A9B16059A4}', '') ;

CALL ImportDocType(211, 275, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(211, ' ', '{AE8281A0-BE7F-4F3A-90BD-A7831E8D842F}', '') ;

CALL ImportDocType(212, 276, '  , ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(212, '  , ', '{B743C24B-6E28-4C9C-B3CA-16AC6E529D07}', '') ;

CALL ImportDocType(300, 0, '  ', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(301, 66, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(302, 63, '  \', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(303, 65, ' ()', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(304, 64, '  ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(305, 61, '  \', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(306, 62, '  ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(308, 67, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(308, ' ', '{B50F2C63-9CF4-42C3-8062-E355EABD53E4}', '') ;

CALL ImportDocType(311, 68, '   ', 0, 'FacialFinCaption', 0,-1,'_',10100,'_') ;

CALL ImportDocType(312, 69, '    ', 0, 'FacialFinCaption', 0,-1,'_',10100,'_') ;

CALL ImportDocType(314, 70, '   ', 0, 'FacialFinCaption', 0,-1,'_',10100,'_') ;

CALL ImportDocType(315, 71, '     ', 0, 'FacialFinCaption', 0,-1,'_',10200,'_') ;

CALL ImportDocType(322, 73, '  ', 0, 'FacialFinCaption', 0,-1,'_',10200,'') ;

CALL ImportDocType(323, 75, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(324, 76, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(401, 0, '   ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(501, 0, '  ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(701, 23, '  ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(702, 0, '  ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(703, 0, ' ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(801, 57, ' ', 0, 'LimitNotifyCaption[RVERSION=RVERSION-1]', 0,34,'_',10100,'_') ;

CALL ImportDocType(802, 0, '  ()', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(803, 0, '    ', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(804, 0, '  ', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(900, 0, '', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(902, 0, '  ()', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(903, 45, '  ', 0, ' ', 0,-1,'',10100,'_') ;

CALL ImportDocType(905, 0, '  ', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(906, 41, '  ()', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(907, 0, '  ()', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(1201, 0, ' ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(1501, 0, ' ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(1601, 224, ' ', 0, 'Promise_Caption', 0,-1,'_',10100,'') ;

CALL ImportDocType(1602, 0, '. - ', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(1701, 222, '', 0, 'REQUESTS[RVERSION=RVERSION-1]', 0,-1,'',10100,'') ;

CALL ImportDocType(1702, 0, '()', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(1805, 0, '  ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1805, '  ', '{FE9F8D41-C23F-11D5-B571-0050BF2079BC}', '') ;

CALL ImportDocType(1807, 0, '  ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1807, '  ', '{DCD3A201-01A8-11D5-9238-4854E826BF13}', '') ;

CALL ImportDocType(1809, 0, '     ', 0, 'BANKEXCH_SUBSTITUTION', 0,0,'',10200,'') ;

CALL UpdateInterfaces(1809, '     ', '{84AB1481-04A6-4885-9524-B0689D95F35A}', '') ;

CALL ImportDocType(1810, 0, '  ', 0, ' ', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1810, '  ', '{EF52F7D8-C963-492E-8012-F94BD6E4197E}', '') ;

CALL ImportDocType(1812, 0, '  ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1812, '  ', '{9CDFC584-6F7A-44CC-95AD-B9B947AFDCA4}', '') ;

CALL ImportDocType(1813, 0, '  ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1813, '  ', '{A7B7ED86-DB11-4D8A-96CE-1BAE4B7EC77F}', '') ;

CALL ImportDocType(1814, 0, '    ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1814, '    ', '{B079EB25-3341-4395-9554-FBAAC3293171}', '') ;

CALL ImportDocType(1815, 0, '    ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1815, '    ', '{D92C5F6D-D02D-4589-B0A8-0E5A05AFEFBF}', '') ;

CALL ImportDocType(1816, 0, '  ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1816, '  ', '{584B1826-AD94-47DC-A420-B5E42F2CA7D7}', '') ;

CALL ImportDocType(1900, 0, '  ()', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(1903, 265, '  ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'',10100,'_') ;

CALL ImportDocType(1906, 271, '   ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'',10100,'__') ;

CALL ImportDocType(2200, 0, '  ()', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(2201, 46, '  ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(2501, 305, ' ', 0, 'Agreements', 0,-65537,'',10100,'') ;

CALL ImportDocType(2502, 304, '', 0, 'Agreements', 0,-65537,'',10100,'') ;

CALL ImportDocType(2503, 308, '  ', 0, 'ExecutionDocumentsCaption', 0,-65537,'',10100,'') ;

CALL ImportDocType(2504, 314, ' ', 0, 'Agreements', 0,-65537,'',10100,'') ;

CALL ImportDocType(2801, 0, '      ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(2802, 0, '  ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(3001, 230, '   ', 0, 'TenderCaption', 0,-65537,'',10100,'') ;

CALL ImportDocType(3003, 234, ' ', 0, 'TenderResultCaption', 0,-65537,'',10100,'') ;

CALL ImportDocType(3004, 0, ' ', 0, 'TenderProposal', 0,0,'',3,' ') ;

CALL ImportDocType(3006, 241, '-', 0, 'TenderCaption', 0,-65537,'',10100,'') ;

CALL ImportDocType(3610, 550, '  ', 0, 'UTypedFormsCaption', 0,-1,'',10100,'5') ;

CALL ImportDocType(3701, 235, ' ', 0, 'TenderObjects', 0,-65537,'',10100,'') ;

CALL ImportDocType(3901, 0, '. ', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(4401, 251, ' ', 0, 'UnionNotifyCaption', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(4401, ' ', '{AB6937F7-A672-461D-A94C-808F4DCA4D71}', '') ;

CALL ImportDocType(4403, 254, ' ,', 0, 'UnionNotifyCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(4801, 528, ' ', 0, 'GeneralDocuments', 0,-1,'_',10100,'') ;

CALL ImportDocType(4901, 525, '   ', 0, 'DataPacket', 0,-1,'_',10100,'') ;

CALL ImportDocType(4902, 526, ' ', 0, '', 0,-1,'',10200,'') ;

CALL ImportDocType(5101, 0, '  ', 0, 'StoredAttributesCaption', 0,-1,'',10200,'') ;

CALL ImportDocType(5201, 555, ' / ', 0, 'WritExecutionCaption', 0,-1,'',10100,'') ;

CALL UpdateInterfaces(5201, ' / ', '{623EE404-09D9-4069-9115-27974DB69AD1}', '') ;

CALL ImportDocType(5301, 0, '   ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(5301, '   ', '{FF462FFC-4DA8-4A24-B2BA-0B6478238E00}', '') ;

CALL ImportDocType(5302, 0, ' ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(5302, ' ', '{A4B37143-4DD8-4BFF-9E80-ADF04718ED02}', '') ;

CALL ImportDocType(5501, 312, '   ', 0, 'CorrectionCaption', 0,-1,'',10100,'_') ;

CALL ImportDocType(5502, 313, '   ', 0, 'CorrectionCaption', 0,-1,'',10100,'_') ;

CALL ImportDocType(5503, 0, '   ', 0, 'ReplacementClsCaption', 0,-1,'',10100,'') ;

CALL UpdateInterfaces(5503, '   ', '{6110B8B7-DFE8-46EF-BD9F-39CCF092BB79}', '') ;

CALL ImportDocType(9601, 0, '', 0, 'ORGANIZATIONS', 0,0,'',20100,'') ;

CALL ImportDocType(9603, 0, '', 0, 'BANKS', 0,0,'',20100,'') ;

CALL ImportDocType(9701, 0, '   ', 0, 'AnalyticalGroupKD', 0,0,'',20100,'') ;

CALL ImportDocType(9702, 0, '   ', 0, 'AnalyticalGroupIFS', 0,0,'',20100,'') ;

CALL ImportDocType(9802, 0, '', 0, 'kfsr', 0,0,'',20200,'') ;

CALL ImportDocType(9803, 0, '', 0, 'KVSR', 0,0,'',20100,'') ;

CALL ImportDocType(9804, 0, '', 0, 'KVR', 0,0,'',20100,'') ;

CALL ImportDocType(9805, 0, '', 0, 'KCSR', 0,0,'',20100,'') ;

CALL ImportDocType(9808, 0, ' ', 0, 'KESRSubCode', 0,0,'',20200,'') ;

CALL ImportDocType(9809, 0, '', 0, 'KD', 0,0,'',20100,'') ;

CALL ImportDocType(9811, 0, '', 0, 'DocTypes', 0,0,'',20200,'') ;

CALL ImportDocType(9813, 0, ' ', 0, 'NOTIFYTYPES', 0,0,'',20200,'') ;

CALL ImportDocType(9814, 0, '', 0, 'KSHK', 0,0,'',20200,'') ;

CALL ImportDocType(9815, 0, ' ', 0, 'VALUECLS', 0,0,'',20200,'') ;

CALL ImportDocType(9816, 0, ' ', 0, 'MeansCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9818, 0, '', 0, 'CURRENCYCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9821, 0, '  ', 0, 'ACC_CLS', 0,0,'',20200,'') ;

CALL ImportDocType(9822, 0, ' ', 0, 'GroupInf_CLS', 0,0,'',20200,'') ;

CALL ImportDocType(9823, 0, '', 0, 'GOSNI', 0,0,'',20200,'') ;

CALL ImportDocType(9827, 0, '  ', 0, 'FinType', 0,0,'',20200,'') ;

CALL ImportDocType(9828, 0, '', 0, 'FACT', 0,0,'',20100,'') ;

CALL ImportDocType(9829, 0, '- ', 0, 'DocBase', 0,0,'',20200,'') ;

CALL ImportDocType(9835, 0, '  (  )', 0, 'BUDGETTYPE', 0,0,'',20200,'') ;

CALL ImportDocType(9841, 0, ' ', 0, 'FACIALACC_CLS', 0,0,'',20200,'') ;

CALL ImportDocType(9842, 0, '2', 0, 'OKVED2', 0,0,'',20200,'2') ;

CALL ImportDocType(9843, 0, ' ', 0, 'PAYTYPECLS', 0,0,'',20200,'') ;

CALL ImportDocType(9845, 0, ' ', 0, 'PAYSYMBOLCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9846, 0, ' ()', 0, 'BUHPAYMENTCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9847, 0, ' ', 0, 'TYPEOPERATIONCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9848, 0, ' ', 0, 'PAYDESTINATIONCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9851, 0, ' ', 0, 'Error', 0,0,'',20200,'') ;

CALL ImportDocType(9852, 0, '   ', 0, 'InnerFinSource', 0,0,'',20100,'') ;

CALL ImportDocType(9854, 0, '', 0, 'INVESTOBJECT', 0,0,'',20100,'') ;

CALL ImportDocType(9857, 0, ' ', 0, 'LOANTYPE', 0,0,'',20200,'') ;

CALL ImportDocType(9858, 0, ' ', 0, 'DEBTTYPE', 0,0,'',20200,'') ;

CALL ImportDocType(9859, 0, '', 0, 'DepartmentCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9860, 0, ' ', 0, 'MEASUREMENTCLS', 0,0,'',20200,'') ;

CALL ImportDocType(9861, 0, ' ', 0, 'TenderObjects', 0,0,'',20200,'') ;

CALL ImportDocType(9862, 0, '', 0, 'OKATO', 0,0,'',20200,'') ;

CALL ImportDocType(9864, 0, ' ', 0, 'PlanDocType', 0,0,'',20200,'') ;

CALL ImportDocType(9865, 0, ' ', 0, 'BuhAccPlan', 0,0,'',20100,'') ;

CALL ImportDocType(9867, 0, '2', 0, 'OKPD2', 0,0,'',20200,'2') ;

CALL ImportDocType(9868, 0, '    ', 0, 'KESR', 0,0,'',20200,'') ;

CALL ImportDocType(9869, 0, '', 0, 'DirectionCLS', 0,0,'',20100,'') ;

CALL ImportDocType(9870, 0, '  ', 0, 'ProgramCode', 0,0,'',20200,'') ;

CALL ImportDocType(9871, 0, '', 0, 'BuhOperationCls', 0,0,'',20200,'') ;

CALL ImportDocType(9872, 0, '', 0, 'BalanceCls', 0,0,'',20200,'') ;

CALL ImportDocType(9878, 0, '', 0, 'budgets_s', 0,0,'',20200,'') ;

CALL ImportDocType(9879, 0, ' ', 0, 'TargetCls', 0,0,'',20200,'') ;

CALL ImportDocType(9880, 0, '  ', 0, 'FundsSource', 0,0,'',20200,'') ;

CALL ImportDocType(9881, 0, '', 0, 'OKFS', 0,0,'',20200,'') ;

CALL ImportDocType(9882, 0, '', 0, 'OKOPF', 0,0,'',20200,'') ;

CALL ImportDocType(9883, 0, ' ', 0, 'Org_Type', 0,0,'',20200,'') ;

CALL ImportDocType(9884, 0, '  ', 0, 'TransfertCLS', 0,0,'',20100,'') ;

CALL ImportDocType(9885, 0, ' ', 0, 'AssignmentKind', 0,0,'',20200,'') ;

CALL ImportDocType(9886, 0, ' ', 0, 'AssignmentSource', 0,0,'',20200,'') ;

CALL ImportDocType(9887, 0, '', 0, 'VariantCls', 0,0,'',20200,'') ;

CALL ImportDocType(9888, 0, '  ', 0, 'OKP', 0,0,'',20200,'') ;

CALL ImportDocType(9889, 0, ' ', 0, 'SubsidyCls', 0,0,'',20100,'') ;

CALL ImportDocType(9890, 0, '  ', 0, 'BudAllocationCls', 0,0,'',20100,'') ;

CALL ImportDocType(9891, 0, '  ', 0, 'PayPromiseCls', 0,0,'',20100,'') ;

CALL ImportDocType(9892, 0, '   ()', 0, 'ARCHIVEDOCTYPE', 0,0,'',20100,'') ;

CALL ImportDocType(9894, 0, '    ', 0, 'COMMDIRECTIONEXPENCECLS', 0,0,'',20100,'') ;

CALL ImportDocType(9895, 0, '', 0, 'OKTMO', 0,0,'',20100,'') ;

CALL ImportDocType(9899, 0, ' ', 0, 'DBUsers', 0,0,'',20100,'') ;

CALL ImportDocType(9903, 0, ' ', 0, ' ', 0,-1,'',10100,'_') ;

CALL ImportDocType(9913, 0, '', 0, '', 0,0,'',10200,'') ;

CALL ImportDocType(9914, 0, '  ', 0, '', 0,-1,'',10200,'') ;

CALL ImportDocType(9915, 0, '  ', 0, 'UnLockDates', 0,-1,'',10100,'') ;

CALL ImportDocType(9916, 0, ' ', 0, '', 0,0,'',10300,'') ;

CALL ImportDocType(9917, 0, ' ', 0, '', 0,0,'',10300,'') ;

CALL ImportDocType(9918, 0, '', 0, '', 0,0,'',10200,'') ;

CALL ImportDocType(9920, 0, '   ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9920, '   ', '{2F5EDB5F-CC69-4F04-9C91-B457D92C75AC}', '') ;

CALL ImportDocType(9922, 0, '  ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9922, '  ', '{C9277BAB-1206-41DD-966D-5D86A9E75AB8}', '') ;

CALL ImportDocType(9923, 0, '  ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9923, '  ', '{82245B63-9A83-41F5-8541-A77AAD1B6EAA}', '') ;

CALL ImportDocType(9926, 0, '   ', 0, 'WritNotifyCls ', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9926, '   ', '{89CAEE9C-9516-4EE2-8A4B-CB0BFA9165AB}', '') ;

CALL ImportDocType(9927, 0, '  ', 0, 'RemoteClient', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9927, '  ', '{60EFBA81-B436-11D6-8CA4-000021DDD8CD}', '') ;

CALL ImportDocType(9929, 0, '    ', 0, 'BudStruct', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9929, '    ', '{B95FC8BB-D031-4122-B714-B6F41ACFA610}', '') ;

CALL ImportDocType(9930, 0, '   ', 0, '', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9930, '   ', '{23B8DC44-93C1-48C2-B2EB-DCAF31C23929}', '') ;

DROP PROCEDURE ImportDocType
/

DROP PROCEDURE UPDATEINTERFACES
/



CREATE OR REPLACE PROCEDURE SELECTIONS_IMPORT(
  ID_ NUMBER,
  KIND_ NUMBER,
  NAME_ VARCHAR2,
  NOTE_ VARCHAR2,
  READONLY_ NUMBER,
  USEINDOC_ NUMBER,
  TABLENAME_ VARCHAR2,
  ALIAS_ VARCHAR2,
  TABLECODE_ NUMBER,
  NEEDGROUPONDB_ NUMBER,
  NEEDDISTINCT_ NUMBER,
  MASTER_ NUMBER,
  DISCRIMVALUE_ VARCHAR2,
  AVAILABLEINDEREF_ NUMBER,
  CACHETYPE_ NUMBER,
  FULLORMODINSREFRTIME_ NUMBER,
  DELETEREFRTIME_ NUMBER,
  FINDTIMEREFRESH_ NUMBER,
  ANNOTATION_ VARCHAR2,
  DEREFNAME_ VARCHAR2,
  GroupID_ NUMBER,
  IsLogged_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONS SET
      KIND = KIND_,
      NAME = NAME_,
      NOTE = NOTE_,
      READONLY = READONLY_,
      USEINDOC = USEINDOC_,
      TABLENAME = TABLENAME_,
      ALIAS = ALIAS_,
      TABLECODE = TABLECODE_,    
      NEEDGROUPONDB = NEEDGROUPONDB_,
      NEEDDISTINCT = NEEDDISTINCT_,
      MASTER = MASTER_,
      DISCRIMVALUE = DISCRIMVALUE_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,         
      CACHETYPE = CACHETYPE_,   
      FULLORMODINSREFRTIME = FULLORMODINSREFRTIME_,   
      DELETEREFRTIME = DELETEREFRTIME_,   
      FINDTIMEREFRESH = FINDTIMEREFRESH_,   
      ANNOTATION = ANNOTATION_,   
      DEREFNAME = DEREFNAME_,     
      GroupID = GroupID_, 
      IsLogged = IsLogged_  
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONS
      (ID, KIND, NAME, NOTE, READONLY, USEINDOC, TABLENAME, ALIAS, TABLECODE, NEEDGROUPONDB, NEEDDISTINCT, MASTER, DISCRIMVALUE,
      AVAILABLEINDEREF, CACHETYPE, FULLORMODINSREFRTIME, DELETEREFRTIME, FINDTIMEREFRESH, ANNOTATION, DEREFNAME, GroupID, IsLogged)
    VALUES
      (ID_, KIND_, NAME_, NOTE_, READONLY_, USEINDOC_, TABLENAME_, ALIAS_, TABLECODE_, NEEDGROUPONDB_, NEEDDISTINCT_, MASTER_, DISCRIMVALUE_,
      AVAILABLEINDEREF_, CACHETYPE_, FULLORMODINSREFRTIME_, DELETEREFRTIME_, FINDTIMEREFRESH_, ANNOTATION_, DEREFNAME_, GroupID_, IsLogged_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  ALIAS_ VARCHAR2,
  JOINORDER_ NUMBER,
  JOINTYPE_ NUMBER,
  RELATIONTYPE_ NUMBER,
  JOINCONDITION_ VARCHAR2,
  DONTUSETABLELIMITS_ NUMBER,
  LIMITNAMESLIST_ VARCHAR2,
  QueryGroup_ NUMBER  
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONSDETAIL
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONSDETAIL SET
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      ALIAS = ALIAS_,
      JOINORDER = JOINORDER_,
      JOINTYPE = JOINTYPE_,
      RELATIONTYPE = RELATIONTYPE_,
      JOINCONDITION = JOINCONDITION_,
      DONTUSETABLELIMITS = DONTUSETABLELIMITS_,
      LIMITNAMESLIST = LIMITNAMESLIST_,
      QueryGroup = QueryGroup_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONSDETAIL
      (ID, SELECTIONREF, TABLEREF, ALIAS, JOINORDER, JOINTYPE, RELATIONTYPE, JOINCONDITION, DONTUSETABLELIMITS, LIMITNAMESLIST, QueryGroup)
    VALUES
      (ID_, SELECTIONREF_, TABLEREF_, ALIAS_, JOINORDER_, JOINTYPE_, RELATIONTYPE_, JOINCONDITION_, DONTUSETABLELIMITS_, LIMITNAMESLIST_, QueryGroup_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_IMPORT(
  ID_ NUMBER,
  FIELDKIND_ NUMBER,
  DESCRIPTIONLEVEL_ NUMBER,
  ANCESTORREF_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  FIELDNAME_ VARCHAR2,
  DATATYPE_ NUMBER,
  SUBDATATYPE_ NUMBER,
  FIELDSIZE_ NUMBER,
  DISPLAYLABEL_ VARCHAR2,
  NOTE_ VARCHAR2,
  DEFAULTWIDTH_ NUMBER,
  EDITMASK_ VARCHAR2,
  DISPLAYFORMAT_ VARCHAR2,
  EDITFORMAT_ VARCHAR2,
  CANTEDIT_ NUMBER,
  NOVISUALIZE_ NUMBER,
  ENUMSREF_ NUMBER,
  REQUIRED_ NUMBER,
  FOREIGNKEY_ NUMBER,
  ONDELACTION_ NUMBER,
  PRIMARYKEY_ NUMBER,
  ISRVERSION_ NUMBER,
  LIMITPARAMNAMES_ VARCHAR2,
  FOLLOWORDER_ NUMBER,
  SORTDIRECTION_ NUMBER,
  SORTORDER_ NUMBER,
  AGRFUNCTION_ NUMBER,
  FLAGFIELDNAME_ NUMBER,
  FLAGDISPLAYLABEL_ NUMBER,
  FLAGNOTE_ NUMBER,
  FLAGDEFAULTWIDTH_ NUMBER,
  FLAGCANTEDIT_ NUMBER,
  FLAGNOVISUALIZE_ NUMBER,
  FLAGREQUIRED_ NUMBER,
  FLAGLIMITPARAMNAMES_ NUMBER,
  FLAGAGRFUNCTION_ NUMBER,
  ISTIMESTAMPFIELD_ NUMBER,
  ISBUDGET_ NUMBER,
  AVAILABLEINDEREF_ NUMBER,
  ANNOTATION_ VARCHAR2,
  ALIAS_ VARCHAR2,
  DEREFNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM FIELDSINFO
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE FIELDSINFO SET
      FIELDKIND = FIELDKIND_,
      DESCRIPTIONLEVEL = DESCRIPTIONLEVEL_,
      ANCESTORREF = ANCESTORREF_,
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      FIELDNAME = FIELDNAME_,
      DATATYPE = DATATYPE_,
      SUBDATATYPE = SUBDATATYPE_,
      FIELDSIZE = FIELDSIZE_,
      DISPLAYLABEL = DISPLAYLABEL_,
      NOTE = NOTE_,
      DEFAULTWIDTH = DEFAULTWIDTH_,
      EDITMASK = EDITMASK_,
      DISPLAYFORMAT = DISPLAYFORMAT_,
      EDITFORMAT = EDITFORMAT_,
      CANTEDIT = CANTEDIT_,
      NOVISUALIZE = NOVISUALIZE_,
      ENUMSREF = ENUMSREF_,
      REQUIRED = REQUIRED_,
      FOREIGNKEY = FOREIGNKEY_,
      ONDELACTION = ONDELACTION_,
      PRIMARYKEY = PRIMARYKEY_,
      ISRVERSION = ISRVERSION_,
      LIMITPARAMNAMES = LIMITPARAMNAMES_,
      FOLLOWORDER = FOLLOWORDER_,
      SORTDIRECTION = SORTDIRECTION_,
      SORTORDER = SORTORDER_,
      AGRFUNCTION = AGRFUNCTION_,
      FLAGFIELDNAME = FLAGFIELDNAME_,
      FLAGDISPLAYLABEL = FLAGDISPLAYLABEL_,
      FLAGNOTE = FLAGNOTE_,
      FLAGDEFAULTWIDTH = FLAGDEFAULTWIDTH_,
      FLAGCANTEDIT = FLAGCANTEDIT_,
      FLAGNOVISUALIZE = FLAGNOVISUALIZE_,
      FLAGREQUIRED = FLAGREQUIRED_,
      FLAGLIMITPARAMNAMES = FLAGLIMITPARAMNAMES_,
      FLAGAGRFUNCTION = FLAGAGRFUNCTION_,
      ISTIMESTAMPFIELD = ISTIMESTAMPFIELD_,
      ISBUDGET = ISBUDGET_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,
      ANNOTATION = ANNOTATION_,
      ALIAS = ALIAS_,
      DEREFNAME = DEREFNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO FIELDSINFO
      (ID, FIELDKIND, DESCRIPTIONLEVEL, ANCESTORREF, SELECTIONREF, TABLEREF, FIELDNAME, DATATYPE, SUBDATATYPE,
       FIELDSIZE, DISPLAYLABEL, NOTE, DEFAULTWIDTH, EDITMASK, DISPLAYFORMAT, EDITFORMAT, CANTEDIT, NOVISUALIZE,
       ENUMSREF, REQUIRED, FOREIGNKEY, ONDELACTION, PRIMARYKEY, ISRVERSION, LIMITPARAMNAMES,
       FOLLOWORDER, SORTDIRECTION, SORTORDER, AGRFUNCTION, FLAGFIELDNAME, FLAGDISPLAYLABEL, FLAGNOTE,
       FLAGDEFAULTWIDTH, FLAGCANTEDIT, FLAGNOVISUALIZE, FLAGREQUIRED, FLAGLIMITPARAMNAMES, FLAGAGRFUNCTION,
       ISTIMESTAMPFIELD, ISBUDGET, AVAILABLEINDEREF, ANNOTATION, ALIAS, DEREFNAME)
    VALUES
      (ID_, FIELDKIND_, DESCRIPTIONLEVEL_, ANCESTORREF_, SELECTIONREF_, TABLEREF_, FIELDNAME_, DATATYPE_, SUBDATATYPE_,
       FIELDSIZE_, DISPLAYLABEL_, NOTE_, DEFAULTWIDTH_, EDITMASK_, DISPLAYFORMAT_, EDITFORMAT_, CANTEDIT_, NOVISUALIZE_,
       ENUMSREF_, REQUIRED_, FOREIGNKEY_, ONDELACTION_, PRIMARYKEY_, ISRVERSION_, LIMITPARAMNAMES_,
       FOLLOWORDER_, SORTDIRECTION_, SORTORDER_, AGRFUNCTION_, FLAGFIELDNAME_, FLAGDISPLAYLABEL_, FLAGNOTE_,
       FLAGDEFAULTWIDTH_, FLAGCANTEDIT_, FLAGNOVISUALIZE_, FLAGREQUIRED_, FLAGLIMITPARAMNAMES_, FLAGAGRFUNCTION_,
       ISTIMESTAMPFIELD_, ISBUDGET_, AVAILABLEINDEREF_, ANNOTATION_, ALIAS_, DEREFNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  EVENTCODE_ NUMBER,
  SCRIPTNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONEVENTS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONEVENTS SET
      SELECTIONREF = SELECTIONREF_,
      EVENTCODE = EVENTCODE_,
      SCRIPTNAME = SCRIPTNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONEVENTS
      (ID, SELECTIONREF, EVENTCODE, SCRIPTNAME)
    VALUES
      (ID_, SELECTIONREF_, EVENTCODE_, SCRIPTNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_DELETE(
  ID_ NUMBER
) IS
BEGIN
  UPDATE DOCUMENTFIELDS SET
    FIELDINFOREF = NULL
  WHERE FIELDINFOREF = ID_;
  DELETE FROM FIELDSINFO FI
  WHERE FI.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONSDETAIL SLD
  WHERE SLD.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONEVENTS SE
  WHERE SE.ID = ID_;
END;
/

-- 
CALL FIELDSINFO_DELETE(16957) ;

CALL FIELDSINFO_DELETE(16958) ;

CALL FIELDSINFO_DELETE(16966) ;

CALL FIELDSINFO_DELETE(16967) ;

CALL FIELDSINFO_DELETE(16968) ;

CALL FIELDSINFO_DELETE(16975) ;

CALL FIELDSINFO_DELETE(16976) ;

CALL FIELDSINFO_DELETE(16977) ;

CALL FIELDSINFO_DELETE(18056) ;

CALL FIELDSINFO_DELETE(18057) ;

CALL FIELDSINFO_DELETE(18058) ;

CALL FIELDSINFO_DELETE(18060) ;

CALL FIELDSINFO_DELETE(18061) ;

CALL FIELDSINFO_DELETE(18062) ;

CALL FIELDSINFO_DELETE(18063) ;

CALL FIELDSINFO_DELETE(18064) ;

CALL FIELDSINFO_DELETE(18065) ;

CALL FIELDSINFO_DELETE(18066) ;

CALL FIELDSINFO_DELETE(18067) ;

CALL FIELDSINFO_DELETE(18068) ;

CALL FIELDSINFO_DELETE(18069) ;

CALL FIELDSINFO_DELETE(18070) ;

CALL FIELDSINFO_DELETE(18071) ;

CALL FIELDSINFO_DELETE(18072) ;

CALL FIELDSINFO_DELETE(18073) ;

CALL FIELDSINFO_DELETE(18098) ;

CALL FIELDSINFO_DELETE(18099) ;

CALL FIELDSINFO_DELETE(18100) ;

CALL FIELDSINFO_DELETE(18101) ;

CALL FIELDSINFO_DELETE(18102) ;

CALL FIELDSINFO_DELETE(18103) ;

CALL FIELDSINFO_DELETE(18104) ;

CALL FIELDSINFO_DELETE(18105) ;

CALL FIELDSINFO_DELETE(18106) ;

CALL FIELDSINFO_DELETE(18107) ;

CALL FIELDSINFO_DELETE(18108) ;

CALL FIELDSINFO_DELETE(18109) ;

CALL FIELDSINFO_DELETE(18110) ;

CALL FIELDSINFO_DELETE(18111) ;

CALL FIELDSINFO_DELETE(18112) ;

CALL FIELDSINFO_DELETE(18113) ;

CALL FIELDSINFO_DELETE(18114) ;

CALL FIELDSINFO_DELETE(18115) ;

CALL FIELDSINFO_DELETE(18116) ;

CALL FIELDSINFO_DELETE(18117) ;

CALL FIELDSINFO_DELETE(18118) ;

CALL FIELDSINFO_DELETE(18119) ;

CALL FIELDSINFO_DELETE(18120) ;

CALL FIELDSINFO_DELETE(18121) ;

CALL FIELDSINFO_DELETE(18154) ;

CALL FIELDSINFO_DELETE(18155) ;

CALL FIELDSINFO_DELETE(18156) ;

CALL FIELDSINFO_DELETE(18157) ;

CALL FIELDSINFO_DELETE(18158) ;

CALL FIELDSINFO_DELETE(18159) ;

CALL FIELDSINFO_DELETE(18160) ;

CALL FIELDSINFO_DELETE(18161) ;

CALL FIELDSINFO_DELETE(18162) ;

CALL FIELDSINFO_DELETE(18163) ;

CALL FIELDSINFO_DELETE(18164) ;

CALL FIELDSINFO_DELETE(18165) ;

CALL FIELDSINFO_DELETE(18166) ;

CALL FIELDSINFO_DELETE(18167) ;

CALL FIELDSINFO_DELETE(18168) ;

CALL FIELDSINFO_DELETE(18169) ;

CALL FIELDSINFO_DELETE(18171) ;

CALL FIELDSINFO_DELETE(18172) ;

CALL FIELDSINFO_DELETE(18173) ;

CALL FIELDSINFO_DELETE(18174) ;

CALL FIELDSINFO_DELETE(18175) ;

CALL FIELDSINFO_DELETE(18176) ;

CALL FIELDSINFO_DELETE(18177) ;

CALL FIELDSINFO_DELETE(18178) ;

CALL FIELDSINFO_DELETE(18179) ;

CALL FIELDSINFO_DELETE(18180) ;

CALL FIELDSINFO_DELETE(18181) ;

CALL FIELDSINFO_DELETE(18182) ;

CALL FIELDSINFO_DELETE(18183) ;

CALL FIELDSINFO_DELETE(18184) ;

CALL FIELDSINFO_DELETE(18185) ;

CALL FIELDSINFO_DELETE(18186) ;

CALL FIELDSINFO_DELETE(18187) ;

CALL FIELDSINFO_DELETE(18188) ;

CALL FIELDSINFO_DELETE(18190) ;

CALL FIELDSINFO_DELETE(18191) ;

CALL FIELDSINFO_DELETE(18192) ;

CALL FIELDSINFO_DELETE(18193) ;

CALL FIELDSINFO_DELETE(18194) ;

CALL FIELDSINFO_DELETE(18195) ;

CALL FIELDSINFO_DELETE(18196) ;

CALL FIELDSINFO_DELETE(18198) ;

CALL FIELDSINFO_DELETE(18199) ;

CALL FIELDSINFO_DELETE(18200) ;

CALL FIELDSINFO_DELETE(18201) ;

CALL FIELDSINFO_DELETE(18202) ;

CALL FIELDSINFO_DELETE(18203) ;

CALL FIELDSINFO_DELETE(18204) ;

CALL FIELDSINFO_DELETE(18205) ;

CALL FIELDSINFO_DELETE(18206) ;

CALL FIELDSINFO_DELETE(18207) ;

CALL FIELDSINFO_DELETE(18208) ;

CALL FIELDSINFO_DELETE(18209) ;

CALL FIELDSINFO_DELETE(18210) ;

CALL FIELDSINFO_DELETE(18211) ;

CALL FIELDSINFO_DELETE(18213) ;

CALL FIELDSINFO_DELETE(18214) ;

CALL FIELDSINFO_DELETE(18215) ;

CALL FIELDSINFO_DELETE(18216) ;

CALL FIELDSINFO_DELETE(18217) ;

CALL FIELDSINFO_DELETE(18218) ;

CALL FIELDSINFO_DELETE(18219) ;

CALL FIELDSINFO_DELETE(18220) ;

CALL FIELDSINFO_DELETE(18221) ;

CALL FIELDSINFO_DELETE(18222) ;

CALL FIELDSINFO_DELETE(18223) ;

CALL FIELDSINFO_DELETE(18224) ;

CALL FIELDSINFO_DELETE(18225) ;

CALL FIELDSINFO_DELETE(18227) ;

CALL FIELDSINFO_DELETE(18228) ;

CALL FIELDSINFO_DELETE(18229) ;

CALL FIELDSINFO_DELETE(18230) ;

CALL FIELDSINFO_DELETE(18231) ;

CALL FIELDSINFO_DELETE(18232) ;

CALL FIELDSINFO_DELETE(18233) ;

CALL FIELDSINFO_DELETE(18234) ;

CALL FIELDSINFO_DELETE(18236) ;

CALL FIELDSINFO_DELETE(18237) ;

CALL FIELDSINFO_DELETE(18238) ;

CALL FIELDSINFO_DELETE(18239) ;

CALL FIELDSINFO_DELETE(18240) ;

CALL FIELDSINFO_DELETE(18241) ;

CALL FIELDSINFO_DELETE(18242) ;

CALL FIELDSINFO_DELETE(18243) ;

CALL FIELDSINFO_DELETE(18244) ;

CALL FIELDSINFO_DELETE(18245) ;

CALL FIELDSINFO_DELETE(18247) ;

CALL FIELDSINFO_DELETE(18248) ;

CALL FIELDSINFO_DELETE(18249) ;

CALL FIELDSINFO_DELETE(18251) ;

CALL FIELDSINFO_DELETE(18252) ;

CALL FIELDSINFO_DELETE(18253) ;

CALL FIELDSINFO_DELETE(18254) ;

CALL FIELDSINFO_DELETE(18255) ;

CALL FIELDSINFO_DELETE(18256) ;

CALL FIELDSINFO_DELETE(18257) ;

CALL FIELDSINFO_DELETE(18258) ;

CALL FIELDSINFO_DELETE(18259) ;

CALL FIELDSINFO_DELETE(18260) ;

CALL FIELDSINFO_DELETE(18261) ;

CALL FIELDSINFO_DELETE(18263) ;

CALL FIELDSINFO_DELETE(18264) ;

CALL FIELDSINFO_DELETE(18265) ;

CALL FIELDSINFO_DELETE(18266) ;

CALL FIELDSINFO_DELETE(18267) ;

CALL FIELDSINFO_DELETE(18268) ;

CALL FIELDSINFO_DELETE(18269) ;

CALL FIELDSINFO_DELETE(18270) ;

CALL FIELDSINFO_DELETE(18272) ;

CALL FIELDSINFO_DELETE(18273) ;

CALL FIELDSINFO_DELETE(18274) ;

CALL FIELDSINFO_DELETE(18275) ;

CALL FIELDSINFO_DELETE(18276) ;

CALL FIELDSINFO_DELETE(18278) ;

CALL FIELDSINFO_DELETE(18279) ;

CALL FIELDSINFO_DELETE(18280) ;

CALL FIELDSINFO_DELETE(18282) ;

CALL FIELDSINFO_DELETE(18283) ;

CALL FIELDSINFO_DELETE(18284) ;

CALL FIELDSINFO_DELETE(18285) ;

CALL FIELDSINFO_DELETE(18286) ;

CALL FIELDSINFO_DELETE(18287) ;

CALL FIELDSINFO_DELETE(18288) ;

CALL FIELDSINFO_DELETE(18289) ;

CALL FIELDSINFO_DELETE(18290) ;

CALL FIELDSINFO_DELETE(18291) ;

CALL FIELDSINFO_DELETE(18292) ;

CALL FIELDSINFO_DELETE(18293) ;

CALL FIELDSINFO_DELETE(18294) ;

CALL FIELDSINFO_DELETE(18295) ;

CALL FIELDSINFO_DELETE(18296) ;

CALL FIELDSINFO_DELETE(18297) ;

CALL FIELDSINFO_DELETE(18298) ;

CALL FIELDSINFO_DELETE(18300) ;

CALL FIELDSINFO_DELETE(18301) ;

CALL FIELDSINFO_DELETE(18302) ;

CALL FIELDSINFO_DELETE(18303) ;

CALL FIELDSINFO_DELETE(18304) ;

CALL FIELDSINFO_DELETE(18305) ;

CALL FIELDSINFO_DELETE(18306) ;

CALL FIELDSINFO_DELETE(18307) ;

CALL FIELDSINFO_DELETE(18309) ;

CALL FIELDSINFO_DELETE(18310) ;

CALL FIELDSINFO_DELETE(18311) ;

CALL FIELDSINFO_DELETE(18312) ;

CALL FIELDSINFO_DELETE(18313) ;

CALL FIELDSINFO_DELETE(18314) ;

CALL FIELDSINFO_DELETE(18315) ;

CALL FIELDSINFO_DELETE(18316) ;

CALL FIELDSINFO_DELETE(18317) ;

CALL FIELDSINFO_DELETE(18318) ;

CALL FIELDSINFO_DELETE(18320) ;

CALL FIELDSINFO_DELETE(18321) ;

CALL FIELDSINFO_DELETE(18322) ;

CALL FIELDSINFO_DELETE(18323) ;

CALL FIELDSINFO_DELETE(18324) ;

CALL FIELDSINFO_DELETE(18325) ;

CALL FIELDSINFO_DELETE(18326) ;

CALL FIELDSINFO_DELETE(18327) ;

CALL FIELDSINFO_DELETE(18328) ;

CALL FIELDSINFO_DELETE(18329) ;

CALL FIELDSINFO_DELETE(18330) ;

CALL FIELDSINFO_DELETE(18332) ;

CALL FIELDSINFO_DELETE(18333) ;

CALL FIELDSINFO_DELETE(18334) ;

CALL FIELDSINFO_DELETE(18336) ;

CALL FIELDSINFO_DELETE(18337) ;

CALL FIELDSINFO_DELETE(18338) ;

CALL FIELDSINFO_DELETE(18339) ;

CALL FIELDSINFO_DELETE(18340) ;

CALL FIELDSINFO_DELETE(18341) ;

CALL FIELDSINFO_DELETE(18342) ;

CALL FIELDSINFO_DELETE(18343) ;

CALL FIELDSINFO_DELETE(18345) ;

CALL FIELDSINFO_DELETE(18346) ;

CALL FIELDSINFO_DELETE(18347) ;

CALL FIELDSINFO_DELETE(18348) ;

CALL FIELDSINFO_DELETE(18349) ;

CALL FIELDSINFO_DELETE(18351) ;

CALL FIELDSINFO_DELETE(18352) ;

CALL FIELDSINFO_DELETE(18353) ;

CALL FIELDSINFO_DELETE(18608) ;

CALL FIELDSINFO_DELETE(18609) ;

CALL FIELDSINFO_DELETE(18610) ;

CALL FIELDSINFO_DELETE(18611) ;

CALL FIELDSINFO_DELETE(18612) ;

CALL FIELDSINFO_DELETE(18613) ;

CALL FIELDSINFO_DELETE(18614) ;

CALL FIELDSINFO_DELETE(18615) ;

CALL FIELDSINFO_DELETE(18616) ;

CALL FIELDSINFO_DELETE(18617) ;

CALL FIELDSINFO_DELETE(18618) ;

CALL FIELDSINFO_DELETE(18619) ;

CALL FIELDSINFO_DELETE(18620) ;

CALL FIELDSINFO_DELETE(18621) ;

CALL FIELDSINFO_DELETE(18622) ;

CALL FIELDSINFO_DELETE(18623) ;

CALL FIELDSINFO_DELETE(18624) ;

CALL FIELDSINFO_DELETE(18625) ;

CALL FIELDSINFO_DELETE(18626) ;

CALL FIELDSINFO_DELETE(18674) ;

CALL FIELDSINFO_DELETE(18675) ;

CALL FIELDSINFO_DELETE(18676) ;

CALL FIELDSINFO_DELETE(18677) ;

CALL FIELDSINFO_DELETE(18678) ;

CALL FIELDSINFO_DELETE(18679) ;

CALL FIELDSINFO_DELETE(18680) ;

CALL FIELDSINFO_DELETE(18681) ;

CALL FIELDSINFO_DELETE(18682) ;

CALL FIELDSINFO_DELETE(18683) ;

CALL FIELDSINFO_DELETE(18684) ;

CALL FIELDSINFO_DELETE(18685) ;

CALL FIELDSINFO_DELETE(18687) ;

CALL FIELDSINFO_DELETE(18688) ;

CALL FIELDSINFO_DELETE(18689) ;

CALL FIELDSINFO_DELETE(18690) ;

CALL FIELDSINFO_DELETE(18691) ;

CALL FIELDSINFO_DELETE(18692) ;

CALL FIELDSINFO_DELETE(18693) ;

CALL FIELDSINFO_DELETE(18694) ;

CALL FIELDSINFO_DELETE(18695) ;

CALL FIELDSINFO_DELETE(18696) ;

CALL FIELDSINFO_DELETE(18698) ;

CALL FIELDSINFO_DELETE(18699) ;

CALL FIELDSINFO_DELETE(18700) ;

CALL FIELDSINFO_DELETE(18701) ;

CALL FIELDSINFO_DELETE(18703) ;

CALL FIELDSINFO_DELETE(18704) ;

CALL FIELDSINFO_DELETE(18705) ;

CALL FIELDSINFO_DELETE(18706) ;

CALL FIELDSINFO_DELETE(18708) ;

CALL FIELDSINFO_DELETE(18709) ;

CALL FIELDSINFO_DELETE(18711) ;

CALL FIELDSINFO_DELETE(18712) ;

CALL FIELDSINFO_DELETE(18714) ;

CALL FIELDSINFO_DELETE(18715) ;

CALL FIELDSINFO_DELETE(32350) ;

CALL FIELDSINFO_DELETE(32351) ;

CALL FIELDSINFO_DELETE(32352) ;

CALL FIELDSINFO_DELETE(32353) ;

CALL FIELDSINFO_DELETE(32354) ;

CALL FIELDSINFO_DELETE(32355) ;

CALL FIELDSINFO_DELETE(32356) ;

CALL FIELDSINFO_DELETE(32357) ;

CALL FIELDSINFO_DELETE(32358) ;

CALL FIELDSINFO_DELETE(32359) ;

CALL FIELDSINFO_DELETE(32935) ;

CALL FIELDSINFO_DELETE(34644) ;

CALL FIELDSINFO_DELETE(34648) ;

CALL FIELDSINFO_DELETE(34676) ;

CALL FIELDSINFO_DELETE(34680) ;

CALL FIELDSINFO_DELETE(34733) ;

CALL FIELDSINFO_DELETE(34737) ;

CALL FIELDSINFO_DELETE(34754) ;

CALL FIELDSINFO_DELETE(34758) ;

CALL FIELDSINFO_DELETE(34773) ;

CALL FIELDSINFO_DELETE(34777) ;

CALL FIELDSINFO_DELETE(34794) ;

CALL FIELDSINFO_DELETE(34798) ;

CALL FIELDSINFO_DELETE(34815) ;

CALL FIELDSINFO_DELETE(34819) ;

CALL FIELDSINFO_DELETE(34835) ;

CALL FIELDSINFO_DELETE(34839) ;

CALL FIELDSINFO_DELETE(35039) ;

CALL FIELDSINFO_DELETE(35040) ;

CALL FIELDSINFO_DELETE(38641) ;

CALL FIELDSINFO_DELETE(38642) ;

CALL FIELDSINFO_DELETE(38645) ;

CALL FIELDSINFO_DELETE(38646) ;

CALL FIELDSINFO_DELETE(38749) ;

CALL FIELDSINFO_DELETE(38752) ;

CALL FIELDSINFO_DELETE(38755) ;

CALL FIELDSINFO_DELETE(38756) ;

CALL FIELDSINFO_DELETE(38757) ;

CALL FIELDSINFO_DELETE(38761) ;

CALL FIELDSINFO_DELETE(38774) ;

CALL FIELDSINFO_DELETE(38957) ;

CALL SELECTIONS_DELETE(18055) ;

CALL SELECTIONS_DELETE(18097) ;

CALL SELECTIONS_DELETE(18153) ;

CALL SELECTIONS_DELETE(18170) ;

CALL SELECTIONS_DELETE(18189) ;

CALL SELECTIONS_DELETE(18197) ;

CALL SELECTIONS_DELETE(18212) ;

CALL SELECTIONS_DELETE(18226) ;

CALL SELECTIONS_DELETE(18235) ;

CALL SELECTIONS_DELETE(18246) ;

CALL SELECTIONS_DELETE(18250) ;

CALL SELECTIONS_DELETE(18262) ;

CALL SELECTIONS_DELETE(18271) ;

CALL SELECTIONS_DELETE(18277) ;

CALL SELECTIONS_DELETE(18281) ;

CALL SELECTIONS_DELETE(18299) ;

CALL SELECTIONS_DELETE(18308) ;

CALL SELECTIONS_DELETE(18319) ;

CALL SELECTIONS_DELETE(18331) ;

CALL SELECTIONS_DELETE(18335) ;

CALL SELECTIONS_DELETE(18344) ;

CALL SELECTIONS_DELETE(18350) ;

CALL SELECTIONS_DELETE(18607) ;

CALL SELECTIONS_DELETE(18673) ;

CALL SELECTIONS_DELETE(18686) ;

CALL SELECTIONS_DELETE(18697) ;

CALL SELECTIONS_DELETE(18702) ;

CALL SELECTIONS_DELETE(18707) ;

CALL SELECTIONS_DELETE(18710) ;

CALL SELECTIONS_DELETE(18713) ;

CALL SELECTIONS_DELETE(38627) ;

CALL SELECTIONS_IMPORT(16955, 1, 'FINTYPE', '  ', 0, 0, 'FINTYPE', 'FinType', 8, 0, 0, 2, '', 1, 1, 1800, null, 5, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(16973, 1, 'DOCBASE', '- ', 0, 0, 'DOCBASE', 'DocBase', 29, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(17043, 1, 'INNERFINSOURCE', '', 0, 0, 'INNERFINSOURCE', 'InnerFinSource', 145, 0, 0, 2, '', 1, 1, 1800, null, 5, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(17408, 1, 'BUDGETDATA', '   ', 0, 0, 'BUDGETDATA', 'BudgetData', 26, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 1) ;

CALL SELECTIONS_IMPORT(17463, 1, 'BUDNOTIFY', '  ', 0, 0, 'BUDNOTIFY', 'BudNotify', 28, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 1) ;

CALL SELECTIONS_IMPORT(17643, 1, 'QUOTESTITLE', '   ', 0, 0, 'QUOTESTITLE', 'QuotesTitle', 160, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 1) ;

CALL SELECTIONS_IMPORT(17668, 1, 'INCOMES32', ' () ', 0, 0, 'INCOMES32', 'Incomes32', 161, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 1) ;

CALL SELECTIONS_IMPORT(18864, 1, 'FACIALFINDETAIL', ' ', 0, 0, 'FACIALFINDETAIL', 'FacialFinDet', 22, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 1) ;

CALL SELECTIONS_IMPORT(18947, 1, 'FACIALFINCAPTION', ' ', 0, 0, 'FACIALFINCAPTION', 'FacialFinCpt', 23, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 1) ;

CALL SELECTIONS_IMPORT(21560, 1, 'PROGRAMCODE', ' ', 0, 0, 'PROGRAMCODE', 'ProgramCode', 0, 0, 0, 1, '', 1, 0, 3, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(22843, 1, 'CORRECTIONCAPTION', '   ', 0, 0, 'CORRECTIONCAPTION', 'CorrectionCpt', 5503, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 1) ;

CALL SELECTIONS_IMPORT(22908, 1, 'CORRECTIONDETAIL', '   ', 0, 0, 'CORRECTIONDETAIL', 'CorrectionDet', 5504, 0, 0, 2, '', 1, 0, 3, null, null, '', '', null, 1) ;

CALL SELECTIONS_IMPORT(32867, 2, 'CLS_302', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(37748, 2, 'CLS_210', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34400, 2, 'CLS_304', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34424, 2, 'CLS_305', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34448, 2, 'CLS_303', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34471, 2, 'CLS_306', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34494, 2, 'CLS_312', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34517, 2, 'CLS_311', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34539, 2, 'CLS_314', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34562, 2, 'CLS_315', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34588, 2, 'CLS_322', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34610, 2, 'CLS_323', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34631, 2, 'CLS_201', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34650, 2, 'CLS_202', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34718, 2, 'CLS_203', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34738, 2, 'CLS_204', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34759, 2, 'CLS_205', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34779, 2, 'CLS_206', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34799, 2, 'CLS_207', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34820, 2, 'CLS_208', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(34841, 2, 'CLS_4903', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, -1, null, 'PERSISTENT=STOREDAYCOUNT=7,"RefreshOptions=NotCheckUpdate=1,NotCheckDelete=1"', '', null, 0) ;

CALL SELECTIONS_IMPORT(35019, 2, 'CLS_903', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(37806, 1, 'OKPD2', '2 ( 034-2014)', 1, 0, 'OKPD2', 'OKPD2', 0, 0, 0, 2, '', 1, 0, -1, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(37807, 1, 'OKVED2', '2 ( 029-2014)', 1, 0, 'OKVED2', 'OKVED2', 0, 0, 0, 2, '', 1, 0, -1, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(36032, 1, 'CHANGELOGBYUPDDATE', '   ', 1, 0, 'CHANGELOGBYUPDDATE', 'ChangeLogByUpdDate', 0, 0, 0, 1, '', 0, 1, 3, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38203, 1, 'INVESTOBJECT', '', 0, 0, 'INVESTOBJECT', 'INVESTOBJECT', 0, 0, 0, 2, '', 1, 0, -1, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38701, 2, 'CLS_308', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38766, 2, 'CLS_324', '', 1, 0, '', '', 0, 1, 0, 1, '', 1, 1, 20, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38791, 2, 'CLS_209', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38818, 2, 'CLS_212', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38846, 2, 'CLS_211', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38906, 1, 'ANALYTICALGROUPKD', '   ', 0, 0, 'ANALYTICALGROUPKD', 'ANALYTICALGROUPKD', 0, 0, 0, 2, '', 1, 0, -1, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38917, 1, 'ANALYTICALGROUPIFS', '    ', 0, 0, 'ANALYTICALGROUPIFS', 'ANALYTICALGROUPIFS', 0, 0, 0, 2, '', 1, 0, -1, null, null, '', '', null, 0) ;

CALL SELECTIONSDETAIL_IMPORT(37751, 37748, 17463, 'BN', 0, 0, 1, 'BN.Progindex=252', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(37752, 37748, 17408, 'BDAT', 1, 2, 1, 'BDAT.RECORDINDEX=BN.ID', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38710, 38701, 18947, 'FFC', 0, 0, 1, 'FFC.Progindex=67', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38711, 38701, 18864, 'FFD', 1, 2, 1, 'FFD.RECORDINDEX=FFC.ID', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38767, 38766, 18947, 'FFC', 0, 0, 1, 'FFC.Progindex=76', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38768, 38766, 18864, 'FFD', 1, 1, 1, 'FFD.RECORDINDEX=FFC.ID', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38792, 38791, 17463, 'BN', 0, 0, 1, 'BN.Progindex=274', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38794, 38791, 17408, 'BDAT', 1, 2, 1, 'BDAT.RECORDINDEX=BN.ID', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38821, 38818, 17463, 'BN', 0, 0, 1, 'BN.Progindex=276', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38822, 38818, 17408, 'BDAT', 1, 2, 1, 'BDAT.RECORDINDEX=BN.ID', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38847, 38846, 17463, 'BN', 0, 0, 1, 'BN.Progindex=275', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38848, 38846, 17408, 'BDAT', 1, 2, 1, 'BDAT.RECORDINDEX=BN.ID', 0, '', 0) ;

-- ORGANIZATIONS
CALL FIELDSINFO_IMPORT(38087, 0, 1, null, 16642, null, 'OGRN', 1, 0, 20, '', '', 15, '9999999999999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 61, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(31711, 0, 1, null, 16642, null, 'DATEOPEN', 6, 0, 0, ' ', '', 11, '99/99/9999', 'dd/mm/yyyy', '', 0, 0, null, 0, null, 0, 0, 0, '', 50, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38088, 0, 1, null, 16642, null, 'REMOTEPBSCODE', 1, 0, 20, '', '', 6, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 62, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38089, 0, 1, null, 16642, null, 'REMOTENOTPBSCODE', 1, 0, 20, '', '', 6, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 63, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- INTCONST
CALL FIELDSINFO_IMPORT(36098, 0, 1, null, 16755, null, 'CLOSEDATE', 11, 0, 0, '  ', '', 20, '99/99/9999', '', '', 1, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36099, 0, 1, null, 16755, null, 'EDITDOCCODE', 3, 0, 0, ' ,     ', '', 11, '', '', '', 1, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

-- VARCHARCONST
CALL FIELDSINFO_IMPORT(36100, 0, 1, null, 16762, null, 'CLOSEDATE', 11, 0, 0, '  ', '', 20, '99/99/9999', '', '', 1, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36101, 0, 1, null, 16762, null, 'EDITDOCCODE', 3, 0, 0, ' ,     ', '', 11, '', '', '', 1, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- REALCONST
CALL FIELDSINFO_IMPORT(36102, 0, 1, null, 16767, null, 'CLOSEDATE', 11, 0, 0, '  ', '', 20, '99/99/9999', '', '', 1, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36103, 0, 1, null, 16767, null, 'EDITDOCCODE', 3, 0, 0, ' ,     ', '', 11, '', '', '', 1, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

-- KD
CALL FIELDSINFO_IMPORT(16830, 0, 1, null, 16824, null, 'KVSR', 3, 0, 0, ' ()', '', 4, '', '', '', 0, 0, null, 1, 16851, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(16834, 0, 1, null, 16824, null, 'PROGRAMCODE', 3, 0, 0, '', '', 5, '9999', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(16835, 0, 1, null, 16824, null, 'KESR', 3, 0, 0, '', '', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(24895, 0, 1, null, 16824, null, 'KD_LEVEL', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39102, 0, 1, null, 16824, null, 'ANALYTICALGROUPKD', 3, 0, 0, ' ()', '', 6, '', '', '', 0, 0, null, 1, 38906, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- KFSR
CALL FIELDSINFO_IMPORT(16845, 0, 1, null, 16844, null, 'ID', 3, 0, 0, '', '', 11, '99.99', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- KVSR
CALL FIELDSINFO_IMPORT(16852, 0, 1, null, 16851, null, 'ID', 3, 0, 0, '', '', 11, '999', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(25472, 0, 1, null, 16851, null, 'CODE', 3, 0, 0, '', '', 4, '999', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- KCSR
CALL FIELDSINFO_IMPORT(16858, 0, 1, null, 16857, null, 'ID', 3, 0, 0, '', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(25462, 0, 1, null, 16857, null, 'CODE', 1, 0, 20, '', '', 10, '>aa.a.aaaa', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- KVR
CALL FIELDSINFO_IMPORT(16865, 0, 1, null, 16864, null, 'ID', 3, 0, 0, '', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(25467, 0, 1, null, 16864, null, 'CODE', 1, 0, 20, '', '', 6, '>a.a.a', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- FINTYPE
CALL FIELDSINFO_IMPORT(16956, 0, 1, null, 16955, null, 'ID', 3, 0, 0, '', '', 11, '9.99', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36852, 0, 1, null, 16955, null, 'BUDGETREF', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36853, 0, 1, null, 16955, null, 'CODE', 1, 0, 20, '', '', 6, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- FACT
CALL FIELDSINFO_IMPORT(16965, 0, 1, null, 16964, null, 'ID', 3, 0, 0, '', '', 11, '99.99.99', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36863, 0, 1, null, 16964, null, 'CODE', 1, 0, 20, '', '', 20, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36864, 0, 1, null, 16964, null, 'BUDGETREF', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38101, 0, 1, null, 16964, null, 'EXTID', 1, 0, 50, 'UID     ', '', 30, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- DOCBASE
CALL FIELDSINFO_IMPORT(16974, 0, 1, null, 16973, null, 'ID', 3, 0, 0, '', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(16978, 0, 1, null, 16973, null, 'NAME', 1, 0, 1024, '', '', 60, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(16981, 0, 1, null, 16973, null, 'DOCUMENTBASEDATE', 6, 0, 0, ' ', ' ', 11, '99/99/9999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(16982, 0, 1, null, 16973, null, 'DOCUMENTBASENUM', 1, 0, 50, ' ', ' ', 40, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36865, 0, 1, null, 16973, null, 'CODE', 1, 0, 20, '', '', 20, '>aa.aa.aaa', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36866, 0, 1, null, 16973, null, 'BUDGETREF', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36867, 0, 1, null, 16973, null, 'DELETEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36868, 0, 1, null, 16973, null, 'STARTDATE', 11, 0, 0, '   ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- INNERFINSOURCE
CALL FIELDSINFO_IMPORT(17049, 0, 1, null, 17043, null, 'KVSR', 3, 0, 0, ' ()', '', 4, '999', '999', '', 0, 0, null, 1, 16851, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(17054, 0, 1, null, 17043, null, 'KESR', 3, 0, 0, '', '', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39103, 0, 1, null, 17043, null, 'ANALYTICALGROUPIFS', 3, 0, 0, ' ()', '', 6, '', '', '', 0, 0, null, 0, 38917, 0, 0, 0, '', 23, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- ORG_ACCOUNTS
CALL FIELDSINFO_IMPORT(37184, 0, 1, null, 17108, null, 'DATEOPEN', 6, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37185, 0, 1, null, 17108, null, 'DATECLOSE', 6, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- FACIALACC_CLS
CALL FIELDSINFO_IMPORT(37183, 0, 1, null, 17129, null, 'PREVCLS', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 0, 17129, 0, 0, 0, '', 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- BUDGETDATA
CALL FIELDSINFO_IMPORT(17461, 0, 1, null, 17408, null, 'KVRCORR', 3, 0, 0, ' ', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16864, 0, 0, 0, '', 53, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- BUDNOTIFY
CALL FIELDSINFO_IMPORT(36043, 0, 1, null, 17463, null, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 50, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

-- QUOTESTITLE
CALL FIELDSINFO_IMPORT(36046, 0, 1, null, 17643, null, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 34, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

-- INCOMES32
CALL FIELDSINFO_IMPORT(36856, 0, 1, null, 17668, null, 'FINTYPE', 3, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 77, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- FACIALFINDETAIL
CALL FIELDSINFO_IMPORT(38150, 0, 1, null, 18864, null, 'TRANSFERTORG_REF', 3, 0, 0, ' ()', '    ()  ', 11, '', '', '', 0, 0, null, 0, 16642, 0, 0, 0, '', 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- FACIALFINCAPTION
CALL FIELDSINFO_IMPORT(38174, 0, 1, null, 18947, null, 'SIGNERS', 1, 0, 1000, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38187, 0, 1, null, 18947, null, 'DESTCLSTYPE', 3, 0, 0, '  ', ' : 0 -  ( ),1 - ', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- TENDEROBJECTS
CALL FIELDSINFO_IMPORT(37820, 0, 1, null, 20694, null, 'OKPD2', 3, 0, 0, '2', '', 9, '99.99.99.999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 46, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37821, 0, 1, null, 20694, null, 'OKVED2', 3, 0, 0, '2', '', 6, '99.99.99', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 47, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- DATECONST
CALL FIELDSINFO_IMPORT(36104, 0, 1, null, 20787, null, 'CLOSEDATE', 11, 0, 0, '  ', '', 20, '99/99/9999', '', '', 1, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36105, 0, 1, null, 20787, null, 'EDITDOCCODE', 3, 0, 0, ' ,     ', '', 11, '', '', '', 1, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

-- DIRECTIONCLS
CALL FIELDSINFO_IMPORT(21556, 0, 1, null, 21555, null, 'ID', 3, 0, 0, '', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36861, 0, 1, null, 21555, null, 'CODE', 1, 0, 20, '', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(36862, 0, 1, null, 21555, null, 'BUDGETREF', 3, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- BUHACCPLAN
CALL FIELDSINFO_IMPORT(21630, 0, 1, null, 21627, null, 'ECCLS', 3, 0, 0, '  ()', '', 4, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39104, 0, 1, null, 21627, null, 'CLSTYPE', 3, 0, 0, ' ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- BUHOPERATIONCLS
CALL FIELDSINFO_IMPORT(36047, 0, 1, null, 21634, null, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

-- UNIONNOTIFYDETAIL
CALL FIELDSINFO_IMPORT(36850, 0, 1, null, 21709, null, 'FINTYPE', 3, 0, 0, '  ()', '', 9, '', '', '', 0, 0, null, 0, 16955, 0, 0, 0, '', 38, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

-- DATAPACKETTYPES
CALL FIELDSINFO_IMPORT(37777, 0, 1, null, 22405, null, 'SIGNSCHEME', 3, 0, 0, '   ', '', 11, '', '', '', 0, 0, null, 0, 30659, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- CORRECTIONCAPTION
CALL FIELDSINFO_IMPORT(36044, 0, 1, null, 22843, null, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 82, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

-- UNLOCKDATES
CALL FIELDSINFO_IMPORT(38954, 0, 1, null, 23058, null, 'DAYKIND', 3, 0, 0, '  ', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

-- WRITEXECUTIONCAPTION
CALL FIELDSINFO_IMPORT(38743, 0, 1, null, 23400, null, 'COMPLETIONDATE', 6, 0, 0, ' ', '', 0, '99/99/9999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 64, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- WRITEXECUTIONDETAIL
CALL FIELDSINFO_IMPORT(38499, 0, 1, null, 23401, null, 'CLSTYPE', 3, 0, 0, ' ', ' ', 11, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 59, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38500, 0, 1, null, 23401, null, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 60, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38765, 0, 1, null, 23401, null, 'NOTE', 1, 0, 1024, ' ', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 61, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- WRITNOTIFYCLS
CALL FIELDSINFO_IMPORT(38513, 0, 1, null, 31616, null, 'ALLOWDOCSTATES', 1, 0, 255, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38514, 0, 1, null, 31616, null, 'ALLOWWRITTYPES', 1, 0, 50, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- OKTMO
CALL FIELDSINFO_IMPORT(32824, 0, 1, null, 32820, null, 'CODE1', 1, 0, 10, ' ', '', 10, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32822, 0, 1, null, 32820, null, 'CODE', 1, 0, 20, '', '', 14, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32825, 0, 1, null, 32820, null, 'CODE2', 3, 0, 0, '  ', '', 11, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32826, 0, 1, null, 32820, null, 'NAME', 1, 0, 1024, '', '', 60, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32827, 0, 1, null, 32820, null, 'NAMEOKTMO8', 1, 0, 1024, ' ', '', 60, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32828, 0, 1, null, 32820, null, 'NOTEOKTMO8', 1, 0, 255, ' ', '', 40, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32829, 0, 1, null, 32820, null, 'STARTDATE', 11, 0, 0, '   ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32830, 0, 1, null, 32820, null, 'DELETEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32831, 0, 1, null, 32820, null, 'CREATEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32832, 0, 1, null, 32820, null, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32833, 0, 1, null, 32820, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32834, 0, 1, null, 32820, null, 'UPDATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(32847, 0, 1, null, 32820, null, 'REGIONCLS', 3, 0, 0, '', '', 11, '99.99.99', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- CHANGELOGBYUPDDATE
CALL FIELDSINFO_IMPORT(36033, 0, 1, null, 36032, null, 'ID', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, '', '', '') ;

CALL FIELDSINFO_IMPORT(36034, 0, 1, null, 36032, null, 'TABLEID', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, '', '', '') ;

CALL FIELDSINFO_IMPORT(36035, 0, 1, null, 36032, null, 'OLDUPDATEDATE', 11, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, '', '', '') ;

CALL FIELDSINFO_IMPORT(36036, 0, 1, null, 36032, null, 'NEWUPDATEDATE', 11, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, '', '', '') ;

CALL FIELDSINFO_IMPORT(36037, 0, 1, null, 36032, null, 'NEWDELETEDATE', 11, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, '', '', '') ;

CALL FIELDSINFO_IMPORT(36038, 0, 1, null, 36032, null, 'CHANGEDATE', 11, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, '', '', '') ;

-- OKPD2
CALL FIELDSINFO_IMPORT(37808, 0, 1, null, 37806, null, 'ID', 3, 0, 0, '', '', 0, '', '', '', 1, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37809, 0, 1, null, 37806, null, 'NAME', 1, 0, 1024, '', '', 0, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37810, 0, 1, null, 37806, null, 'STARTDATE', 11, 0, 0, '   ', '', 0, '', '', '', 1, 0, null, 0, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37811, 0, 1, null, 37806, null, 'DELETEDATE', 11, 0, 0, ' (  )', '', 0, '', '', '', 1, 0, null, 0, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37812, 0, 1, null, 37806, null, 'CREATEDATE', 11, 0, 0, ' ', '', 0, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37813, 0, 1, null, 37806, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 0, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', '', '') ;

-- OKVED2
CALL FIELDSINFO_IMPORT(37814, 0, 1, null, 37807, null, 'ID', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37815, 0, 1, null, 37807, null, 'NAME', 1, 0, 1024, '', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37816, 0, 1, null, 37807, null, 'STARTDATE', 11, 0, 0, '   ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37817, 0, 1, null, 37807, null, 'DELETEDATE', 11, 0, 0, ' (  )', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37818, 0, 1, null, 37807, null, 'CREATEDATE', 11, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(37819, 0, 1, null, 37807, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', '', '') ;

-- INVESTOBJECT
CALL FIELDSINFO_IMPORT(38204, 0, 1, null, 38203, null, 'ID', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38205, 0, 1, null, 38203, null, 'CODE', 1, 0, 20, '', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38206, 0, 1, null, 38203, null, 'SUBCODE', 1, 0, 20, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38207, 0, 1, null, 38203, null, 'BUDGETFINSOURCEOBJECTCODE', 1, 0, 20, '   ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38208, 0, 1, null, 38203, null, 'NAME', 1, 0, 2000, '  ', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38209, 0, 1, null, 38203, null, 'SHORTNAME', 1, 0, 1024, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38210, 0, 1, null, 38203, null, 'OWNERLEVEL', 3, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38211, 0, 1, null, 38203, null, 'BUDGETREF', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38212, 0, 1, null, 38203, null, 'REGIONCLS', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38213, 0, 1, null, 38203, null, 'BUDGETFINSOURCELEVEL', 3, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38214, 0, 1, null, 38203, null, 'PARENTREF', 3, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38215, 0, 1, null, 38203, null, 'STARTDATE', 11, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38216, 0, 1, null, 38203, null, 'DELETEDATE', 11, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38217, 0, 1, null, 38203, null, 'KVSR', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38218, 0, 1, null, 38203, null, 'KCSR', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38219, 0, 1, null, 38203, null, 'TARGETCLS', 3, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38220, 0, 1, null, 38203, null, 'NOTE', 1, 0, 1024, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38221, 0, 1, null, 38203, null, 'MEANSTYPE', 3, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38222, 0, 1, null, 38203, null, 'TRANSFERTCLS', 3, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38223, 0, 1, null, 38203, null, 'FACT', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38224, 0, 1, null, 38203, null, 'OKTMO', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38225, 0, 1, null, 38203, null, 'NPAID', 3, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38226, 0, 1, null, 38203, null, 'NPADATE', 11, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 23, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38227, 0, 1, null, 38203, null, 'NPANUMBER', 1, 0, 20, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 24, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38228, 0, 1, null, 38203, null, 'NPAGROUP', 1, 0, 1024, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38229, 0, 1, null, 38203, null, 'NPANAME', 1, 0, 1024, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38230, 0, 1, null, 38203, null, 'ADDRESS', 1, 0, 1024, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38231, 0, 1, null, 38203, null, 'CREATEDATE', 11, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38232, 0, 1, null, 38203, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 29, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38233, 0, 1, null, 38203, null, 'CREATERUSER', 1, 0, 30, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 30, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38234, 0, 1, null, 38203, null, 'UPDATERUSER', 1, 0, 30, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- ANALYTICALGROUPKD
CALL FIELDSINFO_IMPORT(38907, 0, 1, null, 38906, null, 'ID', 3, 0, 0, ' ', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38908, 0, 1, null, 38906, null, 'CODE', 1, 0, 20, '', '', 0, '999', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38909, 0, 1, null, 38906, null, 'CREATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38910, 0, 1, null, 38906, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38911, 0, 1, null, 38906, null, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38912, 0, 1, null, 38906, null, 'UPDATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38913, 0, 1, null, 38906, null, 'NAME', 1, 0, 1024, '', '', 60, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38914, 0, 1, null, 38906, null, 'BUDGETREF', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38915, 0, 1, null, 38906, null, 'DELETEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38916, 0, 1, null, 38906, null, 'STARTDATE', 11, 0, 0, '   ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38931, 0, 1, null, 38906, null, 'EXTID', 1, 0, 50, 'UID     ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38932, 0, 1, null, 38906, null, 'EXTOWNER', 1, 0, 50, '  ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38933, 0, 1, null, 38906, null, 'EXTSYNCDATE', 11, 0, 0, '     ', '', 20, '99/99/9999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- ANALYTICALGROUPIFS
CALL FIELDSINFO_IMPORT(38918, 0, 1, null, 38917, null, 'ID', 3, 0, 0, ' ', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38919, 0, 1, null, 38917, null, 'CODE', 1, 0, 20, '', '', 0, '999', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38920, 0, 1, null, 38917, null, 'CREATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38921, 0, 1, null, 38917, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38922, 0, 1, null, 38917, null, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38923, 0, 1, null, 38917, null, 'UPDATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38924, 0, 1, null, 38917, null, 'NAME', 1, 0, 1024, '', '', 60, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38925, 0, 1, null, 38917, null, 'BUDGETREF', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38926, 0, 1, null, 38917, null, 'DELETEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38927, 0, 1, null, 38917, null, 'STARTDATE', 11, 0, 0, '   ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38928, 0, 1, null, 38917, null, 'EXTID', 1, 0, 50, 'UID     ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38929, 0, 1, null, 38917, null, 'EXTOWNER', 1, 0, 50, '  ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38930, 0, 1, null, 38917, null, 'EXTSYNCDATE', 11, 0, 0, '     ', '', 20, '99/99/9999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- CLS_302
CALL FIELDSINFO_IMPORT(35935, 0, 2, 18865, 32867, 32869, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 25, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36063, 0, 2, 18948, 32867, 32868, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 26, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

-- CLS_304
CALL FIELDSINFO_IMPORT(35937, 0, 2, 18865, 34400, 34402, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 26, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36065, 0, 2, 18948, 34400, 34401, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 27, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

-- CLS_305
CALL FIELDSINFO_IMPORT(35938, 0, 2, 18865, 34424, 34427, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 26, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36066, 0, 2, 18948, 34424, 34426, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 27, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

-- CLS_303
CALL FIELDSINFO_IMPORT(35936, 0, 2, 18865, 34448, 34451, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 24, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36064, 0, 2, 18948, 34448, 34450, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 25, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38654, 0, 2, 18926, 34448, 34451, 'DESTKD', 3, 0, 0, ' ', '    ', 11, '', '', '', 0, 0, null, 0, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

-- CLS_306
CALL FIELDSINFO_IMPORT(35939, 0, 2, 18865, 34471, 34474, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 25, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36067, 0, 2, 18948, 34471, 34473, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 26, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

-- CLS_312
CALL FIELDSINFO_IMPORT(35941, 0, 2, 18865, 34494, 34497, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 25, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36069, 0, 2, 18948, 34494, 34496, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 26, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

-- CLS_311
CALL FIELDSINFO_IMPORT(34928, 0, 2, 18927, 34517, 34520, 'SOURCEREGIONCLS', 3, 0, 0, ' .', '', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 1, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'REGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(35940, 0, 2, 18865, 34517, 34520, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 24, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36068, 0, 2, 18948, 34517, 34519, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 25, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38753, 0, 2, 18956, 34517, 34519, 'SOURCEACCOUNT', 3, 0, 0, '\ ', '   ()', 11, '', '', '', 0, 0, null, 0, 17108, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'ACCOUNT', '') ;

-- CLS_314
CALL FIELDSINFO_IMPORT(34545, 0, 2, 18958, 34539, 34541, 'DESTACCOUNT', 3, 0, 0, '\ ', '   ()', 11, '', '', '', 0, 0, null, 0, 17108, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DESTACCOUNT', '') ;

CALL FIELDSINFO_IMPORT(35942, 0, 2, 18865, 34539, 34542, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 25, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36070, 0, 2, 18948, 34539, 34541, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 26, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

-- CLS_315
CALL FIELDSINFO_IMPORT(35943, 0, 2, 18865, 34562, 34565, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 25, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36071, 0, 2, 18948, 34562, 34564, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 26, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

-- CLS_322
CALL FIELDSINFO_IMPORT(34603, 0, 2, 18868, 34588, 34591, 'SOURCEKESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 0, 16871, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'KESR', '') ;

CALL FIELDSINFO_IMPORT(36021, 0, 2, 18892, 34588, 34591, 'SOURCEFINSOURCE', 3, 0, 0, ' ', ' ', 4, '999', '', '', 0, 0, null, 1, 16983, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'NOTIFYTYPE', '') ;

CALL FIELDSINFO_IMPORT(35944, 0, 2, 18865, 34588, 34591, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 24, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36072, 0, 2, 18948, 34588, 34590, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 26, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

-- CLS_323
CALL FIELDSINFO_IMPORT(35945, 0, 2, 18865, 34610, 34613, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 23, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36073, 0, 2, 18948, 34610, 34612, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 24, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

-- CLS_201
CALL FIELDSINFO_IMPORT(36042, 0, 2, 17464, 34631, 34632, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 23, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(35927, 0, 2, 17409, 34631, 34633, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36048, 0, 2, 36043, 34631, 34632, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 24, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38635, 0, 2, 17452, 34631, 34633, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

CALL FIELDSINFO_IMPORT(38636, 0, 2, 25270, 34631, 34633, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

-- CLS_202
CALL FIELDSINFO_IMPORT(35928, 0, 2, 17409, 34650, 34653, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36049, 0, 2, 36043, 34650, 34652, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 23, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(36050, 0, 2, 17464, 34650, 34652, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 24, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38637, 0, 2, 17452, 34650, 34653, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

CALL FIELDSINFO_IMPORT(38638, 0, 2, 25270, 34650, 34653, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

-- CLS_203
CALL FIELDSINFO_IMPORT(35929, 0, 2, 17409, 34718, 34721, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36051, 0, 2, 36043, 34718, 34720, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 23, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(36052, 0, 2, 17464, 34718, 34720, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 24, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38639, 0, 2, 17452, 34718, 34721, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

CALL FIELDSINFO_IMPORT(38640, 0, 2, 25270, 34718, 34721, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

-- CLS_204
CALL FIELDSINFO_IMPORT(35718, 0, 2, 17474, 34738, 34740, 'VARIANT', 3, 0, 0, ' ', ' ', 4, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'VARIANT', '') ;

CALL FIELDSINFO_IMPORT(34755, 0, 2, 17472, 34738, 34740, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(34756, 0, 2, 17477, 34738, 34740, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(34878, 0, 2, 17485, 34738, 34740, 'REJECTCLS', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17026, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'REJECTCLS', '') ;

CALL FIELDSINFO_IMPORT(35930, 0, 2, 17409, 34738, 34741, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 23, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36053, 0, 2, 36043, 34738, 34740, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 24, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(36054, 0, 2, 17464, 34738, 34740, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 25, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38643, 0, 2, 17451, 34738, 34741, 'BUHOPERATIONCLS', 3, 0, 0, ' ', '    70', 11, '999.99', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

-- CLS_205
CALL FIELDSINFO_IMPORT(35931, 0, 2, 17409, 34759, 34762, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 21, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36055, 0, 2, 36043, 34759, 34761, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 22, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(36056, 0, 2, 17464, 34759, 34761, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 23, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38644, 0, 2, 17451, 34759, 34762, 'BUHOPERATIONCLS', 3, 0, 0, ' ', '    70', 11, '999.99', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 24, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38647, 0, 2, 17419, 34759, 34762, 'FACIALACC_CLS', 3, 0, 0, ' ', ' ', 13, '999.99.999.9', '', '', 0, 0, null, 1, 17129, 0, 0, 0, '', 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACIALACC_CLS', '') ;

CALL FIELDSINFO_IMPORT(38648, 0, 2, 26542, 34759, 34762, 'SUBSIDYCLS', 3, 0, 0, '', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBSIDYCLS', '') ;

-- CLS_206
CALL FIELDSINFO_IMPORT(35932, 0, 2, 17409, 34779, 34782, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36057, 0, 2, 36043, 34779, 34781, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 23, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(36058, 0, 2, 17464, 34779, 34781, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 24, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38649, 0, 2, 17452, 34779, 34782, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

CALL FIELDSINFO_IMPORT(38650, 0, 2, 25270, 34779, 34782, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

-- CLS_207
CALL FIELDSINFO_IMPORT(36059, 0, 2, 36043, 34799, 34801, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 24, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(35933, 0, 2, 17409, 34799, 34802, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 23, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36060, 0, 2, 17464, 34799, 34801, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 25, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38651, 0, 2, 17452, 34799, 34802, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

-- CLS_208
CALL FIELDSINFO_IMPORT(35934, 0, 2, 17409, 34820, 34823, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36061, 0, 2, 36043, 34820, 34822, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 23, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(36062, 0, 2, 17464, 34820, 34822, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 24, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38652, 0, 2, 17452, 34820, 34823, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

CALL FIELDSINFO_IMPORT(38653, 0, 2, 25270, 34820, 34823, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

-- CLS_4903
CALL FIELDSINFO_IMPORT(35946, 0, 2, 22469, 34841, 34842, 'ID', 3, 0, 0, ' ', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 8, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

-- CLS_903
CALL FIELDSINFO_IMPORT(35947, 0, 2, 17669, 35019, 35024, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 18, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(36074, 0, 2, 36046, 35019, 35023, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 19, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(36075, 0, 2, 17644, 35019, 35023, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 20, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38956, 0, 2, 17712, 35019, 35024, 'KESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KESR', '') ;

-- 
CALL FIELDSINFO_IMPORT(36014, 0, 2, 16965, 36012, 36013, 'ID', 3, 0, 0, '', '', 11, '99.99.99', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'ID', '') ;

-- CLS_210
CALL FIELDSINFO_IMPORT(37753, 0, 2, 17474, 37748, 37751, 'VARIANT', 3, 0, 0, ' ', ' ', 4, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'VARIANT', '') ;

CALL FIELDSINFO_IMPORT(37754, 0, 2, 17451, 37748, 37752, 'BUHOPERATIONCLS', 3, 0, 0, ' ', '    70', 11, '999.99', '', '', 0, 0, null, 0, 21634, 0, 0, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(37755, 0, 2, 17450, 37748, 37752, 'DIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '000', '000', 0, 0, null, 0, 21555, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'DIRECTIONCLS', '') ;

CALL FIELDSINFO_IMPORT(37756, 0, 2, 17419, 37748, 37752, 'FACIALACC_CLS', 3, 0, 0, ' ', ' ', 13, '999.99.999.9', '', '', 0, 0, null, 0, 17129, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'FACIALACC_CLS', '') ;

CALL FIELDSINFO_IMPORT(37757, 0, 2, 17413, 37748, 37752, 'KCSR', 3, 0, 0, '', '', 11, '999.99.99', '000', '000', 0, 0, null, 0, 16857, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'KCSR', '') ;

CALL FIELDSINFO_IMPORT(37758, 0, 2, 17415, 37748, 37752, 'KESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 0, 16871, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'KESR', '') ;

CALL FIELDSINFO_IMPORT(37759, 0, 2, 17411, 37748, 37752, 'KFSR', 3, 0, 0, '', ' ', 6, '99.99', '', '', 0, 0, null, 0, 16844, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'KFSR', '') ;

CALL FIELDSINFO_IMPORT(37760, 0, 2, 17414, 37748, 37752, 'KVR', 3, 0, 0, '', '', 7, '>AAA', '000', '000', 0, 0, null, 0, 16864, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'KVR', '') ;

CALL FIELDSINFO_IMPORT(37761, 0, 2, 17412, 37748, 37752, 'KVSR', 3, 0, 0, '', '', 4, '999', '000', '000', 0, 0, null, 0, 16851, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'KVSR', '') ;

CALL FIELDSINFO_IMPORT(37762, 0, 2, 17416, 37748, 37752, 'SUBKESR', 3, 0, 0, '', '   ', 10, '9.9.9', '', '', 0, 0, null, 0, 16915, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'SUBKESR', '') ;

CALL FIELDSINFO_IMPORT(37763, 0, 2, 26542, 37748, 37752, 'SUBSIDYCLS', 3, 0, 0, '', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'SUBSIDYCLS', '') ;

CALL FIELDSINFO_IMPORT(37764, 0, 2, 17472, 37748, 37751, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(37765, 0, 2, 17477, 37748, 37751, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(37766, 0, 2, 17418, 37748, 37752, 'FACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 0, 16964, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'FACT', '') ;

CALL FIELDSINFO_IMPORT(37767, 0, 2, 17485, 37748, 37751, 'REJECTCLS', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17026, 0, 0, 0, '', 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'REJECTCLS', '') ;

CALL FIELDSINFO_IMPORT(37768, 0, 2, 17426, 37748, 37752, 'MEANSTYPE', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17311, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'MEANSTYPE', '') ;

CALL FIELDSINFO_IMPORT(37769, 0, 2, 17417, 37748, 37752, 'REGIONCLS', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 0, 16688, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'REGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(37770, 0, 2, 17460, 37748, 37752, 'TRANSFERTCLS', 3, 0, 0, '   ()', '    ', 12, '', '', '', 0, 0, null, 0, 22773, 0, 0, 0, '', 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'TRANSFERTCLS', '') ;

CALL FIELDSINFO_IMPORT(37771, 0, 2, 17409, 37748, 37752, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 0, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(37772, 0, 2, 17464, 37748, 37751, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 23, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(37773, 0, 2, 36043, 37748, 37751, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 24, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38633, 0, 2, 17452, 37748, 37752, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FINSOURCE', '') ;

CALL FIELDSINFO_IMPORT(38762, 0, 2, 25270, 37748, 34633, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

-- CLS_308
CALL FIELDSINFO_IMPORT(38713, 0, 2, 18979, 38701, 38710, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(38714, 0, 2, 18983, 38701, 38710, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(38715, 0, 2, 18958, 38701, 38710, 'DESTACCOUNT', 3, 0, 0, '\ ', '   ()', 11, '', '', '', 0, 0, null, 0, 17108, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DESTACCOUNT', '') ;

CALL FIELDSINFO_IMPORT(38716, 0, 2, 18957, 38701, 38710, 'SOURCEFACIALACC_CLS', 3, 0, 0, '\ ', '   ', 13, '999.99.999.9', '', '', 0, 0, null, 1, 17129, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEFACIALACC_CLS', '') ;

CALL FIELDSINFO_IMPORT(38717, 0, 2, 18887, 38701, 38711, 'SOURCEKCSR', 3, 0, 0, ' ()', '  ', 11, '999.99.99', '', '', 0, 0, null, 1, 16857, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEKCSR', '') ;

CALL FIELDSINFO_IMPORT(38718, 0, 2, 18888, 38701, 38711, 'SOURCEKFSR', 3, 0, 0, '', ' ', 6, '99.99', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEKFSR', '') ;

CALL FIELDSINFO_IMPORT(38719, 0, 2, 18867, 38701, 38711, 'SOURCEKVR', 3, 0, 0, ' ()', '  ', 7, '>AAA', '', '', 0, 0, null, 1, 16864, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEKVR', '') ;

CALL FIELDSINFO_IMPORT(38720, 0, 2, 18886, 38701, 38711, 'SOURCEKVSR', 3, 0, 0, ' ()', '  ', 4, '999', '', '', 0, 0, null, 1, 16851, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEKVSR', '') ;

CALL FIELDSINFO_IMPORT(38721, 0, 2, 18919, 38701, 38711, 'BUHOPERATIONCLS', 3, 0, 0, ' ', '    70', 11, '999.99', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38722, 0, 2, 26626, 38701, 38711, 'SOURCESUBSIDYCLS', 3, 0, 0, '', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCESUBSIDYCLS', '') ;

CALL FIELDSINFO_IMPORT(38723, 0, 2, 18891, 38701, 38711, 'SOURCEMEANSTYPE', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 1, 17311, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEMEANSTYPE', '') ;

CALL FIELDSINFO_IMPORT(38724, 0, 2, 18927, 38701, 38711, 'SOURCEREGIONCLS', 3, 0, 0, ' .', '', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEREGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38725, 0, 2, 18935, 38701, 38711, 'SOURCETRANSFERTCLS', 3, 0, 0, '    ()', '    ', 12, '9.99.999.999', '', '', 0, 0, null, 0, 22773, 0, 0, 0, '', 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCETRANSFERTCLS', '') ;

CALL FIELDSINFO_IMPORT(38726, 0, 2, 34968, 38701, 38710, 'DOCCHANGEDATE', 11, 0, 0, '   ', ' ,  ', 20, '99/99/9999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38727, 0, 2, 18972, 38701, 38710, 'REJECT_CLS', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17026, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REJECT_CLS', '') ;

CALL FIELDSINFO_IMPORT(38728, 0, 2, 18865, 38701, 38711, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 1, null, 0, 0, 0, '', 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(38729, 0, 2, 18948, 38701, 38710, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38730, 0, 2, 18898, 38701, 38711, 'DESTSUBKESR', 3, 0, 0, '', '   ', 10, '999.99.99', '', '', 0, 0, null, 1, 16915, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEKESR', '') ;

CALL FIELDSINFO_IMPORT(38731, 0, 2, 18889, 38701, 38711, 'SOURCESUBKESR', 3, 0, 0, '', '   ', 10, '999.99.99', '', '', 0, 0, null, 1, 16915, 0, 0, 0, '', 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCESUBKESR', '') ;

CALL FIELDSINFO_IMPORT(38732, 0, 2, 18913, 38701, 38711, 'SOURCEDIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '', '', 0, 0, null, 1, 21555, 0, 0, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEDIRECTIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38733, 0, 2, 18890, 38701, 38711, 'SOURCEFACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16964, 0, 0, 0, '', 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEFACT', '') ;

CALL FIELDSINFO_IMPORT(38734, 0, 2, 18920, 38701, 38711, 'SOURCEIFS', 3, 0, 0, '  ()', '   .  ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 23, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEIFS', '') ;

CALL FIELDSINFO_IMPORT(38735, 0, 2, 18925, 38701, 38711, 'SOURCEKD', 3, 0, 0, ' ', '    ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 24, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SOURCEKD', '') ;

-- CLS_324
CALL FIELDSINFO_IMPORT(38769, 0, 2, 18983, 38766, 38767, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(38770, 0, 2, 18919, 38766, 38768, 'BUHOPERATIONCLS', 3, 0, 0, ' ', '    70', 11, '999.99', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38771, 0, 2, 18979, 38766, 38767, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(38772, 0, 2, 34968, 38766, 38767, 'DOCCHANGEDATE', 11, 0, 0, '   ', ' ,  ', 20, '99/99/9999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38773, 0, 2, 18948, 38766, 38767, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38775, 0, 2, 18972, 38766, 38767, 'REJECT_CLS', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17026, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REJECT_CLS', '') ;

CALL FIELDSINFO_IMPORT(38776, 0, 2, 18958, 38766, 38767, 'DESTACCOUNT', 3, 0, 0, '\ ', '   ()', 11, '', '', '', 0, 0, null, 0, 17108, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'ACCOUNT', '') ;

CALL FIELDSINFO_IMPORT(38777, 0, 2, 18914, 38766, 38768, 'DESTDIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '', '', 0, 0, null, 1, 21555, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DIRECTIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38778, 0, 2, 18869, 38766, 38768, 'DESTFACIALACC_CLS', 3, 0, 0, '\ ', '   ', 13, '999.99.999.9', '', '', 0, 0, null, 1, 17129, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACIALACC_CLS', '') ;

CALL FIELDSINFO_IMPORT(38779, 0, 2, 18899, 38766, 38768, 'DESTFACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16964, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACT', '') ;

CALL FIELDSINFO_IMPORT(38780, 0, 2, 18896, 38766, 38768, 'DESTKCSR', 3, 0, 0, ' ()', '  ', 11, '999.99.99', '', '', 0, 0, null, 1, 16857, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KCSR', '') ;

CALL FIELDSINFO_IMPORT(38781, 0, 2, 18871, 38766, 38768, 'DESTKESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KESR', '') ;

CALL FIELDSINFO_IMPORT(38782, 0, 2, 18897, 38766, 38768, 'DESTKFSR', 3, 0, 0, '', ' ', 6, '99.99', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KFSR', '') ;

CALL FIELDSINFO_IMPORT(38783, 0, 2, 18870, 38766, 38768, 'DESTKVR', 3, 0, 0, ' ()', '  ', 7, '>AAA', '', '', 0, 0, null, 1, 16864, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVR', '') ;

CALL FIELDSINFO_IMPORT(38784, 0, 2, 18895, 38766, 38768, 'DESTKVSR', 3, 0, 0, ' ()', '  ', 4, '999', '', '', 0, 0, null, 1, 16851, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVSR', '') ;

CALL FIELDSINFO_IMPORT(38785, 0, 2, 18900, 38766, 38768, 'DESTMEANSTYPE', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 1, 17311, 0, 0, 0, '', 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'MEANSTYPE', '') ;

CALL FIELDSINFO_IMPORT(38786, 0, 2, 18928, 38766, 38768, 'DESTREGIONCLS', 3, 0, 0, ' -', '', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38787, 0, 2, 18898, 38766, 38768, 'DESTSUBKESR', 3, 0, 0, '', '   ', 10, '999.99.99', '', '', 0, 0, null, 1, 16915, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBKESR', '') ;

CALL FIELDSINFO_IMPORT(38788, 0, 2, 26624, 38766, 38768, 'DESTSUBSIDYCLS', 3, 0, 0, '', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBSIDYCLS', '') ;

CALL FIELDSINFO_IMPORT(38789, 0, 2, 18936, 38766, 38768, 'DESTTRANSFERTCLS', 3, 0, 0, '    ()', '    ', 12, '9.99.999.999', '', '', 0, 0, null, 0, 22773, 0, 0, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'TRANSFERTCLS', '') ;

CALL FIELDSINFO_IMPORT(38790, 0, 2, 18865, 38766, 38768, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 1, null, 0, 0, 0, '', 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'RECORDCOUNT', '') ;

-- CLS_209
CALL FIELDSINFO_IMPORT(38795, 0, 2, 17472, 38791, 38792, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(38796, 0, 2, 17451, 38791, 38794, 'BUHOPERATIONCLS', 3, 0, 0, ' ', '    70', 11, '999.99', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38797, 0, 2, 17477, 38791, 38792, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(38798, 0, 2, 17450, 38791, 38794, 'DIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '000', '000', 0, 0, null, 1, 21555, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DIRECTIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38799, 0, 2, 36043, 38791, 38792, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38800, 0, 2, 17419, 38791, 38794, 'FACIALACC_CLS', 3, 0, 0, ' ', ' ', 13, '999.99.999.9', '', '', 0, 0, null, 1, 17129, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACIALACC_CLS', '') ;

CALL FIELDSINFO_IMPORT(38801, 0, 2, 17418, 38791, 38794, 'FACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16964, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACT', '') ;

CALL FIELDSINFO_IMPORT(38802, 0, 2, 17409, 38791, 38794, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 1, null, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(38803, 0, 2, 17464, 38791, 38792, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38804, 0, 2, 17452, 38791, 38794, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

CALL FIELDSINFO_IMPORT(38805, 0, 2, 17413, 38791, 38794, 'KCSR', 3, 0, 0, '', '', 11, '999.99.99', '000', '000', 0, 0, null, 1, 16857, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KCSR', '') ;

CALL FIELDSINFO_IMPORT(38806, 0, 2, 17415, 38791, 38794, 'KESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KESR', '') ;

CALL FIELDSINFO_IMPORT(38807, 0, 2, 17411, 38791, 38794, 'KFSR', 3, 0, 0, '', ' ', 6, '99.99', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KFSR', '') ;

CALL FIELDSINFO_IMPORT(38808, 0, 2, 17414, 38791, 38794, 'KVR', 3, 0, 0, '', '', 7, '>AAA', '000', '000', 0, 0, null, 1, 16864, 0, 0, 0, '', 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVR', '') ;

CALL FIELDSINFO_IMPORT(38809, 0, 2, 17412, 38791, 38794, 'KVSR', 3, 0, 0, '', '', 4, '999', '000', '000', 0, 0, null, 1, 16851, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVSR', '') ;

CALL FIELDSINFO_IMPORT(38810, 0, 2, 17426, 38791, 38794, 'MEANSTYPE', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 1, 17311, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'MEANSTYPE', '') ;

CALL FIELDSINFO_IMPORT(38811, 0, 2, 17417, 38791, 38794, 'REGIONCLS', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 0, 0, '', 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38812, 0, 2, 17485, 38791, 38792, 'REJECTCLS', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17026, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REJECTCLS', '') ;

CALL FIELDSINFO_IMPORT(38813, 0, 2, 17416, 38791, 38794, 'SUBKESR', 3, 0, 0, '', '   ', 10, '9.9.9', '', '', 0, 0, null, 1, 16915, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBKESR', '') ;

CALL FIELDSINFO_IMPORT(38814, 0, 2, 26542, 38791, 38794, 'SUBSIDYCLS', 3, 0, 0, '', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBSIDYCLS', '') ;

CALL FIELDSINFO_IMPORT(38815, 0, 2, 17460, 38791, 38794, 'TRANSFERTCLS', 3, 0, 0, '   ()', '    ', 12, '', '', '', 0, 0, null, 0, 22773, 0, 0, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'TRANSFERTCLS', '') ;

CALL FIELDSINFO_IMPORT(38816, 0, 2, 17474, 38791, 38792, 'VARIANT', 3, 0, 0, ' ', ' ', 4, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'VARIANT', '') ;

-- CLS_212
CALL FIELDSINFO_IMPORT(38837, 0, 2, 17414, 38818, 34633, 'KVR', 3, 0, 0, '', '', 7, '>AAA', '000', '000', 0, 0, null, 1, 16864, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVR', '') ;

CALL FIELDSINFO_IMPORT(38838, 0, 2, 17412, 38818, 34633, 'KVSR', 3, 0, 0, '', '', 4, '999', '000', '000', 0, 0, null, 1, 16851, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVSR', '') ;

CALL FIELDSINFO_IMPORT(38839, 0, 2, 17426, 38818, 34633, 'MEANSTYPE', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 1, 17311, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'MEANSTYPE', '') ;

CALL FIELDSINFO_IMPORT(38840, 0, 2, 17417, 38818, 34633, 'REGIONCLS', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38841, 0, 2, 17485, 38818, 38821, 'REJECTCLS', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17026, 0, 0, 0, '', 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REJECTCLS', '') ;

CALL FIELDSINFO_IMPORT(38842, 0, 2, 17416, 38818, 38822, 'SUBKESR', 3, 0, 0, '', '   ', 10, '9.9.9', '', '', 0, 0, null, 1, 16915, 0, 0, 0, '', 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBKESR', '') ;

CALL FIELDSINFO_IMPORT(38843, 0, 2, 26542, 38818, 38822, 'SUBSIDYCLS', 3, 0, 0, '', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 29, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBSIDYCLS', '') ;

CALL FIELDSINFO_IMPORT(38844, 0, 2, 17460, 38818, 38822, 'TRANSFERTCLS', 3, 0, 0, '   ()', '    ', 12, '', '', '', 0, 0, null, 0, 22773, 0, 0, 0, '', 30, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'TRANSFERTCLS', '') ;

CALL FIELDSINFO_IMPORT(38845, 0, 2, 17474, 38818, 38821, 'VARIANT', 3, 0, 0, ' ', ' ', 4, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'VARIANT', '') ;

CALL FIELDSINFO_IMPORT(38823, 0, 2, 17472, 38818, 34632, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(38824, 0, 2, 17451, 38818, 34633, 'BUHOPERATIONCLS', 3, 0, 0, ' ', '    70', 11, '999.99', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38825, 0, 2, 17477, 38818, 34632, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(38826, 0, 2, 17450, 38818, 34633, 'DIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '000', '000', 0, 0, null, 1, 21555, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DIRECTIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38827, 0, 2, 36043, 38818, 34632, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 24, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38828, 0, 2, 17419, 38818, 34633, 'FACIALACC_CLS', 3, 0, 0, ' ', ' ', 13, '999.99.999.9', '', '', 0, 0, null, 1, 17129, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACIALACC_CLS', '') ;

CALL FIELDSINFO_IMPORT(38829, 0, 2, 17418, 38818, 34633, 'FACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16964, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACT', '') ;

CALL FIELDSINFO_IMPORT(38830, 0, 2, 17464, 38818, 34632, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 23, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38831, 0, 2, 17409, 38818, 34633, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(38832, 0, 2, 17452, 38818, 34633, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

CALL FIELDSINFO_IMPORT(38833, 0, 2, 17413, 38818, 34633, 'KCSR', 3, 0, 0, '', '', 11, '999.99.99', '000', '000', 0, 0, null, 1, 16857, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KCSR', '') ;

CALL FIELDSINFO_IMPORT(38834, 0, 2, 25270, 38818, 34633, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

CALL FIELDSINFO_IMPORT(38835, 0, 2, 17415, 38818, 34633, 'KESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KESR', '') ;

CALL FIELDSINFO_IMPORT(38836, 0, 2, 17411, 38818, 34633, 'KFSR', 3, 0, 0, '', ' ', 6, '99.99', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KFSR', '') ;

-- CLS_211
CALL FIELDSINFO_IMPORT(38849, 0, 2, 17472, 38846, 34632, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(38850, 0, 2, 17451, 38846, 34633, 'BUHOPERATIONCLS', 3, 0, 0, ' ', '    70', 11, '999.99', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38851, 0, 2, 17477, 38846, 34632, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(38852, 0, 2, 17450, 38846, 34633, 'DIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '000', '000', 0, 0, null, 1, 21555, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DIRECTIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38853, 0, 2, 36043, 38846, 34632, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 24, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38854, 0, 2, 17419, 38846, 34633, 'FACIALACC_CLS', 3, 0, 0, ' ', ' ', 13, '999.99.999.9', '', '', 0, 0, null, 1, 17129, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACIALACC_CLS', '') ;

CALL FIELDSINFO_IMPORT(38855, 0, 2, 17418, 38846, 34633, 'FACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16964, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACT', '') ;

CALL FIELDSINFO_IMPORT(38856, 0, 2, 17464, 38846, 34632, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 23, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38857, 0, 2, 17409, 38846, 34633, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(38858, 0, 2, 17452, 38846, 34633, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

CALL FIELDSINFO_IMPORT(38859, 0, 2, 17413, 38846, 34633, 'KCSR', 3, 0, 0, '', '', 11, '999.99.99', '000', '000', 0, 0, null, 1, 16857, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KCSR', '') ;

CALL FIELDSINFO_IMPORT(38860, 0, 2, 25270, 38846, 34633, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

CALL FIELDSINFO_IMPORT(38861, 0, 2, 17415, 38846, 34633, 'KESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KESR', '') ;

CALL FIELDSINFO_IMPORT(38862, 0, 2, 17411, 38846, 34633, 'KFSR', 3, 0, 0, '', ' ', 6, '99.99', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KFSR', '') ;

CALL FIELDSINFO_IMPORT(38863, 0, 2, 17414, 38846, 34633, 'KVR', 3, 0, 0, '', '', 7, '>AAA', '000', '000', 0, 0, null, 1, 16864, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVR', '') ;

CALL FIELDSINFO_IMPORT(38864, 0, 2, 17412, 38846, 34633, 'KVSR', 3, 0, 0, '', '', 4, '999', '000', '000', 0, 0, null, 1, 16851, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVSR', '') ;

CALL FIELDSINFO_IMPORT(38865, 0, 2, 17426, 38846, 34633, 'MEANSTYPE', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 1, 17311, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'MEANSTYPE', '') ;

CALL FIELDSINFO_IMPORT(38866, 0, 2, 17417, 38846, 34633, 'REGIONCLS', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38867, 0, 2, 17485, 38846, 38847, 'REJECTCLS', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17026, 0, 0, 0, '', 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REJECTCLS', '') ;

CALL FIELDSINFO_IMPORT(38868, 0, 2, 17416, 38846, 38848, 'SUBKESR', 3, 0, 0, '', '   ', 10, '9.9.9', '', '', 0, 0, null, 1, 16915, 0, 0, 0, '', 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBKESR', '') ;

CALL FIELDSINFO_IMPORT(38869, 0, 2, 26542, 38846, 38848, 'SUBSIDYCLS', 3, 0, 0, '', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 29, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBSIDYCLS', '') ;

CALL FIELDSINFO_IMPORT(38870, 0, 2, 17460, 38846, 38848, 'TRANSFERTCLS', 3, 0, 0, '   ()', '    ', 12, '', '', '', 0, 0, null, 0, 22773, 0, 0, 0, '', 30, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'TRANSFERTCLS', '') ;

CALL FIELDSINFO_IMPORT(38871, 0, 2, 17474, 38846, 38847, 'VARIANT', 3, 0, 0, ' ', ' ', 4, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'VARIANT', '') ;

--  
DROP PROCEDURE SELECTIONS_IMPORT
/

DROP PROCEDURE SELECTIONSDETAIL_IMPORT
/

DROP PROCEDURE FIELDSINFO_IMPORT
/

DROP PROCEDURE SELECTIONEVENTS_IMPORT
/

DROP PROCEDURE FIELDSINFO_DELETE
/

DROP PROCEDURE SELECTIONSDETAIL_DELETE
/

DROP PROCEDURE SELECTIONS_DELETE
/

DROP PROCEDURE SELECTIONEVENTS_DELETE
/

CREATE OR REPLACE PROCEDURE ImportDocCLS (
   ID_                 NUMBER,
   DOCTYPE_            NUMBER,
   DOCTYPENOTE_        VARCHAR2,
   TABLENAME_          VARCHAR2,
   TABLENAMEURM_       VARCHAR2,
   PRIMARYKEYNAME_     VARCHAR2,
   PRIMARYKEYNAMEURM_  VARCHAR2,
   LINKFIELDNAME_      VARCHAR2,
   LINKFIELDNAMEURM_   VARCHAR2,
   CLSTYPE_            NUMBER,
   SELECTIONREFBUDGET_ NUMBER,
   SELECTIONREFURM_    NUMBER,
   PROGINDEX_          NUMBER
) IS IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
   INTO IDExists$
   FROM DOCUMENTCLS
   WHERE (ID = ID_);

   IF (IDExists$ = 0) THEN
   INSERT INTO DOCUMENTCLS
   (ID, DOCTYPE, DOCTYPENOTE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM, LINKFIELDNAME, LINKFIELDNAMEURM, CLSTYPE, 
     SELECTIONREFBUDGET, SELECTIONREFURM, PROGINDEX)
   VALUES (ID_, DOCTYPE_, DOCTYPENOTE_, TABLENAME_, TABLENAMEURM_, PRIMARYKEYNAME_, PRIMARYKEYNAMEURM_, LINKFIELDNAME_, LINKFIELDNAMEURM_, CLSTYPE_, 
     SELECTIONREFBUDGET_, SELECTIONREFURM_, PROGINDEX_);
   ELSE
   UPDATE DOCUMENTCLS 
   SET
     DOCTYPENOTE = DOCTYPENOTE_,
     TABLENAME = TABLENAME_,
     TABLENAMEURM = TABLENAMEURM_,
     PRIMARYKEYNAME = PRIMARYKEYNAME_,
     PRIMARYKEYNAMEURM = PRIMARYKEYNAMEURM_,
     LINKFIELDNAME = LINKFIELDNAME_,
     LINKFIELDNAMEURM = LINKFIELDNAMEURM_,
     CLSTYPE = CLSTYPE_,
     SELECTIONREFBUDGET = SELECTIONREFBUDGET_,
     SELECTIONREFURM = SELECTIONREFURM_,
     PROGINDEX = PROGINDEX_
   WHERE  
    (ID = ID_)
    AND NOT (
            (
                    ((DOCTYPENOTE IS NOT NULL AND DOCTYPENOTE_ IS NOT NULL) AND
                       (UPPER (DOCTYPENOTE) = UPPER (DOCTYPENOTE_))
                    )
                    OR (DOCTYPENOTE IS NULL AND DOCTYPENOTE_ IS NULL)
                )    
        AND (UPPER (TABLENAME) = UPPER (TABLENAME_))    
        AND (
                    ((TABLENAMEURM IS NOT NULL AND TABLENAMEURM_ IS NOT NULL) AND
                       (UPPER (TABLENAMEURM) = UPPER (TABLENAMEURM_))
                    )
                    OR (TABLENAMEURM IS NULL AND TABLENAMEURM_ IS NULL)
                )    
        AND (UPPER (PRIMARYKEYNAME) = UPPER (PRIMARYKEYNAME_))
        AND (
                    ((PRIMARYKEYNAMEURM IS NOT NULL AND PRIMARYKEYNAMEURM_ IS NOT NULL) AND
                       (UPPER (PRIMARYKEYNAMEURM) = UPPER (PRIMARYKEYNAMEURM_))
                    )
                    OR (PRIMARYKEYNAMEURM IS NULL AND PRIMARYKEYNAMEURM_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAME IS NOT NULL AND LINKFIELDNAME_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAME) = UPPER (LINKFIELDNAME_))
                    )
                    OR (LINKFIELDNAME IS NULL AND LINKFIELDNAME_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAMEURM IS NOT NULL AND LINKFIELDNAMEURM_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAMEURM) = UPPER (LINKFIELDNAMEURM_))
                    )
                    OR (LINKFIELDNAMEURM IS NULL AND LINKFIELDNAMEURM_ IS NULL)
                )    
        AND (
                    ((CLSTYPE IS NOT NULL AND CLSTYPE_ IS NOT NULL) AND
                       (UPPER (CLSTYPE) = UPPER (CLSTYPE_))
                    )
                    OR (CLSTYPE IS NULL AND CLSTYPE_ IS NULL)
                ) 
        AND (
                    ((PROGINDEX IS NOT NULL AND PROGINDEX_ IS NOT NULL) AND
                       (PROGINDEX = PROGINDEX_)
                    )
                    OR (PROGINDEX IS NULL AND PROGINDEX_ IS NULL)
                )   
            );
   
   END IF;
END;
/

--   
CALL ImportDocCLS(10100, 101, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10101, 101, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10102, 101, ' ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10103, 101, ' ', 'DEBT', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10104, 101, ' %  ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10105, 101, ' ', 'INCOMES32', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20100, 201, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(20101, 201, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(30100, 301, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30101, 301, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30200, 302, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30201, 302, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30300, 303, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30301, 303, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30400, 304, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30401, 304, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30500, 305, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30501, 305, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30600, 306, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30601, 306, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30700, 307, '', 'FACIALFINREESTR', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(31100, 311, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31101, 311, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31200, 312, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31201, 312, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31400, 314, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31401, 314, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31500, 315, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(31501, 315, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(992500, 9925, '', 'Cards', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992501, 9925, ' ', 'CARDSDETAIL_FACC', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(490300, 4903, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 527) ;

CALL ImportDocCLS(32200, 322, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32201, 322, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32300, 323, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32301, 323, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32400, 324, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(32401, 324, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(40100, 401, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 130) ;

CALL ImportDocCLS(40101, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 131) ;

CALL ImportDocCLS(40102, 401, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 137) ;

CALL ImportDocCLS(40103, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 132) ;

CALL ImportDocCLS(40104, 401, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 134) ;

CALL ImportDocCLS(40105, 401, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 138) ;

CALL ImportDocCLS(40106, 401, ' %', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 133) ;

CALL ImportDocCLS(40107, 401, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40108, 401, '. ', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40109, 401, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 340) ;

CALL ImportDocCLS(40110, 401, '.', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 341) ;

CALL ImportDocCLS(40111, 401, '', 'LOANCREDITCONTRACTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 342) ;

CALL ImportDocCLS(50100, 501, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 120) ;

CALL ImportDocCLS(50101, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 121) ;

CALL ImportDocCLS(50102, 501, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 127) ;

CALL ImportDocCLS(50103, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 122) ;

CALL ImportDocCLS(50104, 501, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 124) ;

CALL ImportDocCLS(50105, 501, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 128) ;

CALL ImportDocCLS(50106, 501, ' %', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 123) ;

CALL ImportDocCLS(50107, 501, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(50108, 501, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 321) ;

CALL ImportDocCLS(70100, 701, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70101, 701, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70200, 702, '', 'PAYDOC32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70201, 702, '', 'PAYDOC32', ' ', 'ID', ' ', 'PARENTINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70300, 703, '', 'FINDOCDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, 36) ;

CALL ImportDocCLS(80100, 801, '', 'LIMITNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80101, 801, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 57) ;

CALL ImportDocCLS(80200, 802, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80300, 803, '', 'REQUESTFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80301, 803, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80400, 804, '', 'LIMITFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90100, 901, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 145) ;

CALL ImportDocCLS(90101, 901, '', 'INCOMES32', ' ', 'ID', ' ', 'RecordIndex', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90300, 903, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90301, 903, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90500, 905, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 44) ;

CALL ImportDocCLS(90600, 906, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 41) ;

CALL ImportDocCLS(90601, 906, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 42) ;

CALL ImportDocCLS(120100, 1201, '', 'BUH_JOURNAL', ' ', 'ID', ' ', '', ' ', 0, null, null, 309) ;

CALL ImportDocCLS(150100, 1501, '', 'ORGOPERAT', ' ', 'ID', ' ', '', ' ', 0, null, null, 35) ;

CALL ImportDocCLS(160100, 1601, '', 'PROMISE_CAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(160101, 1601, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', 'TITLE_REF', ' ', 0, null, null, 345) ;

CALL ImportDocCLS(160200, 1602, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(170100, 1701, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 222) ;

CALL ImportDocCLS(170200, 1702, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 221) ;

CALL ImportDocCLS(170201, 1702, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(190100, 1901, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(190101, 1901, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(220100, 2201, '', 'BUDNOTIFY', 'BUDNOTIFY', 'ID', ' ', '', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(220101, 2201, '', 'BUDGETDATA', 'BUDGETDATA', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(280100, 2801, '', 'ACCSOPERTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(280101, 2801, '', 'PAYDOC32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 16) ;

CALL ImportDocCLS(280200, 2802, '', 'DFACCOUNTOPERATION', ' ', 'ID', ' ', '', ' ', 0, null, null, 50) ;

CALL ImportDocCLS(440100, 4401, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(440101, 4401, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(0, 0, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991304, 9913, ' ', 'STATICLINKS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(440300, 4403, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(440301, 4403, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(989500, 9895, ' ', 'OKTMO', 'OKTMO', 'id', 'id', '', '', 95, null, null, null) ;

CALL ImportDocCLS(990300, 9903, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990301, 9903, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990302, 9903, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990500, 9905, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90200, 902, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 38) ;

CALL ImportDocCLS(20701, 207, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(90700, 907, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181200, 1812, '', 'ED_CorrectionCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181000, 1810, '', 'ED_OUTPAYDOC', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20700, 207, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(181001, 1810, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992700, 9927, '', 'REMOTECLIENT', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550100, 5501, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(20801, 208, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(30701, 307, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', 'REESTR_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21100, 211, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 275) ;

CALL ImportDocCLS(490100, 4901, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 525) ;

CALL ImportDocCLS(992701, 9927, '  ', 'REMOTEREADRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(550101, 5501, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(490301, 4903, '', 'ARCHIVEOPLOG', ' ', 'ID', ' ', 'DATAPACKETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(390100, 3901, '', 'DELOIN', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21101, 211, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(992300, 9923, '', 'SIGNSCHEMECAPTION', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181201, 1812, '', 'ED_CorrectionDetail', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(550200, 5502, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(20800, 208, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(550201, 5502, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(90000, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992301, 9923, '', 'SIGNSCHEMEDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991600, 9916, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992200, 9922, '', 'ARCHIVEDOCTYPE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(90001, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(390101, 3901, '', 'DELOEXEC', ' ', 'ID', ' ', 'DOCID', ' ', 0, null, null, null) ;

CALL ImportDocCLS(180700, 1807, '', 'PayDocExchange', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(21102, 211, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(991700, 9917, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991200, 9912, '', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181600, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30800, 308, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250100, 2501, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 305) ;

CALL ImportDocCLS(21200, 212, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 276) ;

CALL ImportDocCLS(250101, 2501, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(30801, 308, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250200, 2502, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 304) ;

CALL ImportDocCLS(250201, 2502, ' ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(988900, 9889, ' ', 'SubsidyCls', ' ', 'id', ' ', '', '', 89, null, null, null) ;

CALL ImportDocCLS(250202, 2502, '  ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 304) ;

CALL ImportDocCLS(988700, 9887, ' ', 'VariantCls', ' ', 'ID', ' ', '', '', 87, null, null, null) ;

CALL ImportDocCLS(520100, 5201, '', 'WritExecutionCaption', 'WritExecutionCaption', 'id', 'id', '', '', 0, null, null, 555) ;

CALL ImportDocCLS(990800, 9908, '', 'DocumentTypes', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(250300, 2503, '', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21201, 212, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(250301, 2503, '', 'EXECUTIONDOCUMENTSDETAIL', 'EXECUTIONDOCUMENTSDETAIL', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(180500, 1805, '', 'BANKEXCH_MERDOC', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20201, 202, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20301, 203, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20401, 204, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20501, 205, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20601, 206, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190201, 1902, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190301, 1903, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(20000, 200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190601, 1906, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(20200, 202, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20300, 203, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20400, 204, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20500, 205, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20600, 206, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190200, 1902, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190300, 1903, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(180501, 1805, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(190600, 1906, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(988400, 9884, ' ', 'TransfertCLS', ' ', 'ID', ' ', '', '', 84, null, null, null) ;

CALL ImportDocCLS(988800, 9888, ' ', 'OKP', ' ', 'ID', ' ', '', '', 88, null, null, null) ;

CALL ImportDocCLS(989900, 9899, ' ', 'DBUsers', ' ', 'ID', ' ', '', '', 201, null, null, null) ;

CALL ImportDocCLS(990801, 9908, ' ', 'DOCUMENTFIELDS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(361000, 3610, '', 'UTYPEDFORMSCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 550) ;

CALL ImportDocCLS(987200, 9872, ' ', 'BalanceCls', ' ', 'ID', ' ', '', '', 72, null, null, null) ;

CALL ImportDocCLS(984600, 9846, ' ', 'BUHPAYMENTCLS', ' ', 'ID', ' ', '', '', 46, null, null, null) ;

CALL ImportDocCLS(981800, 9818, ' ', 'CURRENCYCLS', ' ', 'ID', ' ', '', '', 18, null, null, null) ;

CALL ImportDocCLS(988500, 9885, ' ', 'AssignmentKind', ' ', 'ID', ' ', '', '', 85, null, null, null) ;

CALL ImportDocCLS(983500, 9835, ' ', 'BUDGETTYPE', ' ', 'ID', ' ', '', '', 35, null, null, null) ;

CALL ImportDocCLS(985800, 9858, ' ', 'DEBTTYPE', ' ', 'ID', ' ', '', '', 58, null, null, null) ;

CALL ImportDocCLS(988600, 9886, ' ', 'AssignmentSource', ' ', 'ID', ' ', ' ', ' ', 86, null, null, null) ;

CALL ImportDocCLS(988300, 9883, ' ', 'Org_Type', ' ', 'ID', ' ', '', '', 83, null, null, null) ;

CALL ImportDocCLS(986400, 9864, ' ', 'PlanDocType', ' ', 'ID', ' ', '', '', 64, null, null, null) ;

CALL ImportDocCLS(985700, 9857, ' ', 'LOANTYPE', ' ', 'ID', ' ', '', '', 57, null, null, null) ;

CALL ImportDocCLS(984300, 9843, ' ', 'PAYTYPECLS', ' ', 'ID', ' ', '', '', 43, null, null, null) ;

CALL ImportDocCLS(982300, 9823, ' ', 'GOSNI', ' ', 'ID', ' ', '', '', 23, null, null, null) ;

CALL ImportDocCLS(982200, 9822, ' ', 'GroupInf_CLS', ' ', 'ID', ' ', '', '', 22, null, null, null) ;

CALL ImportDocCLS(982900, 9829, ' ', 'DocBase', ' ', 'ID', ' ', '', '', 29, null, null, null) ;

CALL ImportDocCLS(981100, 9811, ' ', 'DocTypes', ' ', 'ID', ' ', '', '', 11, null, null, null) ;

CALL ImportDocCLS(986000, 9860, ' ', 'MEASUREMENTCLS', ' ', 'ID', ' ', '', '', 60, null, null, null) ;

CALL ImportDocCLS(988000, 9880, ' ', 'FundsSource', ' ', 'ID', ' ', '', '', 80, null, null, null) ;

CALL ImportDocCLS(985200, 9852, ' ', 'InnerFinSource', ' ', 'ID', ' ', '', '', 52, null, null, null) ;

CALL ImportDocCLS(981300, 9813, ' ', 'NOTIFYTYPES', ' ', 'ID', ' ', '', '', 13, null, null, null) ;

CALL ImportDocCLS(984500, 9845, ' ', 'PAYSYMBOLCLS', ' ', 'ID', ' ', '', '', 45, null, null, null) ;

CALL ImportDocCLS(980400, 9804, ' ', 'KVR', ' ', 'ID', ' ', '', '', 4, null, null, null) ;

CALL ImportDocCLS(980300, 9803, ' ', 'KVSR', ' ', 'ID', ' ', '', '', 3, null, null, null) ;

CALL ImportDocCLS(980900, 9809, ' ', 'KD', ' ', 'ID', ' ', '', '', 9, null, null, null) ;

CALL ImportDocCLS(984700, 9847, ' ', 'TYPEOPERATIONCLS', ' ', 'ID', ' ', '', '', 47, null, null, null) ;

CALL ImportDocCLS(986800, 9868, ' ', 'KESR', ' ', 'ID', ' ', '', '', 68, null, null, null) ;

CALL ImportDocCLS(987900, 9879, ' ', 'TargetCls', ' ', 'ID', ' ', '', '', 79, null, null, null) ;

CALL ImportDocCLS(985100, 9851, ' ', 'Error', ' ', 'ID', ' ', '', '', 51, null, null, null) ;

CALL ImportDocCLS(982100, 9821, ' ', 'ACC_CLS', ' ', 'ID', ' ', '', '', 21, null, null, null) ;

CALL ImportDocCLS(981400, 9814, ' ', 'KSHK', ' ', 'ID', ' ', '', '', 14, null, null, null) ;

CALL ImportDocCLS(980200, 9802, ' ', 'kfsr', ' ', 'ID', ' ', '', '', 2, null, null, null) ;

CALL ImportDocCLS(980500, 9805, ' ', 'KCSR', ' ', 'ID', ' ', '', '', 5, null, null, null) ;

CALL ImportDocCLS(984100, 9841, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', '', '', 41, null, null, null) ;

CALL ImportDocCLS(981500, 9815, ' ', 'VALUECLS', ' ', 'ID', ' ', '', '', 15, null, null, null) ;

CALL ImportDocCLS(982800, 9828, ' ', 'FACT', ' ', 'ID', ' ', '', '', 28, null, null, null) ;

CALL ImportDocCLS(984800, 9848, ' ', 'PAYDESTINATIONCLS', ' ', 'ID', ' ', '', '', 48, null, null, null) ;

CALL ImportDocCLS(986900, 9869, ' ', 'DirectionCLS', ' ', 'ID', ' ', '', '', 69, null, null, null) ;

CALL ImportDocCLS(986200, 9862, ' ', 'OKATO', ' ', 'ID', ' ', '', '', 62, null, null, null) ;

CALL ImportDocCLS(988200, 9882, ' ', 'OKOPF', ' ', 'ID', ' ', '', '', 82, null, null, null) ;

CALL ImportDocCLS(988100, 9881, ' ', 'OKFS', ' ', 'ID', ' ', '', '', 81, null, null, null) ;

CALL ImportDocCLS(981600, 9816, ' ', 'MeansCLS', ' ', 'ID', ' ', '', '', 16, null, null, null) ;

CALL ImportDocCLS(985900, 9859, ' ', 'DepartmentCLS', ' ', 'ID', ' ', '', '', 59, null, null, null) ;

CALL ImportDocCLS(986500, 9865, ' ', 'BuhAccPlan', ' ', 'ID', ' ', '', '', 65, null, null, null) ;

CALL ImportDocCLS(986100, 9861, ' ', 'TenderObjects', ' ', 'ID', ' ', '', '', 61, null, null, null) ;

CALL ImportDocCLS(985000, 9850, ' ', 'RejectCLS', ' ', 'ID', ' ', '', '', 50, null, null, null) ;

CALL ImportDocCLS(987000, 9870, ' ', 'ProgramCode', ' ', 'ID', ' ', '', '', 70, null, null, null) ;

CALL ImportDocCLS(981200, 9812, ' ', 'RegionCLS', ' ', 'ID', ' ', '', '', 12, null, null, null) ;

CALL ImportDocCLS(982600, 9826, ' ', 'BUDGETACCOUNTS', ' ', 'ID', ' ', '', '', 26, null, null, null) ;

CALL ImportDocCLS(981700, 9817, ' ', 'REFCLS', ' ', 'ID', ' ', '', '', 17, null, null, null) ;

CALL ImportDocCLS(981000, 9810, ' ', 'SubKD', ' ', 'ID', ' ', '', '', 10, null, null, null) ;

CALL ImportDocCLS(980600, 9806, ' ', 'SUBKCSR', ' ', 'ID', ' ', '', '', 6, null, null, null) ;

CALL ImportDocCLS(980800, 9808, ' ', 'KESRSubCode', ' ', 'ID', ' ', '', '', 8, null, null, null) ;

CALL ImportDocCLS(986300, 9863, ' ', 'COLLATERALTYPE', ' ', 'ID', ' ', '', '', 63, null, null, null) ;

CALL ImportDocCLS(982000, 9820, ' ', 'ORG_CLS', ' ', 'ID', ' ', '', '', 20, null, null, null) ;

CALL ImportDocCLS(983400, 9834, ' ', 'ReportType', ' ', 'ID', ' ', '', '', 34, null, null, null) ;

CALL ImportDocCLS(985300, 9853, ' ', 'REESTRTYPE', ' ', 'ID', ' ', '', '', 53, null, null, null) ;

CALL ImportDocCLS(984900, 9849, ' ', 'MEANSTYPE', ' ', 'ID', ' ', '', '', 49, null, null, null) ;

CALL ImportDocCLS(982700, 9827, ' ', 'FinType', ' ', 'ID', ' ', '', '', 27, null, null, null) ;

CALL ImportDocCLS(984400, 9844, ' ', 'Org_AccDefaults', ' ', 'ID', ' ', '', '', 44, null, null, null) ;

CALL ImportDocCLS(960100, 9601, ' ', 'ORGANIZATIONS', ' ', 'ID', ' ', '', '', 1000, null, null, null) ;

CALL ImportDocCLS(960200, 9602, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', '', '', 1001, null, null, null) ;

CALL ImportDocCLS(960400, 9604, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', '', 1003, null, null, null) ;

CALL ImportDocCLS(960300, 9603, ' ', 'BANKS', ' ', 'ID', ' ', '', '', 1002, null, null, null) ;

CALL ImportDocCLS(987100, 9871, ' ', 'BuhOperationCls', ' ', 'Id', ' ', '', '', 71, null, null, null) ;

CALL ImportDocCLS(987800, 9878, ' ', 'budgets_s', ' ', 'id', ' ', '', '', 78, null, null, null) ;

CALL ImportDocCLS(991400, 9914, '', 'DATAPACKETTYPES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991401, 9914, '', 'DATAPACKETCONTENT', ' ', 'ID', ' ', 'DATAPACKETTYPE', '', 0, null, null, null) ;

CALL ImportDocCLS(991500, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991501, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', 'ID', '', 0, null, null, null) ;

CALL ImportDocCLS(20001, 200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(30000, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30001, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190000, 1900, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190001, 1900, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(220000, 2200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(220001, 2200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991300, 9913, '', 'INTERFACES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991301, 9913, '', 'Permissions', ' ', 'ID', ' ', 'INTERFACEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(991302, 9913, '', 'LinkType', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991303, 9913, ' ', ' ', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(490200, 4902, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 526) ;

CALL ImportDocCLS(250400, 2504, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', '', 0, null, null, 314) ;

CALL ImportDocCLS(300100, 3001, '', 'TenderCaption', ' ', 'ID', ' ', '', '', 0, null, null, 230) ;

CALL ImportDocCLS(250401, 2504, '  ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(250402, 2504, '   ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 314) ;

CALL ImportDocCLS(250403, 2504, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(300600, 3006, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 241) ;

CALL ImportDocCLS(250102, 2501, '  . ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(70202, 702, '', 'PAYDOCEXCHANGE', ' ', 'ID', ' ', 'PAYDOCREF', '', 0, null, null, null) ;

CALL ImportDocCLS(170101, 1701, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20900, 209, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 274) ;

CALL ImportDocCLS(300601, 3006, '  ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 241) ;

CALL ImportDocCLS(300602, 3006, '   ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300300, 3003, '', 'TenderResultCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(300101, 3001, ' ', 'TenderProduct', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 230) ;

CALL ImportDocCLS(300102, 3001, ' ', 'TenderLot', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300103, 3001, '   ', 'TENDERSOURCEORG', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300104, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300105, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300106, 3001, ' ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300107, 3001, '   ', 'TENDERSUPPLEMENTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300108, 3001, ',  ', 'TENDERSUPDOCUMENT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(370100, 3701, '', 'TenderObjects', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(520101, 5201, '', 'WritExecutionDetail', 'WritExecutionDetail', 'id', 'id', 'RecordIndex', '', 0, null, null, 556) ;

CALL ImportDocCLS(20901, 209, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(21000, 210, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 252) ;

CALL ImportDocCLS(21001, 210, ', ', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 252) ;

CALL ImportDocCLS(21002, 210, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 253) ;

CALL ImportDocCLS(991800, 9918, '', 'USERGENERATOR', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991801, 9918, '', 'USERGENERATORFIELDS', ' ', 'ID', ' ', 'GENREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992702, 9927, '   ', 'REMOTEINPUTRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(21202, 212, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(990802, 9908, ' ', 'STATE_DOCSTATES', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990803, 9908, '', 'STATE_JUMPS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990804, 9908, '', 'STATE_ACTIONS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992703, 9927, '   ', 'REMOTECLIENTACCOUNT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992000, 9920, '', 'BUHOPERATIONCLS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992001, 9920, '', 'BUHACCCORR', ' ', 'ID', ' ', 'BUHOPERATIONCLS', '', 0, null, null, null) ;

CALL ImportDocCLS(992100, 9921, '', 'BUDGETS_S', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992101, 9921, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992102, 9921, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(989000, 9890, ' ', 'BudAllocationCls', ' ', 'id', ' ', '', '', 90, null, null, null) ;

CALL ImportDocCLS(989100, 9891, ' ', 'PayPromiseCls', ' ', 'id', ' ', '', '', 91, null, null, null) ;

CALL ImportDocCLS(550300, 5503, '', 'ReplacementClsCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550301, 5503, '   ', 'ReplacementClsDetail', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(550302, 5503, ' ', 'ReplacementClsDetailInfo', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(250302, 2503, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'EXECUTIONREF', '', 0, null, null, 308) ;

CALL ImportDocCLS(181400, 1814, '', 'BANKEXCH_LS_KB', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(180900, 1809, '', 'BANKEXCH_SUBSTITUTION', 'BANKEXCH_SUBSTITUTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181500, 1815, '', 'BANKEXCH_KO_SALDO', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992900, 9929, '', 'BudStruct', 'BudStruct', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992201, 9922, '', 'ARCHIVEDOCPARAMS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(992400, 9924, '', 'SIGNS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(480101, 4801, '', 'GeneralDocsDetail', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992502, 9925, '', 'CARDSDETAIL_KESR', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(250203, 2502, ' ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 304) ;

CALL ImportDocCLS(250404, 2504, ' ', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(520102, 5201, '2', 'WritExecutionNotify', 'WritExecutionNotify', 'id', 'id', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(989200, 9892, ' ', 'ArchiveDocType', ' ', 'id', ' ', '', '', 92, null, null, null) ;

CALL ImportDocCLS(480100, 4801, '', 'GeneralDocuments', ' ', 'ID', ' ', '', '', 0, null, null, 528) ;

CALL ImportDocCLS(992600, 9926, '', 'WritNotifyCls', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992601, 9926, '', 'WRITNOTIFYCLSDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992602, 9926, ' ', 'WritNotifyClsPart', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(31600, 316, '', 'ManagerBid', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20902, 209, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(992704, 9927, '  + /', 'DUALRIGHTS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992705, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992706, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(990400, 9904, '', 'CONTACTPERSONS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181601, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992707, 9927, '', 'SIGNCERTIFICATE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992708, 9927, '  ', 'SIGNDOCUMENTSGROUP', ' ', 'ID', ' ', 'CLIENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(510100, 5101, '', 'StoredAttributesCaption', 'StoredAttributesCaption', 'id', 'id', '', '', 0, null, null, null) ;

CALL ImportDocCLS(510101, 5101, '', 'StoredAttributesDetail', 'StoredAttributesDetail', 'id', 'id', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(250405, 2504, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(970200, 9702, ' ', 'AnalyticalGroupIFS', 'AnalyticalGroupIFS', 'ID', 'ID', '', '', 102, null, null, null) ;

CALL ImportDocCLS(970100, 9701, ' ', 'AnalyticalGroupKD', 'AnalyticalGroupKD', 'ID', 'ID', '', '', 101, null, null, null) ;

DROP PROCEDURE ImportDocCLS
/

COMMIT WORK
/


CREATE OR REPLACE PROCEDURE ImportField (
   ID_                NUMBER,
   NAME_              VARCHAR2,
   ITFFIELDNAME_      VARCHAR2,
   NOTE_              VARCHAR2,
   TEMPLATEFIELD_     VARCHAR2,
   ISBUDGET_          NUMBER,
   DOCTYPEREF_        NUMBER,
   DETAILNUMBER_      NUMBER,
   ONLYREAD_          NUMBER,
   ReportFieldName_   VARCHAR2,
   KIND_	      NUMBER,
   FIELDINFOREF_      NUMBER,
   CONTAINERREF_      NUMBER, 
   ATTRFIELDKIND_     NUMBER
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentFields
    WHERE (ID = ID_);

   IF (IDExists$ <> 0) THEN
      UPDATE DocumentFields
         SET NAME = NAME_,
             ITFFIELDNAME = ITFFIELDNAME_,
             NOTE = NOTE_,
             TEMPLATEFIELD = TEMPLATEFIELD_,
             ISBUDGET = ISBUDGET_,
             DOCTYPEREF = DOCTYPEREF_,
             DETAILNUMBER = DETAILNUMBER_,
             ONLYREAD = ONLYREAD_,
             ReportFieldName = ReportFieldName_,
			       FIELDINFOREF = FIELDINFOREF_, 
             CONTAINERREF = CONTAINERREF_, 
             ATTRFIELDKIND = ATTRFIELDKIND_
       WHERE (ID = ID_)
         AND NOT (
                      (
                          (
                           (NAME IS NOT NULL AND NAME_ IS NOT NULL) AND
                           (UPPER (NAME) = UPPER (NAME_))
                          )
                       OR (NAME IS NULL AND NAME_ IS NULL)
                      )

                  AND (
                          (
                           (ITFFIELDNAME_ IS NOT NULL AND ITFFIELDNAME IS NOT NULL) AND
                           (UPPER (ITFFIELDNAME_) = UPPER (ITFFIELDNAME))
                          )
                       OR (ITFFIELDNAME_ IS NULL AND ITFFIELDNAME IS NULL)
                      )
                      
                  AND (
                          (
                           (NOTE IS NOT NULL AND NOTE_ IS NOT NULL) AND
                           (UPPER (NOTE) = UPPER (NOTE_))
                          )
                       OR (NOTE IS NULL AND NOTE_ IS NULL)
                      )
                  AND (UPPER (TEMPLATEFIELD) = UPPER (TEMPLATEFIELD_))
                  AND (
                          (
                           (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                           (ISBUDGET = ISBUDGET_)
                          )
                       OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                      )
                  AND (
                          (
                           (FIELDINFOREF IS NOT NULL AND FIELDINFOREF_ IS NOT NULL) AND
                           (FIELDINFOREF = FIELDINFOREF_)
                          )
                       OR (FIELDINFOREF IS NULL AND FIELDINFOREF_ IS NULL)
                      )
                  AND (
                          (
                           (CONTAINERREF IS NOT NULL AND CONTAINERREF_ IS NOT NULL) AND
                           (CONTAINERREF = CONTAINERREF_)
                          )
                       OR (CONTAINERREF IS NULL AND CONTAINERREF_ IS NULL)
                      )   
                  AND (
                          (
                           (ATTRFIELDKIND IS NOT NULL AND ATTRFIELDKIND_ IS NOT NULL) AND
                           (ATTRFIELDKIND = ATTRFIELDKIND_)
                          )
                       OR (ATTRFIELDKIND IS NULL AND ATTRFIELDKIND_ IS NULL)
                      )                                            
                  AND (DOCTYPEREF = DOCTYPEREF_)
                  AND (DETAILNUMBER = DETAILNUMBER_)
                  AND (ONLYREAD = ONLYREAD_)
                  AND (
                          (
                           (ReportFieldName IS NOT NULL AND ReportFieldName_ IS NOT NULL) AND
                           (UPPER (ReportFieldName) = UPPER (ReportFieldName_))
                          )
                       OR (ReportFieldName IS NULL AND ReportFieldName_ IS NULL)
                      )
                 );
   ELSE
      INSERT INTO DocumentFields
                  (ID, NAME, ITFFIELDNAME, NOTE, TEMPLATEFIELD,
                   ISBUDGET, DOCTYPEREF, DETAILNUMBER, ONLYREAD, ReportFieldName, FIELDINFOREF, CONTAINERREF, ATTRFIELDKIND
                  )
           VALUES (ID_, NAME_, ITFFIELDNAME_, NOTE_, TEMPLATEFIELD_,
                   ISBUDGET_, DOCTYPEREF_, DETAILNUMBER_, ONLYREAD_, ReportFieldName_, FIELDINFOREF_, CONTAINERREF_, ATTRFIELDKIND_
                  );
   END IF;

   FOR tab_rec IN (
                   SELECT ID
                     FROM DocumentFields
                    WHERE (ID <> ID_)
                      AND (DOCTYPEREF = DOCTYPEREF_)
                      AND (
                              (
                               (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                               (ISBUDGET = ISBUDGET_)
                              )
                           OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                          )
                      AND (DETAILNUMBER = DETAILNUMBER_)
              AND ( /*      ,       ,       */
                            (
                             ((ITFFIELDNAME_ IS NULL)or(ITFFIELDNAME_=' '))
                 and not((TEMPLATEFIELD_ IS NULL)or(TEMPLATEFIELD_=' '))
                 and(TEMPLATEFIELD is NOT null) and (UPPER(TEMPLATEFIELD)=UPPER(TEMPLATEFIELD_))
                            )
                    or (
                        not ((ITFFIELDNAME_ IS NULL) or (ITFFIELDNAME_=' '))
                                and (ITFFIELDNAME IS NOT NULL) and (UPPER(ITFFIELDNAME)=UPPER(ITFFIELDNAME_)))
                            )
                       )
   LOOP
      UPDATE State_OpenFields
         SET DOCFIELDREF = ID_
       WHERE (DOCFIELDREF = tab_rec.ID);

      UPDATE DOCLOCKFIELDS
         SET FIELDREF = ID_
       WHERE (FIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET PARENTFIELDREF = ID_
      WHERE (PARENTFIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET CHILDFIELDREF = ID_
      WHERE (CHILDFIELDREF = tab_rec.ID);

      DELETE FROM DocumentFields
            WHERE (ID = tab_rec.ID);
   END LOOP;
END;
/

CREATE OR REPLACE PROCEDURE DeleteFields (ID$ NUMBER) IS
BEGIN
  DELETE FROM State_OpenFields
  WHERE (docfieldref = ID$);
  DELETE FROM DOCLOCKFIELDS
  WHERE (fieldref = ID$);

  DELETE FROM STATE_JUMPCONTROL
  WHERE STATICLINKREF IN(SELECT ID FROM staticlinks
                           WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$));
  DELETE FROM staticlinks
  WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$);
  
  DELETE FROM DOCUMENTTEMPLATEFIELDS
  WHERE (FIELDS=ID$);

  DELETE FROM DocumentFields
  WHERE (id = ID$);
END;
/

CREATE OR REPLACE PROCEDURE INSERTCONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER,
  NOTE_          VARCHAR2,
  VARCHARVALUE_  VARCHAR2,
  DOUBLEVALUE_   NUMBER,
  INTVALUE_      INTEGER,
  EDITDOCCODE_   INTEGER
) IS
  IDEXISTS$ NUMBER;
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM IntConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO INTCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,INTVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE INTCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 8) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM VarcharConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO VARCHARCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,VARCHARVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE VARCHARCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 5) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM RealConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO REALCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,DOUBLEVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE REALCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;   
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DELETECONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER
) IS
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    UPDATE IntConst
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
  IF (CONSTTYPE_ = 8) THEN
    UPDATE VARCHARCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_); 
  END IF;
  IF (CONSTTYPE_ = 5) THEN
    UPDATE REALCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
END;
/

--       
ALTER TRIGGER TR_INTCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 DISABLE
/

--     
CALL DeleteFields(20211028) ;

CALL DeleteFields(20300025) ;

CALL DeleteFields(20411028) ;

CALL DeleteFields(20401136) ;

CALL DeleteFields(20511029) ;

CALL DeleteFields(20701209) ;

CALL DeleteFields(20801211) ;

CALL DeleteFields(20901135) ;

CALL DeleteFields(20911144) ;

CALL DeleteFields(20901136) ;

CALL DeleteFields(21011018) ;

CALL DeleteFields(21001057) ;

CALL DeleteFields(21002058) ;

CALL DeleteFields(21101047) ;

CALL DeleteFields(21201048) ;

CALL DeleteFields(30111170) ;

CALL DeleteFields(30101197) ;

CALL DeleteFields(30211155) ;

CALL DeleteFields(30201172) ;

CALL DeleteFields(30311094) ;

CALL DeleteFields(30301079) ;

CALL DeleteFields(30400032) ;

CALL DeleteFields(30410032) ;

CALL DeleteFields(90111011) ;

CALL DeleteFields(190110086) ;

CALL DeleteFields(190210085) ;

CALL DeleteFields(190310086) ;

CALL DeleteFields(390110001) ;

CALL DeleteFields(390110002) ;

CALL DeleteFields(390110003) ;

CALL DeleteFields(390110004) ;

CALL DeleteFields(390110005) ;

CALL DeleteFields(390110006) ;

CALL DeleteFields(390110007) ;

CALL DeleteFields(390110008) ;

CALL DeleteFields(390110009) ;

CALL DeleteFields(390110010) ;

CALL DeleteFields(390110011) ;

CALL DeleteFields(390110012) ;

CALL DeleteFields(390110013) ;

CALL DeleteFields(390110014) ;

CALL DeleteFields(390111015) ;

CALL DeleteFields(390111016) ;

CALL DeleteFields(390111017) ;

CALL DeleteFields(390111018) ;

CALL DeleteFields(980510013) ;

CALL DeleteFields(982710002) ;

CALL DeleteFields(982710003) ;

CALL DeleteFields(982810001) ;

CALL DeleteFields(982810002) ;

CALL DeleteFields(982810003) ;

CALL DeleteFields(982910001) ;

CALL DeleteFields(982910002) ;

CALL DeleteFields(982910003) ;

CALL DeleteFields(990310095) ;

CALL DeleteConst(0, 0, 8) ;

CALL DeleteFields(991610123) ;

CALL DeleteConst(0, 0, 8) ;

CALL DeleteFields(991610124) ;

CALL DeleteConst(0, 0, 8) ;

CALL DeleteFields(991610125) ;

--    , (1)
CALL ImportField(10111013, '', 'FACT', '', ' ', 1, 101, 1, 1, '', 0, 17829, 0, 0) ;

CALL ImportField(10111014, '', 'DirectionCLS', '', ' ', 1, 101, 1, 1, '', 0, 17867, 0, 0) ;

CALL ImportField(10111022, '()', 'FINTYPECode', '', ' ', 1, 101, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(10111023, '', 'REGIONCLS', '', ' ', 1, 101, 1, 0, ',', 0, 17831, 0, 0) ;

CALL ImportField(10111043, '-', 'DOCUMENTBASETYPECODE', '-', ' ', 1, 101, 1, 0, '', 0, 36865, 0, 0) ;

CALL ImportField(10111186, '', 'DirectionCLSCode', '', ' ', 1, 101, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(10111187, '', 'FACTCode', '', ' ', 1, 101, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(10111188, '', 'FINTYPE', ' ', ' ', 1, 101, 1, 0, '', 0, 17833, 0, 0) ;

CALL ImportField(10111189, '-', 'DOCUMENTBASETYPE', '-', ' ', 1, 101, 1, 1, '', 0, 17863, 0, 0) ;

CALL ImportField(10112055, '', 'DirectionCLS', '', ' ', 1, 101, 2, 1, '', 0, 17867, 0, 0) ;

CALL ImportField(10112056, '', 'REGIONCLS', '', ' ', 1, 101, 2, 0, ',', 0, 17831, 0, 0) ;

CALL ImportField(10112059, '()', 'FINTYPECode', '', ' ', 1, 101, 2, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(10112061, '', 'FACT', '', ' ', 1, 101, 2, 1, '', 0, 17829, 0, 0) ;

CALL ImportField(10112077, '-', 'DOCUMENTBASETYPECODE', ' - ', ' ', 1, 101, 2, 1, '', 0, 36865, 0, 0) ;

CALL ImportField(10112217, '', 'DirectionCLSCode', '', ' ', 1, 101, 2, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(10112218, '', 'FACTCode', '', ' ', 1, 101, 2, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(10112219, '', 'FINTYPE', ' ', ' ', 1, 101, 2, 0, '', 0, 17833, 0, 0) ;

CALL ImportField(10112220, '-', 'DOCUMENTBASETYPE', ' - ', ' ', 1, 101, 2, 1, '', 0, 17863, 0, 0) ;

CALL ImportField(10114117, '', 'DirectionCLS', '', ' ', 1, 101, 4, 1, '', 0, 17867, 0, 0) ;

CALL ImportField(10114118, '', 'REGIONCLS', '', ' ', 1, 101, 4, 0, ',', 0, 17831, 0, 0) ;

CALL ImportField(10114121, '', 'FINTYPECode', '', ' ', 1, 101, 4, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(10114122, '', 'FACT', '', ' ', 1, 101, 4, 1, '', 0, 17829, 0, 0) ;

CALL ImportField(10114135, '-', 'DOCUMENTBASETYPECODE', ' - ', ' ', 1, 101, 4, 1, '', 0, 36865, 0, 0) ;

CALL ImportField(10114219, '', 'DirectionCLSCode', '', ' ', 1, 101, 4, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(10114220, '', 'FACTCode', '', ' ', 1, 101, 4, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(10114221, '', 'FINTYPE', ' ', ' ', 1, 101, 4, 0, '', 0, 17833, 0, 0) ;

CALL ImportField(10114222, '-', 'DOCUMENTBASETYPE', ' - ', ' ', 1, 101, 4, 1, '', 0, 17863, 0, 0) ;

CALL ImportField(10115141, '( )', 'KDKESR', '', ' ', 1, 101, 5, 0, '', 0, 38908, 0, 0) ;

--   (), (1)
CALL ImportField(20011007, '  ()', '{("")}', '  ()', ' ', 1, 200, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20011021, '', '{("")}', '', ' ', 1, 200, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20011034, ' ', '{("")}', ' ', ' ', 1, 200, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20011035, '', '{("")}', '', ' ', 1, 200, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20011036, '', '{("")}', ' ()', ' ', 1, 200, 1, 0, '', 0, null, 0, 0) ;

--    (), (1)
CALL ImportField(20110003, ' ', 'DocDat', ' ', 'DocDat', 1, 201, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(20110009, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 201, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(20110012, ' ', 'DocNumber', ' ', 'DocNumber', 1, 201, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(20110023, ' ()', 'DocBaseParent', ' ()', ' ', 1, 201, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20110082, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 201, 0, 0, ',', 0, 17473, 0, 0) ;

CALL ImportField(20111011, '', 'FactCode', '', 'DestFactCls', 1, 201, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(20111049, '', 'DirectionCLSCode', '', 'DestDirectionCLS', 1, 201, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(20111057, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 201, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(20111064, ' () ', 'KVRCORR', ' () ', 'KVRCORRKey', 1, 201, 1, 1, '', 0, 17461, 0, 0) ;

CALL ImportField(20111095, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 201, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(20111183, ' ()', 'DirectionCLS', '', 'DestDirectionCLSKey', 1, 201, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(20111184, ' ()', 'Fact', '', 'DestFactClsKey', 1, 201, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(20111185, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEKey', 1, 201, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(20111186, '', 'InvestObject', '', ' ', 1, 201, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(20111187, '', 'InvestObjectCode', '', ' ', 1, 201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20111193, ' ()', 'KVRCORRCode', ' ()', 'KVRCORR', 1, 201, 1, 0, '', 0, null, 0, 0) ;

--  (), (1)
CALL ImportField(20210014, ' ', 'DOCDAT', ' ', 'DocDat', 1, 202, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(20210037, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 202, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(20210069, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 202, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(20210081, ' ()', 'DocBaseParent', ' ()', ' ', 1, 202, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20210090, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 202, 0, 1, ',', 0, 17473, 0, 0) ;

CALL ImportField(20211035, '', 'FACTCODE', '()', 'DestFactCls', 1, 202, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(20211036, '()', 'DirectionCLSCode', '()', 'DestDirectionCLS', 1, 202, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(20211072, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 202, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(20211103, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 202, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(20211105, '()', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 202, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(20211106, ' ()', 'FACT', '()', 'DestFactClsKey', 1, 202, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(20211107, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 202, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(20211108, '', 'InvestObjectCode', '', ' ', 1, 202, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20211109, '', 'InvestObject', '', ' ', 1, 202, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(20211110, '/ ', 'FCAccountName', '/ ', ' ', 1, 202, 1, 0, '', 0, null, 0, 0) ;

--   (), (1)
CALL ImportField(20310014, ' ', 'DOCDAT', ' ', 'DocDat', 1, 203, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(20310037, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 203, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(20310069, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 203, 0, 0, ',', 0, 17473, 0, 0) ;

CALL ImportField(20310072, ' ()', 'DocBaseParent', ' ()', ' ', 1, 203, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20310081, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 203, 0, 1, ',', 0, 36865, 0, 0) ;

CALL ImportField(20311035, '', 'FACTCODE', '()', 'DestFactCls', 1, 203, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(20311036, '()', 'DirectionCLSCode', '()', 'DestDirectionCLS', 1, 203, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(20311071, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 203, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(20311094, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 203, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(20311095, '()', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 203, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(20311096, ' ()', 'FACT', '()', 'DestFactClsKey', 1, 203, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(20311097, ' .  ()', 'FINTYPE', '   ()', 'DestFINTYPEClsKey', 1, 203, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(20311098, '', 'InvestObjectCode', '', ' ', 1, 203, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20311099, '', 'InvestObject', '', ' ', 1, 203, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(20311100, '/ ', 'FCAccountName', '/ ', ' ', 1, 203, 1, 0, '', 0, null, 0, 0) ;

--  , , (1)
CALL ImportField(20410014, ' ', 'DOCDAT', ' ', 'DocDat', 1, 204, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(20410037, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 204, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(20410069, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 204, 0, 0, ',', 0, 17473, 0, 0) ;

CALL ImportField(20410080, ' ()', 'DocBaseParent', ' ()', ' ', 1, 204, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20410086, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 204, 0, 1, ',', 0, 36865, 0, 0) ;

CALL ImportField(20411035, '', 'FACTCODE', '()', 'DestFactCls', 1, 204, 1, 0, '', 0, 17418, 0, 0) ;

CALL ImportField(20411036, '', 'DirectionCLSCODE', '()', 'DestDirectionCLS', 1, 204, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(20411071, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 204, 1, 0, ',', 0, 17425, 0, 0) ;

CALL ImportField(20411093, '()', 'IFSAGCode', '()', 'IFSAGCode', 1, 204, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(20411097, '()', 'KDAGCode', '()', 'KDAGCode', 1, 204, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(20411112, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 204, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(20411114, ' ()', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 204, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(20411115, ' ()', 'FACT', '()', 'DestFactClsKey', 1, 204, 1, 1, '', 0, 36863, 0, 0) ;

CALL ImportField(20411116, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 204, 1, 1, ',', 0, 36853, 0, 0) ;

CALL ImportField(20411117, '', 'IFS_FinSourceValue', '   ', 'IFS_FinSourceValue', 1, 204, 1, 0, '', 0, 17055, 0, 0) ;

CALL ImportField(20411118, '', 'InvestObjectCode', '', ' ', 1, 204, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20411119, '', 'InvestObject', '', ' ', 1, 204, 1, 1, '', 0, null, 0, 0) ;

-- , (1)
CALL ImportField(20510015, ' ', 'DOCDAT', ' ', 'DocDat', 1, 205, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(20510038, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 205, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(20510067, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 205, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(20510070, ' ()', 'DocBaseParent', ' ()', ' ', 1, 205, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20510089, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 205, 0, 1, ',', 0, 17473, 0, 0) ;

CALL ImportField(20511036, '', 'FACTCODE', '', 'DestFactCls', 1, 205, 1, 0, '', 0, 17418, 0, 0) ;

CALL ImportField(20511037, '', 'DirectionCLSCode', '', 'DestDirectionCLS', 1, 205, 1, 0, '', 0, 17450, 0, 0) ;

CALL ImportField(20511069, ' . ', 'FINTYPECode', '  ', 'DestFINTYPE', 1, 205, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(20511076, '()', 'IFSAGCode', '()', ' ', 1, 205, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(20511079, '()', 'KDAGCode', '()', ' ', 1, 205, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(20511094, ' ', 'ClsType', ' ', 'ClsType', 1, 205, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20511099, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 205, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(20511101, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEKey', 1, 205, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(20511102, ' ()', 'DirectionCLS', ' ()', 'DestDirectionCLSKey', 1, 205, 1, 1, '', 0, 36861, 0, 0) ;

CALL ImportField(20511103, ' ()', 'FACT', '', 'DestFactClsKey', 1, 205, 1, 1, '', 0, 36863, 0, 0) ;

CALL ImportField(20511104, '', 'IFS_FinSourceValue', '   ', 'IFS_FinSourceValue', 1, 205, 1, 0, '', 0, 17055, 0, 0) ;

CALL ImportField(20511105, '', 'InvestObjectCode', '', ' ', 1, 205, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20511106, '', 'InvestObject', '', ' ', 1, 205, 1, 1, '', 0, null, 0, 0) ;

--    (), (1)
CALL ImportField(20610015, ' ', 'DOCDAT', ' ', 'DocDat', 1, 206, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(20610038, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 206, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(20610070, ' ', 'DocBaseCODE', ' ', 'DocBase', 1, 206, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(20610080, ' ()', 'DocBaseParent', ' ()', ' ', 1, 206, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20610082, '', 'KPPERIOD', '', 'KPPeriod', 1, 206, 0, 0, '', 0, 24700, 0, 0) ;

CALL ImportField(20610089, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 206, 0, 1, ',', 0, 17473, 0, 0) ;

CALL ImportField(20611036, '', 'FACTCODE', '()', 'DestFactCls', 1, 206, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(20611037, '', 'DirectionCLSCODE', '()', 'DestDirectionCLS', 1, 206, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(20611073, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 206, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(20611102, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 206, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(20611183, '', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 206, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(20611184, ' ()', 'FACT', '()', 'DestFactClsKey', 1, 206, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(20611185, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 206, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(20611186, '', 'InvestObjectCode', '', ' ', 1, 206, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20611187, '', 'InvestObject', '', ' ', 1, 206, 1, 1, '', 0, null, 0, 0) ;

--   , (1)
CALL ImportField(20710015, ' ', 'DOCDAT', ' ', 'DocDat', 1, 207, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(20710038, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 207, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(20710070, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 207, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(20710074, ' ()', 'DocBaseParent', ' ()', ' ', 1, 207, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20710158, ' ', 'ClsType', ' ', 'ClsType', 1, 207, 0, 0, '', 0, 24698, 0, 0) ;

CALL ImportField(20710160, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 207, 0, 1, ',', 0, 17473, 0, 0) ;

CALL ImportField(20711036, '', 'FACTCODE', '()', 'DestFactCls', 1, 207, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(20711037, '', 'DirectionCLSCODE', '()', 'DestDirectionCLS', 1, 207, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(20711073, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 207, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(20711080, '()', 'IFSAGCode', '()', 'IFS_KESRCode', 1, 207, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(20711168, '()', 'KDAGCode', '()', 'KDKESRCode', 1, 207, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(20711181, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 207, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(20711182, ' ()', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 207, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(20711183, ' ()', 'FACT', '()', 'DestFactClsKey', 1, 207, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(20711184, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 207, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(20711185, '', 'IFS_FinSourceValue', '   ', 'IFS_FinSourceValue', 1, 207, 1, 0, '', 0, 17055, 0, 0) ;

CALL ImportField(20711186, '', 'InvestObjectCode', '', ' ', 1, 207, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20711187, '', 'InvestObject', '', ' ', 1, 207, 1, 1, '', 0, null, 0, 0) ;

--    , (1)
CALL ImportField(20810015, ' ', 'DOCDAT', ' ', 'DocDat', 1, 208, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(20810038, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 208, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(20810070, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 208, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(20810074, ' ()', 'DocBaseParent', ' ()', ' ', 1, 208, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20810076, '', 'KPPERIOD', ' ', 'KPPERIOD', 1, 208, 0, 0, '', 0, 24700, 0, 0) ;

CALL ImportField(20810160, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 208, 0, 1, ',', 0, 17473, 0, 0) ;

CALL ImportField(20811036, '', 'FACTCODE', '()', 'DestFactCls', 1, 208, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(20811037, '', 'DirectionCLSCode', '()', 'DestDirectionCLS', 1, 208, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(20811073, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 208, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(20811080, '()', 'IFSAGCode', '()', 'IFSAGCode', 1, 208, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(20811081, '()', 'IFS_KVSRCode', '()', 'IFS_KVSRCode', 1, 208, 1, 0, '', 0, 25472, 0, 0) ;

CALL ImportField(20811177, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 208, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(20811183, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 208, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(20811184, ' ()', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 208, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(20811185, ' ()', 'FACT', '()', 'DestFactClsKey', 1, 208, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(20811186, '', 'IFS_FinSourceValue', '   ', 'IFS_FinSourceValue', 1, 208, 1, 0, '', 0, 17055, 0, 0) ;

CALL ImportField(20811187, '', 'InvestObjectCode', '', ' ', 1, 208, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(20811188, '', 'InvestObject', '', ' ', 1, 208, 1, 1, '', 0, null, 0, 0) ;

--  , (1)
CALL ImportField(20910007, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 209, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(20910008, ' ()', 'DocBaseParent', ' ()', ' ', 1, 209, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20910009, ' ', 'DOCDAT', ' ', 'DocDat', 1, 209, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20910010, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 209, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20910019, '', 'NUMBER', '', 'Number', 1, 209, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(20910027, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 209, 0, 1, ',', 0, null, 0, 0) ;

CALL ImportField(20911001, ' ', 'ASSIGNMENTKIND', ' ', 'ASSIGNMENTKIND', 1, 209, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(20911006, '()', 'DirectionCLSCode', '()', 'DestDirectionCLS', 1, 209, 1, 1, '', 0, 36861, 0, 0) ;

CALL ImportField(20911007, ' ', 'FACIALACC_CLS', ' ', 'DestFacialAccCls', 1, 209, 1, 1, '', 0, 17419, 0, 0) ;

CALL ImportField(20911009, '', 'FACTCODE', '', 'DestFactCls', 1, 209, 1, 1, '', 0, 36863, 0, 0) ;

CALL ImportField(20911010, ' . ', 'FINTYPECode', '  ', 'DestFinTypeCls', 1, 209, 1, 1, ',', 0, 36853, 0, 0) ;

CALL ImportField(20911012, '()', 'IFSAGCode', '()', 'IFSAGCode', 1, 209, 1, 1, '', 0, 38919, 0, 0) ;

CALL ImportField(20911013, '()', 'IFS_KVSRCode', '()', 'IFS_KVSRCode', 1, 209, 1, 1, '', 0, 25472, 0, 0) ;

CALL ImportField(20911017, '()', 'KESR', '()', 'DestKesr', 1, 209, 1, 1, '', 0, 17415, 0, 0) ;

CALL ImportField(20911018, '()', 'KFSR', '()', 'DestKfsr', 1, 209, 1, 1, '', 0, 17411, 0, 0) ;

CALL ImportField(20911021, ' ', 'MeansType', ' ', 'DestMeansTypeCls', 1, 209, 1, 1, '', 0, 17426, 0, 0) ;

CALL ImportField(20911023, '', 'NOTE', '', 'Note', 1, 209, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(20911027, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 209, 1, 1, '', 0, 17416, 0, 0) ;

CALL ImportField(20911135, ' ()', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 209, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(20911136, ' ()', 'FACT', '()', 'DestFactClsKey', 1, 209, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(20911137, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 209, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(20911138, '  ', 'BudAllocationClsCode', '  ', 'BudAllocationClsCode', 1, 209, 1, 0, '', 0, 27825, 0, 0) ;

CALL ImportField(20911139, '   ', 'BudAllocationCls', '   ()', 'BudAllocationCls', 1, 209, 1, 1, '', 0, 27834, 0, 0) ;

CALL ImportField(20911140, '  ', 'PayPromiseClsCode', '  ', 'PayPromiseClsCode', 1, 209, 1, 0, '', 0, 27849, 0, 0) ;

CALL ImportField(20911141, '   ', 'PayPromiseCls', '   ()', 'PayPromiseCls', 1, 209, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(20911142, '', 'IFS_FinSourceValue', '   ', 'IFS_FinSourceValue', 1, 209, 1, 0, '', 0, 17055, 0, 0) ;

CALL ImportField(20911143, ' ', 'IFS', '    ()', 'IFS', 1, 209, 1, 1, '', 0, 17452, 0, 0) ;

CALL ImportField(20912001, ' ', 'ASSIGNMENTKIND', ' ', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912006, '()', 'DirectionCLSCode', '()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912007, ' ', 'FACIALACC_CLS', ' ', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912009, '', 'FACTCODE', '', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912010, ' . ', 'FINTYPECode', '  ', ' ', 1, 209, 2, 0, ',', 0, null, 0, 0) ;

CALL ImportField(20912012, '()', 'IFSAGCode', '()', ' ', 1, 209, 2, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(20912013, '()', 'IFS_KVSRCode', '()', ' ', 1, 209, 2, 0, '', 0, 25472, 0, 0) ;

CALL ImportField(20912014, '()', 'INN', '()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912015, '()', 'INN20', '()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912016, '()', 'KCSRCode', '()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912017, '()', 'KESR', '()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912018, '()', 'KFSR', '()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912019, '()', 'KVRCode', '()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912020, '()', 'KVSRCode', '()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912021, ' ', 'MeansType', ' ', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912022, '()', 'NAME', '()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912023, '', 'NOTE', '', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912024, '', 'OrgNameAndAcc', '', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912025, ' ', 'REGIONCLS', ' ', ' ', 1, 209, 2, 0, ',,', 0, null, 0, 0) ;

CALL ImportField(20912027, ' ', 'SUBKESR', ' ', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912031, '  ', 'TransfertClsCode', '  ', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912032, ' ', 'ClsType', ' ', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912035, '   ()', 'TransfertCls', '   ()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912036, '  ()', 'SubsidyCls', '  ()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912037, '', 'KCSR', ' ()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912038, '', 'KVR', ' ()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912039, '', 'KVSR', ' ()', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912040, ' ', 'SubsidyClsCode', ' ', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912041, ' ()', 'FACT', '()', ' ', 1, 209, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(20912042, ' ()', 'DirectionCLS', '()', ' ', 1, 209, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(20912043, ' .  ()', 'FINTYPE', '  ', ' ', 1, 209, 2, 1, ',', 0, null, 0, 0) ;

CALL ImportField(20912044, '  ()', 'BudAllocationCls', '   ()', ' ', 1, 209, 2, 1, '', 0, 27834, 0, 0) ;

--  , (1)
CALL ImportField(21010005, ' ', 'ClsType', ' ', ' ', 1, 210, 0, 0, '', 0, 24698, 0, 0) ;

CALL ImportField(21010010, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 210, 0, 1, ',', 0, 36865, 0, 0) ;

CALL ImportField(21010011, ' ', 'DOCDAT', ' ', 'DocDat', 1, 210, 0, 1, '', 0, 17466, 0, 0) ;

CALL ImportField(21010012, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 210, 0, 1, '', 0, 17467, 0, 0) ;

CALL ImportField(21010027, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 210, 0, 1, ',', 0, 17473, 0, 0) ;

CALL ImportField(21011005, '()', 'DirectionCLSCode', '()', 'DestDirectionCLS', 1, 210, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(21011008, '', 'FACTCODE', '', 'DestFactCls', 1, 210, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(21011009, ' . ', 'FINTYPECODE', '  ', 'DestFinTypeCls', 1, 210, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(21011013, '()', 'IFSAGCode', '()', ' ', 1, 210, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(21011017, '()', 'KESR', '()', 'DestKesr', 1, 210, 1, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(21011037, '  ', 'IFS_FinSourceValue', '', 'IFS_FinSourceValue', 1, 210, 1, 1, '', 0, 17055, 0, 0) ;

CALL ImportField(21011042, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 210, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(21011043, '  ', 'PayPromiseClsCode', '', 'PayPromiseClsCode', 1, 210, 1, 0, '', 0, 27849, 0, 0) ;

CALL ImportField(21011044, ' ()', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 210, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(21011045, ' ()', 'FACT', '()', 'DestFactClsKey', 1, 210, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(21011046, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 210, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(21012006, '()', 'DirectionCLSCode', '()', 'DestDirectionCLS', 1, 210, 2, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(21012009, '', 'FACTCODE', '', 'DestFactCls', 1, 210, 2, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(21012010, ' . ', 'FINTYPECODE', '  ', 'DestFinTypeCls', 1, 210, 2, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(21012015, '()', 'KESR', '()', 'DestKesr', 1, 210, 2, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(21012049, '()', 'IFSAGCode', '', ' ', 1, 210, 2, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(21012051, '  ', 'IFS_FinSourceValue', '', 'IFS_FinSourceValue', 1, 210, 2, 1, '', 0, 17055, 0, 0) ;

CALL ImportField(21012056, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 210, 2, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(21012057, '  ', 'PayPromiseClsCode', '', 'PayPromiseClsCode', 1, 210, 2, 0, '', 0, 27849, 0, 0) ;

CALL ImportField(21012058, ' ()', 'FACT', '()', ' ', 1, 210, 2, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(21012059, ' ()', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 210, 2, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(21012060, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 210, 2, 1, ',', 0, 17425, 0, 0) ;

--  , (1)
CALL ImportField(21110001, ' ', 'ASSIGNMENTSOURCE', ' ', 'ASSIGNMENTSOURCE', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110002, '', 'BUDGETREF', '', 'BudgetRef', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110003, ' ', 'ClsType', ' ', 'ClsType', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110004, ' ', 'CryptoStatus', ' ', 'CRYPTOSTATUS', 1, 211, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(21110005, ' ', 'DAT', ' ', 'Dat', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110006, ' ', 'DateInput', ' ', 'DateInput', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110007, ' ', 'DOCDAT', ' ', 'DocDat', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110008, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110009, '', 'DocStateRef', '', 'DocStateRef', 1, 211, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(21110010, '\  ', 'FacialAccCls', '\  ', 'FacialAccCls', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110011, ' ', 'ID', ' ', 'ID', 1, 211, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(21110012, '', 'KPPERIOD', '', 'KPPeriod', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110013, '()', 'NOTE', '()', 'note', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110014, ' ', 'NOTE1', ' ', 'note1 ', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110015, ' ()', 'NOTE2', ' ()', 'note2 ', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110016, '', 'NOTIFYTYPE', '', 'NotifyType', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110017, '', 'NUMBER', '', 'Number', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110018, ' ', 'OrgName', ' ', ' ', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110019, ' ', 'ORGREF', ' ', 'DestOrgRef', 1, 211, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(21110020, ' ', 'PlanDocType', ' ', 'PlanDocType', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110021, ' ', 'ProgIndex', ' ', 'ProgIndex', 1, 211, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(21110022, '  ()', 'RejectCause', '  ()', 'RejectCause', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110023, '  ', 'REJECTCLS', '  ', 'RejectCls', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110024, '', 'Variant', '', 'Variant', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110025, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 211, 0, 0, ',', 0, null, 0, 0) ;

CALL ImportField(21110026, ' ()', 'DocBaseParent', ' ()', ' ', 1, 211, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21110027, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 211, 0, 1, ',', 0, null, 0, 0) ;

CALL ImportField(21111001, '  ', 'TransfertClsCode', '  ', 'TransfertClsValue', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111002, ' ', 'ClsType', ' ', 'ClsType', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111003, ' ', 'ASSIGNMENTKIND', ' ', 'ASSIGNMENTKIND', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111004, ' ()', 'CreateDate', ' ()', 'CreateDate_Det', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111005, '()', 'CREATERUSER', '()', 'CREATERUSER_DET', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111006, '', 'DayPlan', '', 'DayPlan', 1, 211, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(21111007, '', 'DAYPLANSUMMA', '', 'DayPlanSumma', 1, 211, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(21111008, '()', 'DirectionCLSCODE', '()', 'DestDirectionCLS', 1, 211, 1, 1, '', 0, 36861, 0, 0) ;

CALL ImportField(21111009, ' ', 'FACIALACC_CLS', ' ', 'DestFacialAccCls', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111010, '/ ', 'FACIALCODE', '/ ', ' ', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111011, '', 'FACTCODE', '', 'DestFactCls', 1, 211, 1, 1, '', 0, 36863, 0, 0) ;

CALL ImportField(21111012, ' . ', 'FINTYPECODE', '  ', 'DestFinTypeCls', 1, 211, 1, 1, ',', 0, 36853, 0, 0) ;

CALL ImportField(21111013, ' ()', 'IFS_DescriptionCode', ' ()', 'IFS_DescriptionCode', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111014, '()', 'IFSAGCode', '()', 'IFSAGCode', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111015, '()', 'IFS_KVSRCode', '()', 'IFS_KVSRCode', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111016, '()', 'INN', '()', 'DestFacialAccClsOrgINN', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111017, '()', 'INN20', '()', 'DestFacialAccClsOrgKPP', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111018, '()', 'KCSRCode', '()', 'DestKcsr', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111019, '()', 'KESR', '()', 'DestKesr', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111020, '()', 'KFSR', '()', 'DestKfsr', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111021, '()', 'KVRCode', '()', 'DestKvr', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111022, '()', 'KVSRCode', '()', 'DestKvsr', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111023, ' ', 'MeansType', ' ', 'DestMeansTypeCls', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111024, '()', 'NAME', '()', 'DestFacialAccClsOrgName', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111025, '', 'NOTE', '', 'Note', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111026, '', 'OrgNameAndAcc', '', ' ', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111027, ' ', 'REGIONCLS', ' ', 'RegionCLS', 1, 211, 1, 1, ',,', 0, null, 0, 0) ;

CALL ImportField(21111028, '  ', 'RegionCls_name', '  ', ' ', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111029, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111030, '', 'TreeOwner0', '', ' ', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111031, ' ()', 'UpdateDate', ' ()', 'UpdateDate_Det', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111032, '()', 'UpdaterUser', '()', 'UpdaterUser_det', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111033, ' ', 'RECORDINDEX', ' ', 'RecordIndex', 1, 211, 1, 1, '', 0, 17433, 0, 0) ;

CALL ImportField(21111034, ' ', 'ID', ' ', 'Id', 1, 211, 1, 1, '', 0, 17409, 0, 0) ;

CALL ImportField(21111035, '', 'KD', '', 'KD', 1, 211, 1, 1, '', 0, 25270, 0, 0) ;

CALL ImportField(21111036, '()', 'KDAGCode', '()', 'KDAGCode', 1, 211, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(21111037, '()', 'KDKVSRCode', '()', 'KDKVSRCode', 1, 211, 1, 0, '', 0, 25472, 0, 0) ;

CALL ImportField(21111038, ' ', 'KDValue', ' ', 'KDValue', 1, 211, 1, 1, '', 0, 16836, 0, 0) ;

CALL ImportField(21111039, ' ()', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 211, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(21111040, ' ()', 'FACT', '()', 'DestFactClsKey', 1, 211, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(21111041, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 211, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(21111042, '  ', 'BudAllocationClsCode', '  ', 'BudAllocationClsCode', 1, 211, 1, 0, '', 0, 27825, 0, 0) ;

CALL ImportField(21111043, '   ', 'BudAllocationCls', '   ()', 'BudAllocationCls', 1, 211, 1, 1, '', 0, 27834, 0, 0) ;

CALL ImportField(21111044, '  ', 'PayPromiseClsCode', '  ', 'PayPromiseClsCode', 1, 211, 1, 0, '', 0, 27849, 0, 0) ;

CALL ImportField(21111045, '   ', 'PayPromiseCls', '   ()', 'PayPromiseCls', 1, 211, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(21111046, '', 'IFS_FinSourceValue', '   ', 'IFS_FinSourceValue', 1, 211, 1, 0, '', 0, 17055, 0, 0) ;

CALL ImportField(21111047, ' ', 'IFS', '    ()', 'IFS', 1, 211, 1, 1, '', 0, 17452, 0, 0) ;

CALL ImportField(21112001, '  ', 'RecordCount', '  ', ' ', 1, 211, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(21112002, '  ', 'TransfertClsCode', '  ', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112003, ' ', 'ClsType', ' ', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112004, ' ', 'ASSIGNMENTKIND', ' ', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112005, '()', 'DirectionCLSCODE', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112006, ' ', 'FACIALACC_CLS', ' ', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112007, '/ ', 'FACIALCODE', '/ ', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112008, '', 'FACTCODE', '', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112009, ' . ', 'FINTYPECODE', '  ', ' ', 1, 211, 2, 0, ',', 0, null, 0, 0) ;

CALL ImportField(21112010, ' ()', 'IFS_DescriptionCode', ' ()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112011, '()', 'IFSAGCode', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112012, '()', 'IFS_KVSRCode', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112013, '()', 'INN', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112014, '()', 'INN20', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112015, '()', 'KCSRCode', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112016, '()', 'KESR', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112017, '()', 'KFSR', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112018, '()', 'KVRCode', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112019, '()', 'KVSRCode', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112020, ' ', 'MeansType', ' ', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112021, '()', 'NAME', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112022, '', 'NOTE', '', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112023, '', 'OrgNameAndAcc', '', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112024, ' ', 'REGIONCLS', ' ', ' ', 1, 211, 2, 0, ',,', 0, null, 0, 0) ;

CALL ImportField(21112025, '  ', 'RegionCls_name', '  ', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112026, ' ', 'SUBKESR', ' ', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112027, '', 'TreeOwner0', '', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112028, '   ()', 'TransfertCls', '   ()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112029, '  ()', 'SubsidyCls', '  ()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112030, '', 'KVR', ' ()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112031, '', 'KVSR', ' ()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112032, '', 'KCSR', ' ()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112033, ' ', 'SubsidyClsCode', ' ', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112034, ' ()', 'FACT', '()', ' ', 1, 211, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(21112035, ' ()', 'DirectionCLS', '()', ' ', 1, 211, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(21112036, ' .  ()', 'FINTYPE', '  ', ' ', 1, 211, 2, 1, ',', 0, null, 0, 0) ;

CALL ImportField(21112037, '  ()', 'BudAllocationCls', '   ()', ' ', 1, 211, 2, 1, '', 0, 27834, 0, 0) ;

--   , , (1)
CALL ImportField(21210001, ' ', 'ASSIGNMENTSOURCE', ' ', 'ASSIGNMENTSOURCE', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210002, '', 'BUDGETREF', '', 'BudgetRef', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210003, ' ', 'ClsType', ' ', 'ClsType', 1, 212, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(21210004, ' ', 'CryptoStatus', ' ', 'CRYPTOSTATUS', 1, 212, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(21210005, ' ', 'DAT', ' ', 'Dat', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210006, ' ', 'DateInput', ' ', 'DateInput', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210007, ' ', 'DOCDAT', ' ', 'DocDat', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210008, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210009, '', 'DocStateRef', '', 'DocStateRef', 1, 212, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(21210010, '\  ', 'FacialAccCls', '\  ', 'FacialAccCls', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210011, ' ', 'ID', ' ', 'ID', 1, 212, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(21210012, '', 'KPPERIOD', '', 'KPPeriod', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210013, '()', 'NOTE', '()', 'note', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210014, ' ', 'NOTE1', ' ', 'note1 ', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210015, ' ()', 'NOTE2', ' ()', 'note2 ', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210016, '', 'NOTIFYTYPE', '', 'NotifyType', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210017, '', 'NUMBER', '', 'Number', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210018, ' ', 'OrgName', ' ', ' ', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210019, ' ', 'ORGREF', ' ', 'DestOrgRef', 1, 212, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(21210020, ' ', 'PlanDocType', ' ', 'PlanDocType', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210021, ' ', 'ProgIndex', ' ', 'ProgIndex', 1, 212, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(21210022, '  ()', 'RejectCause', '  ()', 'RejectCause', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210023, '  ', 'REJECTCLS', '  ', 'RejectCls', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210024, '', 'Variant', '', 'Variant', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210025, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 212, 0, 0, ',', 0, null, 0, 0) ;

CALL ImportField(21210026, ' ()', 'DocBaseParent', ' ()', ' ', 1, 212, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(21210027, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 212, 0, 1, ',', 0, null, 0, 0) ;

CALL ImportField(21211001, '  ', 'TransfertClsCode', '  ', 'TransfertClsValue', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211002, ' ', 'ClsType', ' ', 'ClsType', 1, 212, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(21211003, ' ', 'ASSIGNMENTKIND', ' ', 'ASSIGNMENTKIND', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211004, ' ()', 'CreateDate', ' ()', 'CreateDate_Det', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211005, '()', 'CREATERUSER', '()', 'CREATERUSER_DET', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211006, '', 'DayPlan', '', 'DayPlan', 1, 212, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(21211007, '', 'DAYPLANSUMMA', '', 'DayPlanSumma', 1, 212, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(21211008, '()', 'DirectionCLSCODE', '()', 'DestDirectionCLS', 1, 212, 1, 1, '', 0, 36861, 0, 0) ;

CALL ImportField(21211009, ' ', 'FACIALACC_CLS', ' ', 'DestFacialAccCls', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211010, '/ ', 'FACIALCODE', '/ ', ' ', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211011, '', 'FACTCODE', '', 'DestFactCls', 1, 212, 1, 1, '', 0, 36863, 0, 0) ;

CALL ImportField(21211012, ' . ', 'FINTYPECODE', '  ', 'DestFinTypeCls', 1, 212, 1, 1, ',', 0, 36853, 0, 0) ;

CALL ImportField(21211013, ' ()', 'IFS_DescriptionCode', ' ()', 'IFS_DescriptionCode', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211014, '()', 'IFSAGCode', '()', 'IFSAGCode', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211015, '()', 'IFS_KVSRCode', '()', 'IFS_KVSRCode', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211016, '()', 'INN', '()', 'DestFacialAccClsOrgINN', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211017, '()', 'INN20', '()', 'DestFacialAccClsOrgKPP', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211018, '()', 'KCSRCode', '()', 'DestKcsr', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211019, '()', 'KESR', '()', 'DestKesr', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211020, '()', 'KFSR', '()', 'DestKfsr', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211021, '()', 'KVRCode', '()', 'DestKvr', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211022, '()', 'KVSRCode', '()', 'DestKvsr', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211023, ' ', 'MeansType', ' ', 'DestMeansTypeCls', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211024, '()', 'NAME', '()', 'DestFacialAccClsOrgName', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211025, '', 'NOTE', '', 'Note', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211026, '', 'OrgNameAndAcc', '', ' ', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211027, ' ', 'REGIONCLS', ' ', 'RegionCLS', 1, 212, 1, 1, ',,', 0, null, 0, 0) ;

CALL ImportField(21211028, '  ', 'RegionCls_name', '  ', ' ', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211029, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211030, '', 'TreeOwner0', '', ' ', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211031, ' ()', 'UpdateDate', ' ()', 'UpdateDate_Det', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211032, '()', 'UpdaterUser', '()', 'UpdaterUser_det', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211033, ' ', 'RECORDINDEX', ' ', 'RecordIndex', 1, 212, 1, 1, '', 0, 17433, 0, 0) ;

CALL ImportField(21211034, ' ', 'ID', ' ', 'Id', 1, 212, 1, 1, '', 0, 17409, 0, 0) ;

CALL ImportField(21211035, '', 'KD', '', 'KD', 1, 212, 1, 1, '', 0, 25270, 0, 0) ;

CALL ImportField(21211036, '()', 'KDAGCode', '()', 'KDAGCode', 1, 212, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(21211037, '()', 'KDKVSRCode', '()', 'KDKVSRCode', 1, 212, 1, 0, '', 0, 25472, 0, 0) ;

CALL ImportField(21211038, ' ', 'KDValue', ' ', 'KDValue', 1, 212, 1, 1, '', 0, 16836, 0, 0) ;

CALL ImportField(21211039, ' ()', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 212, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(21211040, ' ()', 'FACT', '()', 'DestFactClsKey', 1, 212, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(21211041, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 212, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(21211042, ' ()', 'Org_Ref', ' ()', 'Org_Ref_Det', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211043, '  ', 'BudAllocationClsCode', '  ', 'BudAllocationClsCode', 1, 212, 1, 0, '', 0, 27825, 0, 0) ;

CALL ImportField(21211044, '   ', 'BudAllocationCls', '   ()', 'BudAllocationCls', 1, 212, 1, 1, '', 0, 27834, 0, 0) ;

CALL ImportField(21211045, '  ', 'PayPromiseClsCode', '  ', 'PayPromiseClsCode', 1, 212, 1, 0, '', 0, 27849, 0, 0) ;

CALL ImportField(21211046, '   ', 'PayPromiseCls', '   ()', 'PayPromiseCls', 1, 212, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(21211047, '', 'IFS_FinSourceValue', '   ', 'IFS_FinSourceValue', 1, 212, 1, 0, '', 0, 17055, 0, 0) ;

CALL ImportField(21211048, ' ', 'IFS', '    ()', 'IFS', 1, 212, 1, 1, '', 0, 17452, 0, 0) ;

CALL ImportField(21212001, '  ', 'RecordCount', '  ', ' ', 1, 212, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(21212002, '  ', 'TransfertClsCode', '  ', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212003, ' ', 'ClsType', ' ', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212004, ' ', 'ASSIGNMENTKIND', ' ', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212005, '()', 'DirectionCLSCODE', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212006, ' ', 'FACIALACC_CLS', ' ', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212007, '/ ', 'FACIALCODE', '/ ', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212008, '', 'FACTCODE', '', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212009, ' . ', 'FINTYPECODE', '  ', ' ', 1, 212, 2, 0, ',', 0, null, 0, 0) ;

CALL ImportField(21212010, ' ()', 'IFS_DescriptionCode', ' ()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212011, '()', 'IFSAGCode', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212012, '()', 'IFS_KVSRCode', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212013, '()', 'INN', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212014, '()', 'INN20', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212015, '()', 'KCSRCode', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212016, '()', 'KESR', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212017, '()', 'KFSR', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212018, '()', 'KVRCode', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212019, '()', 'KVSRCode', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212020, ' ', 'MeansType', ' ', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212021, '()', 'NAME', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212022, '', 'NOTE', '', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212023, '', 'OrgNameAndAcc', '', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212024, ' ', 'REGIONCLS', ' ', ' ', 1, 212, 2, 0, ',,', 0, null, 0, 0) ;

CALL ImportField(21212025, '  ', 'RegionCls_name', '  ', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212026, ' ', 'SUBKESR', ' ', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212027, '', 'TreeOwner0', '', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212028, '   ()', 'TransfertCls', '   ()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212029, '  ()', 'SubsidyCls', '  ()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212030, '', 'KVR', ' ()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212031, '', 'KVSR', ' ()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212032, '', 'KCSR', ' ()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212033, ' ', 'SubsidyClsCode', ' ', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212034, ' ()', 'FACT', '()', ' ', 1, 212, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(21212035, ' ()', 'DirectionCLS', '()', ' ', 1, 212, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(21212036, ' .  ()', 'FINTYPE', '  ', ' ', 1, 212, 2, 1, ',', 0, null, 0, 0) ;

CALL ImportField(21212037, ' ()', 'Org_Ref', ' ()', ' ', 1, 212, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(21212038, '  ()', 'BudAllocationCls', '   ()', ' ', 1, 212, 2, 1, '', 0, 27834, 0, 0) ;

--   , (1)
CALL ImportField(30011030, '', '{("")}', ' ()', ' ', 1, 300, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(30011043, '', '{("")}', '', ' ', 1, 300, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(30011044, '', '{("")}', ' ()', ' ', 1, 300, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(30011045, ' ', '{("")}', '- ()', ' ', 1, 300, 1, 0, '', 0, null, 0, 0) ;

--  , (1)
CALL ImportField(30111005, ' .( .)', 'SourceKESR', ' ', 'SourceKESR', 1, 301, 1, 0, ',', 0, 18868, 0, 0) ;

CALL ImportField(30111010, ' .', 'SourceFactCode', ' ', 'SourceFACTCLS', 1, 301, 1, 0, ',', 0, 36863, 0, 0) ;

CALL ImportField(30111012, ' .  .', 'SourceFinTypeCode', '   ', 'SourceFINTYPECLS', 1, 301, 1, 0, ',,,', 0, 36853, 0, 0) ;

CALL ImportField(30111017, ' -( -)', 'DestKESR', ' ', 'DestKESR', 1, 301, 1, 0, 'DestKESR,', 0, 18871, 0, 0) ;

CALL ImportField(30111022, ' -', 'DestFactCode', ' ', 'DestFACTCLS', 1, 301, 1, 0, 'DestFact,', 0, 36863, 0, 0) ;

CALL ImportField(30111024, ' .  -', 'DestFinTypeCode', '   ', 'DestFINTYPECLS', 1, 301, 1, 0, 'DestFinType,,', 0, 36853, 0, 0) ;

CALL ImportField(30111029, ' .', 'SourceDirectionClsCode', ' ', 'SourceDirectionCls', 1, 301, 1, 0, ',', 0, 36861, 0, 0) ;

CALL ImportField(30111030, ' -', 'DestDirectionClsCode', ' ', 'DestDirectionCls', 1, 301, 1, 0, 'DestDirectionCls,', 0, 36861, 0, 0) ;

CALL ImportField(30111031, ' ', 'SourceDocBaseCode', ' ', 'SOURCEDOCBASE', 1, 301, 1, 0, ',,', 0, 36865, 0, 0) ;

CALL ImportField(30111032, ' ', 'DestDocBaseCode', ' ', 'DESTDOCBASE', 1, 301, 1, 0, 'DestDocBase,,', 0, 36865, 0, 0) ;

CALL ImportField(30111079, '( .)', 'SourceIFSAGCode', ' ()', ' ', 1, 301, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(30111082, '( -)', 'DestIFSAGCode', ' ()', ' ', 1, 301, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(30111114, '( .)', 'SourceKDAGCode', '', ' ', 1, 301, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(30111118, ' -( -)', 'DestKDAGCode', '1', ' ', 1, 301, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(30111161, '   .', 'SourcePayPromiseCls', '', 'SourcePayPromiseCls', 1, 301, 1, 1, '', 0, 27845, 0, 0) ;

CALL ImportField(30111162, ' .()', 'SourceFact', ' ', 'SourceFACTCLSKey', 1, 301, 1, 1, ',', 0, 18890, 0, 0) ;

CALL ImportField(30111163, ' - ()', 'DestFact', ' ', 'DestFACTCLSKey', 1, 301, 1, 1, 'DestFactKey,', 0, 18899, 0, 0) ;

CALL ImportField(30111164, ' .()', 'SourceDirectionCls', ' ', 'SourceDirectionClsKey', 1, 301, 1, 1, ',', 0, 18913, 0, 0) ;

CALL ImportField(30111165, ' -()', 'DestDirectionCls', ' ', 'DestDirectionClsKey', 1, 301, 1, 1, 'DestDirectionClsKey,', 0, 18914, 0, 0) ;

CALL ImportField(30111166, ' .  . ()', 'SourceFinType', '   ', 'SourceFINTYPECLSKey', 1, 301, 1, 1, ',,,', 0, 18893, 0, 0) ;

CALL ImportField(30111167, ' .  - ()', 'DestFinType', '   ', 'DestFINTYPECLSKey', 1, 301, 1, 1, 'DestFinTypeKey,,', 0, 18902, 0, 0) ;

CALL ImportField(30111168, '  ()', 'SourceDocBase', ' ', 'SOURCEDOCBASEKey', 1, 301, 1, 1, ',,', 0, 18915, 0, 0) ;

CALL ImportField(30111169, '  ()', 'DestDocBase', ' ', 'DESTDOCBASEKey', 1, 301, 1, 1, 'DestDocBaseKey,,', 0, 18916, 0, 0) ;

CALL ImportField(30111171, '  ()', 'SourceInvestObject', ' ', '', 1, 301, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(30111172, '  ()', 'DestInvestObject', ' ', ' ', 1, 301, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(30111173, ' ', 'SourceInvestObjectCode', ' ', ' ', 1, 301, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(30111174, ' ', 'DestInvestObjectCode', ' ', ' ', 1, 301, 1, 0, '', 0, null, 0, 0) ;

--   \, (1)
CALL ImportField(30210026, ' ', 'REESTRDATE', ' ', 'REESTRDATE', 1, 302, 0, 0, '', 0, 19091, 0, 0) ;

CALL ImportField(30210031, ' ', 'CardNumber', '  ', 'CARDNUMBER', 1, 302, 0, 0, '', 0, 18985, 0, 0) ;

CALL ImportField(30210135, '   ', 'StimateID', '   ', 'StimateID', 1, 302, 0, 0, '', 0, 18999, 0, 0) ;

CALL ImportField(30210137, ' ', 'BidDate', ' ', 'BidDate', 1, 302, 0, 0, '', 0, 24730, 0, 0) ;

CALL ImportField(30210151, ' ()', 'CardRef', '  ', 'CardRef', 1, 302, 0, 1, '', 0, 31656, 0, 0) ;

CALL ImportField(30210152, ' ', 'CardRefName', '', ' ', 1, 302, 0, 0, '', 0, 18939, 0, 0) ;

CALL ImportField(30210158, ' ', 'DocOsn', ' ', '', 1, 302, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(30210159, ' ', 'CashierPersonalInfo', ' ', 'CashierPersonalInfo', 1, 302, 0, 0, '', 0, 24731, 0, 0) ;

CALL ImportField(30210160, '', 'Signers', '', 'Signers', 1, 302, 0, 0, '', 0, 38174, 0, 0) ;

CALL ImportField(30211002, '', 'SourceDirectionClsCode', '', 'SourceDirectionCLS', 1, 302, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(30211008, '', 'SOURCEFACTCODE', '', 'SOURCEFACTCLS', 1, 302, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(30211011, ' . ', 'SOURCEFINTYPECODE', '  ', 'SOURCEFINTYPECLS', 1, 302, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(30211016, '', 'SourceDocBaseCode', '', 'SourceDocBase', 1, 302, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(30211076, '()', 'SourceIFSAGCode', ' ( )', ' ', 1, 302, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(30211110, '()', 'SourceKDAGCode', '()', ' ', 1, 302, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(30211151, '()', 'SourceFact', '', 'SourceFACTCLSKey', 1, 302, 1, 1, '', 0, 18890, 0, 0) ;

CALL ImportField(30211152, ' ()', 'SourceDirectionCls', '', 'SourceDirectionClsKey', 1, 302, 1, 1, '', 0, 18913, 0, 0) ;

CALL ImportField(30211153, ' .  ()', 'SOURCEFINTYPE', '  ', 'SourceFINTYPECLSKey', 1, 302, 1, 1, ',', 0, 18893, 0, 0) ;

CALL ImportField(30211154, ' ()', 'SourceDocBase', '', 'SOURCEDOCBASEKey', 1, 302, 1, 1, ',', 0, 18915, 0, 0) ;

CALL ImportField(30211156, '', 'SourceInvestObject', '', ' ', 1, 302, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(30211157, '', 'SourceInvestObjectCode', '', ' ', 1, 302, 1, 0, '', 0, null, 0, 0) ;

--  (), (1)
CALL ImportField(30311018, '', 'DestFactCode', '', 'DestFactCLS', 1, 303, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(30311021, '()', 'DestIFSAGCode', '', ' ', 1, 303, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(30311024, ' . ', 'DestFinTypeCode', '  ', 'DestFinTypeCLS', 1, 303, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(30311037, '', 'DestDirectionCLSCode', '', 'DestDirectionCLS', 1, 303, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(30311039, '', 'DestDocBaseCode', '', 'DESTDOCBASE', 1, 303, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(30311089, ' ()', 'DestFact', '', 'DestFACTCLSKey', 1, 303, 1, 1, '', 0, 18899, 0, 0) ;

CALL ImportField(30311090, ' ()', 'DestDirectionCls', '', 'DestDirectionClsKey', 1, 303, 1, 1, '', 0, 18914, 0, 0) ;

CALL ImportField(30311092, ' .  - ()', 'DestFinType', '   ', 'DestFINTYPECLSKey', 1, 303, 1, 1, ',', 0, 18902, 0, 0) ;

CALL ImportField(30311093, ' ()', 'DestDocBase', '', 'DESTDOCBASEKey', 1, 303, 1, 1, ',', 0, 18916, 0, 0) ;

CALL ImportField(30311095, '', 'DestInvestObject', '', ' ', 1, 303, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(30311096, '', 'DestInvestObjectCode', '', ' ', 1, 303, 1, 0, '', 0, null, 0, 0) ;

--   , (1)
CALL ImportField(30410107, ' ', 'DestAccount', ' ', 'DESTACCOUNT', 1, 304, 0, 1, '', 0, 18958, 0, 0) ;

CALL ImportField(30410129, ' ', 'CardNumber', '   ()', 'CARDNUMBER', 1, 304, 0, 0, '', 0, 18985, 0, 0) ;

CALL ImportField(30410141, ' ()', 'CardRef', '  ', 'CardRef', 1, 304, 0, 1, '', 0, 31656, 0, 0) ;

CALL ImportField(30410142, ' ', 'CardRefName', '  ', 'CardRefName', 1, 304, 0, 0, '', 0, 18939, 0, 0) ;

CALL ImportField(30410143, '(  )', 'Status', '', 'Status', 1, 304, 0, 1, '', 0, 17233, 0, 0) ;

CALL ImportField(30410144, '  ', 'ParentElBank', '  ', ' ', 1, 304, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(30410145, '(  )', 'pdeID', '', ' ', 1, 304, 0, 1, '', 0, 17226, 0, 0) ;

CALL ImportField(30410146, '', 'Signers', '', 'Signers', 1, 304, 0, 0, '', 0, 38174, 0, 0) ;

CALL ImportField(30411001, '', 'SOURCEFACTCODE', '', 'SOURCEFACTCLS', 1, 304, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(30411008, ' . ', 'SOURCEFINTYPECODE', '  ', 'SOURCEFINTYPECLS', 1, 304, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(30411010, '', 'SourceDirectionClsCode', '', 'SourceDirectionCLS', 1, 304, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(30411018, '', 'SourceDocBaseCode', '', 'SourceDocBase', 1, 304, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(30411077, '()', 'SourceIFSAGCode', ' ( )', ' ', 1, 304, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(30411100, '()', 'SourceKDAGCode', '()', ' ', 1, 304, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(30411141, '()', 'SourceFact', '', 'SourceFACTCLSKey', 1, 304, 1, 1, '', 0, 18890, 0, 0) ;

CALL ImportField(30411142, ' ()', 'SourceDirectionCls', '', 'SourceDirectionClsKey', 1, 304, 1, 1, '', 0, 18913, 0, 0) ;

CALL ImportField(30411143, ' .  ()', 'SOURCEFINTYPE', '  ', 'SourceFINTYPECLSKey', 1, 304, 1, 1, ',', 0, 18893, 0, 0) ;

CALL ImportField(30411144, ' ()', 'SourceDocBase', '', 'SOURCEDOCBASEKey', 1, 304, 1, 1, ',', 0, 18915, 0, 0) ;

CALL ImportField(30411145, '', 'SourceInvestObject', '', ' ', 1, 304, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(30411146, '', 'SourceInvestObjectCode', '', ' ', 1, 304, 1, 0, '', 0, null, 0, 0) ;

--   \, (1)
CALL ImportField(30510165, ' ()', 'CardRef', '  ', 'CardRef', 1, 305, 0, 1, '', 0, 31656, 0, 0) ;

CALL ImportField(30510169, '  ', 'CardRefName', '  ', ' ', 1, 305, 0, 0, '', 0, 18939, 0, 0) ;

CALL ImportField(30510172, ' ', 'CardNumber', '  ', 'CardNumber', 1, 305, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(30511019, '', 'DestFactCode', ' ', 'DestFACTCLS', 1, 305, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(30511022, ' . ', 'DestFinTypeCode', '  ', 'DestFINTYPECLS', 1, 305, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(30511024, '', 'DestDirectionCLSCode', ' ', 'DestDirectionCLS', 1, 305, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(30511050, '()', 'DestIFSAGCode', '( )', ' ', 1, 305, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(30511103, '', 'DestDocBaseCode', '', 'DestDocBase', 1, 305, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(30511112, '()', 'DestKDAGCode', '', ' ', 1, 305, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(30511142, ' ()', 'DestFact', '', 'DestFACTCLSKey', 1, 305, 1, 1, '', 0, 18899, 0, 0) ;

CALL ImportField(30511143, ' ()', 'DestDirectionCls', ' ', 'DestDirectionClsKey', 1, 305, 1, 1, '', 0, 18914, 0, 0) ;

CALL ImportField(30511144, ' .  - ()', 'DestFinType', '  ', 'DestFINTYPECLSKey', 1, 305, 1, 1, ',', 0, 18902, 0, 0) ;

CALL ImportField(30511145, ' ()', 'DestDocBase', '', 'DESTDOCBASEKey', 1, 305, 1, 1, ',', 0, 18916, 0, 0) ;

CALL ImportField(30511146, '', 'DestInvestObject', '', ' ', 1, 305, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(30511147, '', 'DestInvestObjectCode', '', ' ', 1, 305, 1, 0, '', 0, null, 0, 0) ;

--   , (1)
CALL ImportField(30610130, ' ', 'CARDNUMBER', '   ()', 'CARDNUMBER', 1, 306, 0, 0, '', 0, 18985, 0, 0) ;

CALL ImportField(30610144, ' ()', 'CardRef', '  ', 'CardRef', 1, 306, 0, 1, '', 0, 31656, 0, 0) ;

CALL ImportField(30610145, ' ', 'CardRefName', '  ', ' ', 1, 306, 0, 0, '', 0, 18939, 0, 0) ;

CALL ImportField(30610146, '(  )', 'UINCode', '  ', 'UINCode', 1, 306, 0, 0, '', 0, 35367, 0, 0) ;

CALL ImportField(30610150, '(  )', 'Status', '', 'Status', 1, 306, 0, 1, '', 0, 17233, 0, 0) ;

CALL ImportField(30610151, '  ', 'ParentElBank', '  ', ' ', 1, 306, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(30610152, '(  )', 'pdeID', '', ' ', 1, 306, 0, 1, '', 0, 17226, 0, 0) ;

CALL ImportField(30611023, '', 'DestFactCode', '', 'DestFACTCLS', 1, 306, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(30611024, '', 'DestDirectionCLSCode', '', 'DestDirectionCLS', 1, 306, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(30611027, '()', 'DestIFSAGCode', '', ' ', 1, 306, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(30611031, '()', 'DestKDAGCode', '', ' ', 1, 306, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(30611032, ' . ', 'DestFinTypeCode', '  ', 'DestFINTYPECLS', 1, 306, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(30611049, '', 'DestDocBaseCode', '', 'DESTDOCBASE', 1, 306, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(30611144, ' ()', 'DestFact', '', 'DestFACTCLSKey', 1, 306, 1, 1, '', 0, 18899, 0, 0) ;

CALL ImportField(30611145, ' ()', 'DestDirectionCls', ' ', 'DestDirectionClsKey', 1, 306, 1, 1, '', 0, 18914, 0, 0) ;

CALL ImportField(30611146, ' .  ()', 'DestFinType', '  ', 'DestFINTYPECLSKey', 1, 306, 1, 1, ',', 0, 18902, 0, 0) ;

CALL ImportField(30611147, ' ()', 'DestDocBase', '', 'DESTDOCBASEKey', 1, 306, 1, 1, ',', 0, 18916, 0, 0) ;

CALL ImportField(30611148, '', 'DestInvestObject', '', ' ', 1, 306, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(30611149, '', 'DestInvestObjectCode', '', ' ', 1, 306, 1, 0, '', 0, null, 0, 0) ;

--  , (1)
CALL ImportField(30711018, ' ', 'DocSended', '  ', ' ', 1, 307, 1, 1, '', 0, null, 0, 0) ;

--  , (1)
CALL ImportField(30810069, '(  )', 'UINCode', '  ', 'UINCode', 1, 308, 0, 0, '', 0, 35367, 0, 0) ;

CALL ImportField(30810070, ' ', 'DestClsType', '', ' ', 1, 308, 0, 1, '', 0, 38187, 0, 0) ;

CALL ImportField(30811008, ' ', 'DestDirectionCLSCode', ' -', 'DestDirectionCLS', 1, 308, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(30811009, ' ', 'DestDocBaseCode', ' ', 'DESTDOCBASE', 1, 308, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(30811016, ' ', 'DestFactCode', ' -', 'DestFACTCLS', 1, 308, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(30811018, ' .  ( )', 'DestFinTypeCode', '   -', 'DestFINTYPECLS', 1, 308, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(30811021, ' ( )', 'DestKDAGCode', ' -( -)', ' ', 1, 308, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(30811030, '', 'NOTE', ' ', 'NOTE', 1, 308, 1, 0, '', 0, 18876, 0, 0) ;

CALL ImportField(30811035, ' .( .)', 'SourceDirectionCLSCode', ' .( .)', 'SourceDirectionCLS', 1, 308, 1, 0, ',', 0, 36861, 0, 0) ;

CALL ImportField(30811036, ' ', 'SourceDocBaseCode', ' ', 'SOURCEDOCBASE', 1, 308, 1, 0, ',,', 0, 36865, 0, 0) ;

CALL ImportField(30811041, ' ', 'SourceFactCode', ' .', 'SourceFACTCLS', 1, 308, 1, 0, ',', 0, 36863, 0, 0) ;

CALL ImportField(30811043, ' .  .', 'SourceFinTypeCode', '   .', 'SourceFINTYPECLS', 1, 308, 1, 0, ',,', 0, 36853, 0, 0) ;

CALL ImportField(30811069, ' ( )', 'DESTKESR', '', 'DestKESR', 1, 308, 1, 0, '', 0, 18871, 0, 0) ;

CALL ImportField(30811077, '( )', 'SourceKDAGCode', '', ' ', 1, 308, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(30811094, ' ( )', 'DestIFS', '', 'DestIFS', 1, 308, 1, 1, '', 0, 18921, 0, 0) ;

CALL ImportField(30811096, '( )', 'DestIFSAGCode', '', ' ', 1, 308, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(30811098, ' ( )', 'SourceIFS', '', 'SourceIFS', 1, 308, 1, 1, ',', 0, 18920, 0, 0) ;

CALL ImportField(30811100, '( )', 'SourceIFSAGCode', '', ' ', 1, 308, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(30811103, '  ()', 'SourceFact', ' ', 'SourceFACTCLSKey', 1, 308, 1, 1, ',', 0, 18890, 0, 0) ;

CALL ImportField(30811104, '  ()', 'DestFact', ' ', 'DestFACTCLSKey', 1, 308, 1, 1, '', 0, 18899, 0, 0) ;

CALL ImportField(30811105, ' .()', 'SourceDirectionCLS', ' ', 'SourceDirectionClsKey', 1, 308, 1, 1, ',', 0, 18913, 0, 0) ;

CALL ImportField(30811106, ' -()', 'DestDirectionCLS', ' ', 'DestDirectionClsKey', 1, 308, 1, 1, '', 0, 18914, 0, 0) ;

CALL ImportField(30811107, ' .  . ()', 'SourceFinType', '   ', 'SourceFINTYPECLSKey', 1, 308, 1, 1, ',,', 0, 18893, 0, 0) ;

CALL ImportField(30811108, ' .  ()', 'DestFinType', '   ', 'DestFINTYPECLSKey', 1, 308, 1, 1, ',', 0, 18902, 0, 0) ;

CALL ImportField(30811109, '  ()', 'SourceDocBase', ' ', 'SOURCEDOCBASEKey', 1, 308, 1, 1, ',,', 0, 18915, 0, 0) ;

CALL ImportField(30811110, '  ()', 'DestDocBase', ' ', 'DESTDOCBASEKey', 1, 308, 1, 1, ',', 0, 18916, 0, 0) ;

CALL ImportField(30811111, '  ()', 'SourceInvestObject', ' ', ' ', 1, 308, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(30811112, '  ()', 'DestInvestObject', ' ', ' ', 1, 308, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(30811113, ' ', 'SourceInvestObjectCode', ' ', ' ', 1, 308, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(30811114, ' ', 'DestInvestObjectCode', ' ', ' ', 1, 308, 1, 0, '', 0, null, 0, 0) ;

--    , (1)
CALL ImportField(31110075, '  ', 'CardRefName', '  ', ' ', 1, 311, 0, 0, '', 0, 18939, 0, 0) ;

CALL ImportField(31110081, ' ', 'CardNumber', '  ', 'CardNumber', 1, 311, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(31111010, '', 'SourceDirectionCLSCode', '', 'SourceDirectionCLS', 1, 311, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(31111011, '', 'SourceFactCode', '', 'SourceFactCls', 1, 311, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(31111013, ' . ', 'SourceFinTypeCode', '  ', 'SourceFinTypeCls', 1, 311, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(31111023, ' ', 'DestDirectionCLSCode', ' ', 'DestDirectionCLS', 1, 311, 1, 1, '', 0, 36861, 0, 0) ;

CALL ImportField(31111024, ' ', 'DestFactCode', ' ', 'DestFactCls', 1, 311, 1, 1, '', 0, 36863, 0, 0) ;

CALL ImportField(31111026, ' .  ', 'DestFinTypeCode', '   ', 'DestFinTypeCls', 1, 311, 1, 1, ',', 0, 36853, 0, 0) ;

CALL ImportField(31111042, '', 'SourceDocBaseCode', '', 'SOURCEDOCBASE', 1, 311, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(31111053, '()', 'SourceIFSAGCode', '', ' ', 1, 311, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(31111057, '()', 'SourceKDAGCode', '', ' ', 1, 311, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(31111100, '  ()', 'SourceFact', ' ', 'SourceFACTCLSKey', 1, 311, 1, 1, '', 0, 18890, 0, 0) ;

CALL ImportField(31111101, '  ()', 'DestFact', ' ', 'DestFACTCLSKey', 1, 311, 1, 1, '', 0, 18899, 0, 0) ;

CALL ImportField(31111102, ' ()', 'SourceDirectionCLS', '', 'SourceDirectionClsKey', 1, 311, 1, 1, '', 0, 18913, 0, 0) ;

CALL ImportField(31111103, '  ()', 'DestDirectionCLS', ' ', 'DestDirectionClsKey', 1, 311, 1, 1, '', 0, 18914, 0, 0) ;

CALL ImportField(31111104, ' .  ()', 'SourceFinType', '   ', 'SourceFINTYPECLSKey', 1, 311, 1, 1, ',', 0, 18893, 0, 0) ;

CALL ImportField(31111105, ' .   ()', 'DestFinType', '   ', 'DestFINTYPECLSKey', 1, 311, 1, 1, ',', 0, 18902, 0, 0) ;

CALL ImportField(31111106, ' ()', 'SourceDocBase', '', 'SOURCEDOCBASEKey', 1, 311, 1, 1, ',,', 0, 18915, 0, 0) ;

CALL ImportField(31111107, '', 'SourceInvestObject', '', ' ', 1, 311, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(31111108, '', 'SourceInvestObjectCode', '', ' ', 1, 311, 1, 0, '', 0, null, 0, 0) ;

--     , (1)
CALL ImportField(31210126, ' ', 'CardNumber', '  ', 'CardNumber', 1, 312, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(31211022, '()', 'DestFACTCode', ' ', 'DestFACTCLS', 1, 312, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(31211025, ' . ', 'DestFINTYPECode', '  ', 'DestFINTYPECLS', 1, 312, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(31211027, '()', 'DestDirectionCLSCode', ' ', 'DestDirectionCLS', 1, 312, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(31211045, ' ', 'SourceDirectionCLSCode', ' ', 'SourceDirectionCLS', 1, 312, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(31211074, '()', 'DestIFSAGCode', ' ( )', ' ', 1, 312, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(31211076, '', 'DestDocBaseCode', '', 'DESTDOCBASE', 1, 312, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(31211099, '()', 'DestKDAGCode', '', ' ', 1, 312, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(31211137, '()', 'DestFact', ' ', 'DestFACTCLSKey', 1, 312, 1, 1, '', 0, 18899, 0, 0) ;

CALL ImportField(31211138, '  ()', 'SourceDirectionCLS', '', 'SourceDirectionClsKey', 1, 312, 1, 1, '', 0, 18913, 0, 0) ;

CALL ImportField(31211139, '()', 'DestDirectionCLS', ' ', 'DestDirectionClsKey', 1, 312, 1, 1, '', 0, 18914, 0, 0) ;

CALL ImportField(31211140, ' ()', 'DestDocBase', '', 'DESTDOCBASEKEY', 1, 312, 1, 1, ',', 0, 18916, 0, 0) ;

CALL ImportField(31211141, ' . ', 'DestFINTYPE', '  ', 'DestFINTYPECLSKey', 1, 312, 1, 1, ',', 0, 18902, 0, 0) ;

CALL ImportField(31211142, '', 'DestInvestObject', '', ' ', 1, 312, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(31211143, '', 'DestInvestObjectCode', '', ' ', 1, 312, 1, 0, '', 0, null, 0, 0) ;

--    , (1)
CALL ImportField(31410126, ' ', 'CardNumber', '  ', 'CardNumber', 1, 314, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(31411027, ' ', 'DestDirectionCLSCode', ' ', 'DestDirectionCLS', 1, 314, 1, 1, '', 0, 36861, 0, 0) ;

CALL ImportField(31411040, '', 'SourceFACTCode', ' ', 'SourceFACTCLS', 1, 314, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(31411043, ' . ', 'SourceFINTYPECode', '   ', 'SourceFINTYPECLS', 1, 314, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(31411045, '', 'SourceDirectionCLSCode', ' ', 'SourceDirectionCLS', 1, 314, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(31411074, '()', 'SourceIFSAGCode', '()', ' ', 1, 314, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(31411075, ' ()', 'SourceIFS_DescriptionCode', ' ()', 'SourceIFS_DescriptionCode', 1, 314, 1, 0, '', 0, 17050, 0, 0) ;

CALL ImportField(31411076, '', 'SourceDocBaseCode', '', 'SourceDocBase', 1, 314, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(31411099, '()', 'SourceKDAGCode', '()', ' ', 1, 314, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(31411136, ' ()', 'SourceFACT', ' ', 'SourceFACTCLSKey', 1, 314, 1, 1, '', 0, 18890, 0, 0) ;

CALL ImportField(31411137, ' ()', 'SourceDirectionCLS', ' ', 'SourceDirectionCLSKey', 1, 314, 1, 1, '', 0, 18913, 0, 0) ;

CALL ImportField(31411138, '  ()', 'DestDirectionCLS', ' ', 'DestDirectionCLSKey', 1, 314, 1, 1, '', 0, 18914, 0, 0) ;

CALL ImportField(31411139, ' .  ()', 'SourceFINTYPE', '   ', 'SourceFINTYPECLSKey', 1, 314, 1, 1, ',', 0, 18893, 0, 0) ;

CALL ImportField(31411140, ' ()', 'SourceDocBase', '', 'SourceDocBaseKey', 1, 314, 1, 1, ',', 0, 18915, 0, 0) ;

CALL ImportField(31411141, '', 'SourceIFS_FullID', '', 'SourceIFS_DescriptionCode', 1, 314, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(31411142, '', 'SourceInvestObject', '', ' ', 1, 314, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(31411143, '', 'SourceInvestObjectCode', '', ' ', 1, 314, 1, 0, '', 0, null, 0, 0) ;

--      , (1)
CALL ImportField(31510097, ' ', 'CardNumber', '  ', 'CARDNUMBER', 1, 315, 0, 0, '', 0, 18985, 0, 0) ;

CALL ImportField(31511021, '', 'DestFactCode', '', 'DestFACTCLS', 1, 315, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(31511022, '', 'DestDirectionCLSCode', '', 'DestDirectionCLS', 1, 315, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(31511025, '()', 'DestIFSAGCode', '', ' ', 1, 315, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(31511029, '()', 'DestKDAGCode', '', ' ', 1, 315, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(31511045, ' . ', 'DestFinTypeCode', '  ', 'DestFINTYPECLS', 1, 315, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(31511047, '', 'DestDocBaseCode', '', 'DestDocBase', 1, 315, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(31511094, ' ()', 'DestDirectionCLS', '', 'DestDirectionCLSKey', 1, 315, 1, 1, '', 0, 18914, 0, 0) ;

CALL ImportField(31511095, '', 'DestFact', '', 'DestFACTCLSKey', 1, 315, 1, 1, '', 0, 18899, 0, 0) ;

CALL ImportField(31511096, ' .  ()', 'DestFinType', '  ', 'DestFINTYPECLSKey', 1, 315, 1, 1, ',', 0, 18902, 0, 0) ;

CALL ImportField(31511097, ' ()', 'DestDocBase', '', 'DestDocBaseKey', 1, 315, 1, 1, ',', 0, 18916, 0, 0) ;

CALL ImportField(31511098, '', 'DestInvestObject', '', ' ', 1, 315, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(31511099, '', 'DestInvestObjectCode', '', ' ', 1, 315, 1, 0, '', 0, null, 0, 0) ;

--   , (1)
CALL ImportField(32210059, ' ', 'DestAccount', ' ', ' ', 1, 322, 0, 1, '', 0, 18958, 0, 0) ;

CALL ImportField(32211028, '', 'SourceFactCode', '', ' ', 1, 322, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(32211029, '', 'SourceDirectionCLSCode', '', ' ', 1, 322, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(32211032, '()', 'SourceIFSAGCode', '', ' ', 1, 322, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(32211042, ' . ', 'SourceFinTypeCode', '  ', ' ', 1, 322, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(32211044, '', 'SourceDocBaseCode', '', ' ', 1, 322, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(32211086, ' ()', 'SourceDirectionCLS', '', ' ', 1, 322, 1, 1, '', 0, 18913, 0, 0) ;

CALL ImportField(32211087, ' ()', 'SourceFact', '', ' ', 1, 322, 1, 1, '', 0, 18890, 0, 0) ;

CALL ImportField(32211088, ' .  ()', 'SourceFinType', '  ', ' ', 1, 322, 1, 1, ',', 0, 18893, 0, 0) ;

CALL ImportField(32211089, ' ()', 'SourceDocBase', '', ' ', 1, 322, 1, 1, ',', 0, 18915, 0, 0) ;

CALL ImportField(32211090, '', 'SourceInvestObject', '', ' ', 1, 322, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(32211091, '', 'SourceInvestObjectCode', '', ' ', 1, 322, 1, 0, '', 0, null, 0, 0) ;

--  , (1)
CALL ImportField(32311019, '', 'DestFactCode', '', 'DestFACTCLS', 1, 323, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(32311020, '', 'DestDirectionCLSCode', '', 'DestDirectionCLS', 1, 323, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(32311023, '()', 'DestIFSAGCode', '', ' ', 1, 323, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(32311034, ' . ', 'DestFinTypeCode', '  ', 'DestFINTYPECLS', 1, 323, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(32311036, '', 'DestDocBaseCode', '', 'DESTDOCBASE', 1, 323, 1, 0, ',,', 0, 36865, 0, 0) ;

CALL ImportField(32311153, ' ()', 'DestDirectionCLS', '', 'DestDirectionCLSKey', 1, 323, 1, 1, '', 0, 18914, 0, 0) ;

CALL ImportField(32311154, ' ()', 'DestFact', '', 'DestFACTCLSKey', 1, 323, 1, 1, '', 0, 18899, 0, 0) ;

CALL ImportField(32311155, ' .  ()', 'DestFinType', '  ', 'DestFINTYPECLSKey', 1, 323, 1, 1, ',', 0, 18902, 0, 0) ;

CALL ImportField(32311156, ' ()', 'DestDocBase', '', 'DESTDOCBASEKEY', 1, 323, 1, 1, ',,', 0, 18916, 0, 0) ;

CALL ImportField(32311157, '', 'DestInvestObject', '', ' ', 1, 323, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(32311158, '', 'DestInvestObjectCode', '', ' ', 1, 323, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(32311159, ' ()', 'TransfertOrg_CalcName', ' () ( )', ' ', 1, 323, 1, 0, '', 1, null, 0, 0) ;

CALL ImportField(32311160, ' ()', 'TransfertOrg_INN', ' ()', ' ', 1, 323, 1, 0, '', 0, 16645, 0, 0) ;

CALL ImportField(32311161, ' ()', 'TransfertOrg_INN20', ' ()', ' ', 1, 323, 1, 0, '', 0, 16653, 0, 0) ;

CALL ImportField(32311162, ' ()', 'TransfertOrg_Name', ' ()', ' ', 1, 323, 1, 0, '', 0, 16646, 0, 0) ;

CALL ImportField(32311163, ' ()', 'TransfertOrg_Ref', ' ()()', 'TransfertOrg_Ref', 1, 323, 1, 1, '', 0, 38150, 0, 0) ;

CALL ImportField(32311164, '    ', 'DestBudgetPromiseNumLine', '    ', 'DestBudgetPromiseNumLine', 1, 323, 1, 1, '', 0, null, 0, 0) ;

--  , (1)
CALL ImportField(32411072, '', 'DestFactCode', ' -', 'DestFACTCLS', 1, 324, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(32411074, ' . ', 'DestFinTypeCode', '   -', 'DestFINTYPECLS', 1, 324, 1, 0, ',,', 0, 36853, 0, 0) ;

CALL ImportField(32411082, '', 'DestDocBaseCode', '', 'DESTDOCBASE', 1, 324, 1, 0, ',,', 0, 36865, 0, 0) ;

CALL ImportField(32411084, '', 'DestDirectionCLSCode', ' -', 'DestDirectionCLS', 1, 324, 1, 0, ',', 0, 36861, 0, 0) ;

CALL ImportField(32411090, '()', 'DestIFSAGCode', '()', ' ', 1, 324, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(32411185, ' ', 'DestIFS_FullID', ' ', 'DestIFS_DescriptionCode', 1, 324, 1, 1, '', 0, 17055, 0, 0) ;

CALL ImportField(32411188, '  ', 'DestBudAllocationClsCode', '', 'DestBudAllocationClsCode', 1, 324, 1, 0, ',', 0, 27825, 0, 0) ;

CALL ImportField(32411189, '  ', 'DestPayPromiseClsCode', '', 'DestPayPromiseClsCode', 1, 324, 1, 0, ',', 0, 27849, 0, 0) ;

CALL ImportField(32411194, ' ()', 'DestFact', ' -', 'DestFACTCLSKey', 1, 324, 1, 1, '', 0, 18899, 0, 0) ;

CALL ImportField(32411195, ' ()', 'DestDirectionCls', ' ', 'DestDirectionClsKey', 1, 324, 1, 1, ',', 0, 18914, 0, 0) ;

CALL ImportField(32411196, ' .  ()', 'DestFinType', '  ', 'DestFINTYPECLSKey', 1, 324, 1, 1, ',,', 0, 18902, 0, 0) ;

CALL ImportField(32411197, ' ()', 'DestDocBase', '', 'DESTDOCBASEKey', 1, 324, 1, 1, ',,', 0, 18916, 0, 0) ;

CALL ImportField(32411198, '', 'DestInvestObject', '', ' ', 1, 324, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(32411199, '', 'DestInvestObjectCode', '', ' ', 1, 324, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(32411200, ' ()', 'TransfertOrg_INN', ' ()', ' ', 1, 324, 1, 0, '', 0, 16645, 0, 0) ;

CALL ImportField(32411201, ' ()', 'TransfertOrg_INN20', ' ()', ' ', 1, 324, 1, 0, '', 0, 16653, 0, 0) ;

CALL ImportField(32411202, ' ()', 'TransfertOrg_CalcName', ' () ( )', ' ', 1, 324, 1, 0, '', 1, null, 0, 0) ;

CALL ImportField(32411203, ' ()', 'TransfertOrg_Name', ' ()', ' ', 1, 324, 1, 0, '', 0, 16646, 0, 0) ;

CALL ImportField(32411204, ' ()', 'TransfertOrg_Ref', ' ()()', 'TransfertOrg_Ref', 1, 324, 1, 1, '', 0, 38150, 0, 0) ;

--    , (1)
CALL ImportField(40110019, '', 'FactCode', '', ' ', 1, 401, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(40110034, '  ()', 'DocBaseCode', '  ', ' ', 1, 401, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(40110221, ' ()', 'Fact', '', ' ', 1, 401, 0, 1, '', 0, 17980, 0, 0) ;

CALL ImportField(40110222, '  ()', 'DocBase', '  ', ' ', 1, 401, 0, 1, '', 0, 17995, 0, 0) ;

CALL ImportField(40116126, '', 'FACTCode', '', ' ', 1, 401, 6, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(40116127, '', 'DirectionCLSCode', '', ' ', 1, 401, 6, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(40116128, ' ', 'FINTYPECode', ' ', ' ', 1, 401, 6, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(40116248, ' ()', 'DirectionCLS', '', ' ', 1, 401, 6, 1, '', 0, 17867, 0, 0) ;

CALL ImportField(40116249, ' ()', 'FACT', '', ' ', 1, 401, 6, 1, '', 0, 17829, 0, 0) ;

CALL ImportField(40116250, '  ()', 'FINTYPE', ' ', ' ', 1, 401, 6, 1, ',', 0, 17833, 0, 0) ;

CALL ImportField(40110190, ' ', 'FINTYPECode', ' ', ' ', 1, 401, 10, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(40110197, '', 'FACTCode', '', ' ', 1, 401, 10, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(40110198, '', 'DirectionCLSCode', '', ' ', 1, 401, 10, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(40110253, ' ()', 'DirectionCLS', '', ' ', 1, 401, 10, 1, '', 0, 17867, 0, 0) ;

CALL ImportField(40110254, ' ()', 'FACT', '', ' ', 1, 401, 10, 1, '', 0, 17829, 0, 0) ;

CALL ImportField(40110255, '  ()', 'FINTYPE', ' ', ' ', 1, 401, 10, 1, ',', 0, 17833, 0, 0) ;

--   , (1)
CALL ImportField(50110025, '', 'FactCode', '', ' ', 1, 501, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(50110029, ' ()', 'DocBaseCode', ' ', ' ', 1, 501, 0, 0, '', 0, 36865, 0, 0) ;

CALL ImportField(50110156, ' ()', 'Fact', '', ' ', 1, 501, 0, 1, '', 0, 17980, 0, 0) ;

CALL ImportField(50110157, ' ()', 'DocBase', ' ', ' ', 1, 501, 0, 1, '', 0, 17995, 0, 0) ;

CALL ImportField(50111043, '', 'FACTCODE', '', ' ', 1, 501, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(50111044, '', 'DirectionCLSCode', '', ' ', 1, 501, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(50111048, ' ', 'FINTYPECODE', ' ', ' ', 1, 501, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(50111178, '()', 'IFSAGCode', '()', ' ', 1, 501, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(50111184, ' ()', 'DirectionCLS', '', ' ', 1, 501, 1, 1, '', 0, 17867, 0, 0) ;

CALL ImportField(50111185, ' ()', 'FACT', '', ' ', 1, 501, 1, 1, '', 0, 17829, 0, 0) ;

CALL ImportField(50111186, '  ()', 'FINTYPE', ' ', ' ', 1, 501, 1, 1, '', 0, 17833, 0, 0) ;

CALL ImportField(50113079, '', 'FACTCODE', '', ' ', 1, 501, 3, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(50113080, '', 'DirectionCLSCode', '', ' ', 1, 501, 3, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(50113084, ' ', 'FINTYPECODE', ' ', ' ', 1, 501, 3, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(50113182, '()', 'IFSAGCode', '()', ' ', 1, 501, 3, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(50113188, ' ()', 'DirectionCLS', '', ' ', 1, 501, 3, 1, '', 0, 17867, 0, 0) ;

CALL ImportField(50113189, ' ()', 'FACT', '', ' ', 1, 501, 3, 1, '', 0, 17829, 0, 0) ;

CALL ImportField(50113190, '  ()', 'FINTYPE', ' ', ' ', 1, 501, 3, 1, '', 0, 17833, 0, 0) ;

--   , (1)
CALL ImportField(70111012, '', 'FACTCODE', '', ' ', 1, 701, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(70111013, '', 'DirectionCLSCode', '', ' ', 1, 701, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(70111021, ' ', 'FINTYPECODE', ' ', ' ', 1, 701, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(70111022, '', 'REGIONCLS', '', ' ', 1, 701, 1, 0, ',', 0, 17831, 0, 0) ;

CALL ImportField(70111042, '-', 'DOCUMENTBASETYPECode', '-', ' ', 1, 701, 1, 0, '', 0, 36865, 0, 0) ;

CALL ImportField(70111070, '', 'DirectionCLS', '', ' ', 1, 701, 1, 1, '', 0, 17867, 0, 0) ;

CALL ImportField(70111071, ' ()', 'FACT', '', ' ', 1, 701, 1, 1, '', 0, 17829, 0, 0) ;

CALL ImportField(70111072, ' ', 'FINTYPE', ' ', ' ', 1, 701, 1, 1, '', 0, 17833, 0, 0) ;

CALL ImportField(70111073, '- ()', 'DOCUMENTBASETYPE', '-', ' ', 1, 701, 1, 1, '', 0, 17863, 0, 0) ;

--  , (1)
CALL ImportField(70310009, '', 'FACTCODE', '', ' ', 1, 703, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(70310010, '', 'DirectionCLSCode', '', ' ', 1, 703, 0, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(70310020, ' ', 'FINTYPECode', ' ', ' ', 1, 703, 0, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(70310052, '', 'DirectionCLS', '', ' ', 1, 703, 0, 1, '', 0, 17867, 0, 0) ;

CALL ImportField(70310053, ' ()', 'FACT', '', ' ', 1, 703, 0, 1, '', 0, 17829, 0, 0) ;

CALL ImportField(70310054, ' ', 'FINTYPE', ' ', ' ', 1, 703, 0, 1, '', 0, 17833, 0, 0) ;

--  , (1)
CALL ImportField(80111008, '', 'DIRECTIONCLSCODE', '', 'DIRECTIONCLS', 1, 801, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(80111009, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 801, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(80111014, '', 'FACTCODE', '', 'FactCLS', 1, 801, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(80111017, ' . ', 'FINTYPECODE', ' . ', 'FinTypeCLS', 1, 801, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(80111035, '', 'REGIONCLS', '', 'REGIONCLS', 1, 801, 1, 0, ',', 0, 18672, 0, 0) ;

CALL ImportField(80111047, '()', 'IFSAGCode', '()', ' ', 1, 801, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(80111080, ' ()', 'DIRECTIONCLS', '', 'DIRECTIONCLSKEY', 1, 801, 1, 1, '', 0, 18663, 0, 0) ;

CALL ImportField(80111081, ' ()', 'FACT', '', 'FactCLSKey', 1, 801, 1, 1, '', 0, 18636, 0, 0) ;

CALL ImportField(80111082, ' .  ()', 'FINTYPE', '   ()', 'FinTypeCLSKey', 1, 801, 1, 1, '', 0, 18634, 0, 0) ;

CALL ImportField(80111083, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 801, 1, 1, ',', 0, 18664, 0, 0) ;

CALL ImportField(80111084, '', 'InvestObject', '', ' ', 1, 801, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(80111085, '', 'InvestObjectCode', '', ' ', 1, 801, 1, 0, '', 0, null, 0, 0) ;

--   (), (1)
CALL ImportField(80210011, '', 'FACTCODE', '', ' ', 1, 802, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(80210012, '()', 'DirectionCLSCode', '', ' ', 1, 802, 0, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(80210015, '()', 'IFSAGCode', '', ' ', 1, 802, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(80210026, ' ', 'FinTypeCode', ' ', ' ', 1, 802, 0, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(80210039, '()', 'DirectionCLS', '', ' ', 1, 802, 0, 1, '', 0, 18663, 0, 0) ;

CALL ImportField(80210040, ' ()', 'FACT', '', ' ', 1, 802, 0, 1, '', 0, 18636, 0, 0) ;

CALL ImportField(80210041, '  ()', 'FinType', ' ', ' ', 1, 802, 0, 1, '', 0, 18634, 0, 0) ;

CALL ImportField(80210042, '', 'InvestObject', '', ' ', 1, 802, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(80210043, '', 'InvestObjectCode', '', ' ', 1, 802, 0, 0, '', 0, null, 0, 0) ;

--     , (1)
CALL ImportField(80311016, '', 'FACTCODE', '', ' ', 1, 803, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(80311019, '()', 'SourceIFSAGCode', '', ' ', 1, 803, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(80311028, ' ', 'FinTypeCode', ' ', ' ', 1, 803, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(80311036, '', 'DirectionCLSCode', '', ' ', 1, 803, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(80311052, ' ()', 'DirectionCLS', '', ' ', 1, 803, 1, 1, '', 0, 18663, 0, 0) ;

CALL ImportField(80311053, ' ()', 'FACT', '', ' ', 1, 803, 1, 1, '', 0, 18636, 0, 0) ;

CALL ImportField(80311054, '  ()', 'FinType', ' ', ' ', 1, 803, 1, 1, '', 0, 18634, 0, 0) ;

CALL ImportField(80311055, '', 'InvestObject', '', ' ', 1, 803, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(80311056, '', 'InvestObjectCode', '', ' ', 1, 803, 1, 0, '', 0, null, 0, 0) ;

--    , (1)
CALL ImportField(90111014, '', 'FactCode', '', ' ', 1, 901, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(90111053, '', 'DirectionCLSCode', '', ' ', 1, 901, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(90111056, '()', 'KDAGCode', '()', ' ', 1, 901, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(90111067, ' ()', 'DirectionCLS', '', ' ', 1, 901, 1, 1, '', 0, 17733, 0, 0) ;

CALL ImportField(90111068, ' ()', 'Fact', '', ' ', 1, 901, 1, 1, '', 0, 17710, 0, 0) ;

--   (), (1)
CALL ImportField(90210033, ' ', 'FactFromCode', ' ', ' ', 1, 902, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(90210034, ' ', 'FactToCode', ' ', ' ', 1, 902, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(90210050, '  ()', 'FactTo', ' ', ' ', 1, 902, 0, 1, '', 0, 17710, 0, 0) ;

CALL ImportField(90210051, '  ()', 'FactFrom', ' ', ' ', 1, 902, 0, 1, '', 0, 17710, 0, 0) ;

--   , (1)
CALL ImportField(90311015, '()', 'KDAGCode', '', ' ', 1, 903, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(90311018, '()', 'IFSAGCode', '', ' ', 1, 903, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(90311030, '', 'KESR', '', 'KESR', 1, 903, 1, 0, '', 0, 17712, 0, 0) ;

CALL ImportField(90311035, ' ', 'CLSType', ' ', 'ClsType', 1, 903, 1, 0, '', 0, 17723, 0, 0) ;

CALL ImportField(90311048, '', 'FactCode', '', 'Fact', 1, 903, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(90311049, '', 'DocBaseCode', '', 'DocBase', 1, 903, 1, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(90311057, '', 'DirectionCLSCode', '', 'DirectionCls', 1, 903, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(90311068, '  ', 'RejectCLS', '  ()', ' ', 1, 903, 1, 0, '', 0, 17730, 0, 0) ;

CALL ImportField(90311087, ' .  ()', 'FinType', '  ', 'FINTYPEKey', 1, 903, 1, 1, ',', 0, 36856, 0, 0) ;

CALL ImportField(90311088, ' . ', 'FinTypeCode', '  ', 'FINTYPE', 1, 903, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(90311089, ' ()', 'DirectionCLS', '', 'DirectionClsKey', 1, 903, 1, 1, '', 0, 17733, 0, 0) ;

CALL ImportField(90311090, ' ()', 'Fact', '', 'FactKey', 1, 903, 1, 1, '', 0, 17710, 0, 0) ;

CALL ImportField(90311091, ' ()', 'DocBase', '', 'DocBaseKey', 1, 903, 1, 1, ',', 0, 17709, 0, 0) ;

CALL ImportField(90311092, '  ()', 'RejectCause', '  () ()', ' ', 1, 903, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(90311093, '', 'InvestObject', '', ' ', 1, 903, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(90311094, '', 'InvestObjectCode', '', ' ', 1, 903, 1, 0, '', 0, null, 0, 0) ;

--   , (1)
CALL ImportField(90510008, '()', 'KDAGCode', '', ' ', 1, 905, 0, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(90510027, '', 'DocBaseCode', '', ' ', 1, 905, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(90510032, '', 'FACTCODE', '', ' ', 1, 905, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(90510038, '()', 'IFSAGCode', '', ' ', 1, 905, 0, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(90510040, ' .  ()', 'FinType', '  ', 'FINTYPEKey', 1, 905, 0, 1, '', 0, 36856, 0, 0) ;

CALL ImportField(90510041, ' . ', 'FinTypeCode', '  ', 'FINTYPE', 1, 905, 0, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(90510042, ' ()', 'FACT', '', ' ', 1, 905, 0, 1, '', 0, 17710, 0, 0) ;

CALL ImportField(90510043, ' ()', 'DocBase', '', ' ', 1, 905, 0, 1, ',', 0, 17709, 0, 0) ;

CALL ImportField(90510044, '', 'InvestObject', '', ' ', 1, 905, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(90510045, '', 'InvestObjectCode', '', ' ', 1, 905, 0, 0, '', 0, null, 0, 0) ;

--   (), (1)
CALL ImportField(90610055, '', 'FactCode', '', ' ', 1, 906, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(90610077, '', 'DirectionCLSCode', '', ' ', 1, 906, 0, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(90610078, ' ()', 'DirectionCLS', '', ' ', 1, 906, 0, 1, '', 0, 17733, 0, 0) ;

CALL ImportField(90610079, ' ()', 'Fact', '', ' ', 1, 906, 0, 1, '', 0, 17710, 0, 0) ;

CALL ImportField(90610080, '', 'InvestObject', '', ' ', 1, 906, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(90610081, '', 'InvestObjectCode', '', ' ', 1, 906, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(90611047, '', 'FactCode', '', ' ', 1, 906, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(90611078, '', 'DirectionClsCode', '', ' ', 1, 906, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(90611082, ' .  ()', 'FinType', '  ', ' ', 1, 906, 1, 1, '', 0, 36856, 0, 0) ;

CALL ImportField(90611083, ' . ', 'FinTypeCode', '  ', ' ', 1, 906, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(90611084, ' ()', 'DirectionCls', '', ' ', 1, 906, 1, 1, '', 0, 17733, 0, 0) ;

CALL ImportField(90611085, ' ()', 'Fact', '', ' ', 1, 906, 1, 1, '', 0, 17710, 0, 0) ;

CALL ImportField(90611086, '', 'InvestObject', '', ' ', 1, 906, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(90611087, '', 'InvestObjectCode', '', ' ', 1, 906, 1, 0, '', 0, null, 0, 0) ;

--   (), (1)
CALL ImportField(90710007, '()', 'KDAGCode', '', ' ', 1, 907, 0, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(90710040, '()', 'IFSAGCode', '()', ' ', 1, 907, 0, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(90710042, '', 'FACTCODE', '', ' ', 1, 907, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(90710049, '', 'DirectionClsCode', '', ' ', 1, 907, 0, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(90710053, '', 'OKTMO', '', ' ', 1, 907, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(90710054, ' ()', 'DirectionCls', '', ' ', 1, 907, 0, 1, '', 0, 17733, 0, 0) ;

CALL ImportField(90710055, ' ()', 'FACT', '', ' ', 1, 907, 0, 1, '', 0, 17710, 0, 0) ;

CALL ImportField(90710056, '', 'InvestObject', '', ' ', 1, 907, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(90710057, '', 'InvestObjectCode', '', ' ', 1, 907, 0, 0, '', 0, null, 0, 0) ;

--  , (1)
CALL ImportField(120110009, '( )', 'KESR', '( )', ' ', 1, 1201, 0, 0, '', 0, 17343, 0, 0) ;

CALL ImportField(120110012, '( )', 'IFSAGCode', '', ' ', 1, 1201, 0, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(120110016, '( )', 'KDAGCode', '', ' ', 1, 1201, 0, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(120110023, '( )', 'KESR_corr', '( )', ' ', 1, 1201, 0, 0, '', 0, 17349, 0, 0) ;

CALL ImportField(120110030, '( )', 'KDAG_corrCode', '', ' ', 1, 1201, 0, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(120110053, '( )', 'DirectionCLSCode', '( )', ' ', 1, 1201, 0, 1, '', 0, 36861, 0, 0) ;

CALL ImportField(120110054, '( )', 'DirectionCLS_corrCode', '( )', ' ', 1, 1201, 0, 1, '', 0, 36861, 0, 0) ;

CALL ImportField(120110057, '', 'FactCode', '', ' ', 1, 1201, 0, 1, '', 0, 36863, 0, 0) ;

CALL ImportField(120110058, '', 'Fact_corrCode', '', ' ', 1, 1201, 0, 1, '', 0, 36863, 0, 0) ;

CALL ImportField(120110061, ' . ', 'FinTypeCode', ' ', ' ', 1, 1201, 0, 1, ',', 0, 36853, 0, 0) ;

CALL ImportField(120110062, ' ', 'FinType_corrCode', ' ', ' ', 1, 1201, 0, 1, '', 0, 36853, 0, 0) ;

CALL ImportField(120110064, '( )', 'IFSAG_corrCode', '( )', ' ', 1, 1201, 0, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(120110073, '( )()', 'DirectionCLS_corr', '( )', ' ', 1, 1201, 0, 1, '', 0, 17380, 0, 0) ;

CALL ImportField(120110074, '( )()', 'DirectionCLS', '( )', ' ', 1, 1201, 0, 1, '', 0, 17379, 0, 0) ;

CALL ImportField(120110075, ' ()', 'Fact', '', ' ', 1, 1201, 0, 1, '', 0, 17370, 0, 0) ;

CALL ImportField(120110076, ' ()', 'Fact_corr', '', ' ', 1, 1201, 0, 1, '', 0, 17371, 0, 0) ;

CALL ImportField(120110077, ' .  ()', 'FinType', ' ', ' ', 1, 1201, 0, 1, ',', 0, 17381, 0, 0) ;

CALL ImportField(120110078, '  ()', 'FinType_corr', ' ', ' ', 1, 1201, 0, 1, '', 0, 17382, 0, 0) ;

--  , (1)
CALL ImportField(150110008, '', 'FACTCODE', '', ' ', 1, 1501, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(150110009, '()', 'DirectionCLSCode', '', ' ', 1, 1501, 0, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(150110015, ' . ', 'FINTYPECODE', ' ', ' ', 1, 1501, 0, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(150110017, '-', 'DocBaseCode', '-', ' ', 1, 1501, 0, 0, '', 0, 36865, 0, 0) ;

CALL ImportField(150110048, '()', 'IFSAGCode', '', ' ', 1, 1501, 0, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(150110052, '()', 'DirectionCLS', '', ' ', 1, 1501, 0, 1, '', 0, 18412, 0, 0) ;

CALL ImportField(150110053, ' ()', 'FACT', '', ' ', 1, 1501, 0, 1, '', 0, 18407, 0, 0) ;

CALL ImportField(150110054, ' .  ()', 'FINTYPE', ' ', ' ', 1, 1501, 0, 1, ',', 0, 18387, 0, 0) ;

CALL ImportField(150110055, '- ()', 'DocBase', '-', ' ', 1, 1501, 0, 1, '', 0, 18413, 0, 0) ;

--  , (1)
CALL ImportField(160110051, ' ', 'Reject_Cls', ' ', 'RejectCls', 1, 1601, 0, 0, '', 0, 17604, 0, 0) ;

CALL ImportField(160111026, '', 'FACTCODE', '', 'FactCls', 1, 1601, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(160111028, ' . ', 'FinTypeCode', ' ', 'FinTypeCls', 1, 1601, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(160111045, ' ', 'RegionCls', '', 'RegionCls', 1, 1601, 1, 1, ',,', 0, 19032, 0, 0) ;

CALL ImportField(160111052, '()', 'DirectionCLSCode', '', 'DirectionCLS', 1, 1601, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(160111085, '()', 'DirectionCLS', '', 'DirectionCLSKey', 1, 1601, 1, 1, '', 0, 19057, 0, 0) ;

CALL ImportField(160111086, ' ()', 'FACT', '', 'FactClsKey', 1, 1601, 1, 1, '', 0, 19025, 0, 0) ;

CALL ImportField(160111087, ' .  ()', 'FinType', ' ', 'FinTypeClsCode', 1, 1601, 1, 1, ',', 0, 19029, 0, 0) ;

-- . - , (1)
CALL ImportField(160210016, '', 'FACTCODE', '', ' ', 1, 1602, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(160210023, '', 'DirectionCLSCode', '', ' ', 1, 1602, 0, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(160210025, ' . ', 'FinTypeCode', ' ', ' ', 1, 1602, 0, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(160210045, ' ()', 'DirectionCLS', '', ' ', 1, 1602, 0, 1, '', 0, 19057, 0, 0) ;

CALL ImportField(160210046, ' ()', 'FACT', '', ' ', 1, 1602, 0, 1, '', 0, 19025, 0, 0) ;

CALL ImportField(160210047, ' .  ()', 'FinType', ' ', ' ', 1, 1602, 0, 1, ',', 0, 19029, 0, 0) ;

-- , (1)
CALL ImportField(170110008, '', 'DIRECTIONCLSCODE', '', 'DIRECTIONCLS', 1, 1701, 0, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(170110011, ' ()', 'DOCUMENTBASETYPE', ' ()', 'DOCUMENTBASETYPEKey', 1, 1701, 0, 0, ',', 0, 19157, 0, 0) ;

CALL ImportField(170110018, '', 'FACTCODE', '', 'FACT', 1, 1701, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(170110021, ' . ', 'FINTYPECODE', ' ', 'FINTYPE', 1, 1701, 0, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(170110041, '', 'REGIONCLS', '', 'REGIONCLS', 1, 1701, 0, 0, ',', 0, 19142, 0, 0) ;

CALL ImportField(170110065, '( )', 'KDAGCode', '', ' ', 1, 1701, 0, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(170110093, ' ()', 'DIRECTIONCLS', '', 'DIRECTIONCLSKEY', 1, 1701, 0, 1, '', 0, 19174, 0, 0) ;

CALL ImportField(170110094, ' ()', 'FACT', '', 'FACTKEY', 1, 1701, 0, 1, '', 0, 19139, 0, 0) ;

CALL ImportField(170110095, ' .  ()', 'FINTYPE', ' ', 'FINTYPEKEY', 1, 1701, 0, 1, ',', 0, 19141, 0, 0) ;

CALL ImportField(170110096, '', 'DocumentBaseTypeCode', '', 'DOCUMENTBASETYPE', 1, 1701, 0, 0, ',', 0, 36865, 0, 0) ;

-- (), (1)
CALL ImportField(170210032, '', 'FactCode', '()', ' ', 1, 1702, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(170210034, '()', 'DirectionCLSCode', '()', ' ', 1, 1702, 0, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(170210038, '', 'RegionCls', '', ' ', 1, 1702, 0, 0, ',', 0, 19142, 0, 0) ;

CALL ImportField(170210047, ' . ', 'FinTypeCode', ' ', ' ', 1, 1702, 0, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(170210051, '()', 'DirectionCLS', '()', ' ', 1, 1702, 0, 1, '', 0, 19174, 0, 0) ;

CALL ImportField(170210052, ' ()', 'Fact', '()', ' ', 1, 1702, 0, 1, '', 0, 19139, 0, 0) ;

CALL ImportField(170210053, ' .  ()', 'FinType', ' ', ' ', 1, 1702, 0, 1, ',', 0, 19141, 0, 0) ;

--      , (1)
CALL ImportField(180910001, '', 'DestKESR', '  ', ' ', 1, 1809, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(180910002, '', 'DestCLSType', '   ', ' ', 1, 1809, 0, 0, '', 0, null, 0, 0) ;

--   , (1)
CALL ImportField(181610001, 'FullKDValue', 'FullKDValue', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610002, 'FullFinSourceValue', 'FullFinSourceValue', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610003, '', 'KVSR', ' ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610004, '', 'KFSR', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610005, '', 'KCSR', ' ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610006, '', 'KVR', ' ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610007, '', 'KESR', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610008, ' ', 'ID', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610009, ' /', 'PayDocNum', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610010, ' ', 'ElNum', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610011, ' ', 'NotUsedSumma', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610012, ' ', 'DestName', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610013, ' ', 'DestOrgRef', '  ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610014, ' ', 'DFAccount', '  ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610015, '  ', 'SourceAccRef', '  ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610016, ' ', 'SourceOrgRef', '  ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610017, ' ', 'InPayerOrgRef', '  ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610018, '   ', 'InPayerAccRef', '  ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610019, ' ', 'Summa', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610020, ' ', 'ProcDocClass', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610021, ' ', 'RegionCls', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610022, ' .  ()', 'FinType', '   ()', ' ', 1, 1816, 0, 0, ',', 0, null, 0, 0) ;

CALL ImportField(181610023, ' . ', 'FinTypeCode', '  ', ' ', 1, 1816, 0, 0, ',', 0, null, 0, 0) ;

CALL ImportField(181610024, ' ', 'FacialAccMaster', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610025, ' ', 'TypeOperationCls', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610026, '', 'KVRCode', ' ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610027, '', 'KVSRCode', ' ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610028, '', 'KCSRCode', ' ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610029, ' ()', 'DirectionCls', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610030, '', 'DirectionClsCode', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610031, ' ()', 'Fact', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610032, '', 'FactCode', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610033, ' ', 'MeansType', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610034, ' ', 'SubKESR', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610035, ' ', 'FinSource', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610036, ' ', 'KD', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610037, '', 'IFS', '  ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610038, '', 'BuhOperationCls', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610039, '', 'BudgetRef', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610040, ' ()', 'DocBase', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610041, '', 'DocBaseCode', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610042, '  ()', 'BuhPaymentsCls', '. ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610043, '   ()', 'TransfertCls', '   ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610044, '  ', 'TransfertClsCode', '  ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610045, '  ()', 'SubsidyCls', '  ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610046, ' ', 'SubsidyClsCode', ' ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610047, '   ()', 'BudAllocationCls', '   ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610048, '  ', 'BudAllocationClsCode', '  ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610049, '   ()', 'PayPromiseCls', '   ()', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610050, '  ', 'PayPromiseClsCode', '  ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610051, '', 'DocType', ' (.  )', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610098, ' ', 'ClsType', '  (, , )', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610099, '  ', 'DestPromise', '  ', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611052, ' ', 'ID', 'ID', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611053, ' /', 'PayDocNum', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611054, ' ', 'ElNum', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611055, ' ', 'DFAccount', '  ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611056, ' ', 'InPayerOrgRef', '  ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611057, '   ', 'InPayerAccRef', '  ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611058, ' ', 'Summa', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611059, ' ', 'RegionCls', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611060, '', 'DocType', ' (.  )', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611061, ' ', 'MeansType', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611062, ' ', 'TypeOperationCls', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611063, '', 'KFSR', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611064, '', 'KVSR', ' ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611065, '', 'KVSRCode', ' ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611066, '', 'KCSR', ' ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611067, '', 'KCSRCode', ' ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611068, '', 'KVR', ' ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611069, '', 'KVRCode', ' ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611070, '', 'KESR', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611071, ' ()', 'DirectionCls', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611072, '', 'DirectionClsCode', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611073, ' ', 'SubKESR', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611074, ' ', 'FinSource', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611075, ' ()', 'Fact', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611076, '', 'FactCode', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611077, ' .  ()', 'FinType', '   ()', ' ', 1, 1816, 1, 0, ',', 0, null, 0, 0) ;

CALL ImportField(181611078, ' . ', 'FinTypeCode', '  ', ' ', 1, 1816, 1, 0, ',', 0, null, 0, 0) ;

CALL ImportField(181611079, ' ', 'KD', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611080, ' ', 'FullKDValue', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611081, '', 'IFS', '  ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611082, '', 'FullFinSourceValue', '  ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611083, '', 'BudgetRef', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611084, ' ()', 'DocBase', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611085, '', 'DocBaseCode', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611086, '   ()', 'TransfertCls', '   ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611087, '  ', 'TransfertClsCode', '  ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611088, '  ()', 'SubsidyCls', '  ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611089, ' ', 'SubsidyClsCode', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611090, '   ()', 'BudAllocationCls', '   ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611091, '  ', 'BudAllocationClsCode', '  ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611092, '   ()', 'PayPromiseCls', '   ()', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611093, '  ', 'PayPromiseClsCode', '  ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611094, '  ()', 'BuhPaymentCls', '. ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611095, ' ', 'FacialAccMaster', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611096, ' ', 'ProcDocClass', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611097, '', 'BuhOperationCls', ' ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611100, '  ', 'DestPromise', '  ', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611101, ' ', 'ClsType', '  (, , )', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

--   (), (1)
CALL ImportField(190011034, '  ()', '{("")}', '  ()', ' ', 1, 1900, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(190011035, ' ', '{("")}', ' ', ' ', 1, 1900, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(190011036, '', '{("")}', '', ' ', 1, 1900, 1, 0, '', 0, null, 0, 0) ;

--  (), (1)
CALL ImportField(190110007, ' ()', 'DocBaseParent', ' ()', ' ', 1, 1901, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(190110010, ' ', 'DOCDAT', ' ', 'DocDat', 1, 1901, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(190110011, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 1901, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(190110012, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 1901, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(190110087, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 1901, 0, 1, ',', 0, 17473, 0, 0) ;

CALL ImportField(190111015, '  ', 'IFS_FinSourceValue', '  ', 'IFS_FinSourceValue', 1, 1901, 1, 0, '', 0, 17055, 0, 0) ;

CALL ImportField(190111018, '(  )', 'IFSAGCode', '', ' ', 1, 1901, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(190111019, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1901, 1, 0, '', 0, 17416, 0, 0) ;

CALL ImportField(190111020, '', 'DirectionCLSCode', '', 'DestDirectionCLS', 1, 1901, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(190111023, '', 'FACTCODE', '', 'DestFactCls', 1, 1901, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(190111024, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 1901, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(190111100, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 1901, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(190111102, ' ()', 'DirectionCLS', '', 'DestDirectionCLSKEY', 1, 1901, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(190111103, ' ()', 'FACT', '', 'DestFactClsKey', 1, 1901, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(190111104, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 1901, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(190111105, '', 'InvestObject', '', ' ', 1, 1901, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(190111106, '', 'InvestObjectCode', '', ' ', 1, 1901, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(190111107, '', 'Kesr', '', 'DestKesr', 1, 1901, 1, 0, '', 0, 17415, 0, 0) ;

--    (), (1)
CALL ImportField(190210017, ' ', 'DOCDAT', ' ', 'DocDat', 1, 1902, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(190210041, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 1902, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(190210073, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 1902, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(190210080, ' ()', 'DocBaseParent', ' ()', ' ', 1, 1902, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(190210086, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 1902, 0, 1, ',', 0, 17473, 0, 0) ;

CALL ImportField(190211006, '(  )', 'IFSAGCode', '()', ' ', 1, 1902, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(190211039, '', 'FACTCODE', '()', 'DestFactCls', 1, 1902, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(190211040, '', 'DirectionCLSCode', '()', 'DestDirectionCLS', 1, 1902, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(190211071, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1902, 1, 0, '', 0, 17416, 0, 0) ;

CALL ImportField(190211077, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 1902, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(190211079, '  ', 'IFS_FinSourceValue', '  ( )', 'IFS_FinSourceValue', 1, 1902, 1, 0, '', 0, 17055, 0, 0) ;

CALL ImportField(190211099, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 1902, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(190211100, ' ()', 'DirectionCLS', '()', 'DestDirectionCLSKey', 1, 1902, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(190211101, ' ()', 'FACT', '()', 'DestFactClsKey', 1, 1902, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(190211102, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 1902, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(190211103, '', 'InvestObject', '', ' ', 1, 1902, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(190211104, '', 'InvestObjectCode', '', ' ', 1, 1902, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(190211105, '', 'Kesr', '', 'DestKesr', 1, 1902, 1, 0, '', 0, 17415, 0, 0) ;

--   (), (1)
CALL ImportField(190310017, ' ', 'DOCDAT', ' ', 'DocDat', 1, 1903, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(190310040, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 1903, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(190310072, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 1903, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(190310082, ' ()', 'DocBaseParent', ' ()', ' ', 1, 1903, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(190310087, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 1903, 0, 1, ',', 0, 17473, 0, 0) ;

CALL ImportField(190311038, '', 'FACTCODE', '', 'DestFactCls', 1, 1903, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(190311039, '', 'DirectionCLSCode', '', 'DestDirectionCLS', 1, 1903, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(190311070, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1903, 1, 0, '', 0, 17416, 0, 0) ;

CALL ImportField(190311075, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 1903, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(190311077, '(  )', 'IFSAGCode', '()', ' ', 1, 1903, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(190311081, '  ', 'IFS_FinSourceValue', '  ( )', 'IFS_FinSourceValue', 1, 1903, 1, 0, '', 0, 17055, 0, 0) ;

CALL ImportField(190311100, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 1903, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(190311101, ' ()', 'DirectionCLS', '', 'DestDirectionCLSKey', 1, 1903, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(190311102, ' ()', 'FACT', '', 'DestFactClsKey', 1, 1903, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(190311103, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 1903, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(190311104, '', 'InvestObject', '', ' ', 1, 1903, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(190311105, '', 'InvestObjectCode', '', ' ', 1, 1903, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(190311106, '', 'Kesr', '', 'DestKesr', 1, 1903, 1, 0, '', 0, 17415, 0, 0) ;

--    (), (1)
CALL ImportField(190610018, ' ', 'DOCDAT', ' ', 'DocDat', 1, 1906, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(190610041, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 1906, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(190610073, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 1906, 0, 0, ',', 0, 17473, 0, 0) ;

CALL ImportField(190610084, ' ()', 'DocBaseParent', ' ()', ' ', 1, 1906, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(190610088, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 1906, 0, 1, ',', 0, 17473, 0, 0) ;

CALL ImportField(190611039, '', 'FACTCODE', '', 'DestFactCls', 1, 1906, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(190611040, '', 'DirectionCLSCode', '', 'DestDirectionCLS', 1, 1906, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(190611071, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1906, 1, 0, '', 0, 17416, 0, 0) ;

CALL ImportField(190611076, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 1906, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(190611078, '(  )', 'IFSAGCode', '()', ' ', 1, 1906, 1, 0, '', 0, 38919, 0, 0) ;

CALL ImportField(190611083, '  ', 'IFS_FinSourceValue', '  ( )', 'IFS_FinSourceValue', 1, 1906, 1, 0, '', 0, 17055, 0, 0) ;

CALL ImportField(190611102, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 1906, 1, 1, '', 0, 27835, 0, 0) ;

CALL ImportField(190611103, ' ()', 'DirectionCLS', '', 'DestDirectionCLSKey', 1, 1906, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(190611104, ' ()', 'FACT', '', 'DestFactClsKey', 1, 1906, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(190611105, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 1906, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(190611106, '', 'InvestObject', '', ' ', 1, 1906, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(190611107, '', 'InvestObjectCode', '', ' ', 1, 1906, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(190611108, '', 'Kesr', '', 'DestKesr', 1, 1906, 1, 0, '', 0, 17415, 0, 0) ;

--   (), (1)
CALL ImportField(220011010, '', '{("")}', '', ' ', 1, 2200, 1, 0, '', 0, null, 0, 0) ;

--   (), (1)
CALL ImportField(220110007, ' ()', 'DocBaseParent', ' ()', ' ', 1, 2201, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(220110009, ' ', 'DOCBASECODE', ' ', 'DocBase', 1, 2201, 0, 0, ',', 0, 36865, 0, 0) ;

CALL ImportField(220110010, ' ', 'DOCNUMBER', ' ', 'DocNumber', 1, 2201, 0, 0, '', 0, 17467, 0, 0) ;

CALL ImportField(220110011, ' ', 'DOCDAT', ' ', 'DocDat', 1, 2201, 0, 0, '', 0, 17466, 0, 0) ;

CALL ImportField(220110070, '  ()', 'DOCBASE', '  ()', 'DocBaseKey', 1, 2201, 0, 1, ',', 0, 17473, 0, 0) ;

CALL ImportField(220111016, '()', 'KDAGCode', '', 'KDAGCode', 1, 2201, 1, 0, '', 0, 38908, 0, 0) ;

CALL ImportField(220111017, '.  ', 'SUBKD', '. ', 'SubKD', 1, 2201, 1, 0, '', 0, 25271, 0, 0) ;

CALL ImportField(220111018, ' ', 'REGIONCLS', '', 'RegionCLS', 1, 2201, 1, 0, ',', 0, 17417, 0, 0) ;

CALL ImportField(220111040, '', 'FactCode', '', 'DestFactCls', 1, 2201, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(220111055, '', 'DirectionCLSCode', '', 'DestDirectionCLS', 1, 2201, 1, 0, '', 0, 21556, 0, 0) ;

CALL ImportField(220111074, ' .  ()', 'FinType', '  ', 'DestFINTYPEKey', 1, 2201, 1, 1, ',', 0, 17425, 0, 0) ;

CALL ImportField(220111075, ' . ', 'FinTypeCode', '  ', 'DestFINTYPECls', 1, 2201, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(220111076, ' ()', 'DirectionCLS', '', 'DestDirectionCLSKey', 1, 2201, 1, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(220111077, ' ()', 'Fact', '', 'DestFactClsKey', 1, 2201, 1, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(220111078, '', 'InvestObject', '', ' ', 1, 2201, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(220111079, '', 'InvestObjectCode', '', ' ', 1, 2201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(220111080, '', 'Kesr', '', 'DestKesr', 1, 2201, 1, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(220111081, '/ ', 'FCAccountName', '/ ', ' ', 1, 2201, 1, 0, '', 0, null, 0, 0) ;

--  , +(2)
CALL ImportField(250110033, '', 'FactCode', '', 'Fact', 2, 2501, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(250110075, ' ', 'ReestrVersion', '  .  ', 'ReestrVersion', 2, 2501, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(250110076, ' ()', 'Fact', '', 'FactKey', 2, 2501, 0, 1, '', 0, 19822, 0, 0) ;

-- , +(2)
CALL ImportField(250210012, '', 'FactCode', '', 'Fact', 2, 2502, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(250210058, ' ()', 'Fact', '', 'FactKey', 2, 2502, 0, 1, '', 0, 19822, 0, 0) ;

CALL ImportField(250212001, '    ', 'SummaPreviousYear', '', 'SummaPreviousYear', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212002, '     ', 'SummaFinPreviousYear', '', 'SummaFinPreviousYear', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212003, '', 'Summa', '', 'Summa', 2, 2502, 2, 0, '', 0, 20140, 0, 0) ;

CALL ImportField(250212004, ' ', 'SubKESR', '', 'SubKESR', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212005, '', 'Region', '', 'Region', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212006, ' IV', 'Quarter4', '', 'Quarter4', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212007, ' III', 'Quarter3', '', 'Quarter3', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212008, ' II', 'Quarter2', '', 'Quarter2', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212009, ' I', 'Quarter1', '', 'Quarter1', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212010, ' ', 'PromiseType', '', 'PromiseType', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212011, '  ', 'ParentNumber', '', 'ParentNumber', 2, 2502, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250212012, ' ', 'ANumber', '', 'ANumber', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212013, '', 'Month12', '', 'Month12', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212014, '', 'Month11', '', 'Month11', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212015, '', 'Month10', '', 'Month10', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212016, '', 'Month09', '', 'Month09', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212017, '', 'Month08', '', 'Month08', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212018, '', 'Month07', '', 'Month07', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212019, '', 'Month06', '', 'Month06', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212020, '', 'Month05', '', 'Month05', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212021, '', 'Month04', '', 'Month04', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212022, '', 'Month03', '', 'Month03', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212023, '', 'Month02', '', 'Month02', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212024, '', 'Month01', '', 'Month01', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212025, ' ', 'MeansType', '', 'MeansType', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212026, '', 'KVSR', '', 'KVSR', 2, 2502, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250212027, '', 'KVR', '', 'KVR', 2, 2502, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250212028, '', 'KFSR', '', 'KFSR', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212029, '', 'KESR', '', 'KESR', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212030, '', 'KCSR', '', 'KCSR', 2, 2502, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250212031, ' . ', 'FinTypeCode', '', 'FinType', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212032, ' ', 'FinSource', '', 'FinSource', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212033, '', 'FactCode', '', 'Fact', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212034, '/ ', 'FacialCode', '', 'FacialCode', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212035, ' ', 'FacialAcc_Cls', '', 'FacialAcc_Cls', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212036, ' ()', 'DirectionCls', '', 'DirectionClsKey', 2, 2502, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250212037, '', 'BuhOperationCls', '', 'BuhOperationCls', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212038, ' (+)', 'TreeOwner0', '', 'BudTree', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212040, '  ', 'TransfertClsCode', '  ', 'TransfertClsCode', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212041, '', 'KVSRCode', '', 'KVSR', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212042, '', 'KVRCode', '', 'KVR', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212043, '', 'KCSRCode', '', 'KCSR', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212044, ' ', 'StepNumber', '', 'StepNumber', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212045, '  ', 'BudAllocationClsCode', '', 'BudAllocationClsCode', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212046, '  ', 'PayPromiseClsCode', '', 'PayPromiseClsCode', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212047, '  ', 'SummaYear2', '', 'SummaYear2', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212048, '  ', 'SummaYear3', '', 'SummaYear3', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212049, ' ', 'PromiseNumber', '', 'PromiseNumber', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212050, ' ', 'SubsidyClsCode', '', 'SubsidyClsCode', 2, 2502, 2, 0, '', 0, 26641, 0, 0) ;

CALL ImportField(250212051, '', 'DirectionClsCode', '', 'DirectionCls', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212052, ' ()', 'Fact', '', 'FactKey', 2, 2502, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250212053, ' . ', 'FinType', '', 'FinTypeKey', 2, 2502, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250212054, '', 'InvestObject', '', ' ', 2, 2502, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250212055, '', 'InvestObjectCode', '', ' ', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212056, '  ()', 'SubsidyCls', '', 'SubsidyCls', 2, 2502, 2, 1, '', 0, 27625, 0, 0) ;

CALL ImportField(250213001, ' ', 'VATSumma', '', 'VATSumma', 2, 2502, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250213002, ' ', 'VATPercent', '', 'VATPercent', 2, 2502, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250213003, '   ', 'Summa', '', 'Summa', 2, 2502, 3, 0, '', 0, 20242, 0, 0) ;

CALL ImportField(250213004, ' ', 'ProductName', '', 'ProductName', 2, 2502, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250213005, '  (+)', 'Product', '', 'Product', 2, 2502, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250213006, '  ', 'PriceVAT', '  ', 'PriceVAT', 2, 2502, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250213007, '  ', 'Price', '', 'Price', 2, 2502, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250213008, '', 'Cost', '', 'Cost', 2, 2502, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250213009, '', 'Amount', '', 'Amount', 2, 2502, 3, 1, '', 0, null, 0, 0) ;

--   , +(2)
CALL ImportField(250310026, '', 'FactCode', '', 'Fact', 2, 2503, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(250310042, ' ()', 'Fact', '', 'FactKey', 2, 2503, 0, 1, '', 0, 19769, 0, 0) ;

CALL ImportField(250310043, '  / ', 'SupplierAcc_Ref', '', 'Supplieracc_ref', 2, 2503, 0, 1, '', 0, 17109, 0, 0) ;

CALL ImportField(250312004, '', 'DirectionClsCode', '', 'DirectionCls', 2, 2503, 2, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(250312007, '', 'FactCode', '', 'Fact', 2, 2503, 2, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(250312009, ' . ', 'FinTypeCode', '', 'FinType', 2, 2503, 2, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(250312046, ' ()', 'DirectionCls', '', 'DirectionClsKey', 2, 2503, 2, 1, '', 0, 20277, 0, 0) ;

CALL ImportField(250312047, ' ()', 'Fact', '', 'FactKey', 2, 2503, 2, 1, '', 0, 20248, 0, 0) ;

CALL ImportField(250312048, ' . ', 'FinType', '', 'FinTypeKey', 2, 2503, 2, 1, '', 0, 20247, 0, 0) ;

CALL ImportField(250312049, '', 'InvestObject', '', ' ', 2, 2503, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250312050, '', 'InvestObjectCode', '', ' ', 2, 2503, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250312051, '  ()', 'SubsidyCls', '', 'SubsidyCls', 2, 2503, 2, 1, '', 0, 27625, 0, 0) ;

--  , +(2)
CALL ImportField(250410044, '', 'FactCode', '', 'Fact', 2, 2504, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(250410046, '/c ', 'FacialAcc_Cls', '', 'FacialAcc_Cls', 2, 2504, 0, 0, '', 0, 19803, 0, 0) ;

CALL ImportField(250410097, ' ', 'ReestrVersion', '  .  ', 'ReestrVersion', 2, 2504, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(250410098, ' ()', 'Fact', '', 'FactKey', 2, 2504, 0, 1, '', 0, 19822, 0, 0) ;

CALL ImportField(250412001, ' ', 'StepNumber', ' ', 'StepNumber', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412002, '  ', 'TransfertClsCode', '  ', 'TransfertClsCode', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412003, ' (+)', 'TreeOwner0', '', 'BudTree', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412004, '  ', 'summayear3', '', 'summayear3', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412005, '  ', 'summayear2', '', 'summayear2', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412006, '    ', 'SummaPreviousYear', '', 'SummaPreviousYear', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412007, '     ', 'SummaFinPreviousYear', '', 'SummaFinPreviousYear', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412008, '', 'Summa', '', 'Summa', 2, 2504, 2, 0, '', 0, 20140, 0, 0) ;

CALL ImportField(250412009, ' ', 'SubsidyClsCode', '', 'SubsidyClsCode', 2, 2504, 2, 0, '', 0, 26641, 0, 0) ;

CALL ImportField(250412010, ' ', 'SubKESR', '', 'SubKESR', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412011, '', 'Region', '', 'Region', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412012, ' IV', 'Quarter4', '', 'Quarter4', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412013, ' III', 'Quarter3', '', 'Quarter3', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412014, ' II', 'Quarter2', '', 'Quarter2', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412015, ' I', 'Quarter1', '', 'Quarter1', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412016, ' ', 'PromiseType', '', 'PromiseType', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412017, '  ', 'PayPromiseClsCode', '', 'PayPromiseClsCode', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412018, '', 'Month12', '', 'Month12', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412019, '', 'Month11', '', 'Month11', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412020, '', 'Month10', '', 'Month10', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412021, '', 'Month09', '', 'Month09', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412022, '', 'Month08', '', 'Month08', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412023, '', 'Month07', '', 'Month07', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412024, '', 'Month06', '', 'Month06', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412025, '', 'Month05', '', 'Month05', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412026, '', 'Month04', '', 'Month04', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412027, '', 'Month03', '', 'Month03', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412028, '', 'Month02', '', 'Month02', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412029, '', 'Month01', '', 'Month01', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412030, ' ', 'MeansType', '', 'MeansType', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412031, '', 'KVSRCode', '', 'KVSR', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412032, '', 'KVSR', '', 'KVSR', 2, 2504, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250412033, '', 'KVRCode', '', 'KVR', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412034, '', 'KVR', '', 'KVR', 2, 2504, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250412035, '', 'KFSR', '', 'KFSR', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412036, '', 'KESR', '', 'KESR', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412037, '', 'KCSRCode', '', 'KCSR', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412038, '', 'KCSR', '', 'KCSR', 2, 2504, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250412039, ' . ', 'FinTypeCode', '', 'FinType', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412040, ' ', 'FinSource', '', 'FinSource', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412041, '', 'FactCode', '', 'Fact', 2, 2504, 2, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(250412042, '/ ', 'FacialCode', '', 'FacialCode', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412043, ' ', 'FacialAcc_Cls', '', 'FacialAcc_Cls', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412044, '', 'DirectionClsCode', '', 'DirectionCls', 2, 2504, 2, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(250412045, '', 'BuhOperationCls', '', 'BuhOperationCls', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412046, '  ', 'BudAllocationClsCode', '', 'BudAllocationClsCode', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412047, ' ', 'ANumber', '', 'ANumber', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412049, ' ', 'PromiseNumber', '', 'PromiseNumber', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412050, ' ()', 'DirectionCls', '', 'DirectionClsKey', 2, 2504, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250412051, ' ()', 'Fact', '', 'FactKey', 2, 2504, 2, 1, '', 0, 20248, 0, 0) ;

CALL ImportField(250412052, ' .  ()', 'FinType', '', 'FinTypeKey', 2, 2504, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250412053, '', 'InvestObject', '', ' ', 2, 2504, 2, 1, '', 0, null, 0, 0) ;

CALL ImportField(250412054, '', 'InvestObjectCode', '', ' ', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412055, '  ()', 'SubsidyCls', '', 'SubsidyCls', 2, 2504, 2, 1, '', 0, 27625, 0, 0) ;

CALL ImportField(250413001, ' ', 'VATSumma', '', 'VATSumma', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250413002, ' ', 'VATPercent', '', 'VATPercent', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250413003, '   ', 'Summa', '', 'Summa', 2, 2504, 3, 0, '', 0, 20242, 0, 0) ;

CALL ImportField(250413004, ' ', 'ProductName', '', 'ProductName', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250413005, ' ', 'Product', '', 'Product', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250413006, '  ', 'PriceVAT', '  ', 'PriceVAT', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250413007, '  ', 'Price', '', 'Price', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250413008, '  ', 'FacialAcc_Cls', '  ', 'FacialAcc_Cls', 2, 2504, 3, 0, '', 0, 20249, 0, 0) ;

CALL ImportField(250413009, '', 'Cost', '', 'Cost', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250413010, ' ', 'ClientName', ' ', 'ClientName', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250413011, ' ', 'ClientKPP', ' ', 'ClientKPP', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250413012, ' ', 'ClientINN', ' ', 'ClientINN', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250413013, ' (+)', 'ClientAll', '', 'ClientAll', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250413014, '', 'Amount', '', 'Amount', 2, 2504, 3, 0, '', 0, null, 0, 0) ;

CALL ImportField(250415001, ' (+)', 'TreeOwner0', '', 'TreeOwner0', 2, 2504, 5, 0, '', 0, null, 0, 0) ;

CALL ImportField(250415002, '', 'SUMMA', '', 'SUMMA', 2, 2504, 5, 0, '', 0, null, 0, 0) ;

CALL ImportField(250415003, '', 'Note', '', 'Note', 2, 2504, 5, 0, '', 0, null, 0, 0) ;

CALL ImportField(250415004, ' ', 'MEANSTYPE', ' ', 'MEANSTYPE', 2, 2504, 5, 0, '', 0, null, 0, 0) ;

CALL ImportField(250415005, '', 'KVSRCode', '', 'KVSR', 2, 2504, 5, 0, '', 0, null, 0, 0) ;

CALL ImportField(250415006, '', 'KVSR', '', 'KVSR', 2, 2504, 5, 1, '', 0, null, 0, 0) ;

CALL ImportField(250415007, '', 'KVRCode', '', 'KVR', 2, 2504, 5, 0, '', 0, null, 0, 0) ;

CALL ImportField(250415008, '', 'KVR', '', 'KVR', 2, 2504, 5, 1, '', 0, null, 0, 0) ;

CALL ImportField(250415009, '', 'KFSR', '', 'KFSR', 2, 2504, 5, 0, '', 0, null, 0, 0) ;

CALL ImportField(250415010, '', 'KESR', '', 'KESR', 2, 2504, 5, 0, '', 0, null, 0, 0) ;

CALL ImportField(250415011, '', 'KCSRCode', '', 'KCSR', 2, 2504, 5, 0, '', 0, null, 0, 0) ;

CALL ImportField(250415012, '', 'KCSR', '', 'KCSR', 2, 2504, 5, 1, '', 0, null, 0, 0) ;

CALL ImportField(250415013, '', 'FinYear', '', 'FinYear', 2, 2504, 5, 0, '', 0, null, 0, 0) ;

--   , (1)
CALL ImportField(280210014, '', 'FactCode', '', ' ', 1, 2802, 0, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(280210017, ' ()', 'Fact', '', ' ', 1, 2802, 0, 0, '', 0, 25295, 0, 0) ;

--    , +(2)
CALL ImportField(300110013, ' ', 'REJECTCLS', ' ', 'REJECTCLS', 2, 3001, 0, 0, '', 0, 21288, 0, 0) ;

CALL ImportField(300110014, '  ()', 'REJECTCAUSE', '  ()', 'REJECTCAUSE', 2, 3001, 0, 0, '', 0, 21289, 0, 0) ;

CALL ImportField(300111045, ' . ', 'FinTypeCode', ' ', 'FinType', 2, 3001, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(300111049, '', 'FactClsCode', '', 'FactCls', 2, 3001, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(300111053, '', 'DirectionClsCode', '', 'DirectionCls', 2, 3001, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(300111095, ' ()', 'DirectionCls', '', 'DirectionClsKey', 2, 3001, 1, 1, '', 0, 21104, 0, 0) ;

CALL ImportField(300111096, ' ()', 'FactCls', '', 'FactClsKey', 2, 3001, 1, 1, '', 0, 21040, 0, 0) ;

CALL ImportField(300111097, ' .  ()', 'FinType', ' ', 'FinTypeKey', 2, 3001, 1, 1, '', 0, 21114, 0, 0) ;

CALL ImportField(300111098, '', 'InvestObject', '', ' ', 2, 3001, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(300111099, '', 'InvestObjectCode', '', ' ', 2, 3001, 1, 0, '', 0, null, 0, 0) ;

--  , +(2)
CALL ImportField(300410001, ' ()', 'SupplierRef', '', ' ', 2, 3004, 0, 0, '', 0, null, 0, 0) ;

-- -, +(2)
CALL ImportField(300610023, ' ', 'ExportDate', '', ' ', 2, 3006, 0, 0, '', 0, 21311, 0, 0) ;

CALL ImportField(300610024, '/  ( - )', 'FacialCode', '', ' ', 2, 3006, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(300610025, ' - ', 'OrgRecipient', '', ' ', 2, 3006, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(300610027, '  ', 'AgreementExecutionDate', '', 'AgreementExecutionDate', 2, 3006, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(300610046, '   , %', 'SecurityTSize', '', 'SecurityTSize', 2, 3006, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(300610047, '  , %', 'SecurytiASize', '', 'SecurytiASize', 2, 3006, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(300610048, ' , %', 'AvansSize', '', 'AvansSize', 2, 3006, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(300611005, '', 'OKPD', '', 'OKPD', 2, 3006, 1, 0, '', 0, 35318, 0, 0) ;

CALL ImportField(300611009, '', 'KCSR', '', 'KCSRKey', 2, 3006, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(300611010, '', 'FactCLSCode', '', 'FactCLS', 2, 3006, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(300611046, '', 'DirectionClsCode', '', ' ', 2, 3006, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(300611047, '/  ( - )', 'FacialCode', '', ' ', 2, 3006, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(300611048, '( - )', 'FacialOrgName', '', ' ', 2, 3006, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(300611049, ' . ', 'FinTypeCode', '', ' ', 2, 3006, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(300611050, '', 'ProductCollaps', '', ' ', 2, 3006, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(300611051, ' ', 'subkesr', '', ' ', 2, 3006, 1, 0, '', 0, 21039, 0, 0) ;

CALL ImportField(300611052, ' ', 'SubsidyClsCode', '', ' ', 2, 3006, 1, 0, '', 0, 26641, 0, 0) ;

CALL ImportField(300611053, ' ()', 'DirectionCls', '', ' ', 2, 3006, 1, 1, '', 0, 21104, 0, 0) ;

CALL ImportField(300611054, ' .  ()', 'FinType', '', ' ', 2, 3006, 1, 1, '', 0, 21114, 0, 0) ;

CALL ImportField(300611055, ' ', 'FinSourceCls', '', 'FinSourceCls', 2, 3006, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(300611056, '', 'InvestObject', '', ' ', 2, 3006, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(300611057, '', 'InvestObjectCode', '', ' ', 2, 3006, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(300611058, ' ()', 'FactCls', '', 'FactClsKey', 2, 3006, 1, 0, '', 0, 21040, 0, 0) ;

CALL ImportField(300611059, '  ', 'TransfertClsCode', '  ', 'TransfertClsCode', 2, 3006, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(300611060, '  ', 'BudAllocationClsCode', '', 'BudAllocationClsCode', 2, 3006, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(300611061, '  ', 'PayPromiseClsCode', '', 'PayPromiseClsCode', 2, 3006, 1, 0, '', 0, null, 0, 0) ;

--   , (1)
CALL ImportField(361010006, ' ', 'RegionCLS', ' ', '', 1, 3610, 0, 0, ',', 0, null, 0, 0) ;

CALL ImportField(361010007, '', 'FacialAcc_CLS', ' c', 'FacialAcc_CLS', 1, 3610, 0, 0, '', 0, null, 0, 0) ;

--  , +(2)
CALL ImportField(370110024, '2', 'OKVED2', '2 ( 029-2014)', 'OKVED2', 2, 3701, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(370110025, '2', 'OKPD2', '2 ( 034-2014)', 'OKPD2', 2, 3701, 0, 0, '', 0, null, 0, 0) ;

--  , (1)
CALL ImportField(440110059, '', 'DEPARTMENTCLS', '', 'DEPARTMENTCLS', 1, 4401, 0, 1, '', 0, 18989, 0, 0) ;

CALL ImportField(440110060, ' ', 'FinTypeCode', '', 'FINTYPE', 1, 4401, 0, 1, '', 0, 36853, 0, 0) ;

CALL ImportField(440111058, '', 'DirectionCLSCode', '', ' ', 1, 4401, 1, 1, '', 0, 36861, 0, 0) ;

CALL ImportField(440111059, '', 'FactCode', '', ' ', 1, 4401, 1, 1, '', 0, 36863, 0, 0) ;

CALL ImportField(440111067, '  ()', 'FinType', ' ', 'FINTYPEKey', 1, 4401, 1, 1, '', 0, 36850, 0, 0) ;

CALL ImportField(440111068, ' ()', 'DirectionCLS', '', ' ', 1, 4401, 1, 1, '', 0, 25359, 0, 0) ;

CALL ImportField(440111069, ' ()', 'Fact', '', ' ', 1, 4401, 1, 1, '', 0, 25360, 0, 0) ;

CALL ImportField(440111070, '', 'InvestObject', '', ' ', 1, 4401, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(440111071, '', 'InvestObjectCode', '', ' ', 1, 4401, 1, 0, '', 0, null, 0, 0) ;

--  ,, (1)
CALL ImportField(440311058, '', 'DirectionCLSCode', '', ' ', 1, 4403, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(440311059, '', 'FactCode', '', ' ', 1, 4403, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(440311065, ' ()', 'DirectionCLS', '', ' ', 1, 4403, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(440311066, ' ()', 'Fact', '', ' ', 1, 4403, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(440311067, '', 'InvestObject', '', ' ', 1, 4403, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(440311068, '', 'InvestObjectCode', '', ' ', 1, 4403, 1, 0, '', 0, null, 0, 0) ;

--  , +(2)
CALL ImportField(480110007, '/  ', 'FacialAccCls', '', 'FacialAccCls', 2, 4801, 0, 0, ',', 0, 31680, 0, 0) ;

CALL ImportField(480110031, ' ()', 'DocBase', '', 'DocBaseKey', 2, 4801, 0, 0, ',', 0, 31675, 0, 0) ;

CALL ImportField(480110033, '', 'DocBaseCode', '', 'DocBase', 2, 4801, 0, 0, ',', 0, null, 0, 0) ;

--    , (1)
CALL ImportField(490110003, '', 'Note', '', 'Note', 1, 4901, 0, 0, '', 0, 22485, 0, 0) ;

CALL ImportField(490110023, ' ', 'IsSignEnd', '', ' ', 1, 4901, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(490110024, '   ', 'SchemeID', '', ' ', 1, 4901, 0, 1, '', 0, null, 0, 0) ;

--  / , (1)
CALL ImportField(520110026, '', 'BUDGETREF', '', 'BudgetRef', 1, 5201, 0, 0, '', 0, 25391, 0, 0) ;

CALL ImportField(520110046, '()', 'LevierName', '', 'LevierName', 1, 5201, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(520110055, '  -', 'NameJudicialAgencyRef', '', 'NameJudicialAgencyRef', 1, 5201, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(520110056, '  ', 'JudicialDecisionDate', '', 'JudicialDecisionDate', 1, 5201, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(520110057, '  ', 'NumberPostNotice', '', 'NumberPostNotice', 1, 5201, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(520110058, '  ', 'DatePostNotice', '', 'DatePostNotice', 1, 5201, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(520110059, ' ', 'NumberDepartmentCB', '', 'NumberDepartmentCB', 1, 5201, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(520110060, '-', 'DestOrgName', '', ' ', 1, 5201, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(520110061, ' ', 'CompletionDate', '   ', 'CompletionDate', 1, 5201, 0, 0, '', 0, 38743, 0, 0) ;

CALL ImportField(520111003, '', 'DIRECTIONCLSCode', '', 'DIRECTIONCLS', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111006, '', 'FACTCode', '', 'FACT', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111008, ' ()', 'FINTYPECode', ' ', 'FINTYPE', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111059, ' ()', 'DIRECTIONCLS', '', 'DIRECTIONCLSKey', 1, 5201, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(520111060, ' ()', 'FACT', '', 'FACTKey', 1, 5201, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(520111061, ' ()', 'FINTYPE', ' ', 'FINTYPEKey', 1, 5201, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(520111062, '', 'InvestObject', '', ' ', 1, 5201, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(520111063, '', 'InvestObjectCode', '', ' ', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111064, ' ', 'kd', ' ', 'KD', 1, 5201, 1, 1, '', 0, 38500, 0, 0) ;

CALL ImportField(520111065, ' ()', 'KDDescriptionCode', ' ()', ' ', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111066, '()', 'KDAGCode', '()', ' ', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111067, '()', 'KDKVSR', '()', ' ', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111068, '()', 'KDKVSRCode', '()', ' ', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111069, '()', 'KDProgramCode', '()', ' ', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111070, ' ', 'KDValue', '', 'KDValue', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111071, ' ', 'ClsType', ' ', 'ClsType', 1, 5201, 1, 0, '', 0, 38499, 0, 0) ;

CALL ImportField(520111072, ' ', 'Note', '  ', 'Note', 1, 5201, 1, 0, '', 0, 38765, 0, 0) ;

--    , (1)
CALL ImportField(550110165, ' ', 'RegionContractor', ' ', 'RegionContractor', 1, 5501, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(550111061, '()', 'IFSAGCode', '()', ' ', 1, 5501, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(550111065, '()', 'KDAGCode', '()', ' ', 1, 5501, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(550111067, '()', 'DirectionClsCode', '', 'DirectionCls', 1, 5501, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(550111068, '', 'FACTCode', '', 'Fact', 1, 5501, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(550111071, ' . ', 'FinTypeCode', '  ', 'FinType', 1, 5501, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(550111111, '.  ', 'BudgetPromise', '.  ', 'BUDGETPROMISE', 1, 5501, 1, 1, ',', 0, 25283, 0, 0) ;

CALL ImportField(550111163, '()', 'DirectionCls', '', 'DirectionClsKey', 1, 5501, 1, 1, '', 0, 22920, 0, 0) ;

CALL ImportField(550111164, ' .  ()', 'FinType', '  ', 'FinTypeKey', 1, 5501, 1, 1, ',', 0, 22925, 0, 0) ;

CALL ImportField(550111165, ' ()', 'FACT', '', 'FactKey', 1, 5501, 1, 1, '', 0, 22922, 0, 0) ;

CALL ImportField(550111166, '', 'InvestObject', '', ' ', 1, 5501, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(550111167, '', 'InvestObjectCode', '', ' ', 1, 5501, 1, 0, '', 0, null, 0, 0) ;

--    , (1)
CALL ImportField(550210149, ' ', 'RegionContractor', ' ', 'RegionContractor', 1, 5502, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(550211061, '()', 'IFSAGCode', '()', ' ', 1, 5502, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(550211065, '()', 'KDAGCode', '()', ' ', 1, 5502, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(550211067, '', 'DirectionClsCode', '', 'DirectionCls', 1, 5502, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(550211068, '', 'FACTCode', '', 'Fact', 1, 5502, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(550211071, ' . ', 'FinTypeCode', '  ', 'FinType', 1, 5502, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(550211110, '.  ', 'BudgetPromise', '.  ', 'BUDGETPROMISE', 1, 5502, 1, 1, ',', 0, 25283, 0, 0) ;

CALL ImportField(550211142, ' ()', 'DirectionCls', '', 'DirectionClsKey', 1, 5502, 1, 1, '', 0, 22920, 0, 0) ;

CALL ImportField(550211143, ' ()', 'FACT', '', 'FactKey', 1, 5502, 1, 1, '', 0, 22922, 0, 0) ;

CALL ImportField(550211144, ' .  ()', 'FinType', '  ', 'FinTypeKey', 1, 5502, 1, 1, ',', 0, 22925, 0, 0) ;

CALL ImportField(550211145, '', 'InvestObject', '', ' ', 1, 5502, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(550211146, '', 'InvestObjectCode', '', ' ', 1, 5502, 1, 0, '', 0, null, 0, 0) ;

--    , (1)
CALL ImportField(550310056, '', 'BudgetRef', '', ' ', 1, 5503, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(550311017, '', 'FactCode', '', 'Fact', 1, 5503, 1, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(550311018, '', 'DirectionClsCode', '', 'DirectionCls', 1, 5503, 1, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(550311020, ' . ', 'FinTypeCode', '  ', 'FinType', 1, 5503, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(550311026, '', 'DocBaseCode', '', 'DocBase', 1, 5503, 1, 0, '', 0, 36865, 0, 0) ;

CALL ImportField(550311034, '()', 'IFSAGCode', '', ' ', 1, 5503, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(550311038, '()', 'KDAGCode', '', ' ', 1, 5503, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(550311057, '', 'BudgetRef', '', ' ', 1, 5503, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(550311058, ' ()', 'DirectionCls', '', 'DirectionClsKey', 1, 5503, 1, 1, '', 0, 31719, 0, 0) ;

CALL ImportField(550311059, ' ()', 'Fact', '', 'FactKey', 1, 5503, 1, 1, '', 0, 31722, 0, 0) ;

CALL ImportField(550311060, ' .  ()', 'FinType', '  ', 'FinTypeKey', 1, 5503, 1, 1, ',', 0, 31724, 0, 0) ;

CALL ImportField(550311061, ' ()', 'DocBase', '', 'DocBaseKey', 1, 5503, 1, 1, '', 0, 31720, 0, 0) ;

CALL ImportField(550311062, '', 'InvestObject', '', ' ', 1, 5503, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(550311063, '', 'InvestObjectCode', '', ' ', 1, 5503, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(550312008, '', 'DirectionClsCode', '', ' ', 1, 5503, 2, 0, '', 0, 36861, 0, 0) ;

CALL ImportField(550312009, '', 'DocBaseCode', '', ' ', 1, 5503, 2, 0, '', 0, 36865, 0, 0) ;

CALL ImportField(550312011, '', 'FactCode', '', ' ', 1, 5503, 2, 0, '', 0, 36863, 0, 0) ;

CALL ImportField(550312013, ' . ', 'FinTypeCode', '  ', ' ', 1, 5503, 2, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(550312015, '()', 'IFSAGCode', '', ' ', 1, 5503, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(550312019, '()', 'KDAGCode', '', ' ', 1, 5503, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(550312056, ' ()', 'DirectionCls', '', ' ', 1, 5503, 2, 1, '', 0, 17450, 0, 0) ;

CALL ImportField(550312057, ' ()', 'Fact', '', ' ', 1, 5503, 2, 1, '', 0, 17418, 0, 0) ;

CALL ImportField(550312058, ' .  ()', 'FinType', '  ', ' ', 1, 5503, 2, 1, '', 0, 17425, 0, 0) ;

CALL ImportField(550312059, ' ()', 'DocBase', '', ' ', 1, 5503, 2, 1, '', 0, 17473, 0, 0) ;

-- , (1)
CALL ImportField(960110055, '', 'OGRN', '', ' ', 1, 9601, 0, 1, '', 0, null, 0, 0) ;

-- , +(2)
CALL ImportField(960110054, '', 'OKPO', '', ' ', 2, 9601, 0, 0, '', 0, 32938, 0, 0) ;

CALL ImportField(960110056, '', 'RemotePBSCode', '', ' ', 2, 9601, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(960110057, '', 'RemoteNotPBSCode', '', ' ', 2, 9601, 0, 0, '', 0, null, 0, 0) ;

--    , +(2)
CALL ImportField(970110001, '', 'ID', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970110002, '', 'Code', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970110003, '', 'Name', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970110004, '', 'BudgetRef', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970110005, '   ', 'StartDate', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970110006, ' ', 'DeleteDate', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970110007, ' ', 'CreateDate', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970110008, ' ', 'UpdateDate', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970110009, '', 'CreaterUser', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970110010, '', 'UpdaterUser', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0) ;

--    , +(2)
CALL ImportField(970210001, '', 'ID', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970210002, '', 'Code', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970210003, '', 'Name', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970210004, '', 'BudgetRef', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970210005, '   ', 'StartDate', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970210006, ' ', 'DeleteDate', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970210007, ' ', 'CreateDate', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970210008, ' ', 'UpdateDate', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970210009, '', 'CreaterUser', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(970210010, '', 'UpdaterUser', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0) ;

-- , +(2)
CALL ImportField(980410002, '', 'ID', '', ' ', 2, 9804, 0, 0, '', 0, 16865, 0, 0) ;

CALL ImportField(980410006, '', 'CODE', '', ' ', 2, 9804, 0, 0, '', 0, 25467, 0, 0) ;

-- , +(2)
CALL ImportField(980510002, '', 'ID', '', ' ', 2, 9805, 0, 0, '', 0, 16858, 0, 0) ;

CALL ImportField(980510006, '', 'CODE', '', ' ', 2, 9805, 0, 0, '', 0, 25462, 0, 0) ;

-- , +(2)
CALL ImportField(980910008, '', 'KESR', '', ' ', 2, 9809, 0, 0, '', 0, 16835, 0, 0) ;

CALL ImportField(980910009, ' ()', 'KVSR', '', ' ', 2, 9809, 0, 0, '', 0, 16830, 0, 0) ;

CALL ImportField(980910010, ' ', 'MAINDESCRIPTIONCODE', '', ' ', 2, 9809, 0, 0, '', 0, 16832, 0, 0) ;

CALL ImportField(980910017, '', 'KVSRCODE', '', ' ', 2, 9809, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(980910019, '', 'KD_LEVEL', '', ' ', 2, 9809, 0, 0, '', 0, 24895, 0, 0) ;

CALL ImportField(980910025, ' ()', 'ANALYTICALGROUPKD', '', ' ', 2, 9809, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(980910026, '', 'ANALYTICALGROUPKDCODE', '', ' ', 2, 9809, 0, 1, '', 0, null, 0, 0) ;

-- , +(2)
CALL ImportField(982810013, ' ', 'CODE', '', ' ', 2, 9828, 0, 0, '', 0, 36863, 0, 0) ;

-- 2, +(2)
CALL ImportField(984210001, '', 'ID', '', ' ', 2, 9842, 0, 1, '', 0, 37814, 0, 0) ;

CALL ImportField(984210002, '', 'Name', '', ' ', 2, 9842, 0, 1, '', 0, 37815, 0, 0) ;

CALL ImportField(984210003, '   ', 'StartDate', '', ' ', 2, 9842, 0, 1, '', 0, 37816, 0, 0) ;

CALL ImportField(984210004, ' (  )', 'DeleteDate', '', ' ', 2, 9842, 0, 1, '', 0, 37817, 0, 0) ;

CALL ImportField(984210005, ' ', 'CreateDate', '', ' ', 2, 9842, 0, 1, '', 0, 37818, 0, 0) ;

CALL ImportField(984210006, ' ', 'UpdateDate', '', ' ', 2, 9842, 0, 1, '', 0, 37819, 0, 0) ;

--    , (1)
CALL ImportField(985210018, '', 'KVSRCODE', '', ' ', 1, 9852, 0, 0, '', 0, null, 0, 0) ;

--    , +(2)
CALL ImportField(985210010, '', 'KESR', '', ' ', 2, 9852, 0, 0, '', 0, 17054, 0, 0) ;

CALL ImportField(985210011, ' ()', 'KVSR', '', ' ', 2, 9852, 0, 0, '', 0, 17049, 0, 0) ;

CALL ImportField(985210025, ' ()', 'ANALYTICALGROUPIFS', '', ' ', 2, 9852, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(985210026, '', 'ANALYTICALGROUPIFSCODE', '', ' ', 2, 9852, 0, 1, '', 0, null, 0, 0) ;

-- , (1)
CALL ImportField(985410008, '', '_FAVORITE', '', ' ', 1, 9854, 0, 1, '', 0, null, 0, 0) ;

-- , +(2)
CALL ImportField(985410001, ' ', 'CREATEDATE', '', ' ', 2, 9854, 0, 1, '', 0, 38231, 0, 0) ;

CALL ImportField(985410002, '', 'CREATERUSER', '', ' ', 2, 9854, 0, 1, '', 0, 38233, 0, 0) ;

CALL ImportField(985410003, '', 'CODE', '', ' ', 2, 9854, 0, 0, '', 0, 38205, 0, 0) ;

CALL ImportField(985410004, '', 'NAME', '', ' ', 2, 9854, 0, 0, '', 0, 38208, 0, 0) ;

CALL ImportField(985410005, ' ', 'SHORTNAME', '', ' ', 2, 9854, 0, 0, '', 0, 38209, 0, 0) ;

CALL ImportField(985410006, ' ', 'UPDATEDATE', '', ' ', 2, 9854, 0, 0, '', 0, 38232, 0, 0) ;

CALL ImportField(985410007, '', 'UPDATERUSER', '', ' ', 2, 9854, 0, 0, '', 0, 38234, 0, 0) ;

CALL ImportField(985410009, '   ', 'BudgetFinSourceObjectCode', '', ' ', 2, 9854, 0, 0, '', 0, 38207, 0, 0) ;

CALL ImportField(985410010, ' ', 'SubCode', '', ' ', 2, 9854, 0, 0, '', 0, 38206, 0, 0) ;

CALL ImportField(985410011, '', 'BudgetRef', '', ' ', 2, 9854, 0, 0, '', 0, 38211, 0, 0) ;

CALL ImportField(985410012, '', 'RegionCls', '', ' ', 2, 9854, 0, 0, '', 0, 38212, 0, 0) ;

CALL ImportField(985410013, '  ', 'BudgetFinSourceLevel', '', ' ', 2, 9854, 0, 0, '', 0, 38213, 0, 0) ;

CALL ImportField(985410014, '  ', 'ParentRef', '', ' ', 2, 9854, 0, 0, '', 0, 38214, 0, 0) ;

CALL ImportField(985410015, '  ', 'StartDate', '', ' ', 2, 9854, 0, 0, '', 0, 38215, 0, 0) ;

CALL ImportField(985410016, '  ', 'DeleteDate', '', ' ', 2, 9854, 0, 0, '', 0, 38216, 0, 0) ;

CALL ImportField(985410017, '', 'KVSR', '', ' ', 2, 9854, 0, 1, '', 0, 38217, 0, 0) ;

CALL ImportField(985410018, '', 'KCSR', '', ' ', 2, 9854, 0, 0, '', 0, 38218, 0, 0) ;

CALL ImportField(985410019, ' ', 'TARGETCLS', '', ' ', 2, 9854, 0, 0, '', 0, 38219, 0, 0) ;

CALL ImportField(985410020, '', 'Note', '', ' ', 2, 9854, 0, 0, '', 0, 38220, 0, 0) ;

CALL ImportField(985410021, ' ', 'MeansType', '', ' ', 2, 9854, 0, 0, '', 0, 38221, 0, 0) ;

CALL ImportField(985410022, '  ', 'TransfertCLS', '', ' ', 2, 9854, 0, 0, '', 0, 38222, 0, 0) ;

CALL ImportField(985410023, '', 'Fact', '', ' ', 2, 9854, 0, 0, '', 0, 38223, 0, 0) ;

CALL ImportField(985410024, '', 'OKTMO', '', ' ', 2, 9854, 0, 0, '', 0, 38224, 0, 0) ;

CALL ImportField(985410025, ' ', 'NPAId', '', ' ', 2, 9854, 0, 0, '', 0, 38225, 0, 0) ;

CALL ImportField(985410026, ' ', 'NPADate', '', ' ', 2, 9854, 0, 0, '', 0, 38226, 0, 0) ;

CALL ImportField(985410027, ' ', 'NPANumber', '', ' ', 2, 9854, 0, 0, '', 0, 38227, 0, 0) ;

CALL ImportField(985410028, '', 'NPAGroup', '', ' ', 2, 9854, 0, 0, '', 0, 38228, 0, 0) ;

CALL ImportField(985410029, '', 'KVSRCODE', '', ' ', 2, 9854, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(985410030, '', 'NPAName', '', ' ', 2, 9854, 0, 0, '', 0, 38229, 0, 0) ;

CALL ImportField(985410031, '', 'Address', '', ' ', 2, 9854, 0, 0, '', 0, 38230, 0, 0) ;

-- 2, +(2)
CALL ImportField(986710001, '', 'ID', '', ' ', 2, 9867, 0, 1, '', 0, 37808, 0, 0) ;

CALL ImportField(986710002, '', 'Name', '', ' ', 2, 9867, 0, 1, '', 0, 37809, 0, 0) ;

CALL ImportField(986710003, '   ', 'StartDate', '', ' ', 2, 9867, 0, 1, '', 0, 37810, 0, 0) ;

CALL ImportField(986710004, ' (  )', 'DeleteDate', '', ' ', 2, 9867, 0, 1, '', 0, 37811, 0, 0) ;

CALL ImportField(986710005, ' ', 'CreateDate', '', ' ', 2, 9867, 0, 1, '', 0, 37812, 0, 0) ;

CALL ImportField(986710006, ' ', 'UpdateDate', '', ' ', 2, 9867, 0, 1, '', 0, 37813, 0, 0) ;

-- , +(2)
CALL ImportField(986910008, ' ', 'CODE', '', ' ', 2, 9869, 0, 0, '', 0, 36861, 0, 0) ;

--  , (1)
CALL ImportField(990310094, '', 'OGRN', '', ' ', 1, 9903, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(990310096, ' ', 'REJECT_CLS', ' ', 'REJECTCLS', 1, 9903, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(990310097, '  ()', 'RejectCause', '  ()', 'RejectCause', 1, 9903, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(990311029, '   ()', 'FinType', '   ()', 'FINTYPEKey', 1, 9903, 1, 0, '', 0, 17114, 0, 0) ;

CALL ImportField(990311098, '  ', 'FinTypeCode', '  ', 'FINTYPE', 1, 9903, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(990311100, ' ', 'DateClose', '', ' ', 1, 9903, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(990311101, ' ', 'DATEOPEN', '', ' ', 1, 9903, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(990312047, '   ()', 'FINTYPE', '   ()', 'FINTYPEKey', 1, 9903, 2, 0, '', 0, 17141, 0, 0) ;

CALL ImportField(990312099, ' ', 'HigherOrg_Name', ' ', ' ', 1, 9903, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(990312100, '  /', 'PrevCls', '', ' ', 1, 9903, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(990312101, '  ', 'FinTypeCode', '  l', 'FINTYPE', 1, 9903, 2, 0, '', 0, 36853, 0, 0) ;

--  , +(2)
CALL ImportField(990310001, '', 'INN', '', ' ', 2, 9903, 0, 0, '', 0, 16645, 0, 0) ;

CALL ImportField(990310002, '', 'INN20', '', ' ', 2, 9903, 0, 0, '', 0, 16653, 0, 0) ;

CALL ImportField(990310003, '', 'NAME', '', ' ', 2, 9903, 0, 0, '', 0, 16646, 0, 0) ;

CALL ImportField(990310004, ' ', 'ShortName', ' ', ' ', 2, 9903, 0, 0, '', 0, 16670, 0, 0) ;

CALL ImportField(990310008, '', 'RegionCLS', '', ' ', 2, 9903, 0, 0, '', 0, 16644, 0, 0) ;

CALL ImportField(990310009, '', 'CITY', '', ' ', 2, 9903, 0, 0, '', 0, 16648, 0, 0) ;

CALL ImportField(990310010, '', 'ADDRESS', '', ' ', 2, 9903, 0, 0, '', 0, 16651, 0, 0) ;

CALL ImportField(990310011, '', 'COUNTRY', '', ' ', 2, 9903, 0, 0, '', 0, 16649, 0, 0) ;

CALL ImportField(990310012, '', 'PHONE', '', ' ', 2, 9903, 0, 0, '', 0, 16650, 0, 0) ;

CALL ImportField(990310057, ' ', 'Org_Type', '  ', ' ', 2, 9903, 0, 0, '', 0, 16682, 0, 0) ;

CALL ImportField(990310078, ' ', 'SupplierStatus', ' ', ' ', 2, 9903, 0, 0, '', 0, 16685, 0, 0) ;

CALL ImportField(990310079, ' ', 'CountryCode', ' ', ' ', 2, 9903, 0, 0, '', 0, 16686, 0, 0) ;

CALL ImportField(990310093, '', 'OKTMOCode', '', ' ', 2, 9903, 0, 0, '', 0, 32822, 0, 0) ;

--  , (1)
CALL ImportField(991210007, ' \', 'isForBusiness', ' \', ' ', 1, 9912, 0, 0, '', 0, 17280, 0, 0) ;

--   , (1)
CALL ImportField(991510005, '  ', 'DayKind', '  ', 'DayKind', 1, 9915, 0, 0, '', 0, 38954, 0, 0) ;

--  , (1)
CALL ImportField(991610001, ' \  \  , ,   ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 24, 8, ' \  \  , ,   ', '', 0, 0, 9916) ;

CALL ImportField(991610003, ' \ \   ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 14, 3, ' \ \   ', '', 0, 0, 9916) ;

CALL ImportField(991610004, ' \ \   ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 13, 3, ' \ \   ', '', 0, 0, 9916) ;

CALL ImportField(991610006, ' \  ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 19, 3, ' \  ', '', 0, 0, 9916) ;

CALL ImportField(991610007, ' \           ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 27, 8, ' \           ', '', 0, 0, 9916) ;

CALL ImportField(991610008, ' \           ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 26, 8, ' \           ', '', 0, 0, 9916) ;

CALL ImportField(991610009, ' \,    /C', '_C', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(16, 2, 3, ' \,    /C', '', 0, 0, 9916) ;

CALL ImportField(991610010, ' \   ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(380, 1, 3, ' \   ', '', 0, 0, 9916) ;

CALL ImportField(991610011, ' \    ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 19, 8, ' \    ', '', 0, 0, 9916) ;

CALL ImportField(991610012, ' \ .        ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 23, 3, ' \ .        ', '', 0, 0, 9916) ;

CALL ImportField(991610013, ' \  \ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 2, 8, ' \  \ ', '', 0, 0, 9916) ;

CALL ImportField(991610014, ' \  \ \   ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 20, 8, ' \  \ \   ', '', 0, 0, 9916) ;

CALL ImportField(991610015, ' \  \  - ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 10, 8, ' \  \  - ', '', 0, 0, 9916) ;

CALL ImportField(991610016, ' \  \  - \', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 9, 8, ' \  \  - \', '', 0, 0, 9916) ;

CALL ImportField(991610017, ' \  \ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 6, 8, ' \  \ ', '', 0, 0, 9916) ;

CALL ImportField(991610018, ' \  \ - ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 23, 8, ' \  \ - ', '', 0, 0, 9916) ;

CALL ImportField(991610019, ' \  \ - \', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 24, 8, ' \  \ - \', '', 0, 0, 9916) ;

CALL ImportField(991610020, ' \  \  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 1, 8, ' \  \  ', '', 0, 0, 9916) ;

CALL ImportField(991610021, ' \  \  \', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 8, 8, ' \  \  \', '', 0, 0, 9916) ;

CALL ImportField(991610022, ' \  \ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 3, 8, ' \  \ ', '', 0, 0, 9916) ;

CALL ImportField(991610023, ' \  ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 4, 8, ' \  ', '', 0, 0, 9916) ;

CALL ImportField(991610025, ' \ \ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 7, 8, ' \ \ ', '', 0, 0, 9916) ;

CALL ImportField(991610026, ' \ \  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 0, 5, ' \ \  ', '', null, 0, 9916) ;

CALL ImportField(991610027, ' \ \ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 27, 3, ' \ \ ', '', 0, 0, 9916) ;

CALL ImportField(991610028, ' \ \ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(34, 1, 3, ' \ \ ', '', 0, 0, 9916) ;

CALL ImportField(991610029, ' \ ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 3, 3, ' \ ', '', 0, 0, null) ;

CALL ImportField(991610030, ' \ ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 5, 3, ' \ ', '', 0, 0, null) ;

CALL ImportField(991610032, '\  ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 7, 3, '\  ', '', 0, 0, 9916) ;

CALL ImportField(991610037, ' \ \ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 1601, 8, ' \ \ ', '', 0, 0, 9916) ;

CALL ImportField(991610038, ' \ \   ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 4, 3, ' \ \   ', '', 0, 0, 9916) ;

CALL ImportField(991610039, ' \ \    ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 21, 3, ' \ \    ', '', 0, 0, 9916) ;

CALL ImportField(991610041, ' \\      :', '__:', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(3, 0, 8, ' \\      :', '___11701____________', 0, 0, 9916) ;

CALL ImportField(991610054, ' \\  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 15, 3, ' \\  ', '', 0, 0, 9916) ;

CALL ImportField(991610055, ' \\ \  \ ( )', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 63, 8, ' \\ \  \ ( )', '', 0, 0, 9916) ;

CALL ImportField(991610056, ' \\ \  \ (/)', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(34, 63, 8, ' \\ \  \ (/)', '', 0, 0, 9916) ;

CALL ImportField(991610057, ' \\  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 1, 3, ' \\  ', '', 0, 0, 9916) ;

CALL ImportField(991610058, ' \ (Limits.ocx )\ \  ', '_LimitsOcx__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 57, 8, ' \ (Limits.ocx )\ \  ', '', 0, 0, 9916) ;

CALL ImportField(991610065, ' \ , , \    \ ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 25, 3, ' \ , , \    \ ', '', 0, 0, 9916) ;

CALL ImportField(991610066, ' \ , , \      \', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 11, 3, ' \ , , \      \', '', 0, 0, 9916) ;

CALL ImportField(991610067, ' \ , , \      \ ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 12, 3, ' \ , , \      \ ', '', 0, 0, 9916) ;

CALL ImportField(991610068, ' \ , , \      \', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 10, 3, ' \ , , \      \', '', 0, 0, 9916) ;

CALL ImportField(991610070, ' \ , , \ \\ ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 265, 8, ' \ , , \ \\ ', '', 0, 0, 9916) ;

CALL ImportField(991610071, ' \ , , \ \\  ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 271, 8, ' \ , , \ \\  ', '', 0, 0, 9916) ;

CALL ImportField(991610074, ' \ , , \ \\', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 263, 8, ' \ , , \ \\', '', 0, 0, 9916) ;

CALL ImportField(991610075, ' \ , , \ \\ ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 261, 8, ' \ , , \ \\ ', '', 0, 0, 9916) ;

CALL ImportField(991610079, ' \ , , \ \\ , ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 262, 8, ' \ , , \ \\ , ', '', 0, 0, 9916) ;

CALL ImportField(991610080, ' \ , , \  \ (),   ()\ ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 35, 3, ' \ , , \  \ (),   ()\ ', '', 0, 0, 9916) ;

CALL ImportField(991610081, ' \ , , \  \ (),   ()\', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 31, 3, ' \ , , \  \ (),   ()\', '', 0, 0, 9916) ;

CALL ImportField(991610082, ' \ , , \  \', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 33, 3, ' \ , , \  \', '', 0, 0, 9916) ;

CALL ImportField(991610083, ' \ , , \  \,  \ ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 34, 3, ' \ , , \  \,  \ ', '', 0, 0, 9916) ;

CALL ImportField(991610084, ' \ , , \  \,  \', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 30, 3, ' \ , , \  \,  \', '', 0, 0, 9916) ;

CALL ImportField(991610085, ' \ , , \  \ , ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 32, 3, ' \ , , \  \ , ', '', 0, 0, 9916) ;

CALL ImportField(991610086, ' \ , , \  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(18, 1, 3, ' \ , , \  ', '', 0, 0, 9916) ;

CALL ImportField(991610087, ' \ , , \  ,   ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 19, 3, ' \ , , \  ,   ', '', 0, 0, 9916) ;

CALL ImportField(991610088, ' \ , , \ \,  (, )', '__2007_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 27, 3, ' \ , , \ \,  (, )', '', 0, 0, 9916) ;

CALL ImportField(991610089, ' \ , , \   ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 1, 3, ' \ , , \   ', '', 0, 0, 9916) ;

CALL ImportField(991610090, ' \ \ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(11, 1, 3, ' \ \ ', '', 0, 0, 9916) ;

CALL ImportField(991610092, ' \  \ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(19, 2, 8, ' \  \ ', '', 0, 0, 9916) ;

CALL ImportField(991610093, ' \  \  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(19, 4, 3, ' \  \  ', '', 0, 0, 9916) ;

CALL ImportField(991610094, ' \  \ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(19, 3, 3, ' \  \ ', '', 0, 0, 9916) ;

CALL ImportField(991610095, ' \  \ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(19, 1, 3, ' \  \ ', '', 0, 0, 9916) ;

CALL ImportField(991610096, ' \  \      ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(1, 55, 3, ' \  \      ', '', 0, 0, 9916) ;

CALL ImportField(991610098, ' ,   :', ':', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(3, 2, 3, ' ,   :', '', 0, 0, 9916) ;

CALL ImportField(991610099, ' \  ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 26, 8, ' \  ', '', 0, 0, 9916) ;

CALL ImportField(991610101, ' \ \    ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 24, 3, ' \ \    ', '', 0, 0, 9916) ;

CALL ImportField(991610102, ' \ ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 61, 3, ' \ ', '', 0, 0, 9916) ;

CALL ImportField(991610103, ' \  ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(1000, 47, 3, ' \  ', '', 0, 0, 9916) ;

CALL ImportField(991610104, ' \   ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 6, 3, ' \   ', '', 0, 0, 9916) ;

CALL ImportField(991610105, ' \ / ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 5, 3, ' \ / ', '', 0, 0, 9916) ;

CALL ImportField(991610106, ' \ / ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 8, 3, ' \ / ', '', 0, 0, 9916) ;

CALL ImportField(991610107, ' \ \   ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 30, 3, ' \ \   ', '', 0, 0, 9916) ;

CALL ImportField(991610108, ' \   ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 0, 8, ' \   ', '', 0, 0, 9916) ;

CALL ImportField(991610111, ' \ \', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 15, 8, ' \ \', '', 0, 0, 9916) ;

CALL ImportField(991610112, ' \ \', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 14, 8, ' \ \', '', 0, 0, 9916) ;

CALL ImportField(991610113, ' \ \  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 13, 8, ' \ \  ', '', 0, 0, 9916) ;

CALL ImportField(991610114, ' \\ ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(40, 1, 3, ' \\ ', '', 0, 0, 9916) ;

CALL ImportField(991610115, '\ \           ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 50, 3, '\ \           ', '', 0, 0, 9916) ;

CALL ImportField(991610116, '\ \      ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 5, 8, '\ \      ', '', 0, 0, 9916) ;

CALL ImportField(991610117, '\ \      ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 4, 8, '\ \      ', '', 0, 0, 9916) ;

CALL ImportField(991610118, '\ \     /  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 3, 3, '\ \     /  ', '', 0, 0, 9916) ;

CALL ImportField(991610119, '\ ,   \  " "', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 20, 3, '\ ,   \  " "', '', 0, 0, 9916) ;

CALL ImportField(991610120, '\ ,   \    ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 10, 3, '\ ,   \    ', '', 0, 0, 9916) ;

CALL ImportField(991610121, '\ ,   \    .   ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 11, 3, '\ ,   \    .   ', '', 0, 0, 9916) ;

CALL ImportField(991610126, '\ ,   \      ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(2, 1, 3, '\ ,   \      ', '', 0, 0, 9916) ;

CALL ImportField(991610127, '\ ,   \ "  "\ ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 22, 3, '\ ,   \ "  "\ ', '', 0, 0, 9916) ;

CALL ImportField(991610128, '\ ,   \ "  "\  ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 23, 3, '\ ,   \ "  "\  ', '', 0, 0, 9916) ;

CALL ImportField(991610129, '\ ,   \       ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 60, 3, '\ ,   \       ', '', 0, 0, 9916) ;

CALL ImportField(991610130, '\ ,   \ -', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 15, 3, '\ ,   \ -', '', 0, 0, 9916) ;

CALL ImportField(991610131, ' \ , , \    /   (  )       (    )', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 39, 3, ' \ , , \    /   (  )       (    )', '', 0, 0, 9916) ;

CALL ImportField(991610132, ' \ , , \  \ /   \       ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 17, 3, ' \ , , \  \ /   \       ', '', 0, 0, 9916) ;

CALL ImportField(991610133, ' \ , , \  \ /   \, , ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 13, 3, ' \ , , \  \ /   \, , ', '', 0, 0, 9916) ;

CALL ImportField(991610134, ' \ , , \  \ /  \       ', '_____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 2, 3, ' \ , , \  \ /  \       ', '', 0, 0, 9916) ;

CALL ImportField(991610135, ' \ , , \  \ /  \, ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 3, 3, ' \ , , \  \ /  \, ', '', 0, 0, 9916) ;

CALL ImportField(991610136, ' \ , , \   ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 38, 3, ' \ , , \   ', '', 0, 0, 9916) ;

CALL ImportField(991610137, ' \   ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(3, 10, 3, ' \   ', '', 0, 0, 9916) ;

CALL ImportField(991610138, ' \ , , \ \\  ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 272, 8, ' \ , , \ \\  ', '', 0, 0, 9916) ;

CALL ImportField(991610139, ' \ , , \ \\   ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 273, 8, ' \ , , \ \\   ', '', 0, 0, 9916) ;

CALL ImportField(991610140, ' \  \     ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 25, 3, ' \  \     ', '', 0, -1, 9916) ;

CALL ImportField(991610141, ' \ , , \ \\  ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 215, 8, ' \ , , \ \\  ', '', 0, 0, 9916) ;

CALL ImportField(991610142, ' \ , , \ \\', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 264, 8, ' \ , , \ \\', '', 0, 0, 9916) ;

CALL ImportField(991610143, ' \ , , \ \\   (  )', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(34, 32, 8, ' \ , , \ \\   (  )', '', 0, 0, 9916) ;

CALL ImportField(991610144, ' \ , , \ \\ (  )', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 260, 8, ' \ , , \ \\ (  )', '', 0, 0, 9916) ;

CALL ImportField(991610145, ' \ , , \ \\   (  )', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 32, 8, ' \ , , \ \\   (  )', '', 0, 0, 9916) ;

CALL ImportField(991610146, ' \ , , \ \\ (  )', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(34, 260, 8, ' \ , , \ \\ (  )', '', 0, 0, 9916) ;

CALL ImportField(991610148, ' \ \          ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(44, 4, 3, ' \ \          ', '', 0, 0, 9916) ;

CALL ImportField(991610149, ' \ , , \ \\  ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 268, 8, ' \ , , \ \\  ', '', 0, 0, 9916) ;

CALL ImportField(991610150, ' \ \    ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(44, 1, 3, ' \ \    ', '', 0, 0, 9916) ;

CALL ImportField(991610151, ' \ \  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(44, 2, 3, ' \ \  ', '', 0, 0, 9916) ;

CALL ImportField(991610152, ' \ \  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(44, 3, 3, ' \ \  ', '', 0, 0, 9916) ;

CALL ImportField(991610153, ' \\      :', '__:', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(3, 11, 8, ' \\      :', '___30398____________', 0, 0, 9916) ;

CALL ImportField(991610155, '  \  ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 71, 3, '  \  ', '', 0, 0, 9916) ;

CALL ImportField(991610156, '  \.    ()', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 72, 3, '  \.    ()', '', 0, 0, 9916) ;

CALL ImportField(991610157, ' \ , , \ \\   ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 274, 8, ' \ , , \ \\   ', '', 0, 0, 9916) ;

CALL ImportField(991610158, ' \  \    ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(1, 56, 3, ' \  \    ', '', 0, 0, 9916) ;

CALL ImportField(991610159, ' \ \  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 28, 8, ' \ \  ', '', 0, 0, 9916) ;

CALL ImportField(991610160, ' \ \', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 29, 8, ' \ \', '', 0, 0, 9916) ;

CALL ImportField(991610161, ' \ \', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 30, 8, ' \ \', '', 0, 0, 9916) ;

CALL ImportField(991610162, ' \  ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 73, 3, ' \  ', '', 0, 0, 9916) ;

CALL ImportField(991610163, ' \ , , \  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 36, 3, ' \ , , \  ', '', 0, 0, 9916) ;

CALL ImportField(991610164, '  \   ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 74, 3, '  \   ', '', 0, 0, 9916) ;

CALL ImportField(991610165, ' \  ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 41, 3, ' \  ', '', 0, 0, 9916) ;

CALL ImportField(991610167, ' \ \    ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(44, 5, 3, ' \ \    ', '', 0, 0, 9916) ;

CALL ImportField(991610168, ' \     ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(60, 31, 3, ' \     ', '', 0, 0, 9916) ;

CALL ImportField(991610169, '\ ,   \  /,   /', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 75, 3, '\ ,   \  /,   /', '', 0, 0, 9916) ;

CALL ImportField(991610171, ' \   ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 42, 3, ' \   ', '', 0, 0, 9916) ;

CALL ImportField(991610172, '  \.   ,     ()', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 76, 3, '  \.   ,     ()', '', 0, 0, 9916) ;

CALL ImportField(991610173, ' \\         ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 80, 3, ' \\         ', '', 0, 0, 9916) ;

CALL ImportField(991610175, '\ ,   \  -   ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 44, 3, '\ ,   \  -   ', '', 0, 0, 9916) ;

CALL ImportField(991610176, ' \  \ \ ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 315, 8, ' \  \ \ ', '', 0, 0, 9916) ;

CALL ImportField(991610177, ' \  \ \ ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 316, 8, ' \  \ \ ', '', 0, 0, 9916) ;

CALL ImportField(991610178, '  \ ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 70, 8, '  \ ', '', 0, 0, 9916) ;

CALL ImportField(991610179, '  \      ( )', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 71, 8, '  \      ( )', '', 0, 0, 9916) ;

CALL ImportField(991610180, ' \   ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 80, 8, ' \   ', '', 0, 0, 9916) ;

CALL ImportField(991610181, '  \  ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(527, 1, 3, '  \  ', '', 0, 0, 9916) ;

CALL ImportField(991610183, '  \ http-  ', '_HTTP', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(527, 2, 3, '  \ http-  ', '', 0, 0, 9916) ;

CALL ImportField(991610184, '  \ FTP-\  \ ', '_FTP__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(527, 3, 8, '  \ FTP-\  \ ', '', 0, 0, 9916) ;

CALL ImportField(991610185, '  \ FTP-\  \', '_FTP__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(527, 4, 8, '  \ FTP-\  \', '', 0, 0, 9916) ;

CALL ImportField(991610186, '  \ FTP-\ [:]', '_FTP_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(527, 5, 8, '  \ FTP-\ [:]', '', 0, 0, 9916) ;

CALL ImportField(991610187, '  \ FTP-\  \ ', '_FTP__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(527, 6, 8, '  \ FTP-\  \ ', '', 0, 0, 9916) ;

CALL ImportField(991610188, '  \ FTP-\  \', '_FTP__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(527, 7, 8, '  \ FTP-\  \', '', 0, 0, 9916) ;

CALL ImportField(991610189, '  \ FTP-\  ', '_FTP_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(527, 8, 3, '  \ FTP-\  ', '', 0, 0, 9916) ;

CALL ImportField(991610190, '  \ FTP-\FTP-   ', '_FTP_FTP', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(527, 9, 8, '  \ FTP-\FTP-   ', '', 0, 0, 9916) ;

CALL ImportField(991610191, '  \ FTP-\  \ ', '_FTP__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(527, 10, 8, '  \ FTP-\  \ ', '', 0, 0, 9916) ;

CALL ImportField(991610192, '  \ FTP-\  \', '_FTP__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(527, 11, 8, '  \ FTP-\  \', '', 0, 0, 9916) ;

CALL ImportField(991610193, '    , \,       , ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(30, 45, 8, '    , \,       , ', '400-499,610-629', 0, 0, null) ;

CALL ImportField(991610194, '    , \   /      ( )', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 44, 3, '    , \   /      ( )', '', 0, 0, 9916) ;

CALL ImportField(991610195, ' \ \  ', '__', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 2, 3, ' \ \  ', '', 0, 0, null) ;

CALL ImportField(991610196, '\ ,   \', '__', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 4, 3, '\ ,   \', '', 0, 0, null) ;

CALL ImportField(991610197, '\ \  ', '__', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(6, 1, 8, '\ \  ', '', 0, 0, null) ;

CALL ImportField(991610199, ' \ , , \ \ /        ,   ', '__2007_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(32, 40, 3, ' \ , , \ \ /        ,   ', '', 0, 0, null) ;

CALL ImportField(991610200, ' \  " "', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(51, 1, 3, ' \  " "', '', 0, 0, null) ;

CALL ImportField(991610201, '\ \    ', '__', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(60, 1, 8, '\ \    ', '', 0, 0, null) ;

CALL ImportField(991610202, ' \   ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(60, 9, 3, ' \   ', '', 0, 0, null) ;

CALL ImportField(991610203, ' \   ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(60, 10, 3, ' \   ', '', 0, 0, null) ;

CALL ImportField(991610204, ' \  ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(60, 15, 3, ' \  ', '', 0, 0, null) ;

CALL ImportField(991610205, ' \   ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(60, 18, 8, ' \   ', '', 0, 0, null) ;

CALL ImportField(991610206, ' \   ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(60, 20, 3, ' \   ', '', 0, 0, null) ;

CALL ImportField(991610207, ' \   ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(60, 21, 3, ' \   ', '', 0, 0, null) ;

CALL ImportField(991610211, ' \ , , \  \  \     ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 46, 3, ' \ , , \  \  \     ', '', 0, 0, 9916) ;

CALL ImportField(991610212, ' \ , , \    \() ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(32, 45, 3, ' \ , , \    \() ', '', 0, 0, 9916) ;

CALL ImportField(991610214, ' \ , , \ \\  ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(33, 275, 8, ' \ , , \ \\  ', '', 0, 0, 9916) ;

CALL ImportField(991610215, ' \   \ ,     ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 16, 8, ' \   \ ,     ', '', 0, 0, 9916) ;

CALL ImportField(991610216, '\    \ /  ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 81, 8, '\    \ /  ', '', 0, 0, 9916) ;

CALL ImportField(991610217, ' \ \    ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 31, 3, ' \ \    ', '', 0, 0, 9916) ;

--  , (1)
CALL ImportField(991710001, '     "     "', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 55, 3, '     "     "', '', 0, 0, 9917) ;

CALL ImportField(991710003, '    / ,   / ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(58, 0, 3, '    / ,   / ', '', 0, 0, 9917) ;

CALL ImportField(991710004, ' ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 20, 3, ' ', '', 0, 0, 9917) ;

CALL ImportField(991710005, '    ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 11, 3, '    ', '', 0, 0, 9917) ;

CALL ImportField(991710006, '  ', '', '', ' ', 1, 9917, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(30, 35, 3, '  ', '', 0, 0, null) ;

CALL ImportField(991710007, '/ ()   ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 14, 3, '/ ()   ', '', 0, 0, 9917) ;

CALL ImportField(991710008, '/ ()  ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 8, 3, '/ ()  ', '', 0, 0, 9917) ;

CALL ImportField(991710009, '..    ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 3, 3, '..    ', '', 0, 0, 9917) ;

CALL ImportField(991710010, '/ ()     ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 7, 3, '/ ()     ', '', 0, 0, 9917) ;

CALL ImportField(991710011, '/ ()   ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 33, 3, '/ ()   ', '', 0, 0, 9917) ;

CALL ImportField(991710012, '/ ()   ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 12, 3, '/ ()   ', '', 0, 0, 9917) ;

CALL ImportField(991710013, '/ "  "', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(1000, 20, 3, '/ "  "', '', 0, 0, 9917) ;

CALL ImportField(991710016, '  - ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 10, 8, '  - ', '', 0, 0, 9917) ;

CALL ImportField(991710017, '  - \', '_', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(-1, 9, 8, '  - \', '', 0, 0, 9917) ;

CALL ImportField(991710018, '  ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 1, 3, '  ', '', 0, 0, 9917) ;

CALL ImportField(991710019, '  \  ', '_', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(63, 1, 3, '  \  ', '', 0, 0, 9917) ;

CALL ImportField(991710020, ' ,   :', ':', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 2, 3, ' ,   :', '', 0, 0, 9917) ;

CALL ImportField(991710021, '   " ", " "\  /   " "  " "', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 29, 3, '   " ", " "\  /   " "  " "', '', 0, 0, 9917) ;

CALL ImportField(991710022, '  \  ', '_', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(56, 10, 3, '  \  ', '', 0, 0, 9917) ;

CALL ImportField(991710023, ' ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 16, 3, ' ', '', 0, 0, 9917) ;

CALL ImportField(991710024, '    ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 6, 3, '    ', '', 0, 0, 9917) ;

CALL ImportField(991710025, ' . ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 10, 8, ' . ', '', 0, 0, 9917) ;

CALL ImportField(991710029, '  \    ', '_', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(56, 0, 3, '  \    ', '', 0, 0, 9917) ;

CALL ImportField(991710030, '   " ", " "\     /   " "', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 41, 3, '   " ", " "\     /   " "', '', 0, 0, 9917) ;

CALL ImportField(991710031, '   " ", " "\     /   " "', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 39, 3, '   " ", " "\     /   " "', '', 0, 0, 9917) ;

CALL ImportField(991710033, '  " "\ /   ', '', '', ' ', 1, 9917, 0, 0, '', 0, null, 0, 0) ;

CALL InsertConst(30, 43, 3, '  " "\ /   ', '', 0, 0, 9917) ;

CALL ImportField(991710035, '       . .', '', '', ' ', 1, 9917, 0, 1, '', 0, null, 0, 0) ;

CALL InsertConst(30, 17, 3, '       . .', '', 0, 0, null) ;

--    , (1)
CALL ImportField(992011010, '', 'CreditAccRef', '', ' ', 1, 9920, 1, 1, '', 0, 21655, 0, 0) ;

CALL ImportField(992011011, '', 'DebitAccRef', '', ' ', 1, 9920, 1, 1, '', 0, 21654, 0, 0) ;

--    , (1)
CALL ImportField(992610006, '   ', 'AllowDocStates', '', ' ', 1, 9926, 0, 0, '', 0, 38513, 0, 0) ;

CALL ImportField(992610007, '   ', 'AllowWritTypes', '', ' ', 1, 9926, 0, 0, '', 0, 38514, 0, 0) ;

--     , (1)
CALL ImportField(992910001, '', 'ID', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(992910002, '', 'KVSRCode', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910003, '', 'KFSR', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910004, '', 'KCSRCode', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910005, '', 'KVRCode', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910006, '', 'KESR', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910007, '  ', 'TransfertClsCode', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910008, '. ', 'SubKESR', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910009, '', 'DirectionCLSCode', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910010, '', 'RegionCls', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910011, '', 'FactCode', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910012, ' . ', 'FinTypeCode', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910013, ' ', 'MeansType', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910014, '  ', 'BudAllocationClsCode', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910015, '  ', 'PayPromiseClsCode', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910016, ' ', 'SubsidyClsCode', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910017, '   ', 'StartDate', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910018, ' ', 'ActualDate', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910019, '   ', 'IsLimitSpend', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(992910020, '', 'BudgetRef', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(992910021, ' ()', 'KVSR', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(992910022, ' ()', 'KCSR', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(992910023, ' ()', 'KVR', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(992910024, ' ()', 'DirectionCLS', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(992910025, ' ()', 'Fact', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(992910026, ' .  ()', 'FinType', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(992910027, '   ()', 'TransfertCls', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(992910028, '   ()', 'BudAllocationCls', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(992910029, '   ()', 'PayPromiseCls', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

CALL ImportField(992910030, '  ()', 'SubsidyCls', '', ' ', 1, 9929, 0, 1, '', 0, null, 0, 0) ;

--       
ALTER TRIGGER TR_INTCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 ENABLE
/

DROP PROCEDURE ImportField
/

/*      */
ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 DISABLE
/

Update TB_DocumentFields df
set documentcls=doctyperef*100+detailnumber
where (detailnumber<100)and(documentcls is null)
 and(exists(select dc.id from documentcls dc where id=df.doctyperef*100+df.detailnumber))
/

ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 ENABLE
/

DROP PROCEDURE DeleteFields
/

DROP PROCEDURE InsertConst
/

DROP PROCEDURE DELETECONST
/




CREATE OR REPLACE PROCEDURE DOCLOCK_IMPORT(
  NAME_              VARCHAR2,
  LOCKMASK_          NUMBER,
  DOCREF_            NUMBER,
  DETAILNUM_         NUMBER,
  RUNPOS_            NUMBER,
  LOCKACTION_        NUMBER,
  USERIGHTS_        NUMBER,
  FORMULA_           VARCHAR2,
  FORDELETE_         NUMBER,
  ISSYSTEM_          NUMBER,
  NOTE_              VARCHAR2,
  FORINSERT_         NUMBER,
  VALIDATEMESSAGE_ VARCHAR2,
  VALIDATELEVEL_   NUMBER,
  VALIDATEFILTER_  VARCHAR2,
  ISBUDGET_ NUMBER)
IS
  DOCLOCKID$ Number(10);
BEGIN
   BEGIN
     SELECT ID
     INTO DOCLOCKID$
     FROM DOCLOCK
     WHERE (DOCREF = DOCREF_) AND(DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DOCLOCKID$ := NULL;  
   END;
   
   IF (DOCLOCKID$ is not null) THEN
     IF (ISSYSTEM_ = 3) THEN
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         USERIGHTS = USERIGHTS_
       WHERE ID = DOCLOCKID$;  
     ELSE
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_
       WHERE ID = DOCLOCKID$;    
     END IF;  
   ELSE
     INSERT INTO DOCLOCK
       (ISBUDGET,NAME,LOCKMASK,DOCREF,DETAILNUM,RUNPOS,LOCKACTION,USERIGHTS,FORMULA,FORDELETE,ISSYSTEM,NOTE,FORINSERT,VALIDATEMESSAGE,VALIDATELEVEL,VALIDATEFILTER)
     VALUES
       (ISBUDGET_,NAME_,LOCKMASK_,DOCREF_,DETAILNUM_,RUNPOS_,LOCKACTION_,USERIGHTS_,FORMULA_,FORDELETE_,ISSYSTEM_,NOTE_,FORINSERT_,VALIDATEMESSAGE_,VALIDATELEVEL_,VALIDATEFILTER_);
   END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_INSERTFIELD(
  NAME_      VARCHAR2,
  DOCREF_    NUMBER,
  DETAILNUM_ NUMBER,
  FIELDREF_  NUMBER,
  ISBUDGET_ NUMBER)
IS
  NID$ NUMBER(10);
  cnt$ number(10);
BEGIN
  BEGIN
    SELECT ID
    INTO NID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      NID$ := NULL;  
  END;

  IF (NID$ is not null) THEN
    CNT$ := 0;
    SELECT count(ID)
    into cnt$
    FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    
    IF (cnt$ = 0) THEN
      INSERT INTO DOCLOCKFIELDS
        (DOCLOCKREF,FIELDREF,ISSYSTEM)
      VALUES
        (NID$,FIELDREF_,1);
    ELSE
      UPDATE DOCLOCKFIELDS SET
        ISSYSTEM = 1
      WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    END IF;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCK_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCK
    WHERE ID = DOCLOCKID$;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, CANCHANGEFIELDS_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION  
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;  

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = DOCLOCKID$) AND ((ISSYSTEM = 1) OR ((ISSYSTEM = 0) AND (CANCHANGEFIELDS_ = 0) ));
  END IF;
END;
/

-- 
CALL DOCLOCK_DELETE('   ',211, 0, 1) ;

CALL DOCLOCK_DELETE('   ',304, 0, 1) ;

CALL DOCLOCK_DELETE('  ',1601, -1, 1) ;

CALL DOCLOCK_DELETE('   ',1601, 1, 2) ;

CALL DOCLOCK_DELETE('     ,',1601, 1, 2) ;

CALL DOCLOCK_DELETE('      ',1601, 1, 1) ;

CALL DOCLOCK_DELETE('      ',1601, 1, 1) ;

CALL DOCLOCK_DELETE('      ',1601, 1, 1) ;

CALL DOCLOCK_DELETE(' ',1816, -1, 1) ;

CALL DOCLOCK_DELETE('      ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('   ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     , ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('   ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     , ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     ,  ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('   ',2502, 0, 1) ;

CALL DOCLOCK_DELETE('   ',2502, 3, 1) ;

CALL DOCLOCK_DELETE('     ,',2502, 3, 1) ;

CALL DOCLOCK_DELETE('   ',2503, 2, 1) ;

CALL DOCLOCK_DELETE('     ,',2503, 2, 1) ;

CALL DOCLOCK_DELETE('123',2503, 2, 1) ;

CALL DOCLOCK_DELETE('    ',2504, 4, 2) ;

CALL DOCLOCK_DELETE('   ',4901, 0, 1) ;

CALL DOCLOCK_DELETE('     ',5201, 0, 1) ;

CALL DOCLOCK_DELETE('',5501, 0, 1) ;

CALL DOCLOCK_DELETE('crhsdf',5501, 1, 1) ;

CALL DOCLOCK_DELETE('    ',9912, 0, 1) ;

CALL DOCLOCK_DELETE('   5-  ',9920, 1, 1) ;

CALL DOCLOCK_IMPORT('   ',0,200,1,0,11,0,'',0,1,'        - \.',0,'        ',null,'(([960110035] between 010800 and 010999)
([960110021]=("_.",.[20011008])))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 200, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',200,1,20011028,1) ;

CALL DOCLOCK_IMPORT('    ',0,200,1,0,11,0,'((=204)(=212))(((".",)))',0,3,'         ".  , "',0,'         ',null,'([988910010]=0)',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 200, 1, 0, 1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',200,1,20011015,1) ;

CALL DOCLOCK_IMPORT('      ',0,200,1,0,11,0,'[20011012] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[20011018] = 0)  (.[20011024] = [988410026]))

(([988410022] = 0)  (.[20011020] = 0)  (.[20011020] = [988410022]))

(([988410023] = 0)  (.[20011019] = 0)  (.[20011023] = [988410024]))

(([988410018] = 0)  (.[20011022] = 0)  (.[20011025] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 200, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('      ',200,1,20011011,1) ;

CALL DOCLOCK_IMPORT('     ',0,200,1,0,11,0,'[20011012] = 2',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[20011017] = 0)  ([988410008] = .[20011026]) 
   ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[20011017]))
   (((".",[988410006])=(".",.[20011017]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[20011017]))) 
(((".", .[20011017]) div 100000) between 218 and 219)  
(((".", .[20011017]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 200, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',200,1,20011011,1) ;

CALL DOCLOCK_IMPORT('   ',0,200,1,0,11,0,'[20011007] <> 0',0,1,'       ,      ',0,'         ',null,'((".", .[20011007]) = 0) 
((".", .[20011007]) = [988510003]) 
((((".", .[20011007]) mod 100) = 0) 
 (((".", .[20011007]) div 100) = ([988510003] div 100))) 
((((".", .[20011007]) mod 10000) = 0) 
 (((".", .[20011007]) div 10000) = ([988510003] div 10000)))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 200, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',200,1,20011034,1) ;

CALL DOCLOCK_IMPORT('     ,',0,200,1,0,11,0,'("_._",[20011008])   ("_._",[20011008])   ("_.",[20011008])',0,3,',        =- \,  =.    \ \,     <>.   \ \      .',0,'         ',null,'([988910008] = ("_.",.[20011008])
 (((".",[988910008]) between 10100  10199)
 ((".",[988910008]) between 11000  11099)))
   
(( ("_._",.[20011008])
 ([988910010] = 0))

(("_._",.[20011008])
 ([988910010] <> 0)))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 200, 1, 0, 1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',200,1,20011015,1) ;

CALL DOCLOCK_IMPORT('    / ,',0,200,1,0,11,0,' ((=204)(=212))',0,3,'  \,  ,       ',0,'    / , ,  / , , /       ',null,'([984110041]=0)([984110045]=0)([984110046]=0)',1) ;

CALL DOCLOCKFIELDS_DELETE('    / ,', 200, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    / ,',200,1,20011008,1) ;

CALL DOCLOCK_IMPORT('   ',32768,200,1,0,3,0,'((("..",[20010014]) between 10800  11099)    (("_...",[20011008]) between 10800  11099)     ((("_...",[20011008]) between 10000  10499)         (=204) ))',0,1,'  " "  \   -   01.08.00-01.10.99  01.01.00-01.04.99 ( ,  ,  .(.) ).           ,',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 200, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',200,1,20011014,1) ;

CALL DOCLOCK_IMPORT('    ',0,200,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[20011012] = 0)  ([986810009] = 1)) 
((.[20011012] = 1)  ([986810008] = 1)) 
((.[20011012] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 200, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',200,1,20011021,1) ;

CALL DOCLOCK_IMPORT('   ',32768,201,1,0,3,0,' (".", )',0,3,'  " "  ,     .          , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 201, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',201,1,20111182,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',201,1,20111181,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',201,1,20111180,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',201,1,20111096,1) ;

CALL DOCLOCK_IMPORT('   (2)',32768,201,1,0,3,0,'((([20111089] is not null)   (([20111085],(30,45,8),"9.9.9")))    ([20111085] between 500 and 599)     (([20111082] is not null)  (tonumber([020111083],1) <> 0))   )',0,1,'  " "  ,     .     ,            ( ),      , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   (2)', 201, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',201,1,20111182,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',201,1,20111181,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',201,1,20111180,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',201,1,20111096,1) ;

CALL DOCLOCK_IMPORT('     ',32768,204,-1,0,3,0,'((32, 43, 3) = 0)  ((32, 43, 3) = 2)',0,3,'     ,   ,     ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 204, -1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',204,-1,20411059,1) ;

CALL DOCLOCK_IMPORT('   ',32768,206,1,0,3,0,' (".", )',0,3,'  " "  ,     .          , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 206, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',206,1,20611182,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',206,1,20611181,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',206,1,20611180,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',206,1,20611103,1) ;

CALL DOCLOCK_IMPORT('   (2)',32768,206,1,0,3,0,'((([20611096] is not null)  (([20611092],(30,45,8),"9.9.9")))      ([20611092] between 500 and 599)    (([20611089] is not null)  (tonumber([20611090],1) <> 0))   )',0,1,'  " "  ,     .     ,            ( ),      , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   (2)', 206, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',206,1,20611182,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',206,1,20611181,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',206,1,20611180,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',206,1,20611103,1) ;

CALL DOCLOCK_IMPORT('   ',32768,208,1,0,3,0,' (".", )',0,3,'  " "  ,     .          , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 208, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',208,1,20811182,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',208,1,20811181,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',208,1,20811180,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',208,1,20811179,1) ;

CALL DOCLOCK_IMPORT('   (2)',32768,208,1,0,3,0,'((([20811170] is not null)  (([20811167],(30,45,8),"9.9.9")))    ([20811167] between 500 and 599)    (([20811163] is not null)  (tonumber([20811164],1) <> 0))   )',0,1,'  " "  ,     .     ,            ( ),      , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   (2)', 208, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',208,1,20811182,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',208,1,20811181,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',208,1,20811180,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',208,1,20811179,1) ;

CALL DOCLOCK_IMPORT('      ',0,209,2,0,11,0,'[20912032] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[20912039] = 0)  (.[20912020] = [988410026]))

(([988410022] = 0)  (.[20912018] = 0)  (.[20912018] = [988410022]))

(([988410023] = 0)  (.[20912038] = 0)  (.[20912019] = [988410024]))

(([988410018] = 0)  (.[20912037] = 0)  (.[20912016] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 209, 2, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('      ',209,2,20912035,1) ;

CALL DOCLOCK_IMPORT('   ',0,209,2,0,11,0,'[20912044] <> 0',0,1,'       ,      ',0,'         ',null,'((".", .[20912044]) = 0) 
((".", .[20912044]) = [988510003]) 
((((".", .[20912044]) mod 100) = 0) 
 (((".", .[20912044]) div 100) = ([988510003] div 100))) 
((((".", .[20912044]) mod 10000) = 0) 
 (((".", .[20912044]) div 10000) = ([988510003] div 10000)))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 209, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',209,2,20912001,1) ;

CALL DOCLOCK_IMPORT('   /(2)',0,209,2,0,11,0,'((32,39,3)=0)  ((32,27,3) <> 1)',0,3,'   /  .  ,      \ ,     \.',0,'    ',null,'[984110044] = 0',1) ;

CALL DOCLOCKFIELDS_DELETE('   /(2)', 209, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   /(2)',209,2,20912007,1) ;

CALL DOCLOCK_IMPORT('   /(1)',0,209,2,0,11,0,'((32,39,3)=0)  ((32,27,3) <> 1)',0,3,'   /  .       \ ,       \.',0,'      ',null,'([984110042] = 1)  ([984110041] = 1)  ([984110045] = 1)   ([984110043] = 1)',1) ;

CALL DOCLOCKFIELDS_DELETE('   /(1)', 209, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   /(1)',209,2,20912007,1) ;

CALL DOCLOCK_IMPORT('    ',0,209,2,0,11,0,'',0,3,'     ',0,'      ',null,'((.[20011012] = 0)  ([986810009] = 1)) 
((.[20011012] = 1)  ([986810008] = 1)) 
((.[20011012] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 209, 2, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',209,2,20912017,1) ;

CALL DOCLOCK_IMPORT('      ',0,210,2,0,11,0,'[21010005] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[21012020] = 0)  (.[21012021] = [988410026]))

(([988410022] = 0)  (.[21012017] = 0)  (.[21012017] = [988410022]))

(([988410023] = 0)  (.[21012018] = 0)  (.[21012019] = [988410024]))

(([988410018] = 0)  (.[21012013] = 0)  (.[21012014] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 210, 2, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',210,2,21012045,1) ;

CALL DOCLOCK_IMPORT('    ',0,210,2,0,11,0,'',0,3,'     ',0,'      ',null,'((.[20001012] = 0)  ([986810009] = 1)) 
((.[20001012] = 1)  ([986810008] = 1)) 
((.[20001012] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 210, 2, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',210,2,21012015,1) ;

CALL DOCLOCK_IMPORT('   ',0,211,0,0,9,0,'([21110011])?(([21111034])=0):1',0,3,'        ',0,'        ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 211, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',211,0,21110003,1) ;

CALL DOCLOCK_IMPORT('   ',0,211,0,0,11,0,'',0,1,'    ',0,'         ',null,'([984110044]=1)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 211, 0, 0, 1) ;

--  "\  "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',211,0,21110010,1) ;

CALL DOCLOCK_IMPORT('  /   / ',0,211,2,0,11,0,'[21110010] > 0',0,3,'        / ,   .  /   ,    ,      ,   .',0,'        ',null,'[984110018]=("_.",.[21110010])
 [984110021]=.[21110010]',1) ;

CALL DOCLOCKFIELDS_DELETE('  /   / ', 211, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  /   / ',211,2,21112006,1) ;

CALL DOCLOCK_IMPORT('      ',0,211,2,0,11,0,'[21112003] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[21112031] = 0)  (.[21112019] = [988410026]))

(([988410022] = 0)  (.[21112017] = 0)  (.[21112017] = [988410022]))

(([988410023] = 0)  (.[21112030] = 0)  (.[21112018] = [988410024]))

(([988410018] = 0)  (.[21112032] = 0)  (.[21112015] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 211, 2, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('      ',211,2,21112028,1) ;

CALL DOCLOCK_IMPORT('   ',0,211,2,0,11,0,'[21112037] <> 0',0,1,'       ,      ',0,'         ',null,'((".", .[21112037]) = 0) 
((".", .[21112037]) = [988510003]) 
((((".", .[21112037]) mod 100) = 0) 
 (((".", .[21112037]) div 100) = ([988510003] div 100))) 
((((".", .[21112037]) mod 10000) = 0) 
 (((".", .[21112037]) div 10000) = ([988510003] div 10000)))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 211, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',211,2,21112004,1) ;

CALL DOCLOCK_IMPORT('   ',0,211,2,0,11,0,'("_.",[21112006])   ("_.",[21112006])',0,1,' (   , , )          . ',0,'         ',null,'(("_...",.[21112006]) between 10000  10499)

(((".",[988910008]) between 10100  10199)

([988910008] = ("_.",.[21112006]))
 ((("_.",.[21112006])<>0)
      (("_.",.[21112006])=0)
     ((".",[988910008])= ("_.",.[21112006])))
)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 211, 2, 0, 1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',211,2,21112029,1) ;

CALL DOCLOCK_IMPORT('     ,',0,211,2,0,11,0,'("_._",[21112006])   ("_._",[21112006])   ("_.",[21112006])',0,3,',        =- \,  =. ',0,'         ',null,'([988910008] = ("_.",.[21112006])
 ((".",[988910008]) between 10100  10199))
   
(( ("_._",.[21112006])
 ([988910010] = 0))

(("_._",.[21112006])
 ([988910010] <> 0)))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 211, 2, 0, 1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',211,2,21112029,1) ;

CALL DOCLOCK_IMPORT('    ',0,211,2,0,11,0,'',0,3,'     ',0,'      ',null,'((.[20001012] = 0)  ([986810009] = 1)) 
((.[20001012] = 1)  ([986810008] = 1)) 
((.[20001012] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 211, 2, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',211,2,21112016,1) ;

CALL DOCLOCK_IMPORT('  ',32768,211,2,0,3,0,'[21112003] = 1',0,1,'  "  "   ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 211, 2, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',211,2,21112002,1) ;

CALL DOCLOCK_IMPORT('   ',32768,211,2,0,3,0,'((("..",[21110019]) between 10800  10999)    (("_...",[21112006]) between 10800  10999)     ((("_...",[21112006]) between 10000  10499)      (=204) ))',0,1,'  " "  \   -   01.08.00-01.09.99  01.01.00-01.04.99 ( ,  ,  .(.) ).           ,',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 211, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',211,2,21112033,1) ;

CALL DOCLOCK_IMPORT('    / ,',0,211,2,0,11,0,'',0,1,'    ',0,'         ',null,'([984110044]=1)',1) ;

CALL DOCLOCKFIELDS_DELETE('    / ,', 211, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    / ,',211,2,21112006,1) ;

CALL DOCLOCK_IMPORT('     ,',0,211,2,0,11,0,'',0,1,'          "",   -   ""',0,'       ""          ""  ',null,'((.[21112003]=2)  ([988410016] = 0)) 

((.[21112003]=0)  ([988410016] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 211, 2, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',211,2,21112028,1) ;

CALL DOCLOCK_IMPORT('  ',32768,211,2,0,3,0,'',0,1,'  ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 211, 2, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ',211,2,21112023,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',211,2,21112021,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',211,2,21112014,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',211,2,21112013,1) ;

CALL DOCLOCK_IMPORT('   ',0,212,2,0,11,0,'[21212038] <> 0',0,1,'       ,      ',0,'         ',null,'((".", .[21212038]) = 0) 
((".", .[21212038]) = [988510003]) 
((((".", .[21212038]) mod 100) = 0) 
 (((".", .[21212038]) div 100) = ([988510003] div 100))) 
((((".", .[21212038]) mod 10000) = 0) 
 (((".", .[21212038]) div 10000) = ([988510003] div 10000)))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 212, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',212,2,21212004,1) ;

CALL DOCLOCK_IMPORT('  /  ',0,212,2,0,11,0,'(("..",[21210019]) between 10000 and 10499)',0,3,'  - \. - \     ',0,'- \     ',null,'([984110018]=.[21210019])',1) ;

CALL DOCLOCKFIELDS_DELETE('  /  ', 212, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  /  ',212,2,21212006,1) ;

CALL DOCLOCK_IMPORT('    ',0,212,2,0,11,0,'',0,3,'     ',0,'      ',null,'((.[20001012] = 0)  ([986810009] = 1)) 
((.[20001012] = 1)  ([986810008] = 1)) 
((.[20001012] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 212, 2, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',212,2,21212016,1) ;

CALL DOCLOCK_IMPORT('     , ',0,212,2,0,11,0,'("_._",[21212006])   ("_._",[21212006])   ("_.",[21212006])',0,1,' \ ,         2,3,4,7,8; ',0,'         ',null,'(("_._",.[21212006])
 (([984910001] between 2  4)([984910001] between 7  8)))

(("_.",.[21212006])
 ([984910001] between 7  8))

(("_._",.[21212006])
 (([984910001] between 5  6)([984910001] = 9)))',1) ;

CALL DOCLOCKFIELDS_DELETE('     , ', 212, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     , ',212,2,21212020,1) ;

CALL DOCLOCK_IMPORT('    / ,  ',0,212,2,0,11,0,'((".",))',0,3,'  \   \ ,, \      ".  , "',0,'    / , , /       ',null,'([984110041]=0)([984110046]=0)',1) ;

CALL DOCLOCKFIELDS_DELETE('    / ,  ', 212, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    / ,  ',212,2,21212006,1) ;

CALL DOCLOCK_IMPORT('  ',32768,212,2,0,3,0,'[21212003] = 1',0,1,'  "  "   ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 212, 2, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',212,2,21212002,1) ;

CALL DOCLOCK_IMPORT('   ',32768,212,2,0,3,0,'((("..",[21210019]) between 10800  10999)    (("_...",[21212006]) between 10800  10999)     ((("_...",[21212006]) between 10000  10499)      (=204) ))',0,1,'  " "  \   -   01.08.00-01.09.99  01.01.00-01.04.99 ( ,  ,  .(.) ).           ,',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 212, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',212,2,21212033,1) ;

CALL DOCLOCK_IMPORT('   /',0,212,2,0,11,0,'',0,1,'   /  . ',0,'      / , ,  / ,   / ',null,'([984110041] <> 0)  ([984110045] <> 0)  ([984110046] <> 0)',1) ;

CALL DOCLOCKFIELDS_DELETE('   /', 212, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   /',212,2,21212006,1) ;

CALL DOCLOCK_IMPORT('   /',0,212,2,0,11,0,'',0,1,'  - \. -          01.08.00  01.10.99',0,'-       ()   ()',null,'(("..",[984110031]) between 10800 and 11099)',1) ;

CALL DOCLOCKFIELDS_DELETE('   /', 212, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   /',212,2,21212006,1) ;

CALL DOCLOCK_IMPORT('  ',32768,212,2,0,3,0,'',0,1,'  ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 212, 2, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ',212,2,21212023,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',212,2,21212021,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',212,2,21212014,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',212,2,21212013,1) ;

CALL DOCLOCK_IMPORT('     (2)',0,300,0,0,11,0,'(<>323)  (("/._",[30010021]) = 0)    ((("/.",[30010021]) <> 0)  (30,44,3) = 1)   (("/._",[30010021]) = 0)  (("/._",[30010021]) = 0)',0,1,'          () ,   , ,  /c  /c   ',0,'         ", "  " , " ',null,'(([984110041] = 1)  ([984110045] = 1)  ([984110046]=1)) 
( ([984110044] = 0)  ([984110042] = 0)  ([984110043] = 0) )',1) ;

CALL DOCLOCKFIELDS_DELETE('     (2)', 300, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     (2)',300,0,30010008,1) ;

CALL DOCLOCK_IMPORT('     ',0,300,0,0,11,0,'(("/.",[30010021]) = 0) (("/.",[30010021])=0)',0,1,'            ,   /c   ", "  " , "  ""',0,'     , ,          ',null,'(([984110042] = 1)  ([984110044] = 1)  ([984110043] = 1)) 
( ([984110044] = 0)  ([984110042] = 0)  ([984110041] = 0)  
    ([984110045] = 0)  ([984110046] = 0)  ([984110043] = 0) )',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 300, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',300,0,30010008,1) ;

CALL DOCLOCK_IMPORT('     ,',0,300,1,0,11,0,'',0,1,'  ,      ,  =0 (    )        "",   -   ""',0,'       ""          ""  ',null,'(((.[30011019]=2)  
((.[30011019]=1)  (("_..",.[30011041])=0)))  
 ([988410016] = 0))

((.[30011019]=0)  ([988410016] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 300, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',300,1,30011018,1) ;

CALL DOCLOCK_IMPORT('      ',0,300,1,0,11,0,'[30011019] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[30011026] = 0)  (.[30011033] = [988410026]))

(([988410022] = 0)  (.[30011029] = 0)  (.[30011029] = [988410022]))

(([988410023] = 0)  (.[30011028] = 0)  (.[30011032] = [988410024]))

(([988410018] = 0)  (.[30011027] = 0)  (.[30011031] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 300, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('      ',300,1,30011018,1) ;

CALL DOCLOCK_IMPORT('     ',0,300,1,0,11,0,'([30011019] = 2)   ((( <> 305)  ( <> 302))    (("_..",[30010008]) between 010800 and 011099))',0,3,'          ,    / , ()         /.      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[30011025] = 0)  (.[30011034] = [988410008])
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[30011025]))
   (((".",[988410006])=(".",.[30011025]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[30011025])))
 (((".", .[30011025]) div 100000) between 218 and 219) 
 (((".", .[30011025]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 300, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',300,1,30011018,1) ;

CALL DOCLOCK_IMPORT('  ',32768,300,1,0,3,0,'([30011019] = 1) (("_..",[30011041])=0)',0,1,'  "  "   ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 300, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',300,1,30011020,1) ;

CALL DOCLOCK_IMPORT('   ',32768,300,1,0,3,0,'((("_...",[30010008]) between 10800  11099)    (("_...",[30010008]) between 10000  10499)   ( in(0323,0324)))',0,1,'  " "      -   01.08.00-01.10.99  01.01.00-01.04.99 ( ,  ,  () ,   ()).    3.23,3.24()',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 300, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',300,1,30011022,1) ;

CALL DOCLOCK_IMPORT('    ',0,300,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[30011019] = 0)  ([986810009] = 1)) 
((.[30011019] = 1)  ([986810008] = 1)) 
((.[30011019] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 300, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',300,1,30011030,1) ;

CALL DOCLOCK_IMPORT('    .  ',0,301,1,0,11,0,'[30110110] = 2',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[30111122] = 0)  (.[30111130] = [988410008])
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[30111122]))
   (((".",[988410006])=(".",.[30111122]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[30111122])))
 (((".", .[30111122]) div 100000) between 218 and 219)
 (((".", .[30111122]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('    .  ', 301, 1, 0, 1) ;

--  "   ."
CALL DOCLOCKFIELDS_INSERTFIELD('    .  ',301,1,30111136,1) ;

CALL DOCLOCK_IMPORT('    .   ',0,301,1,0,11,0,'[30111051] = 0',0,1,'         , , , .    ,         ,      ',0,'        ',null,'(([988410025] = 0)  (.[30111020] = 0)  (.[30111143] = [988410026]))

(([988410022] = 0)  (.[30111018] = 0)  (.[30111018] = [988410022]))

(([988410023] = 0)  (.[30111016] = 0)  (.[30111142] = [988410024]))

(([988410018] = 0)  (.[30111019] = 0)  (.[30111140] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('    .   ', 301, 1, 0, 1) ;

--  "   ."
CALL DOCLOCKFIELDS_INSERTFIELD('    .   ',301,1,30111136,1) ;

CALL DOCLOCK_IMPORT('  ',32768,301,1,0,3,0,'([30110110] = 1) (("_..",[30111119])=0)',0,1,'  "   .", "   ."   ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 301, 1, 0, 1) ;

--  "   -"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',301,1,30111138,1) ;

--  "   ."
CALL DOCLOCKFIELDS_INSERTFIELD('  ',301,1,30111137,1) ;

CALL DOCLOCK_IMPORT('    ',0,301,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[30011019] = 0)  ([986810009] = 1)) 
((.[30011019] = 1)  ([986810008] = 1)) 
((.[30011019] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 301, 1, 0, 1) ;

--  " -( -)"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',301,1,30111017,1) ;

CALL DOCLOCK_IMPORT('   ',32768,306,0,0,3,0,'([30610152])',0,3,'  " "  ,     ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 306, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',306,0,30610010,1) ;

CALL DOCLOCK_IMPORT('     ',0,307,0,0,9,0,'([30710001] = 1)  (([30711018]) = 0)',0,1,'          .     .   ,         .',0,'  ,      ( )',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 307, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('     ',307,0,30710001,1) ;

CALL DOCLOCK_IMPORT('     (,)',0,308,1,0,11,0,'',0,1,'          "",   -   ""',0,'       ""          ""  ',null,'(((.[30811007]=2)
((.[30811007]=1)  (("_..",.[30811094])=0)))
 ([988410016] = 0))

((.[30811007]=0)  ([988410016] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('     (,)', 308, 1, 0, 1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('     (,)',308,1,30811063,1) ;

CALL DOCLOCK_IMPORT('    .   ',0,308,1,0,11,0,'[30811003] = 0',0,1,'         , , , .    ,         ,      ',0,'        ',null,'(([988410025] = 0)  (.[30811073] = 0)  (.[30811074] = [988410026]))

(([988410022] = 0)  (.[30811070] = 0)  (.[30811070] = [988410022]))

(([988410023] = 0)  (.[30811071] = 0)  (.[30811072] = [988410024]))

(([988410018] = 0)  (.[30811067] = 0)  (.[30811068] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('    .   ', 308, 1, 0, 1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('    .   ',308,1,30811063,1) ;

CALL DOCLOCK_IMPORT('    /',0,308,1,0,11,0,'[30811003] = 1',0,3,'                ',0,'             ',null,'((.[30810013] = 0)  ([985210006] = -1)) 
((.[30810013] = 1)  ([985210006] = -1)) 
((.[30810013] = 2)  ([985210006] = 1)) 
((.[30810013] = 3)  ([985210006] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    /', 308, 1, 0, 1) ;

--  " ( )"
CALL DOCLOCKFIELDS_INSERTFIELD('    /',308,1,30811098,1) ;

CALL DOCLOCK_IMPORT('    .  ',0,308,1,0,11,0,'[30811003] = 2',0,1,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[30811019] = 0)  (.[30811093] = [988410008]) 
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[30811019]))
   (((".",[988410006])=(".",.[30811019]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[30811019])))
 (((".", .[30811019]) div 100000) between 218 and 219)
 (((".", .[30811019]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('    .  ', 308, 1, 0, 1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('    .  ',308,1,30811063,1) ;

CALL DOCLOCK_IMPORT('    /',0,308,1,0,11,0,'[30811007] = 1',0,3,'                ',0,'             ',null,'((.[30810013] = 0)  ([985210006] = 1)) 
((.[30810013] = 1)  ([985210006] = -1)) 
((.[30810013] = 2)  ([985210006] = 1)) 
((.[30810013] = 3)  ([985210006] = -1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    /', 308, 1, 0, 1) ;

--  " ( )"
CALL DOCLOCKFIELDS_INSERTFIELD('    /',308,1,30811094,1) ;

CALL DOCLOCK_IMPORT('   ',32768,308,1,0,3,0,'((("_...", [30810064]) between 10800  11099)     (("_...",[30810064]) between 10000  10499))',0,1,'  " "      -   01.08.00-01.10.99  01.01.00-01.04.99 ( ,  ,  () ,   ()).    3.23,3.24()',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 308, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',308,1,30811082,1) ;

CALL DOCLOCK_IMPORT('    ',0,308,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[30810070] = 0)  ([986810009] = 1)) 
((.[30810070] = 1)  ([986810008] = 1)) 
((.[30810070] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 308, 1, 0, 1) ;

--  " ( )"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',308,1,30811069,1) ;

CALL DOCLOCK_IMPORT('   ',32768,323,-1,0,3,0,' (".", )',0,3,'  " "  ,     .          , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 323, -1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',323,-1,32311162,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',323,-1,32311161,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',323,-1,32311160,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',323,-1,32311159,1) ;

CALL DOCLOCK_IMPORT('   (2)',32768,323,-1,0,3,0,' ((([32311149] is not null)   (([32311143],(30,45,8),"9.9.9")))    ([32311143] between 500 and 599)     (([32311139] is not null)  (tonumber([32311140],1) <> 0))   )',0,1,'  " "  ,     .     ,            ( ),      , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   (2)', 323, -1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',323,-1,32311162,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',323,-1,32311161,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',323,-1,32311160,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',323,-1,32311159,1) ;

CALL DOCLOCK_IMPORT('      ',0,323,0,0,11,0,'((30,41,3) = 1)  (("/._",[32310052]) = 0)    ((("/.",[32310052]) <> 0)  (30,44,3) = 1)   (("/._",[32310052]) = 0)  (("/._",[32310052]) = 0)',0,1,'          () ,   , ,  /c  /c   ',0,'         ", "  " , " ',null,'(([984110041] = 1)  ([984110045] = 1)  ([984110046]=1)) 
( ([984110044] = 0)  ([984110042] = 0)  ([984110043] = 0) )',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 323, 0, 0, 1) ;

--  "/ . (.)"
CALL DOCLOCKFIELDS_INSERTFIELD('      ',323,0,32310138,1) ;

CALL DOCLOCK_IMPORT('   ',0,323,1,0,11,0,'[32311151] <> 0',0,1,'       ,      ',0,'         ',null,'((".", .[32311151]) = 0) 
((".", .[32311151]) = [988510003]) 
((((".", .[32311151]) mod 100) = 0) 
 (((".", .[32311151]) div 100) = ([988510003] div 100))) 
((((".", .[32311151]) mod 10000) = 0) 
 (((".", .[32311151]) div 10000) = ([988510003] div 10000)))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 323, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',323,1,32311137,1) ;

CALL DOCLOCK_IMPORT('     (2)',0,323,1,0,11,0,'((30,41,3) = 0)  (("/._",[32310052]) = 0)    ((("/.",[32310052]) <> 0)  (30,44,3) = 1)   (("/._",[32310052]) = 0)  (("/._",[32310052]) = 0)',0,1,'          () ,   , ,  /c  /c   ',0,'         ", "  " , " ',null,'(([984110041] = 1)  ([984110045] = 1)  ([984110046]=1)) 
( ([984110044] = 0)  ([984110042] = 0)  ([984110043] = 0) )',1) ;

CALL DOCLOCKFIELDS_DELETE('     (2)', 323, 1, 0, 1) ;

--  "/ "
CALL DOCLOCKFIELDS_INSERTFIELD('     (2)',323,1,32311012,1) ;

CALL DOCLOCK_IMPORT('   ',32768,323,1,0,3,0,'((("_...", [32311012]) between 10800  11099)   (("_...",[32311012]) between 10000  10499))',0,1,'  " "      -   01.08.00-01.10.99  01.01.00-01.04.99 ( ,  ,  () ,   ()).',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 323, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',323,1,32311150,1) ;

CALL DOCLOCK_IMPORT('   ',0,323,1,0,11,0,'',0,1,'        - \.',0,'        ',null,'(([960110035] between 010800 and 010999)
([960110021]=("_.",.[32311012])))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 323, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',323,1,32311163,1) ;

CALL DOCLOCK_IMPORT('   ',32768,324,-1,0,3,0,' (".", )',0,3,'  " "  ,     .          , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 324, -1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',324,-1,32411203,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',324,-1,32411202,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',324,-1,32411201,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',324,-1,32411200,1) ;

CALL DOCLOCK_IMPORT('   (2)',32768,324,-1,0,3,0,'((([32411190] is not null)   (([32411183],(30,45,8),"9.9.9")))    ([32411183] between 500 and 599)     (([32411178] is not null)  (tonumber([32411179],1) <> 0))   )',0,1,'  " "  ,     .     ,            ( ),      , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   (2)', 324, -1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',324,-1,32411203,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',324,-1,32411202,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',324,-1,32411201,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',324,-1,32411200,1) ;

CALL DOCLOCK_IMPORT('   ',32768,324,-1,0,3,0,'((("_...",[32411026]) between 10800  11099)    (("_...",[32411026]) between 10000  10499) )',0,1,'  " "      -   01.08.00-01.10.99  01.01.00-01.04.99 ( ,  ,  () ,   ()).',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 324, -1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',324,-1,32411191,1) ;

CALL DOCLOCK_IMPORT('   ',0,324,1,0,11,0,'[32411192] <> 0',0,1,'       ,      ',0,'         ',null,'((".", .[32411192]) = 0) 
((".", .[32411192]) = [988510003]) 
((((".", .[32411192]) mod 100) = 0) 
 (((".", .[32411192]) div 100) = ([988510003] div 100))) 
((((".", .[32411192]) mod 10000) = 0) 
 (((".", .[32411192]) div 10000) = ([988510003] div 10000)))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 324, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',324,1,32411175,1) ;

CALL DOCLOCK_IMPORT('   ',0,324,1,0,11,0,'',0,1,'        - \.',0,'        ',null,'(([960110035] between 010800 and 010999)
([960110021]=("_.",.[32411026])))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 324, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',324,1,32411204,1) ;

CALL DOCLOCK_IMPORT('      ',0,801,1,0,11,0,'[80111052] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[80111026] = 0)  (.[80111060] = [988410026]))

(([988410022] = 0)  (.[80111024] = 0)  (.[80111024] = [988410022]))

(([988410023] = 0)  (.[80111025] = 0)  (.[80111059] = [988410024]))

(([988410018] = 0)  (.[80111022] = 0)  (.[80111058] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 801, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',801,1,80111055,1) ;

CALL DOCLOCK_IMPORT('    ',0,801,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[80111052] = 0)  ([986810009] = 1)) 
((.[80111052] = 1)  ([986810008] = 1)) 
((.[80111052] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 801, 1, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',801,1,80111023,1) ;

CALL DOCLOCK_IMPORT('     ',0,900,1,0,11,0,'([90011001] = 2) (([90011001] = 1) ("_..",[90011006])=0)',0,3,'  ,      ,  =0 (    )           ""',0,'       ""   ',null,'[988410016] = 0',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 900, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',900,1,90011002,1) ;

CALL DOCLOCK_IMPORT('     ',0,900,1,0,11,0,'([90011001] = 2)  (( <> 903)    (("_..",[90011008]) between 010800 and 011099))',0,3,'          ,  / , ()   (09.03)   .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[90011004] = 0)  (.[90011005] = [988410008]) 
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[90011004]))
   (((".",[988410006])=(".",.[90011004]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[90011004])))
 (((".", .[90011004]) div 100000) between 218 and 219) 
 (((".", .[90011004]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 900, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',900,1,90011002,1) ;

CALL DOCLOCK_IMPORT('  ',32768,900,1,0,3,0,'([90011001] = 1) (("_..",[90011006])=0)',0,1,'  "  "   ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 900, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',900,1,90011003,1) ;

CALL DOCLOCK_IMPORT('  ',131072,903,1,0,7,0,'([90311072])',1,3,' ,      ',1,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 903, 1, 0, 1) ;

CALL DOCLOCK_IMPORT('    ',0,903,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[90311035] = 0)  ([986810009] = 1)) 
((.[90311035] = 1)  ([986810008] = 1)) 
((.[90311035] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 903, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',903,1,90311030,1) ;

CALL DOCLOCK_IMPORT('    ',0,1201,0,0,11,0,'',0,3,'     ',0,'      ',null,'((.[120110017] = 0)  ([986810009] = 1)) 
((.[120110017] = 1)  ([986810008] = 1)) 
((.[120110017] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1201, 0, 0, 1) ;

--  "( )"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1201,0,120110009,1) ;

CALL DOCLOCK_IMPORT('  .   ',0,1201,0,0,11,0,'',0,3,'     ',0,'      ',null,'((.[120110031] = 0)  ([986810009] = 1)) 
((.[120110031] = 1)  ([986810008] = 1)) 
((.[120110031] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('  .   ', 1201, 0, 0, 1) ;

--  "( )"
CALL DOCLOCKFIELDS_INSERTFIELD('  .   ',1201,0,120110023,1) ;

CALL DOCLOCK_IMPORT('       ',0,1601,0,0,10,0,'((30,37,3)=0) ([160110002] is null) ([160111018] is not null) ([160110051] is not null)',0,3,'        ',0,'    ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('       ', 1601, 0, 0, 1) ;

--  " /"
CALL DOCLOCKFIELDS_INSERTFIELD('       ',1601,0,160110002,1) ;

CALL DOCLOCK_IMPORT('       ',0,1601,0,0,10,0,'((30,37,3)=1) ([160110002] is null) ([160111018] is not null) ([160110051] is not null)',0,3,'        ',0,'   ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('       ', 1601, 0, 0, 1) ;

--  " /"
CALL DOCLOCKFIELDS_INSERTFIELD('       ',1601,0,160110002,1) ;

CALL DOCLOCK_IMPORT('      ',0,1601,1,0,11,0,'',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[160111021] = 0)  (.[160111076] = [988410026]))

(([988410022] = 0)  (.[160111022] = 0)  (.[160111022] = [988410022]))

(([988410023] = 0)  (.[160111024] = 0)  (.[160111075] = [988410024]))

(([988410018] = 0)  (.[160111023] = 0)  (.[160111074] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 1601, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',1601,1,160111072,1) ;

CALL DOCLOCK_IMPORT('   ',0,1601,1,0,11,0,'("_.",[160111019])   ("_.",[160111019])',0,1,' (   , , )          .     \   .   \      .',0,'         ',null,'(("_...",.[160111019]) between 10000  10499)

(((".",[988910008]) between 10100  10199)

([988910008] = ("_.",.[160111019]))
 ((("_.",.[160111019])<>0)
      (("_.",.[160111019])=0)
     ((".",[988910008])= ("_.",.[160111019])))
)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 1601, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',1601,1,160111078,1) ;

CALL DOCLOCK_IMPORT('     ,',0,1601,1,0,11,0,'("_._",[160111019])   ("_._",[160111019])   ("_.",[160111019])',0,3,',        =- \,  =. ',0,'         ',null,'([988910008] = ("_.",.[160111019])     
 (((".",[988910008]) between 10100  10199)
 ((".",[988910008]) between 11000  11099)))
   
(( ("_._",.[160111019])
 ([988910010] = 0))

(("_._",.[160111019])
 ([988910010] <> 0)))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 1601, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',1601,1,160111078,1) ;

CALL DOCLOCK_IMPORT('   ',32768,1601,1,0,3,0,'(("_...",[160111019]) = 10500)',0,1,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 1601, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',1601,1,160111077,1) ;

CALL DOCLOCK_IMPORT('    ',0,1601,1,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1601, 1, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1601,1,160111025,1) ;

CALL DOCLOCK_IMPORT('    ',0,1809,0,0,11,0,'([180910002] is null)',0,3,'     ',0,'      ',null,'((.[180910002] = 0)  ([986810009] = 1))    
((.[180910002] = 1)  ([986810008] = 1)) 
((.[180910002] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1809, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1809,0,180910001,1) ;

CALL DOCLOCK_IMPORT('  ',0,1816,0,0,9,0,'([181610099] is null)  ((30,35,3) = 0)  ((30,15,3) = 1)   (   ((".",[181610099]) = 1)    ((".",[181610099]) = 0)       ((".",[181610099]) <> 0)     ((".",[181610099])=[181610024]) )',0,3,'  ',0,'          ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 1816, 0, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',1816,0,181610099,1) ;

CALL DOCLOCK_IMPORT('    ',0,1816,0,0,11,0,'',0,3,'     ',0,'      ',null,'((.[181610098] = 0)  ([986810009] = 1)) 
((.[181610098] = 1)  ([986810008] = 1)) 
((.[181610098] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1816, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1816,0,181610007,1) ;

CALL DOCLOCK_IMPORT(' ',2,1816,0,0,8,2,'',1,1,'     .       .',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 1816, 0, 0, 1) ;

CALL DOCLOCK_IMPORT('  ',0,1816,1,0,9,0,'([181611100] is null)  ((30,35,3) = 0)  ((30,15,3) = 1)   (   ((".",[181611100]) = 1)    ((".",[181611100]) = 0)       ((".",[181611100]) <> 0)     ((".",[181611100])=[181611095]) )',0,3,'  ',0,'          ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 1816, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',1816,1,181611100,1) ;

CALL DOCLOCK_IMPORT('    ',0,1816,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[181611101] = 0)  ([986810009] = 1)) 
((.[181611101] = 1)  ([986810008] = 1)) 
((.[181611101] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1816, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1816,1,181611070,1) ;

CALL DOCLOCK_IMPORT('   ',0,1900,1,0,11,0,'[190011034] <> 0',0,1,'       ,      ',0,'         ',null,'((".", .[190011034]) = 0) 
((".", .[190011034]) = [988510003]) 
((((".", .[190011034]) mod 100) = 0) 
 (((".", .[190011034]) div 100) = ([988510003] div 100))) 
((((".", .[190011034]) mod 10000) = 0) 
 (((".", .[190011034]) div 10000) = ([988510003] div 10000)))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 1900, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',1900,1,190011035,1) ;

CALL DOCLOCK_IMPORT('    ',0,1900,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[190011001] = 0)  ([986810009] = 1)) 
((.[190011001] = 1)  ([986810008] = 1)) 
((.[190011001] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1900, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1900,1,190011036,1) ;

CALL DOCLOCK_IMPORT('    ',0,2201,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[220111061] = 0)  ([986810009] = 1)) 
((.[220111061] = 1)  ([986810008] = 1)) 
((.[220111061] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2201, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2201,1,220111080,1) ;

CALL DOCLOCK_IMPORT('     ',0,2201,1,0,11,0,'',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[220111046] = 0)  (.[220111012] = [988410008])
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[220111046]))
   (((".",[988410006])=(".",.[220111046]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[220111046])))
 (((".", .[220111046]) div 100000) between 218 and 219) 
 (((".", .[220111046]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 2201, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',2201,1,220111064,1) ;

CALL DOCLOCK_IMPORT('  ',0,2501,0,0,9,0,'[250110057] <= [250110054]',0,0,'',0,'              ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2501, 0, 0, 1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2501,0,250110054,1) ;

CALL DOCLOCK_IMPORT('  ',0,2501,0,0,9,0,'([250110057] <= [250110054])  ([250110054] is null)',0,0,'',0,'              ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2501, 0, 0, 1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2501,0,250110057,1) ;

CALL DOCLOCK_IMPORT('    ',0,2501,2,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2501, 2, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2501,2,250112004,2) ;

CALL DOCLOCK_IMPORT('  ',0,2502,0,0,9,0,'[250210038] <= [250210035]',0,0,'',0,'              ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2502, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2502,0,250210035,1) ;

CALL DOCLOCK_IMPORT('  ',0,2502,0,0,9,0,'([250210038] <= [250210035])  ([250210035] is null)',0,0,'',0,'              ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2502, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2502,0,250210038,1) ;

CALL DOCLOCK_IMPORT('   ',0,2502,2,0,11,0,'("_.",[250212035])   ("_.",[250212035])',0,1,' (   , , )          .     \   .   \      .',0,'         ',null,'(("_...",.[250212035]) between 10000  10499)

(((".",[988910008]) between 10100  10199)

([988910008] = ("_.",.[250212035]))
 ((("_.",.[250212035])<>0)
      (("_.",.[250212035])=0)
     ((".",[988910008])= ("_.",.[250212035])))
)',2) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2502, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',2502,2,250212056,2) ;

CALL DOCLOCK_IMPORT('     ,',0,2502,2,0,11,0,'("_._",[250212035])   ("_._",[250212035])   ("_.",[250212035])',0,3,',        =- \,  =. ',0,'         ',null,'([988910008] = ("_.",.[250212035])
 (((".",[988910008]) between 10100  10199)
 ((".",[988910008]) between 11000  11099)))
   
(( ("_._",.[250212035])
 ([988910010] = 0))

(("_._",.[250212035])
 ([988910010] <> 0)))',2) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 2502, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',2502,2,250212056,2) ;

CALL DOCLOCK_IMPORT('    ',0,2502,2,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2502, 2, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2502,2,250212029,2) ;

CALL DOCLOCK_IMPORT('   ',0,2503,2,0,11,0,'("_.",[250312005])   ("_.",[250312005])',0,1,' (   , , )          .     \   .   \      .',0,'         ',null,'(("_...",.[250312005]) between 10000  10499)

(((".",[988910008]) between 10100  10199)

([988910008] = ("_.",.[250312005]))
 ((("_.",.[250312005])<>0)
      (("_.",.[250312005])=0)
     ((".",[988910008])= ("_.",.[250312005])))
)',2) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2503, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',2503,2,250312051,2) ;

CALL DOCLOCK_IMPORT('     ,',0,2503,2,0,11,0,'("_._",[250312005])   ("_._",[250312005])   ("_.",[250312005])',0,3,',        =- \,  =. ',0,'         ',null,'([988910008] = ("_.",.[250312005])
 (((".",[988910008]) between 10100  10199)
 ((".",[988910008]) between 11000  11099)))
   
(( ("_._",.[250312005])
 ([988910010] = 0))

(("_._",.[250312005])
 ([988910010] <> 0)))',2) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 2503, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',2503,2,250312051,2) ;

CALL DOCLOCK_IMPORT('    ',0,2503,2,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2503, 2, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2503,2,250312011,2) ;

CALL DOCLOCK_IMPORT('  ',0,2504,0,0,9,0,'[250410086] <= [250410083]',0,0,'',0,'              ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2504, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2504,0,250410083,1) ;

CALL DOCLOCK_IMPORT('  ',0,2504,0,0,9,0,'([250410086] <= [250410083])  ([250410083] is null)',0,0,'',0,'              ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2504, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2504,0,250410086,1) ;

CALL DOCLOCK_IMPORT('   ',0,2504,2,0,11,0,'("_.",[250412043])   ("_.",[250412043])',0,1,' (   , , )          .     \   .   \      .',0,'         ',null,'(("_...",.[250412043]) between 10000  10499)

(((".",[988910008]) between 10100  10199)

([988910008] = ("_.",.[250412043]))
 ((("_.",.[250412043])<>0)
      (("_.",.[250412043])=0)
     ((".",[988910008])= ("_.",.[250412043])))
)',2) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2504, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',2504,2,250412055,2) ;

CALL DOCLOCK_IMPORT('     ,',0,2504,2,0,11,0,'("_._",[250412043])   ("_._",[250412043])   ("_.",[250412043])',0,3,',        =- \,  =. ',0,'         ',null,'([988910008] = ("_.",.[250412043])
 (((".",[988910008]) between 10100  10199)
 ((".",[988910008]) between 11000  11099)))
   
(( ("_._",.[250412043])
 ([988910010] = 0))

(("_._",.[250412043])
 ([988910010] <> 0)))',2) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 2504, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',2504,2,250412055,2) ;

CALL DOCLOCK_IMPORT('    ',0,2504,2,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2504, 2, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2504,2,250412036,2) ;

CALL DOCLOCK_IMPORT('    ',0,2504,5,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2504, 5, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2504,5,250415010,2) ;

CALL DOCLOCK_IMPORT('    ',0,3001,1,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 3001, 1, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',3001,1,300111041,2) ;

CALL DOCLOCK_IMPORT('    ',0,3006,1,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 3006, 1, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',3006,1,300611008,2) ;

CALL DOCLOCK_IMPORT(' ',32768,4901,0,0,3,0,'[490110012] = 0',0,3,'',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 4901, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ',4901,0,490110003,1) ;

CALL DOCLOCK_IMPORT('  ',2,5201,-1,0,8,2,'',1,1,'     ,   .       .',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5201, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('  ',0,5201,0,0,9,0,'(([520110052] = 4)    (("_._",[520110033])   ("_._",[520110033])   ("_.",[520110033])))   (([520110052] = 3)    (("_.",[520110033])  ("_.",[520110033])   ))   (([520110052] = 0)  ([520110052] = 1)  ([520110052] = 2))',0,3,'',0,'       ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5201, 0, 0, 1) ;

--  " . "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,0,520110052,1) ;

CALL DOCLOCK_IMPORT('      . ',0,5201,0,0,11,0,'([520110052] = 0)  ([520110052] = 3)',0,3,'',0,'   .       ", "  " , " ',null,'(([984110041] = 1)  ([984110045] = 1)  ([984110046]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      . ', 5201, 0, 0, 1) ;

--  "/  "
CALL DOCLOCKFIELDS_INSERTFIELD('      . ',5201,0,520110033,1) ;

CALL DOCLOCK_IMPORT('      . . ',0,5201,0,0,11,0,'([520110052] = 1)  ([520110052] = 4)',0,3,'',0,'   .   , ,          ',null,'(([984110042] = 1)  ([984110044]  = 1)  ([984110043] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('      . . ', 5201, 0, 0, 1) ;

--  "/  "
CALL DOCLOCKFIELDS_INSERTFIELD('      . . ',5201,0,520110033,1) ;

CALL DOCLOCK_IMPORT('    ',0,5201,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[520111071] = 0)  ([986810009] = 1)) 
((.[520111071] = 1)  ([986810008] = 1)) 
((.[520111071] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 5201, 1, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',5201,1,520111011,1) ;

CALL DOCLOCK_IMPORT('      ',0,5201,1,0,11,0,'[520111071] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[520111015] = 0)  (.[520111016] = [988410026]))

(([988410022] = 0)  (.[520111012] = 0)  (.[520111012] = [988410022]))

(([988410023] = 0)  (.[520111013] = 0)  (.[520111014] = [988410024]))

(([988410018] = 0)  (.[520111009] = 0)  (.[520111010] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 5201, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',5201,1,520111052,1) ;

CALL DOCLOCK_IMPORT('     ',0,5201,1,0,11,0,'[520111071] = 2',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[520111064] = 0)  ([988410008] = .[520111070]) 
   ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[520111064]))
   (((".",[988410006])=(".",.[520111064]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[520111064]))) 
(((".", .[520111064]) div 100000) between 218 and 219) 
(((".", .[520111064]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5201, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5201,1,520111052,1) ;

CALL DOCLOCK_IMPORT('   ',0,5201,1,0,11,0,'(("_.",[520111005])  ("_.",[520111005]))',0,1,' \    \        1,2,3',0,'         ',null,'[984910001] between 1  3',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 5201, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',5201,1,520111017,1) ;

CALL DOCLOCK_IMPORT('     , ',0,5201,1,0,11,0,'(("_._",[520111005])  ("_._",[520111005])  ("_.",[520111005]))',0,1,' \ ,         2,3,4,7,8;    \ ,       5,6,9;   \        7  8.',0,'         ',null,'(("_._",.[520111005])
 (([984910001] between 2  4)([984910001] between 7  8)))

(("_.",.[520111005])
 ([984910001] between 7  8))

(("_._",.[520111005])
 (([984910001] between 5  6)([984910001] = 9)))',1) ;

CALL DOCLOCKFIELDS_DELETE('     , ', 5201, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     , ',5201,1,520111017,1) ;

CALL DOCLOCK_IMPORT('  ',32768,5201,1,0,3,0,'[520111071]=2',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5201, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,1,520111019,1) ;

--  "  ( . -)"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,1,520111025,1) ;

--  " . "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,1,520111024,1) ;

CALL DOCLOCK_IMPORT('     , ',0,5201,1,0,11,0,'',0,3,'          "",   -   ""',0,'       ""          ""  ',null,'((.[520111071]=2)  ([988410016] = 0)) 

((.[520111071]=0)  ([988410016] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('     , ', 5201, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     , ',5201,1,520111052,1) ;

CALL DOCLOCK_IMPORT(' ',65536,5501,-1,0,8,2,'',0,1,'  .       ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 5501, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('    ',0,5501,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[550111066] = 0)  ([986810009] = 1)) 
((.[550111066] = 1)  ([986810008] = 1)) 
((.[550111066] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 5501, 1, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',5501,1,550111058,1) ;

CALL DOCLOCK_IMPORT('     ,',0,5501,1,0,11,0,'',0,1,'  ,      ,  =0 (    )        "",   -   ""',0,'       ""          ""  ',null,'(((.[550111066] = 2)  
((.[550111066] = 1)  (("_..",.[550111088])=0)))  
 ([988410016] = 0))

((.[550111066]=0)  ([988410016] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 5501, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',5501,1,550111144,1) ;

CALL DOCLOCK_IMPORT('      ',0,5501,1,0,11,0,'[550111066] = 0',0,3,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[550111054] = 0)  (.[550111148] = [988410026]))

(([988410022] = 0)  (.[550111055] = 0)  (.[550111055] = [988410022]))

(([988410023] = 0)  (.[550111057] = 0)  (.[550111147] = [988410024]))

(([988410018] = 0)  (.[550111056] = 0)  (.[550111146] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 5501, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',5501,1,550111144,1) ;

CALL DOCLOCK_IMPORT('     ',0,5501,1,0,11,0,'[550111066] = 2',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       . ',0,'      ',null,'([988410006] = 0)  (.[550111090] = 0)  (.[550111156] = [988410008]) 
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[550111090]))
   (((".",[988410006])=(".",.[550111090]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[550111090])))
 (((".", .[550111090]) div 100000) between 218 and 219) 
  (((".", .[550111090]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5501, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5501,1,550111144,1) ;

CALL DOCLOCK_IMPORT('      ',0,5501,1,0,11,0,'(("/..",[550110048]) >= 20300)  (("/..",[550110048]) <= 20399)',0,3,'           02.03.00 - 02.03.99',0,'              02.03.00 - 02.03.99',null,'([988410030] = .[550110165])  
([988410030] = ((.[550110165] div 100) * 100))  
([988410030] = ((.[550110165] div 10000) * 10000))  
([988410030] = 0)',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 5501, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',5501,1,550111144,1) ;

CALL DOCLOCK_IMPORT(' ',65536,5502,-1,0,8,2,'',0,1,'  .       .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 5502, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('     ,',0,5502,1,0,11,0,'',0,1,'  ,      ,  =0 (    )        "",   -   ""',0,'       ""          ""  ',null,'(((.[550211066] = 2)  
((.[550211066] = 1)  (("_..",.[550211088])=0)))  
 ([988410016] = 0))

((.[550211066]=0)  ([988410016] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 5502, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',5502,1,550211125,1) ;

CALL DOCLOCK_IMPORT('     ',0,5502,1,0,11,0,'[550211066] = 2',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       . ',0,'      ',null,'([988410006] = 0)  (.[550211090] = 0)  (.[550211135] = [988410008]) 
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[550211090]))
   (((".",[988410006])=(".",.[550211090]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[550211090])))
 (((".", .[550211090]) div 100000) between 218 and 219) 
  (((".", .[550211090]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5502, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5502,1,550211125,1) ;

CALL DOCLOCK_IMPORT('      ',0,5502,1,0,11,0,'[550211066]  =  0',0,3,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[550211054] = 0)  (.[550211129] = [988410026]))

(([988410022] = 0)  (.[550211055] = 0)  (.[550211055] = [988410022]))

(([988410023] = 0)  (.[550211057] = 0)  (.[550211128] = [988410024]))

(([988410018] = 0)  (.[550211056] = 0)  (.[550211127] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 5502, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',5502,1,550211125,1) ;

CALL DOCLOCK_IMPORT('      ',0,5502,1,0,11,0,'(("/..",[550210048]) >= 20300)  (("/..",[550210048]) <= 20399)',0,3,'           02.03.00 - 02.03.99',0,'              02.03.00 - 02.03.99',null,'([988410030] = .[550210149])  
([988410030] = ((.[550210149] div 100) * 100))  
([988410030] = ((.[550210149] div 10000) * 10000))  
([988410030] = 0)',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 5502, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',5502,1,550211125,1) ;

CALL DOCLOCK_IMPORT('    ',0,5502,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[550211066] = 0)  ([986810009] = 1)) 
((.[550211066] = 1)  ([986810008] = 1)) 
((.[550211066] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 5502, 1, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',5502,1,550211058,1) ;

CALL DOCLOCK_IMPORT('  ',32768,5503,-1,0,7,0,'(not ([550310009] is null))  ((not ([550310014] is null))  (not ([550310014] = "")))',1,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5503, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('    ',0,5503,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[550311008] = 0)  ([986810009] = 1)) 
((.[550311008] = 1)  ([986810008] = 1)) 
((.[550311008] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 5503, 1, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',5503,1,550311015,1) ;

CALL DOCLOCK_IMPORT('     ,',0,5503,1,0,11,0,'',0,1,'  ,      ,  =0 (    )        "",   -   ""',0,'       ""          ""  ',null,'(((.[550311008] = 2)  
((.[550311008] = 1)  (("_..",.[550311023])=0)))  
 ([988410016] = 0))

((.[550311008]=0)  ([988410016] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 5503, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',5503,1,550311025,1) ;

CALL DOCLOCK_IMPORT('      ',0,5503,1,0,11,0,'[550311008] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[550311011] = 0)  (.[550311042] = [988410026]))

(([988410022] = 0)  (.[550311012] = 0)  (.[550311012] = [988410022]))

(([988410023] = 0)  (.[550311014] = 0)  (.[550311041] = [988410024]))

(([988410018] = 0)  (.[550311013] = 0)  (.[550311036] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 5503, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',5503,1,550311025,1) ;

CALL DOCLOCK_IMPORT('     ',0,5503,1,0,11,0,'[550311008] = 2',0,1,'          ,    /          /.      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[550311022] = 0)  (.[550311022] = [988410006])
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[550311022]))
   (((".",[988410006])=(".",.[550311022]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[550311022])))
 (((".", .[550311022]) div 100000) between 218 and 219) 
 (((".", .[550311022]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5503, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5503,1,550311025,1) ;

CALL DOCLOCK_IMPORT('     ',0,5503,1,0,11,0,'',0,1,'',0,'    ,    ',null,'([988410032] = .[550311057])  ([988410032] = 0)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5503, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5503,1,550311025,1) ;

CALL DOCLOCK_IMPORT('  ',32768,5503,1,0,3,0,'[550311008] = 4',0,1,'          ( )',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5503, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5503,1,550311049,1) ;

CALL DOCLOCK_IMPORT('  ',0,5503,1,0,4,0,'not([550311008] = 4)',0,1,'         ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5503, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5503,1,550311049,1) ;

CALL DOCLOCK_IMPORT('    ',32768,9903,0,0,3,0,'((53,1,3)=1)  ("200", (53,3,8))',1,3,'        ',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 9903, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310085,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310076,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310020,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310010,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310004,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310003,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310002,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310001,1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310062,1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310061,1) ;

CALL DOCLOCK_IMPORT(' /    ',0,9912,0,0,11,0,'',0,1,' \ - /  \      .       ""/" "  / "",       " , "/"  /"/" /" - / ", "',0,'    - /         /    .',null,'((([984110031]=("..",.[991210001]))
    ([984110031]=("/.",.[991210014])))
 (([984110003]=0)([984110003]=.[991210001]))
 ((((.[991210017]<>0)(.[991210019]<>0)(.[991210007]<>0))([984110041]<>0))
   (([984110042]<>0)
   ((.[991210006]<>0)(.[991210008]<>0)))
  ))
([984110021]=0)',1) ;

CALL DOCLOCKFIELDS_DELETE(' /    ', 9912, 0, 0, 1) ;

--  "/ "
CALL DOCLOCKFIELDS_INSERTFIELD(' /    ',9912,0,991210018,1) ;

CALL DOCLOCK_IMPORT('  ',2,9915,-1,0,8,2,'',1,1,'     ,   .       .',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 9915, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('   5- ',0,9920,1,0,11,0,'',0,1,'     22-    5- ',0,'  .   5-  22-    ',null,'( ([986510004] like ''5*''))  (([986510004] like ''5*'')  ([986510004] like ''???0*''))',1) ;

CALL DOCLOCKFIELDS_DELETE('   5- ', 9920, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('   5- ',9920,1,992011010,1) ;

CALL DOCLOCK_IMPORT('   5-  ',0,9920,1,0,11,0,'',0,1,'     22-    5- ',0,'  .   5-  22-    ',null,'( ([986510004] like ''5*''))  (([986510004] like ''5*'')  ([986510004] like ''???0*''))',1) ;

CALL DOCLOCKFIELDS_DELETE('   5-  ', 9920, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('   5-  ',9920,1,992011011,1) ;

CALL DOCLOCK_IMPORT('  ',262144,9926,0,0,5,0,'([992610001]<100) and (([992610001]))',1,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 9926, 0, 0, 1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9926,0,992610007,1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9926,0,992610006,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9926,0,992610002,1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9926,0,992610005,1) ;

CALL DOCLOCK_IMPORT('  ',2,9929,0,0,8,2,'',1,1,'     ,   .       .',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 9929, 0, 0, 1) ;

DROP PROCEDURE DOCLOCK_IMPORT      
/

DROP PROCEDURE DocLockFields_InsertField
/

DROP PROCEDURE DOCLOCK_DELETE
/

DROP PROCEDURE DOCLOCKFIELDS_DELETE
/

CREATE OR REPLACE PROCEDURE LINKTYPE_DELETE(
  NAME_         VARCHAR2,
  TEMPLATECLS_  NUMBER,
  PARENTDOCCLS_ NUMBER,
  CHILDDOCCLS_  NUMBER) IS
BEGIN
  FOR tab_rec in (SELECT id FROM LINKTYPE LT
  WHERE (((NAME_ <> '') or (NAME_ is not null)) and (LT.NAME = NAME_)) or 
    (((NAME_ = '') or (NAME_ is null)) and (LT.TEMPLATECLS = TEMPLATECLS_ AND LT.PARENTDOCCLS = PARENTDOCCLS_ AND LT.CHILDDOCCLS = CHILDDOCCLS_)))    
  LOOP
    UPDATE STATE_JUMPCONTROL SET
      REFERENCEREF = NULL
    WHERE REFERENCEREF = tab_rec.id;
    DELETE FROM REPLACEMENTCLSDETAIL WHERE LINKID IN (SELECT ID FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id);
    DELETE FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id;
    DELETE FROM LINKTYPE LT
      WHERE LT.ID = tab_rec.id;
  END LOOP;     
END;
/

CREATE OR REPLACE PROCEDURE LINKTYPE_IMPORT(
   ID_                    NUMBER,
   NAME_                  VARCHAR2,
   TEMPLATECLS_           NUMBER,
   PARENTDOCCLS_          NUMBER,
   CHILDDOCCLS_           NUMBER,
   LINKCOMMENT_           VARCHAR2,
   BLOCKPARENT_           NUMBER,
   BLOCKCHILD_            NUMBER,
   CANDELBLOCKPARENT_     NUMBER,
   CANDELBLOCKCHILD_      NUMBER,
   PARENTPICTURETYPE_     NUMBER,
   PARENTPICTURENAME_     VARCHAR2,
   CHILDPICTURETYPE_      NUMBER,
   CHILDPICTURENAME_      VARCHAR2,
   PICTURECOLLECTIONNAME_ VARCHAR2,
   URMUSE_                NUMBER,
   DELMACROSNAME_         VARCHAR2,
   NEEDDELCHILD_          NUMBER,
   LINKKIND_              NUMBER
) IS
   CNT$ NUMBER(10);
BEGIN
   /*          ,     */
   /*  ,   , ,  ,     */
   IF (
   ((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0))or(Name_ is not null))   
   THEN
     FOR tab_rec in(SELECT id FROM LINKTYPE LT WHERE 
		 (id<>ID_)	
         and(((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0)and(LT.TEMPLATECLS = TEMPLATECLS_)
         and (LT.PARENTDOCCLS = PARENTDOCCLS_) and (LT.CHILDDOCCLS = CHILDDOCCLS_))
         or((Name_ is not null)and(lt.Name=Name_))))
     LOOP
        /*             */    
        DELETE FROM LINKRECORDS WHERE LINKTYPEREF = -10;  
        DELETE FROM TB_LINKTYPE WHERE ID = -10;
        DELETE FROM DOCUMENTCLS WHERE ID = -10;
        DELETE FROM DOCUMENTTYPES WHERE ID = -10;
        INSERT INTO DOCUMENTTYPES(ID, PROGINDEX) VALUES(-10, -10);
        INSERT INTO DOCUMENTCLS(ID, DOCTYPE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM)
           VALUES(-10, -10, ' ', ' ', ' ', ' ');
        INSERT INTO LINKTYPE(ID, PARENTDOCCLS, CHILDDOCCLS, NAME) VALUES(-10, -10, -10, ' ');
        UPDATE STATE_JUMPCONTROL SET
           REFERENCEREF = -10
        WHERE
           REFERENCEREF = tab_rec.id;
        UPDATE LINKRECORDS SET
           LINKTYPEREF = -10
        WHERE
           LINKTYPEREF = tab_rec.id;
        DELETE FROM TB_LINKTYPE WHERE ID = tab_rec.Id;
     END LOOP;
   end if;
   /*      */ 
   SELECT count(*) into CNT$
      FROM LINKTYPE LT WHERE LT.ID = ID_;
   IF (CNT$ = 0)    
   THEN
      INSERT INTO LINKTYPE
       (ID,NAME,TEMPLATECLS,PARENTDOCCLS, CHILDDOCCLS, LINKCOMMENT, BLOCKPARENT,BLOCKCHILD,CANDELBLOCKPARENT,
        CANDELBLOCKCHILD, PARENTPICTURETYPE,PARENTPICTURENAME,CHILDPICTURETYPE,CHILDPICTURENAME,
        PICTURECOLLECTIONNAME,URMUSE,DELMACROSNAME,NEEDDELCHILD,LINKKIND)
      VALUES
       (ID_,NAME_,TEMPLATECLS_, PARENTDOCCLS_, CHILDDOCCLS_, LINKCOMMENT_, BLOCKPARENT_,BLOCKCHILD_,CANDELBLOCKPARENT_,
        CANDELBLOCKCHILD_, PARENTPICTURETYPE_,PARENTPICTURENAME_,CHILDPICTURETYPE_,CHILDPICTURENAME_,
        PICTURECOLLECTIONNAME_,URMUSE_,DELMACROSNAME_,NEEDDELCHILD_,LINKKIND_);
   ELSE
      UPDATE LINKTYPE SET
         NAME = NAME_,
         TEMPLATECLS = TEMPLATECLS_,
         PARENTDOCCLS = PARENTDOCCLS_,
         CHILDDOCCLS = CHILDDOCCLS_,
         LINKCOMMENT = LINKCOMMENT_,
         BLOCKPARENT = BLOCKPARENT_,
         BLOCKCHILD = BLOCKCHILD_,
         CANDELBLOCKPARENT = CANDELBLOCKPARENT_,
         CANDELBLOCKCHILD = CANDELBLOCKCHILD_,
         PARENTPICTURETYPE = PARENTPICTURETYPE_,
         PARENTPICTURENAME = PARENTPICTURENAME_,
         CHILDPICTURETYPE = CHILDPICTURETYPE_,
         CHILDPICTURENAME = CHILDPICTURENAME_,
         PICTURECOLLECTIONNAME = PICTURECOLLECTIONNAME_,
         URMUSE = URMUSE_,
         DELMACROSNAME = DELMACROSNAME_,
         NEEDDELCHILD = NEEDDELCHILD_,
         LINKKIND = LINKKIND_
      WHERE ID = ID_;
   END IF;      
   
   /*      ,      */
   UPDATE STATE_JUMPCONTROL SET
     REFERENCEREF = ID_
   WHERE
     REFERENCEREF = -10;
   UPDATE LINKRECORDS SET
      LINKTYPEREF = ID_
   WHERE
      LINKTYPEREF = -10;
   /*   */  
   DELETE FROM TB_LINKTYPE WHERE ID = -10;
   DELETE FROM DOCUMENTCLS WHERE ID = -10;
   DELETE FROM DOCUMENTTYPES WHERE ID = -10;
END;
/

--  
CALL LINKTYPE_DELETE('',0, 520101, 520101) ;

CALL LINKTYPE_IMPORT(252500100,'',null,250202,250202,'     ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(252500200,'',null,250202,250202,'      ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(520300100,'  -  ()',null,520100,30201,'     ,   ',0,0,0,0,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(522500100,'  -  ()_',null,520101,250203,'      ()',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(522500200,'  -  ()_',null,520101,250403,'      ()',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(521600100,'  -  (  )',null,520101,160101,'       ',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(522500300,'  -  ( )',null,520101,250302,'      ( )',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(24800800,'',null,20900,480100,'     ',0,0,0,0,1,'',1,'','1616',1,'',0,0) ;

CALL LINKTYPE_IMPORT(24901600,'2',null,20900,490200,'  ,        ',0,0,0,0,2,'',1,'','1616',1,'',0,1) ;

CALL LINKTYPE_IMPORT(24901700,'',null,20900,490300,'  ,        ',0,0,1,1,2,'_',1,'','1616',0,'',0,3) ;

CALL LINKTYPE_IMPORT(525200100,'',null,520100,520100,'      ',1,0,0,0,1,'',1,'','',1,'',1,0) ;

CALL LINKTYPE_IMPORT(525200200,'',null,520101,520101,'       ',1,0,0,0,1,'',1,'','',1,'',1,0) ;

CALL LINKTYPE_IMPORT(484800100,'',null,480100,480100,'      ',0,0,0,0,1,'',1,'','1616',1,'',0,0) ;

CALL LINKTYPE_IMPORT(520300200,' - ',null,520101,30201,'     ',0,0,0,0,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(520300300,' - ',null,520100,30200,'     ',0,0,0,0,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(24800900,'',null,21100,480100,'     ',0,0,0,0,1,'',1,'','1616',1,'',0,0) ;

CALL LINKTYPE_IMPORT(20204200,'',null,21101,21101,'         ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(24901800,'',null,21100,490200,'  ,        ',0,0,0,0,2,'',1,'','1616',1,'',0,1) ;

CALL LINKTYPE_IMPORT(20204300,'',null,21101,21101,'          ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(24901900,'',null,21100,490300,'  ,        ',0,0,1,1,2,'_',1,'','1616',0,'',0,3) ;

CALL LINKTYPE_IMPORT(303000300,'',null,300601,300601,'',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(303000500,'',null,300300,300300,'',1,0,0,0,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(303000400,'',null,300601,300601,'',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(994900200,'',null,990300,490200,'    ',0,0,0,0,2,'',1,'','1616',1,'',0,1) ;

CALL LINKTYPE_IMPORT(24801000,'',null,21200,480100,'     ',0,0,0,0,1,'',1,'','1616',1,'',0,0) ;

CALL LINKTYPE_IMPORT(20204400,'',null,21201,21201,'    ,      ,   ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(24902000,'',null,21200,490200,'  ,        ',0,0,0,0,2,'',1,'','1616',1,'',0,1) ;

CALL LINKTYPE_IMPORT(20204500,'',null,21201,21201,'   ,     ,    ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(24902100,'',null,21200,490300,'  ,        ',0,0,1,1,2,'_',1,'','1616',0,'',0,3) ;

CALL LINKTYPE_IMPORT(30303600,'->',null,30201,32301,'',1,1,0,0,1,'',1,'','',0,'',1,0) ;

CALL LINKTYPE_IMPORT(30303700,'_->_',null,30200,32300,'',1,1,0,0,1,'',1,'','',0,'',1,0) ;

CALL LINKTYPE_IMPORT(30303800,'->',null,30200,30500,'        ',0,0,0,0,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(520300400,' - ',null,520101,30501,'',0,0,0,0,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(520300500,' - ',null,520100,30500,'',0,0,0,0,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(252500700,'',null,250402,250402,'       ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(252500800,'',null,250402,250402,'        ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(522500400,'  -  ()',null,520101,250402,'      ()',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(444900600,'->',null,440100,490300,'     ',0,0,1,1,2,'_',1,'','1616',0,'',0,3) ;

CALL LINKTYPE_IMPORT(522500500,'  -  ()',null,520101,250202,'      ()',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(520300600,' - ',null,520100,30800,'       ',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(520300700,' - ',null,520101,30801,'       ',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(30303900,'->',null,30800,30200,'',1,0,0,0,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(20204600,'->_',null,20300,20200,'   ()   ()',1,0,0,1,1,'',1,'','1616',0,'',1,0) ;

CALL LINKTYPE_IMPORT(30304000,'->',null,30800,30500,'',1,0,0,0,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(994900300,'',null,991500,490100,'        ',0,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(252500900,'__',null,250300,250300,'       ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(252501000,'__',null,250300,250300,'        ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(520900100,' - ',null,520100,90300,'',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(520900200,' - ',null,520101,90301,'',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(555501200,'___',null,550101,550101,'    ,    ""',0,0,1,1,1,'',1,'','',0,'',0,0) ;

DROP PROCEDURE LINKTYPE_DELETE
/

DROP PROCEDURE LINKTYPE_IMPORT
/

CREATE OR REPLACE PROCEDURE STATICLINK_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATICLINKS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE STATICLINK_IMPORT(
  ID_             NUMBER,
  NAME_           VARCHAR2,
  PARENTFIELDREF_ NUMBER,
  CHILDFIELDREF_  NUMBER,
  LINKKIND_      NUMBER,
  ParentDelAction_ NUMBER
) IS
  FINDID$ NUMBER;
  FINDNEWID$ NUMBER;
  IDExists$ NUMBER;
BEGIN
  /*     ID,    CHILDFIELDREF,PARENTFIELDREF. 
   ,     ,    ID.       ID  , 
   (  )     id ,      */
  BEGIN
    SELECT
      SL.ID
    INTO FINDID$
    FROM 
      STATICLINKS SL
    WHERE (SL.CHILDFIELDREF = CHILDFIELDREF_) AND (SL.PARENTFIELDREF = PARENTFIELDREF_) AND (SL.ID <> ID_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      FINDID$ := NULL;
  END;
  
  IF (FINDID$ IS NOT NULL) THEN
  /*   ID         */

    SELECT COUNT (ID)
      INTO IDExists$
      FROM STATE_JUMPCONTROL
    WHERE (STATICLINKREF = FINDID$);

    IF (IDExists$ > 0) THEN

      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM 
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
 
      IF (FINDNEWID$ IS NULL) THEN
        INSERT INTO STATICLINKS
         (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
        VALUES
          (ID_,NAME_,CHILDFIELDREF_,PARENTFIELDREF_,1,ParentDelAction_);
      END IF;        
      UPDATE STATE_JUMPCONTROL
        SET STATICLINKREF = ID_
      WHERE (STATICLINKREF = FINDID$);

      DELETE FROM STATICLINKS  
      WHERE ID=FINDID$;
    ELSE   
      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
      IF (FINDNEWID$ IS NULL) THEN
        UPDATE STATICLINKS
        SET ID=ID_
        WHERE ID=FINDID$;
      ELSE
        DELETE FROM STATICLINKS
        WHERE ID=FINDID$;
      END IF;
    END IF;
      
  END IF; /*  id  */
  
  /*       ( ), 
   ,            CHILDFIELDREF.
   ,        1( )*/
  IF (LINKKIND_=0) THEN
    UPDATE STATICLINKS
    SET LINKKIND=1  
    WHERE (CHILDFIELDREF = CHILDFIELDREF_) AND (ID <> ID_) AND (LINKKIND=0);
  END IF;    
  
  /*        id.  ,   .  ,   */
  BEGIN
    SELECT SL.ID
      INTO FINDID$
      FROM
        STATICLINKS SL
      WHERE
        (SL.ID = ID_);
  EXCEPTION
      WHEN NO_DATA_FOUND THEN
        FINDID$ := NULL;
  END;
  IF (FINDID$ IS NOT NULL) THEN
    UPDATE STATICLINKS SET
      NAME           = NAME_,
      PARENTFIELDREF = PARENTFIELDREF_,
      CHILDFIELDREF  = CHILDFIELDREF_,
      LINKKIND       = LINKKIND_,
      ParentDelAction = ParentDelAction_
      WHERE ID = ID_;
  ELSE
    INSERT INTO STATICLINKS
     (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
    VALUES
      (ID_,NAME_,PARENTFIELDREF_,CHILDFIELDREF_,LINKKIND_,ParentDelAction_);
  END IF;      

END;
/

--  
CALL STATICLINK_DELETE(990200600) ;

CALL STATICLINK_DELETE(990201300) ;

CALL STATICLINK_DELETE(990202700) ;

CALL STATICLINK_DELETE(990203400) ;

CALL STATICLINK_DELETE(990210600) ;

CALL STATICLINK_DELETE(982500100) ;

CALL STATICLINK_DELETE(982502300) ;

CALL STATICLINK_DELETE(982501900) ;

CALL STATICLINK_DELETE(982501000) ;

CALL STATICLINK_DELETE(962500900) ;

CALL STATICLINK_DELETE(982502500) ;

CALL STATICLINK_DELETE(983001000) ;

CALL STATICLINK_DELETE(983000700) ;

CALL STATICLINK_DELETE(993000400) ;

CALL STATICLINK_DELETE(983002000) ;

CALL STATICLINK_DELETE(992501100) ;

CALL STATICLINK_DELETE(982503000) ;

CALL STATICLINK_DELETE(982503400) ;

CALL STATICLINK_DELETE(982504900) ;

CALL STATICLINK_DELETE(982504500) ;

CALL STATICLINK_DELETE(982503600) ;

CALL STATICLINK_DELETE(992501600) ;

CALL STATICLINK_DELETE(965200800) ;

CALL STATICLINK_DELETE(990229300) ;

CALL STATICLINK_DELETE(980357300) ;

CALL STATICLINK_IMPORT(444400500,'.1.ID()->.ID()',440110010,440110010,0,0) ;

CALL STATICLINK_IMPORT(990901600,'_.1.KESR()->.ID',986810006,90311030,0,0) ;

CALL STATICLINK_IMPORT(30304100,'.1.ID()->.ID()',32310045,32310045,0,0) ;

CALL STATICLINK_IMPORT(222200200,'_.1.ID()->_.ID()',220110045,220110045,0,0) ;

CALL STATICLINK_IMPORT(980228400,'_.1.KVRCORR()->.ID',980410002,20111064,1,0) ;

CALL STATICLINK_IMPORT(20202200,'.1.ID()->.ID()',20510026,20510026,0,0) ;

CALL STATICLINK_IMPORT(30304000,'.1.ID()->.ID()',30810011,30810011,0,0) ;

CALL STATICLINK_IMPORT(990230000,'.1.->.ID',986810006,20011021,0,1) ;

CALL STATICLINK_IMPORT(990336300,'.1.->.ID',986810006,30011030,0,1) ;

CALL STATICLINK_IMPORT(982502100,'.2.SUBKESR->.ID',980810002,250212004,0,1) ;

CALL STATICLINK_IMPORT(982502000,'.2.REGION->.ID',981210005,250212005,0,1) ;

CALL STATICLINK_IMPORT(982502200,'.2.MEANSTYPE->.ID',984910002,250212025,0,1) ;

CALL STATICLINK_IMPORT(982501500,'.2.KVSR->.ID',980310002,250212026,0,1) ;

CALL STATICLINK_IMPORT(982501400,'.2.KVR->.ID',980410002,250212027,0,1) ;

CALL STATICLINK_IMPORT(982501600,'.2.KFSR->.ID',980210004,250212028,0,1) ;

CALL STATICLINK_IMPORT(992500500,'.2.KESR->.ID',986810006,250212029,0,1) ;

CALL STATICLINK_IMPORT(982501700,'.2.KCSR->.ID',980510002,250212030,0,1) ;

CALL STATICLINK_IMPORT(982501300,'.2.FINSOURCE->.ID',981310002,250212032,0,1) ;

CALL STATICLINK_IMPORT(982501800,'.2.FACIALACC_CLS->.ID',984110021,250212035,0,0) ;

CALL STATICLINK_IMPORT(992500600,'.2.DIRECTIONCLS->.ID',986910002,250212036,0,1) ;

CALL STATICLINK_IMPORT(992500700,'.2.BUHOPERATIONCLS->.ID',987110021,250212037,0,1) ;

CALL STATICLINK_IMPORT(982504700,'.2.SUBKESR->.ID',980810002,250412010,0,1) ;

CALL STATICLINK_IMPORT(982504600,'.2.REGION->.ID',981210005,250412011,0,1) ;

CALL STATICLINK_IMPORT(982505400,'.5.MEANSTYPE->.ID',984910002,250415004,0,1) ;

CALL STATICLINK_IMPORT(982504800,'.2.MEANSTYPE->.ID',984910002,250412030,0,1) ;

CALL STATICLINK_IMPORT(982505100,'.5.KVSR->.ID',980310002,250415006,0,1) ;

CALL STATICLINK_IMPORT(982504100,'.2.KVSR->.ID',980310002,250412032,0,1) ;

CALL STATICLINK_IMPORT(982505000,'.5.KVR->.ID',980410002,250415008,0,1) ;

CALL STATICLINK_IMPORT(982504000,'.2.KVR->.ID',980410002,250412034,0,1) ;

CALL STATICLINK_IMPORT(982505200,'.5.KFSR->.ID',980210004,250415009,0,1) ;

CALL STATICLINK_IMPORT(982504200,'.2.KFSR->.ID',980210004,250412035,0,1) ;

CALL STATICLINK_IMPORT(992501800,'.5.KESR->.ID',986810006,250415010,0,1) ;

CALL STATICLINK_IMPORT(992501500,'.2.KESR->.ID',986810006,250412036,0,1) ;

CALL STATICLINK_IMPORT(982505300,'.5.KCSR->.ID',980510002,250415012,0,1) ;

CALL STATICLINK_IMPORT(982504300,'.2.KCSR->.ID',980510002,250412038,0,1) ;

CALL STATICLINK_IMPORT(982503900,'.2.FINSOURCE->.ID',981310002,250412040,0,1) ;

CALL STATICLINK_IMPORT(982504400,'.2.FACIALACC_CLS->.ID',984110021,250412043,0,0) ;

CALL STATICLINK_IMPORT(982503800,'.3.FACIALACC_CLS->.ID',984110021,250413008,0,0) ;

CALL STATICLINK_IMPORT(992501700,'.2.BUHOPERATIONCLS->.ID',987110021,250412045,0,1) ;

CALL STATICLINK_IMPORT(995200800,'.1.KESR()->.ID',986810006,520111011,0,0) ;

CALL STATICLINK_IMPORT(985200500,'.1.MEANSTYPE()->.ID',984910002,520111017,0,0) ;

CALL STATICLINK_IMPORT(525200100,'.1.RECORDINDEX()->.ID()',520110001,520111020,0,2) ;

CALL STATICLINK_IMPORT(980357600,'.DESTFACIALACC_CLS()->.ID',984110021,30810064,0,0) ;

CALL STATICLINK_IMPORT(990335900,'.1.DESTIFS()->.ID',985210008,30811094,0,0) ;

CALL STATICLINK_IMPORT(990335800,'.1.SOURCEIFS(,)->.ID',985210008,30811098,0,0) ;

CALL STATICLINK_IMPORT(995504100,'.1.KESR()->.ID',986810006,550311015,0,0) ;

CALL STATICLINK_IMPORT(995200600,'.1.TRANSFERTCLS()->.ID',988410002,520111052,0,0) ;

CALL STATICLINK_IMPORT(990229500,'_.2.ASSIGNMENTKIND()->.ID',988510003,20912001,0,1) ;

CALL STATICLINK_IMPORT(990230400,'_.2.KESR()->.ID',986810006,20912017,0,1) ;

CALL STATICLINK_IMPORT(990227800,'_.ASSIGNMENTSOURCE()->.ID',988610003,21110001,0,0) ;

CALL STATICLINK_IMPORT(990227900,'_.BUDGETREF()->.ID',987810006,21110002,0,0) ;

CALL STATICLINK_IMPORT(990229200,'_.2.ASSIGNMENTKIND()->.ID',988510003,21112004,0,1) ;

CALL STATICLINK_IMPORT(980226800,'_.2.FACIALACC_CLS->.ID',984110021,21112006,0,1) ;

CALL STATICLINK_IMPORT(980227300,'_.FACIALACCCLS()->.ID',984110021,21110010,0,0) ;

CALL STATICLINK_IMPORT(980227400,'_.NOTIFYTYPE()->.ID',981310002,21110016,0,0) ;

CALL STATICLINK_IMPORT(990230500,'_.2.KESR()->.ID',986810006,21112016,0,1) ;

CALL STATICLINK_IMPORT(990228000,'_.PLANDOCTYPE()->.ID',988410002,21110020,0,0) ;

CALL STATICLINK_IMPORT(980226900,'_.2.MEANSTYPE->.ID',984910002,21112020,0,1) ;

CALL STATICLINK_IMPORT(990228100,'_.REJECTCLS()->.ID',985010005,21110023,0,0) ;

CALL STATICLINK_IMPORT(990227400,'_.2.TRANSFERTCLS->.ID',988410002,21112028,0,1) ;

CALL STATICLINK_IMPORT(990227500,'_.2.SUBSIDYCLS->.ID',988910006,21112029,0,1) ;

CALL STATICLINK_IMPORT(20202300,'_.1.RECORDINDEX()->_.ID()',21110011,21111033,0,2) ;

CALL STATICLINK_IMPORT(981800000,'.KCSR->.ID',980510002,181610005,0,0) ;

CALL STATICLINK_IMPORT(991800200,'.KESR()->.ID',986810006,181610007,0,0) ;

CALL STATICLINK_IMPORT(980909800,'_.1.FINTYPE()->.ID',982710006,90311087,0,0) ;

CALL STATICLINK_IMPORT(980910100,'_.FINTYPE->.ID',982710006,90510040,0,0) ;

CALL STATICLINK_IMPORT(980910000,'_.1.FINTYPE->.ID',982710006,90611082,0,0) ;

CALL STATICLINK_IMPORT(980205800,'.1.FINTYPE()->.ID',982710006,20511101,0,0) ;

CALL STATICLINK_IMPORT(980100800,'.1.FINTYPE()->.ID',982710006,10111188,0,0) ;

CALL STATICLINK_IMPORT(980102400,'.2.FINTYPE()->.ID',982710006,10112219,0,0) ;

CALL STATICLINK_IMPORT(980104600,'.4.FINTYPE()->.ID',982710006,10114221,0,0) ;

CALL STATICLINK_IMPORT(980100400,'.1.DOCUMENTBASETYPE()->.ID',982910007,10111189,0,0) ;

CALL STATICLINK_IMPORT(980102000,'.2.DOCUMENTBASETYPE()->.ID',982910007,10112220,0,0) ;

CALL STATICLINK_IMPORT(980104200,'.4.DOCUMENTBASETYPE()->.ID',982910007,10114222,0,0) ;

CALL STATICLINK_IMPORT(990200400,'_.1.DIRECTIONCLS()->.ID',986910002,20111183,0,0) ;

CALL STATICLINK_IMPORT(980200500,'_.1.FACT()->.ID',982810005,20111184,0,0) ;

CALL STATICLINK_IMPORT(980200600,'_.1.FINTYPE()->.ID',982710006,20111185,0,0) ;

CALL STATICLINK_IMPORT(980200000,'_.DOCBASE()->.ID',982910007,20110082,0,0) ;

CALL STATICLINK_IMPORT(990201100,'_.1.DIRECTIONCLS()->.ID',986910002,20211105,0,0) ;

CALL STATICLINK_IMPORT(980201800,'_.1.FACT()->.ID',982810005,20211106,0,0) ;

CALL STATICLINK_IMPORT(980201900,'_.1.FINTYPE()->.ID',982710006,20211107,0,0) ;

CALL STATICLINK_IMPORT(980201400,'_.DOCBASE()->.ID',982910007,20210090,0,0) ;

CALL STATICLINK_IMPORT(990201800,'_.1.DIRECTIONCLS()->.ID',986910002,20311095,0,0) ;

CALL STATICLINK_IMPORT(980203100,'_.1.FACT()->.ID',982810005,20311096,0,0) ;

CALL STATICLINK_IMPORT(980203200,'_.1.FINTYPE()->.ID',982710006,20311097,0,0) ;

CALL STATICLINK_IMPORT(980202700,'_.DOCBASE()->.ID',982910007,20310081,0,0) ;

CALL STATICLINK_IMPORT(990202500,'_.1.DIRECTIONCLS()->.ID',986910002,20411114,0,0) ;

CALL STATICLINK_IMPORT(980204400,'_.1.FACT()->.ID',982810005,20411115,0,0) ;

CALL STATICLINK_IMPORT(980204500,'_.1.FINTYPE()->.ID',982710006,20411116,0,0) ;

CALL STATICLINK_IMPORT(980204000,'_.DOCBASE()->.ID',982910007,20410086,0,0) ;

CALL STATICLINK_IMPORT(990203200,'.1.DIRECTIONCLS()->.ID',986910002,20511102,0,0) ;

CALL STATICLINK_IMPORT(980205700,'.1.FACT()->.ID',982810005,20511103,0,0) ;

CALL STATICLINK_IMPORT(980205300,'.DOCBASE()->.ID',982910007,20510089,0,0) ;

CALL STATICLINK_IMPORT(990203900,'__.1.DIRECTIONCLS()->.ID',986910002,20611183,0,0) ;

CALL STATICLINK_IMPORT(980207100,'__.1.FACT()->.ID',982810005,20611184,0,0) ;

CALL STATICLINK_IMPORT(980207200,'__.1.FINTYPE()->.ID',982710006,20611185,0,0) ;

CALL STATICLINK_IMPORT(980206600,'__.DOCBASE()->.ID',982910007,20610089,0,0) ;

CALL STATICLINK_IMPORT(990206800,'_.1.DIRECTIONCLS()->.ID',986910002,20711182,0,0) ;

CALL STATICLINK_IMPORT(980208600,'_.1.FACT()->.ID',982810005,20711183,0,0) ;

CALL STATICLINK_IMPORT(980208700,'_.1.FINTYPE()->.ID',982710006,20711184,0,0) ;

CALL STATICLINK_IMPORT(980208200,'_.DOCBASE()->.ID',982910007,20710160,0,0) ;

CALL STATICLINK_IMPORT(980210000,'__.1.FINTYPE()->.ID',982710006,20811183,0,0) ;

CALL STATICLINK_IMPORT(990207900,'__.1.DIRECTIONCLS()->.ID',986910002,20811184,0,0) ;

CALL STATICLINK_IMPORT(980209900,'__.1.FACT()->.ID',982810005,20811185,0,0) ;

CALL STATICLINK_IMPORT(980209500,'__.DOCBASE()->.ID',982910007,20810160,0,0) ;

CALL STATICLINK_IMPORT(980211200,'_.DOCBASE()->.ID',982910007,20910027,0,0) ;

CALL STATICLINK_IMPORT(980227200,'_.DOCBASE()->.ID',982910007,21110027,0,0) ;

CALL STATICLINK_IMPORT(990210300,'.1.DIRECTIONCLS()->.ID',986910002,21011044,0,0) ;

CALL STATICLINK_IMPORT(980211900,'.1.FACT()->.ID',982810005,21011045,0,0) ;

CALL STATICLINK_IMPORT(980212000,'.1.FINTYPE()->.ID',982710006,21011046,0,0) ;

CALL STATICLINK_IMPORT(980211500,'.DOCBASE()->.ID',982910007,21010027,0,0) ;

CALL STATICLINK_IMPORT(980212900,'.2.FACT()->.ID',982810005,21012058,0,0) ;

CALL STATICLINK_IMPORT(990211000,'.2.DIRECTIONCLS()->.ID',986910002,21012059,0,0) ;

CALL STATICLINK_IMPORT(980213000,'.2.FINTYPE()->.ID',982710006,21012060,0,0) ;

CALL STATICLINK_IMPORT(980302000,'.1.SOURCEFACT()->.ID',982810005,30111162,0,0) ;

CALL STATICLINK_IMPORT(980300700,'.1.DESTFACT()->.ID',982810005,30111163,0,0) ;

CALL STATICLINK_IMPORT(990300400,'.1.SOURCEDIRECTIONCLS()->.ID',986910002,30111164,0,0) ;

CALL STATICLINK_IMPORT(990300100,'.1.DESTDIRECTIONCLS()->.ID',986910002,30111165,0,0) ;

CALL STATICLINK_IMPORT(980302200,'.1.SOURCEFINTYPE()->.ID',982710006,30111166,0,0) ;

CALL STATICLINK_IMPORT(980300900,'.1.DESTFINTYPE()->.ID',982710006,30111167,0,0) ;

CALL STATICLINK_IMPORT(980301800,'.1.SOURCEDOCBASE()->.ID',982910007,30111168,0,0) ;

CALL STATICLINK_IMPORT(980300400,'.1.DESTDOCBASE()->.ID',982910007,30111169,0,0) ;

CALL STATICLINK_IMPORT(980303900,'.1.SOURCEFACT()->.ID',982810005,30211151,0,0) ;

CALL STATICLINK_IMPORT(990300900,'.1.SOURCEDIRECTIONCLS()->.ID',986910002,30211152,0,0) ;

CALL STATICLINK_IMPORT(980304100,'.1.SOURCEFINTYPE()->.ID',982710006,30211153,0,0) ;

CALL STATICLINK_IMPORT(980303600,'.1.SOURCEDOCBASE()->.ID',982910007,30211154,0,0) ;

CALL STATICLINK_IMPORT(980305600,'.1.DESTFACT()->.ID',982810005,30311089,0,0) ;

CALL STATICLINK_IMPORT(990301400,'.1.DESTDIRECTIONCLS()->.ID',986910002,30311090,0,0) ;

CALL STATICLINK_IMPORT(980305800,'.1.DESTFINTYPE()->.ID',982710006,30311092,0,0) ;

CALL STATICLINK_IMPORT(980305300,'.1.DESTDOCBASE()->.ID',982910007,30311093,0,0) ;

CALL STATICLINK_IMPORT(980307500,'.1.SOURCEFACT()->.ID',982810005,30411141,0,0) ;

CALL STATICLINK_IMPORT(990301900,'.1.SOURCEDIRECTIONCLS()->.ID',986910002,30411142,0,0) ;

CALL STATICLINK_IMPORT(980307700,'.1.SOURCEFINTYPE()->.ID',982710006,30411143,0,0) ;

CALL STATICLINK_IMPORT(980307200,'.1.SOURCEDOCBASE()->.ID',982910007,30411144,0,0) ;

CALL STATICLINK_IMPORT(980309600,'.1.DESTFACT()->.ID',982810005,30511142,0,0) ;

CALL STATICLINK_IMPORT(990302400,'.1.DESTDIRECTIONCLS()->.ID',986910002,30511143,0,0) ;

CALL STATICLINK_IMPORT(980309800,'.1.DESTFINTYPE()->.ID',982710006,30511144,0,0) ;

CALL STATICLINK_IMPORT(980309200,'.1.DESTDOCBASE()->.ID',982910007,30511145,0,0) ;

CALL STATICLINK_IMPORT(980311300,'.1.DESTFACT()->.ID',982810005,30611144,0,0) ;

CALL STATICLINK_IMPORT(990302800,'.1.DESTDIRECTIONCLS()->.ID',986910002,30611145,0,0) ;

CALL STATICLINK_IMPORT(980311500,'.1.DESTFINTYPE()->.ID',982710006,30611146,0,0) ;

CALL STATICLINK_IMPORT(980311100,'.1.DESTDOCBASE()->.ID',982910007,30611147,0,0) ;

CALL STATICLINK_IMPORT(980334200,'.1.SOURCEFACT()->.ID',982810005,30811103,0,0) ;

CALL STATICLINK_IMPORT(980333300,'.1.DESTFACT()->.ID',982810005,30811104,0,0) ;

CALL STATICLINK_IMPORT(990313200,'.1.SOURCEDIRECTIONCLS()->.ID',986910002,30811105,0,0) ;

CALL STATICLINK_IMPORT(990313100,'.1.DESTDIRECTIONCLS()->.ID',986910002,30811106,0,0) ;

CALL STATICLINK_IMPORT(980334400,'.1.SOURCEFINTYPE()->.ID',982710006,30811107,0,0) ;

CALL STATICLINK_IMPORT(980333500,'.1.DESTFINTYPE()->.ID',982710006,30811108,0,0) ;

CALL STATICLINK_IMPORT(980334000,'.1.SOURCEDOCBASE()->.ID',982910007,30811109,0,0) ;

CALL STATICLINK_IMPORT(980333000,'.1.DESTDOCBASE()->.ID',982910007,30811110,0,0) ;

CALL STATICLINK_IMPORT(980314300,'_.1.SOURCEFACT()->.ID',982810005,31111100,0,0) ;

CALL STATICLINK_IMPORT(980313100,'_.1.DESTFACT()->.ID',982810005,31111101,0,0) ;

CALL STATICLINK_IMPORT(990303600,'_.1.SOURCEDIRECTIONCLS()->.ID',986910002,31111102,0,0) ;

CALL STATICLINK_IMPORT(990303400,'_.1.DESTDIRECTIONCLS()->.ID',986910002,31111103,0,0) ;

CALL STATICLINK_IMPORT(980314500,'_.1.SOURCEFINTYPE()->.ID',982710006,31111104,0,0) ;

CALL STATICLINK_IMPORT(980313300,'_.1.DESTFINTYPE()->.ID',982710006,31111105,0,0) ;

CALL STATICLINK_IMPORT(980314000,'_.1.SOURCEDOCBASE()->.ID',982910007,31111106,0,0) ;

CALL STATICLINK_IMPORT(980331500,'_.1.DESTFACT()->.ID',982810005,31211137,0,0) ;

CALL STATICLINK_IMPORT(990312300,'_.1.DESTDIRECTIONCLS()->.ID',986910002,31211139,0,0) ;

CALL STATICLINK_IMPORT(980331200,'_.1.DESTDOCBASE()->.ID',982910007,31211140,0,0) ;

CALL STATICLINK_IMPORT(980331700,'_.1.DESTFINTYPE()->.ID',982710006,31211141,0,0) ;

CALL STATICLINK_IMPORT(980316700,'_.1.SOURCEFACT()->.ID',982810005,31411136,0,0) ;

CALL STATICLINK_IMPORT(990304300,'_.1.SOURCEDIRECTIONCLS()->.ID',986910002,31411137,0,0) ;

CALL STATICLINK_IMPORT(990304100,'_.1.DESTDIRECTIONCLS()->.ID',986910002,31411138,0,0) ;

CALL STATICLINK_IMPORT(980316900,'_.1.SOURCEFINTYPE()->.ID',982710006,31411139,0,0) ;

CALL STATICLINK_IMPORT(980316400,'_.1.SOURCEDOCBASE()->.ID',982910007,31411140,0,0) ;

CALL STATICLINK_IMPORT(990304800,'_.1.DESTDIRECTIONCLS()->.ID',986910002,31511094,0,0) ;

CALL STATICLINK_IMPORT(980318500,'_.1.DESTFACT()->.ID',982810005,31511095,0,0) ;

CALL STATICLINK_IMPORT(980318700,'_.1.DESTFINTYPE()->.ID',982710006,31511096,0,0) ;

CALL STATICLINK_IMPORT(980318200,'_.1.DESTDOCBASE()->.ID',982910007,31511097,0,0) ;

CALL STATICLINK_IMPORT(990306300,'.1.SOURCEDIRECTIONCLS()->.ID',986910002,32211086,0,0) ;

CALL STATICLINK_IMPORT(980325400,'.1.SOURCEFACT()->.ID',982810005,32211087,0,0) ;

CALL STATICLINK_IMPORT(980325600,'.1.SOURCEFINTYPE()->.ID',982710006,32211088,0,0) ;

CALL STATICLINK_IMPORT(980325200,'.1.SOURCEDOCBASE()->.ID',982910007,32211089,0,0) ;

CALL STATICLINK_IMPORT(990306700,'.1.DESTDIRECTIONCLS()->.ID',986910002,32311153,0,0) ;

CALL STATICLINK_IMPORT(980327000,'.1.DESTFACT()->.ID',982810005,32311154,0,0) ;

CALL STATICLINK_IMPORT(980327200,'.1.DESTFINTYPE()->.ID',982710006,32311155,0,0) ;

CALL STATICLINK_IMPORT(980326700,'.1.DESTDOCBASE()->.ID',982910007,32311156,0,0) ;

CALL STATICLINK_IMPORT(980328600,'.1.DESTFACT()->.ID',982810005,32411194,0,0) ;

CALL STATICLINK_IMPORT(990307100,'.1.DESTDIRECTIONCLS()->.ID',986910002,32411195,0,0) ;

CALL STATICLINK_IMPORT(980328800,'.1.DESTFINTYPE()->.ID',982710006,32411196,0,0) ;

CALL STATICLINK_IMPORT(980328300,'.1.DESTDOCBASE()->.ID',982910007,32411197,0,0) ;

CALL STATICLINK_IMPORT(990400600,'.6.DIRECTIONCLS->.ID',986910002,40116248,0,0) ;

CALL STATICLINK_IMPORT(990401000,'.10.DIRECTIONCLS->.ID',986910002,40110253,0,0) ;

CALL STATICLINK_IMPORT(980400300,'.FACT()->.ID',982810005,40110221,0,0) ;

CALL STATICLINK_IMPORT(980403300,'.6.FACT()->.ID',982810005,40116249,0,0) ;

CALL STATICLINK_IMPORT(980405400,'.10.FACT()->.ID',982810005,40110254,0,0) ;

CALL STATICLINK_IMPORT(980403500,'.6.FINTYPE()->.ID',982710006,40116250,0,0) ;

CALL STATICLINK_IMPORT(980405600,'.10.FINTYPE()->.ID',982710006,40110255,0,0) ;

CALL STATICLINK_IMPORT(980400100,'.DOCBASE()->.ID',982910007,40110222,0,0) ;

CALL STATICLINK_IMPORT(990500100,'.1.DIRECTIONCLS->.ID',986910002,50111184,0,0) ;

CALL STATICLINK_IMPORT(990500300,'.3.DIRECTIONCLS->.ID',986910002,50113188,0,0) ;

CALL STATICLINK_IMPORT(980500200,'.FACT()->.ID',982810005,50110156,0,0) ;

CALL STATICLINK_IMPORT(980500800,'.1.FACT()->.ID',982810005,50111185,0,0) ;

CALL STATICLINK_IMPORT(980502200,'.3.FACT()->.ID',982810005,50113189,0,0) ;

CALL STATICLINK_IMPORT(980501000,'.1.FINTYPE()->.ID',982710006,50111186,0,0) ;

CALL STATICLINK_IMPORT(980502400,'.3.FINTYPE()->.ID',982710006,50113190,0,0) ;

CALL STATICLINK_IMPORT(980500000,'.DOCBASE()->.ID',982910007,50110157,0,0) ;

CALL STATICLINK_IMPORT(990700000,'.1.DIRECTIONCLS()->.ID',986910002,70111070,0,0) ;

CALL STATICLINK_IMPORT(980700600,'.1.FACT()->.ID',982810005,70111071,0,0) ;

CALL STATICLINK_IMPORT(980700800,'.1.FINTYPE()->.ID',982710006,70111072,0,0) ;

CALL STATICLINK_IMPORT(990700600,'.DIRECTIONCLS()->.ID',986910002,70310052,0,0) ;

CALL STATICLINK_IMPORT(980703100,'.FACT()->.ID',982810005,70310053,0,0) ;

CALL STATICLINK_IMPORT(980703300,'.FINTYPE()->.ID',982710006,70310054,0,0) ;

CALL STATICLINK_IMPORT(990800200,'_.1.DIRECTIONCLS()->.ID',986910002,80111080,0,0) ;

CALL STATICLINK_IMPORT(980800600,'_.1.FACT()->.ID',982810005,80111081,0,0) ;

CALL STATICLINK_IMPORT(980800800,'_.1.FINTYPE()->.ID',982710006,80111082,0,0) ;

CALL STATICLINK_IMPORT(980800300,'_.1.DOCBASE()->.ID',982910007,80111083,0,0) ;

CALL STATICLINK_IMPORT(990800600,'_.DIRECTIONCLS()->.ID',986910002,80210039,0,0) ;

CALL STATICLINK_IMPORT(980801800,'_.FACT()->.ID',982810005,80210040,0,0) ;

CALL STATICLINK_IMPORT(980802000,'_.FINTYPE()->.ID',982710006,80210041,0,0) ;

CALL STATICLINK_IMPORT(990800900,'_.1.DIRECTIONCLS()->.ID',986910002,80311052,0,0) ;

CALL STATICLINK_IMPORT(980803000,'_.1.FACT()->.ID',982810005,80311053,0,0) ;

CALL STATICLINK_IMPORT(980803200,'_.1.FINTYPE()->.ID',982710006,80311054,0,0) ;

CALL STATICLINK_IMPORT(990900000,'_.1.DIRECTIONCLS()->.ID',986910002,90111067,0,0) ;

CALL STATICLINK_IMPORT(980900300,'_.1.FACT()->.ID',982810005,90111068,0,0) ;

CALL STATICLINK_IMPORT(980901600,'_.FACT()->.ID',982810005,90210050,0,0) ;

CALL STATICLINK_IMPORT(980901500,'_.FACT()->.ID',982810005,90210051,0,0) ;

CALL STATICLINK_IMPORT(990901100,'_.1.DIRECTIONCLS()->.ID',986910002,90311089,0,0) ;

CALL STATICLINK_IMPORT(980903400,'_.1.FACT()->.ID',982810005,90311090,0,0) ;

CALL STATICLINK_IMPORT(980903100,'_.1.DOCBASE()->.ID',982910007,90311091,0,0) ;

CALL STATICLINK_IMPORT(980908500,'_.FACT()->.ID',982810005,90510042,0,0) ;

CALL STATICLINK_IMPORT(980904600,'_.DOCBASE()->.ID',982910007,90510043,0,0) ;

CALL STATICLINK_IMPORT(990905600,'_.DIRECTIONCLS()->.ID',986910002,90610078,0,0) ;

CALL STATICLINK_IMPORT(990905700,'_.1.DIRECTIONCLS()->.ID',986910002,90611084,0,0) ;

CALL STATICLINK_IMPORT(980906600,'_.1.FACT()->.ID',982810005,90611085,0,0) ;

CALL STATICLINK_IMPORT(980905700,'_.FACT()->.ID',982810005,90610079,0,0) ;

CALL STATICLINK_IMPORT(990905800,'_.DIRECTIONCLS()->.ID',986910002,90710054,0,0) ;

CALL STATICLINK_IMPORT(980908400,'_.FACT()->.ID',982810005,90710055,0,0) ;

CALL STATICLINK_IMPORT(991200700,'.DIRECTIONCLS_CORR()->.ID',986910002,120110073,0,0) ;

CALL STATICLINK_IMPORT(991200600,'.DIRECTIONCLS()->.ID',986910002,120110074,0,0) ;

CALL STATICLINK_IMPORT(981201400,'.FACT()->.ID',982810005,120110075,0,0) ;

CALL STATICLINK_IMPORT(981201500,'.FACT_CORR()->.ID',982810005,120110076,0,0) ;

CALL STATICLINK_IMPORT(981201800,'.FINTYPE()->.ID',982710006,120110077,0,0) ;

CALL STATICLINK_IMPORT(981201900,'.FINTYPE_CORR()->.ID',982710006,120110078,0,0) ;

CALL STATICLINK_IMPORT(991500000,'.DIRECTIONCLS()->.ID',986910002,150110052,0,0) ;

CALL STATICLINK_IMPORT(981500300,'.FACT()->.ID',982810005,150110053,0,0) ;

CALL STATICLINK_IMPORT(981500500,'.FINTYPE()->.ID',982710006,150110054,0,0) ;

CALL STATICLINK_IMPORT(981500100,'.DOCBASE()->.ID',982910007,150110055,0,0) ;

CALL STATICLINK_IMPORT(991600100,'.1.DIRECTIONCLS()->.ID',986910002,160111085,0,0) ;

CALL STATICLINK_IMPORT(981600300,'.1.FACT()->.ID',982810005,160111086,0,0) ;

CALL STATICLINK_IMPORT(981600500,'.1.FINTYPE()->.ID',982710006,160111087,0,0) ;

CALL STATICLINK_IMPORT(991600400,'_.DIRECTIONCLS()->.ID',986910002,160210045,0,0) ;

CALL STATICLINK_IMPORT(981601500,'_.FACT()->.ID',982810005,160210046,0,0) ;

CALL STATICLINK_IMPORT(981601700,'_.FINTYPE()->.ID',982710006,160210047,0,0) ;

CALL STATICLINK_IMPORT(991700000,'.DIRECTIONCLS()->.ID',986910002,170110093,0,0) ;

CALL STATICLINK_IMPORT(981700500,'.FACT()->.ID',982810005,170110094,0,0) ;

CALL STATICLINK_IMPORT(981700700,'.FINTYPE()->.ID',982710006,170110095,0,0) ;

CALL STATICLINK_IMPORT(991700500,'_.DIRECTIONCLS()->.ID',986910002,170210051,0,0) ;

CALL STATICLINK_IMPORT(981702300,'_.FACT()->.ID',982810005,170210052,0,0) ;

CALL STATICLINK_IMPORT(981702500,'_.FINTYPE()->.ID',982710006,170210053,0,0) ;

CALL STATICLINK_IMPORT(991900400,'_.1.DIRECTIONCLS()->.ID',986910002,190111102,0,0) ;

CALL STATICLINK_IMPORT(981900500,'_.1.FACT()->.ID',982810005,190111103,0,0) ;

CALL STATICLINK_IMPORT(981900600,'_.1.FINTYPE()->.ID',982710006,190111104,0,0) ;

CALL STATICLINK_IMPORT(981900000,'_.DOCBASE()->.ID',982910007,190110087,0,0) ;

CALL STATICLINK_IMPORT(991901100,'_.1.DIRECTIONCLS()->.ID',986910002,190211100,0,0) ;

CALL STATICLINK_IMPORT(981901400,'_.1.FACT()->.ID',982810005,190211101,0,0) ;

CALL STATICLINK_IMPORT(981901500,'_.1.FINTYPE()->.ID',982710006,190211102,0,0) ;

CALL STATICLINK_IMPORT(981901000,'_.DOCBASE()->.ID',982910007,190210086,0,0) ;

CALL STATICLINK_IMPORT(991901800,'_.1.DIRECTIONCLS()->.ID',986910002,190311101,0,0) ;

CALL STATICLINK_IMPORT(981902300,'_.1.FACT()->.ID',982810005,190311102,0,0) ;

CALL STATICLINK_IMPORT(981902400,'_.1.FINTYPE()->.ID',982710006,190311103,0,0) ;

CALL STATICLINK_IMPORT(981901900,'_.DOCBASE()->.ID',982910007,190310087,0,0) ;

CALL STATICLINK_IMPORT(991904100,'__.1.DIRECTIONCLS()->.ID',986910002,190611103,0,0) ;

CALL STATICLINK_IMPORT(981905200,'__.1.FACT()->.ID',982810005,190611104,0,0) ;

CALL STATICLINK_IMPORT(981905300,'__.1.FINTYPE()->.ID',982710006,190611105,0,0) ;

CALL STATICLINK_IMPORT(981904700,'__.DOCBASE()->.ID',982910007,190610088,0,0) ;

CALL STATICLINK_IMPORT(992202100,'_.1.DIRECTIONCLS()->.ID',986910002,220111076,0,0) ;

CALL STATICLINK_IMPORT(982200300,'_.1.FACT()->.ID',982810005,220111077,0,0) ;

CALL STATICLINK_IMPORT(982200000,'_.DOCBASE()->.ID',982910007,220110070,0,0) ;

CALL STATICLINK_IMPORT(982506400,'.FACT->.ID',982810005,250110076,0,0) ;

CALL STATICLINK_IMPORT(982506300,'.2.FACT->.ID',982810005,250212052,0,0) ;

CALL STATICLINK_IMPORT(982506200,'.FACT->.ID',982810005,250210058,0,0) ;

CALL STATICLINK_IMPORT(982506100,'.2.FINTYPE->.ID',982710006,250212053,0,0) ;

CALL STATICLINK_IMPORT(992502000,'.2.DIRECTIONCLS->.ID',986910002,250312046,0,0) ;

CALL STATICLINK_IMPORT(982505900,'.FACT->.ID',982810005,250310042,0,0) ;

CALL STATICLINK_IMPORT(982506000,'.2.FACT->.ID',982810005,250312047,0,0) ;

CALL STATICLINK_IMPORT(982505800,'.2.FINTYPE->.ID',982710006,250312048,0,0) ;

CALL STATICLINK_IMPORT(992501900,'.2.DIRECTIONCLS->.ID',986910002,250412050,0,0) ;

CALL STATICLINK_IMPORT(982505500,'.2.FACT->.ID',982810005,250412051,0,1) ;

CALL STATICLINK_IMPORT(982505600,'.FACT->.ID',982810005,250410098,0,0) ;

CALL STATICLINK_IMPORT(982505700,'.2.FINTYPE->.ID',982710006,250412052,0,0) ;

CALL STATICLINK_IMPORT(982800300,'.FACT()->.ID',982810005,280210017,0,0) ;

CALL STATICLINK_IMPORT(993001100,'.1.DIRECTIONCLS->.ID',986910002,300111095,0,0) ;

CALL STATICLINK_IMPORT(983002200,'.1.FACTCLS->.ID',982810005,300111096,0,0) ;

CALL STATICLINK_IMPORT(983002100,'.1.FINTYPE->.ID',982710006,300111097,0,0) ;

CALL STATICLINK_IMPORT(993001200,'.1.DIRECTIONCLS->.ID',986910002,300611053,0,0) ;

CALL STATICLINK_IMPORT(983002400,'.1.FINTYPE->.ID',982710006,300611054,0,0) ;

CALL STATICLINK_IMPORT(994401700,'.1.DIRECTIONCLS()->.ID',986910002,440111068,0,0) ;

CALL STATICLINK_IMPORT(984401400,'.1.FACT()->.ID',982810005,440111069,0,0) ;

CALL STATICLINK_IMPORT(994401600,'.1.DIRECTIONCLS()->.ID',986910002,440311065,0,0) ;

CALL STATICLINK_IMPORT(984401000,'.1.FACT()->.ID',982810005,440311066,0,0) ;

CALL STATICLINK_IMPORT(995500100,'_.1.DIRECTIONCLS()->.ID',986910002,550111163,0,0) ;

CALL STATICLINK_IMPORT(985500500,'_.1.FINTYPE()->.ID',982710006,550111164,0,0) ;

CALL STATICLINK_IMPORT(985500300,'_.1.FACT()->.ID',982810005,550111165,0,0) ;

CALL STATICLINK_IMPORT(995500600,'_.1.DIRECTIONCLS()->.ID',986910002,550211142,0,0) ;

CALL STATICLINK_IMPORT(985501700,'_.1.FACT()->.ID',982810005,550211143,0,0) ;

CALL STATICLINK_IMPORT(985501900,'_.1.FINTYPE()->.ID',982710006,550211144,0,0) ;

CALL STATICLINK_IMPORT(980700400,'.1.DOCUMENTBASETYPE()->.ID',982910007,70111073,0,0) ;

CALL STATICLINK_IMPORT(990228200,'_.ASSIGNMENTSOURCE()->.ID',988610003,21210001,0,0) ;

CALL STATICLINK_IMPORT(990228300,'_.BUDGETREF()->.ID',987810006,21210002,0,0) ;

CALL STATICLINK_IMPORT(990229800,'_.2.ASSIGNMENTKIND()->.ID',988510003,21212004,0,1) ;

CALL STATICLINK_IMPORT(980227500,'_.2.FACIALACC_CLS->.ID',984110021,21212006,0,1) ;

CALL STATICLINK_IMPORT(980227600,'_.FACIALACCCLS()->.ID',984110021,21210010,0,0) ;

CALL STATICLINK_IMPORT(980227700,'_.NOTIFYTYPE()->.ID',981310002,21210016,0,0) ;

CALL STATICLINK_IMPORT(990230600,'_.2.KESR()->.ID',986810006,21212016,0,1) ;

CALL STATICLINK_IMPORT(990228400,'_.PLANDOCTYPE()->.ID',988410002,21210020,0,0) ;

CALL STATICLINK_IMPORT(980228000,'_.2.MEANSTYPE->.ID',984910002,21212020,0,1) ;

CALL STATICLINK_IMPORT(990228500,'_.REJECTCLS()->.ID',985010005,21210023,0,0) ;

CALL STATICLINK_IMPORT(990228800,'_.2.TRANSFERTCLS->.ID',988410002,21212028,0,1) ;

CALL STATICLINK_IMPORT(990228900,'_.2.SUBSIDYCLS->.ID',988910006,21212029,0,1) ;

CALL STATICLINK_IMPORT(20202400,'_.1.RECORDINDEX()->_.ID()',21210011,21211033,0,2) ;

CALL STATICLINK_IMPORT(980228100,'_.DOCBASECODE()->.ID',982910007,21210027,0,0) ;

CALL STATICLINK_IMPORT(990229000,'.1.->.ID',989010006,20011007,0,1) ;

CALL STATICLINK_IMPORT(990229100,'.1.->.ID',988510003,20011034,0,1) ;

CALL STATICLINK_IMPORT(991912000,'.1.->.ID',989010006,190011034,0,1) ;

CALL STATICLINK_IMPORT(991912100,'.1.->.ID',988510003,190011035,0,1) ;

CALL STATICLINK_IMPORT(962501000,'.SUPPLIERACC_REF->.ID',960210003,250310043,0,0) ;

CALL STATICLINK_IMPORT(990229600,'_.2.BUDALLOCATIONCLS()->.ID',989010006,21112037,0,1) ;

CALL STATICLINK_IMPORT(990229400,'_.2.BUDALLOCATIONCLS()->.ID',989010006,20912044,0,1) ;

CALL STATICLINK_IMPORT(990229700,'_.2.BUDALLOCATIONCLS()->.ID',989010006,21212038,0,1) ;

CALL STATICLINK_IMPORT(980357400,'.1.->.ID',982810005,30011044,0,1) ;

CALL STATICLINK_IMPORT(980228200,'.1.->.ID',982810005,20011036,0,1) ;

CALL STATICLINK_IMPORT(960304700,'.1.TRANSFERTORG_REF()->.ID',960110033,32311163,0,1) ;

CALL STATICLINK_IMPORT(960304900,'.1.TRANSFERTORG_REF()->.ID',960110033,32411204,0,1) ;

CALL STATICLINK_IMPORT(999902900,'.1.CREDITACCREF->.ID',986510005,992011010,0,0) ;

CALL STATICLINK_IMPORT(999902800,'.1.DEBITACCREF->.ID',986510005,992011011,0,0) ;

CALL STATICLINK_IMPORT(989904600,'.KFSR->.ID',980210004,992910003,0,0) ;

CALL STATICLINK_IMPORT(999903000,'.KESR->.ID',986810006,992910006,0,0) ;

CALL STATICLINK_IMPORT(989904900,'.REGIONCLS->.ID',981210005,992910010,0,0) ;

CALL STATICLINK_IMPORT(989905200,'.MEANSTYPE->.ID',984910002,992910013,0,0) ;

CALL STATICLINK_IMPORT(989904500,'.KVSR->.ID',980310002,992910021,0,0) ;

CALL STATICLINK_IMPORT(989904700,'.KCSR->.ID',980510002,992910022,0,0) ;

CALL STATICLINK_IMPORT(989904800,'.KVR->.ID',980410002,992910023,0,0) ;

CALL STATICLINK_IMPORT(999903200,'.DIRECTIONCLS->.ID',986910002,992910024,0,0) ;

CALL STATICLINK_IMPORT(989905000,'.FACT->.ID',982810005,992910025,0,0) ;

CALL STATICLINK_IMPORT(989905100,'.FINTYPE->.ID',982710006,992910026,0,0) ;

CALL STATICLINK_IMPORT(999903100,'.TRANSFERTCLS->.ID',988410002,992910027,0,0) ;

CALL STATICLINK_IMPORT(999903300,'.BUDALLOCATIONCLS->.ID',989010006,992910028,0,0) ;

CALL STATICLINK_IMPORT(999903400,'.PAYPROMISECLS->.ID',989110006,992910029,0,0) ;

CALL STATICLINK_IMPORT(999903500,'.SUBSIDYCLS->.ID',988910006,992910030,0,0) ;

CALL STATICLINK_IMPORT(983002300,'.1.FACTCLS->.ID',982810005,300611058,0,0) ;

CALL STATICLINK_IMPORT(960304500,'.1.->.ID',960110033,30011045,0,1) ;

CALL STATICLINK_IMPORT(981800100,'.MEANSTYPE()->.ID',984910002,181610033,0,0) ;

CALL STATICLINK_IMPORT(991800000,'.TRANSFERTCLS()->.ID',988410002,181610043,0,0) ;

CALL STATICLINK_IMPORT(991800100,'.SUBSIDYCLS()->.ID',988910006,181610045,0,0) ;

CALL STATICLINK_IMPORT(991800300,'.1.KESR()->.ID',986810006,181611070,0,0) ;

CALL STATICLINK_IMPORT(985200600,'.1.KD()->.ID',980910006,520111064,0,0) ;

CALL STATICLINK_IMPORT(965200900,'.NameJudicialAgencyRef()->.Id',960110033,520110055,0,0) ;

CALL STATICLINK_IMPORT(992502200,'.2.SUBSIDYCLS->.ID',988910006,250212056,0,0) ;

CALL STATICLINK_IMPORT(992502100,'.2.SUBSIDYCLS->.ID',988910006,250312051,0,0) ;

CALL STATICLINK_IMPORT(992502300,'.2.SUBSIDYCLS->.ID',988910006,250412055,0,0) ;

CALL STATICLINK_IMPORT(963000000,'.SupplierRef()->.ID',960110033,300410001,0,0) ;

CALL STATICLINK_IMPORT(992203400,'_.1.KESR()->.ID',986810006,220111080,0,0) ;

CALL STATICLINK_IMPORT(991912300,'.1.->.ID',986810006,190011036,0,1) ;

CALL STATICLINK_IMPORT(979900000,'.ANALYTICALGROUPIFS->.ID',970210001,985210025,0,0) ;

CALL STATICLINK_IMPORT(979800000,'.ANALYTICALGROUPKD->.ID',970110001,980910025,0,0) ;

CALL STATICLINK_IMPORT(991800400,'.DESTKESR->.ID',986810006,180910001,0,0) ;

DROP PROCEDURE STATICLINK_DELETE
/

DROP PROCEDURE STATICLINK_IMPORT
/

CREATE OR REPLACE PROCEDURE FILTERS_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATE_JUMPCONTROL
  WHERE STATE_JUMPCONTROL.FILTERCODE = ID_;
  UPDATE STATE_ACTIONJUMPS SAJ
  SET SAJ.FILTERCODE = NULL, SAJ.OPTIONS = NULL
  WHERE SAJ.FILTERCODE = ID_;
  DELETE FROM State_Filter SF
  WHERE SF.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORT(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValue_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValue,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValue_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValue = FilterValue_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORTURM(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValueURM_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValueURM,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValueURM_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValueURM = FilterValueURM_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

-- 
CALL FILTERS_IMPORT(3010600, '', '    ', '(("_._.",[30110003])=2)  
((("_._",[30110003])=0) 
 ("/._",[30110028])  ("/.",[30110028]))', 0, 1, 1) ;

CALL FILTERS_IMPORT(3020600, '', '    ', '(("_._.",[30210032])=2)  
((("_._",[30210032])=0) 
 ("/._",[30210043])  ("/.",[30210043]))', 0, 1, 1) ;

CALL FILTERS_IMPORT(3030600, '', '    ', '(("/._",[30310041])( ("/.",[30310041])))([30310052]=2)', 0, 1, 1) ;

CALL FILTERS_IMPORT(3040600, '', '    ', '(("_._.",[30410017])=2)  
((("_._",[30410017])=0) 
 ("/._",[30410033])  ("/.",[30410033]))', 0, 1, 1) ;

CALL FILTERS_IMPORT(3050600, '', '    ', '(("_._.",[30510021])=2)  
((("_._",[30510021])=0) 
 ("/._",[30510020])  ("/.",[30510020]))', 0, 1, 1) ;

CALL FILTERS_IMPORT(3060600, '', '    ', '(("_._.",[30610002])=2)  
((("_._",[30610002])=0) 
 ("/._",[30610108])  ("/.",[30610108]))', 0, 1, 1) ;

CALL FILTERS_IMPORT(3110600, '', '    ', '(("/._",[31110004])( ("/.",[31110004])))([31110062]=2)', 0, 1, 1) ;

CALL FILTERS_IMPORT(3120600, '', '    ', '(("/._",[31210021])( ("/.",[31210021])))([31210108]=2)', 0, 1, 1) ;

CALL FILTERS_IMPORT(3140600, '', '    ', '(("/._",[31410021])( ("/.",[31410021])))([31410108]=2)', 0, 1, 1) ;

CALL FILTERS_IMPORT(3230600, '', '    ', '(("/._",[32310052])( ("/.",[32310052])))([32310009]=2)', 0, 1, 1) ;

CALL FILTERS_IMPORT(3240600, '', '    ', '(("_._.",[32410005])=2)  
((("_._",[32410005])=0) 
 ("/._",[32410059])  ("/.",[32410059]))', 0, 1, 1) ;

CALL FILTERS_IMPORT(25020300, '_', '   ,  ', '("_._",[250210014])', 0, 1, 2) ;

CALL FILTERS_IMPORT(25030300, '_', '   ,  ', '("_._",[250310027])', 0, 1, 2) ;

CALL FILTERS_IMPORT(25040300, '_', '   ,  ', '("_._",[250410046])', 0, 1, 2) ;

DROP PROCEDURE FILTERS_DELETE
/

DROP PROCEDURE FILTERS_IMPORT
/

DROP PROCEDURE FILTERS_IMPORTURM
/

CREATE OR REPLACE PROCEDURE STATUSICONS_IMPORT(
  ID_ NUMBER,
  NOTE_ VARCHAR2,
  DOCREF_ NUMBER,
  DETAILNUM_ NUMBER,
  ICONNAME_ VARCHAR2,
  ISSYSTEM_ NUMBER,
  ICONPOS_ NUMBER,
  RUNPOS_ NUMBER,
  RESERVEPOS_ NUMBER,
  ICONHINT_ VARCHAR2,
  ICONKIND_ NUMBER,
  LOCKMASK_ NUMBER,
  FORMULA_ VARCHAR2,
  ISBUDGET_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM STATUSICONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE STATUSICONS SET
      NOTE = NOTE_,
      DOCREF = DOCREF_,
      DETAILNUM = DETAILNUM_,
      ICONNAME = ICONNAME_,
      ISSYSTEM = ISSYSTEM_,
      ICONPOS = ICONPOS_,
      RUNPOS = RUNPOS_,
      RESERVEPOS = RESERVEPOS_,
      ICONHINT = ICONHINT_,
      ICONKIND = ICONKIND_,
      LOCKMASK = LOCKMASK_,
      ISBUDGET = ISBUDGET_,
      FORMULA = FORMULA_
    WHERE ID = ID_;
  ELSE
    INSERT INTO STATUSICONS
      (ISBUDGET, ID, NOTE, DOCREF, DETAILNUM, ICONNAME, ISSYSTEM, ICONPOS, RUNPOS, RESERVEPOS, ICONHINT, ICONKIND, LOCKMASK, FORMULA)
    VALUES
      (ISBUDGET_, ID_, NOTE_, DOCREF_, DETAILNUM_, ICONNAME_, ISSYSTEM_, ICONPOS_, RUNPOS_, RESERVEPOS_, ICONHINT_, ICONKIND_, LOCKMASK_, FORMULA_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE STATUSICONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM STATUSICONS SI
  WHERE SI.ID = ID_;
END;
/

--  
CALL STATUSICONS_IMPORT(37541,'',211,2,'',1,5,1,0,'   ',0,0,'[21112001] > 0',1) ;

CALL STATUSICONS_IMPORT(37538,'',212,2,'',1,5,1,0,'   ',0,0,'[21212001] > 0',1) ;

CALL STATUSICONS_IMPORT(13728,'',300,0,'',1,1,4,1,'   ',0,0,'[30010002]=(1000,102,3)',1) ;

CALL STATUSICONS_IMPORT(8933799,'',300,0,'',1,2,4,1,'    ',1,4,'',1) ;

CALL STATUSICONS_IMPORT(13729,'',300,0,'',1,3,2,1,' ',0,0,'([30010002])',1) ;

CALL STATUSICONS_IMPORT(13776,'',300,0,'',1,3,3,1,'     ',1,64,'',1) ;

CALL STATUSICONS_IMPORT(8931594,'',300,0,'',1,3,4,1,' ',1,1,'',1) ;

CALL STATUSICONS_IMPORT(8933203,'',300,0,'',1,3,6,1,' ',1,65536,'',1) ;

CALL STATUSICONS_IMPORT(13828,'',302,0,'',1,5,5,1,' ',0,0,'[30210134] = 11',1) ;

CALL STATUSICONS_IMPORT(38132,'',304,0,'',1,2,5,1,' ',0,0,'[30410143] = 11',1) ;

CALL STATUSICONS_IMPORT(38128,'',306,0,'',1,2,5,1,' ',0,0,'[30610150] = 11',1) ;

CALL STATUSICONS_IMPORT(39110,'',4901,0,'',1,2,2,0,'   ',0,0,'([490110024])  ([490110023] = 1)',1) ;

DROP PROCEDURE STATUSICONS_IMPORT
/

DROP PROCEDURE STATUSICONS_DELETE
/


CREATE OR REPLACE PROCEDURE ENUMS_IMPORT(NAME_ VARCHAR2,FACIALACCCLS_ NUMBER) IS
  IDEXISTS$ NUMBER;
BEGIN
  SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMS WHERE NAME = NAME_;
  IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMS E1
      WHERE (E1.NAME = NAME_) AND (E1.ID > (SELECT MIN(E2.ID) FROM ENUMS E2 WHERE E2.NAME = NAME_));
  END IF;
  IF (IDEXISTS$ > 0) THEN
    UPDATE ENUMS SET
      FACIALACCCLS = FACIALACCCLS_,
      ISSYSTEM = 1
    WHERE NAME = NAME_;
  ELSE
    INSERT INTO ENUMS
      (NAME,FACIALACCCLS,ISSYSTEM)    
    VALUES
      (NAME_,FACIALACCCLS_,1);
  END IF;    
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_IMPORT(ENUMNAME_ VARCHAR2,NAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
  IDEXISTS$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      IDENUM$ := NULL;
  END;  
  IF (IDENUM$ IS NOT NULL) THEN
    SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMVALUES WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMVALUES EV1
      WHERE (EV1.ENUMREF = IDENUM$) AND (EV1.VAL = VAL_) AND
        (EV1.ID > (SELECT MIN(EV2.ID) FROM ENUMVALUES EV2 WHERE EV2.ENUMREF = IDENUM$ AND EV2.VAL = VAL_));
    END IF;
    IF (IDEXISTS$ > 0) THEN
      UPDATE ENUMVALUES SET
        NAME = NAME_
      WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    ELSE
      INSERT INTO ENUMVALUES
        (VAL,NAME,ENUMREF)  
      VALUES
        (VAL_,NAME_,IDENUM$);
    END IF;    
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE ENUMS_DELETE(NAME_ VARCHAR2) IS
BEGIN
  DELETE FROM ENUMS WHERE NAME = NAME_;
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_DELETE(ENUMNAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       IDENUM$ := NULL;  
  END;
  IF (IDENUM$ IS NOT NULL) THEN
    DELETE FROM ENUMVALUES WHERE (VAL = VAL_) AND (ENUMREF = IDENUM$);
  END IF;  
END;
/

-- 
CALL ENUMVALUES_IMPORT('','  ',230) ;

CALL ENUMVALUES_IMPORT('','  -',241) ;

DROP PROCEDURE ENUMS_IMPORT
/

DROP PROCEDURE ENUMVALUES_IMPORT
/

DROP PROCEDURE ENUMS_DELETE
/

DROP PROCEDURE ENUMVALUES_DELETE
/

--      
INSERT INTO DFUCHANGELOG (VersionID, BEGINUPDATECODE, ENDUPDATECODE, LASTUPDATEDFU, ISBUDGET, INCLUDEDEL, INCLUDEBLOCKS, INCLUDEDOCS, SCRIPTCREATOR, SCRIPTCREATEDATE, NOTE) VALUES (1144, 100000, 110000, TO_DATE('12.12.2015 17:9:59', 'DD.MM.YYYY HH24:MI:SS'), 1, 1, ',    ,  , ,  , ,  , , ', '00.00, 01.01, 02.00, 02.01, 02.02, 02.03, 02.04, 02.05, 02.06, 02.07, 02.08, 02.09, 02.10, 02.11, 02.12, 03.00, 03.01, 03.02, 03.03, 03.04, 03.05, 03.06, 03.07, 03.08, 03.11, 03.12, 03.14, 03.15, 03.16, 03.22, 03.23, 03.24, 04.01, 05.01, 07.01, 07.02, 07.03, 08.01, 08.02, 08.03, 08.04, 09.00, 09.01, 09.02, 09.03, 09.05, 09.06, 09.07, 12.01, 15.01, 16.01, 16.02, 17.01, 17.02, 18.05, 18.07, 18.09, 18.10, 18.12, 18.13, 18.14, 18.15, 18.16, 19.00, 19.01, 19.02, 19.03, 19.06, 22.00, 22.01, 25.01, 25.02, 25.03, 25.04, 28.01, 28.02, 30.01, 30.03, 30.04, 30.06, 36.10, 37.01, 39.01, 44.01, 44.03, 48.01, 49.01, 49.02, 49.03, 51.01, 52.01, 53.01, 53.02, 55.01, 55.02, 55.03, 96.01, 96.02, 96.03, 96.04, 97.01, 97.02, 98.02, 98.03, 98.04, 98.05, 98.06, 98.08, 98.09, 98.10, 98.11, 98.12, 98.13, 98.14, 98.15, 98.16, 98.17, 98.18, 98.20, 98.21, 98.22, 98.23, 98.26, 98.27, 98.28, 98.29, 98.34, 98.35, 98.41, 98.42, 98.43, 98.44, 98.45, 98.46, 98.47, 98.48, 98.49, 98.50, 98.51, 98.52, 98.53, 98.54, 98.57, 98.58, 98.59, 98.60, 98.61, 98.62, 98.63, 98.64, 98.65, 98.67, 98.68, 98.69, 98.70, 98.71, 98.72, 98.78, 98.79, 98.80, 98.81, 98.82, 98.83, 98.84, 98.85, 98.86, 98.87, 98.88, 98.89, 98.90, 98.91, 98.92, 98.94, 98.95, 98.99, 99.03, 99.04, 99.05, 99.08, 99.12, 99.13, 99.14, 99.15, 99.16, 99.17, 99.18, 99.19, 99.20, 99.21, 99.22, 99.23, 99.24, 99.25, 99.26, 99.27, 99.28, 99.29, 99.30', 'SHIBAEV8/shibaev', TO_DATE('15.12.2015 15:54:44', 'DD.MM.YYYY HH24:MI:SS'), '') ;

COMMIT WORK
/



-- #########################################################
-- #########################################################
-- DBVersion.sql
-- #########################################################
-- #########################################################

INSERT INTO DataBaseVersion(VERSION, Major, Minor, AComment)
  VALUES ('11.00.00', 1100, 00, ' 11.0')
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Index_Fix.sql
-- #########################################################
-- #########################################################

--      INDX
DECLARE
  CURSOR C$ IS
    select INDEX_NAME from DBA_INDEXES
    where OWNER = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      and TABLESPACE_NAME <> 'INDX'
      and INDEX_TYPE LIKE '%NORMAL%';
  CNT$ NUMBER(10);    
BEGIN
  BEGIN
    select count(*) into CNT$ from V$TABLESPACE
    where name = 'INDX';
  EXCEPTION
    WHEN OTHERS THEN
      CNT$ := 1;
  END;
  IF CNT$ = 1 THEN
    FOR R$ IN C$ LOOP
      EXECUTE IMMEDIATE 'ALTER INDEX ' || R$.INDEX_NAME || ' REBUILD TABLESPACE INDX';
    END LOOP;
  END IF;
END;
/

-- #########################################################
-- #########################################################
-- compile_scr.sql
-- #########################################################
-- #########################################################

--      , 
--  -  
--  DBMS_UTILITY.COMPILE_SCHEMA(user, TRUE);

DECLARE
  CURSOR C$ IS
    SELECT 'ALTER ' || object_type || ' ' || owner || '.' || object_name || ' COMPILE' AS str,
      object_type, object_name
    FROM SYS.ALL_OBJECTS
    WHERE owner = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      AND object_type IN ('VIEW', 'PROCEDURE', 'TRIGGER')
      AND status = 'INVALID'
      AND object_name not like 'BIN$%'
    ORDER BY DECODE(object_type, 'VIEW', 1, 'PROCEDURE', 2, 'TRIGGER', 3), object_name;
  S VARCHAR2(100);
BEGIN
  FOR R$ IN C$ LOOP
    BEGIN
      S := R$.object_type || ' ' || R$.object_name;
      EXECUTE IMMEDIATE R$.str;
    EXCEPTION
      WHEN OTHERS THEN 
        --DBMS_OUTPUT.PUT_LINE(S);
        RAISE_APPLICATION_ERROR(-20000, '    ' || S);
    END;
  END LOOP;
END;
/

-- #########################################################
-- #########################################################
-- dbms_stats_scr.sql
-- #########################################################
-- #########################################################

ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.,'
/

BEGIN
  DBMS_STATS.GATHER_SCHEMA_STATS(
    SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA'),
    DBMS_STATS.AUTO_SAMPLE_SIZE,
    false,
    'FOR ALL COLUMNS SIZE AUTO',
    cascade=>TRUE
  );
END;
/

exit
